/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/base/public/nsMsgFolderFlags.idl
 */

#ifndef __gen_nsMsgFolderFlags_h__
#define __gen_nsMsgFolderFlags_h__

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
typedef uint32_t  nsMsgFolderFlagType;


/* starting interface:    nsMsgFolderFlags */
#define NS_MSGFOLDERFLAGS_IID_STR "fbe7cba8-3141-4c44-9660-99af6b53f27e"

#define NS_MSGFOLDERFLAGS_IID \
  {0xfbe7cba8, 0x3141, 0x4c44, \
    { 0x96, 0x60, 0x99, 0xaf, 0x6b, 0x53, 0xf2, 0x7e }}

class NS_NO_VTABLE nsMsgFolderFlags {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_MSGFOLDERFLAGS_IID)

  enum {
    Newsgroup = 1U,
    NewsHost = 2U,
    Mail = 4U,
    Directory = 8U,
    Elided = 16U,
    Virtual = 32U,
    Subscribed = 64U,
    Unused2 = 128U,
    Trash = 256U,
    SentMail = 512U,
    Drafts = 1024U,
    Queue = 2048U,
    Inbox = 4096U,
    ImapBox = 8192U,
    Archive = 16384U,
    Unused1 = 32768U,
    Unused4 = 65536U,
    GotNew = 131072U,
    ImapServer = 262144U,
    ImapPersonal = 524288U,
    ImapPublic = 1048576U,
    ImapOtherUser = 2097152U,
    Templates = 4194304U,
    PersonalShared = 8388608U,
    ImapNoselect = 16777216U,
    CreatedOffline = 33554432U,
    ImapNoinferiors = 67108864U,
    Offline = 134217728U,
    OfflineEvents = 268435456U,
    CheckNew = 536870912U,
    Junk = 1073741824U,
    Favorite = 2147483648U,
    SpecialUse = 1077960448U
  };

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsMsgFolderFlags, NS_MSGFOLDERFLAGS_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSMSGFOLDERFLAGS \

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSMSGFOLDERFLAGS(_to) \

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSMSGFOLDERFLAGS(_to) \

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public nsMsgFolderFlags
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSMSGFOLDERFLAGS

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, nsMsgFolderFlags)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsMsgFolderFlags_h__ */
