/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsIDOMEvent.idl"

interface mozIDOMApplication;

[scriptable, builtinclass, uuid(dae640fb-0a14-42d8-88d3-541c6f077820)]
interface nsIDOMMozApplicationEvent : nsIDOMEvent
{
  readonly attribute mozIDOMApplication application;

  [noscript] void initMozApplicationEvent(in DOMString aType,
                                          in boolean aCanBubble,
                                          in boolean aCancelable,
                                          in mozIDOMApplication aApplication);
};

dictionary MozApplicationEventInit : EventInit
{
  mozIDOMApplication application;
};
