/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsIDOMSVGTextContentElement.idl"

interface nsIDOMSVGAnimatedLength;
interface nsIDOMSVGAnimatedEnumeration;

[scriptable, uuid(89FFAFFA-3BF5-4C6C-82B9-155BB2F33033)]
interface nsIDOMSVGTextPathElement
  : nsIDOMSVGTextContentElement
/*
        The SVG DOM makes use of multiple interface inheritance.
        Since XPCOM only supports single interface inheritance,
        the best thing that we can do is to promise that whenever
        an object implements _this_ interface it will also
        implement the following interfaces. (We then have to QI to
        hop between them.)
        
    nsIDOMSVGURIReference,
*/
{
    // textPath Method Types
    const unsigned short TEXTPATH_METHODTYPE_UNKNOWN  = 0;
    const unsigned short TEXTPATH_METHODTYPE_ALIGN    = 1;
    const unsigned short TEXTPATH_METHODTYPE_STRETCH  = 2;
    // textPath Spacing Types
    const unsigned short TEXTPATH_SPACINGTYPE_UNKNOWN = 0;
    const unsigned short TEXTPATH_SPACINGTYPE_AUTO    = 1;
    const unsigned short TEXTPATH_SPACINGTYPE_EXACT   = 2;

    readonly attribute nsIDOMSVGAnimatedLength startOffset;
    readonly attribute nsIDOMSVGAnimatedEnumeration method;
    readonly attribute nsIDOMSVGAnimatedEnumeration spacing;
};
