/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/imap/public/nsIImapMockChannel.idl
 */

#ifndef __gen_nsIImapMockChannel_h__
#define __gen_nsIImapMockChannel_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsIChannel_h__
#include "nsIChannel.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIStreamListener; /* forward declaration */

class nsIProgressEventSink; /* forward declaration */

class nsIURI; /* forward declaration */

class nsIImapProtocol; /* forward declaration */


/* starting interface:    nsIImapMockChannel */
#define NS_IIMAPMOCKCHANNEL_IID_STR "e0178cd5-d37b-4bde-9ab8-752083536225"

#define NS_IIMAPMOCKCHANNEL_IID \
  {0xe0178cd5, 0xd37b, 0x4bde, \
    { 0x9a, 0xb8, 0x75, 0x20, 0x83, 0x53, 0x62, 0x25 }}

class NS_NO_VTABLE nsIImapMockChannel : public nsIChannel {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IIMAPMOCKCHANNEL_IID)

  /* attribute nsIProgressEventSink progressEventSink; */
  NS_IMETHOD GetProgressEventSink(nsIProgressEventSink * *aProgressEventSink) = 0;
  NS_IMETHOD SetProgressEventSink(nsIProgressEventSink *aProgressEventSink) = 0;

  /* void GetChannelListener (out nsIStreamListener aChannelListener); */
  NS_IMETHOD GetChannelListener(nsIStreamListener * *aChannelListener) = 0;

  /* void GetChannelContext (out nsISupports aChannelContext); */
  NS_IMETHOD GetChannelContext(nsISupports * *aChannelContext) = 0;

  /* void Close (); */
  NS_IMETHOD Close(void) = 0;

  /* void setImapProtocol (in nsIImapProtocol aProtocol); */
  NS_IMETHOD SetImapProtocol(nsIImapProtocol *aProtocol) = 0;

  /* [noscript] void setSecurityInfo (in nsISupports securityInfo); */
  NS_IMETHOD SetSecurityInfo(nsISupports *securityInfo) = 0;

  /* void setURI (in nsIURI uri); */
  NS_IMETHOD SetURI(nsIURI *uri) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIImapMockChannel, NS_IIMAPMOCKCHANNEL_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIIMAPMOCKCHANNEL \
  NS_IMETHOD GetProgressEventSink(nsIProgressEventSink * *aProgressEventSink); \
  NS_IMETHOD SetProgressEventSink(nsIProgressEventSink *aProgressEventSink); \
  NS_IMETHOD GetChannelListener(nsIStreamListener * *aChannelListener); \
  NS_IMETHOD GetChannelContext(nsISupports * *aChannelContext); \
  NS_IMETHOD Close(void); \
  NS_IMETHOD SetImapProtocol(nsIImapProtocol *aProtocol); \
  NS_IMETHOD SetSecurityInfo(nsISupports *securityInfo); \
  NS_IMETHOD SetURI(nsIURI *uri); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIIMAPMOCKCHANNEL(_to) \
  NS_IMETHOD GetProgressEventSink(nsIProgressEventSink * *aProgressEventSink) { return _to GetProgressEventSink(aProgressEventSink); } \
  NS_IMETHOD SetProgressEventSink(nsIProgressEventSink *aProgressEventSink) { return _to SetProgressEventSink(aProgressEventSink); } \
  NS_IMETHOD GetChannelListener(nsIStreamListener * *aChannelListener) { return _to GetChannelListener(aChannelListener); } \
  NS_IMETHOD GetChannelContext(nsISupports * *aChannelContext) { return _to GetChannelContext(aChannelContext); } \
  NS_IMETHOD Close(void) { return _to Close(); } \
  NS_IMETHOD SetImapProtocol(nsIImapProtocol *aProtocol) { return _to SetImapProtocol(aProtocol); } \
  NS_IMETHOD SetSecurityInfo(nsISupports *securityInfo) { return _to SetSecurityInfo(securityInfo); } \
  NS_IMETHOD SetURI(nsIURI *uri) { return _to SetURI(uri); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIIMAPMOCKCHANNEL(_to) \
  NS_IMETHOD GetProgressEventSink(nsIProgressEventSink * *aProgressEventSink) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetProgressEventSink(aProgressEventSink); } \
  NS_IMETHOD SetProgressEventSink(nsIProgressEventSink *aProgressEventSink) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetProgressEventSink(aProgressEventSink); } \
  NS_IMETHOD GetChannelListener(nsIStreamListener * *aChannelListener) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetChannelListener(aChannelListener); } \
  NS_IMETHOD GetChannelContext(nsISupports * *aChannelContext) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetChannelContext(aChannelContext); } \
  NS_IMETHOD Close(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->Close(); } \
  NS_IMETHOD SetImapProtocol(nsIImapProtocol *aProtocol) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetImapProtocol(aProtocol); } \
  NS_IMETHOD SetSecurityInfo(nsISupports *securityInfo) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetSecurityInfo(securityInfo); } \
  NS_IMETHOD SetURI(nsIURI *uri) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetURI(uri); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsImapMockChannel : public nsIImapMockChannel
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIIMAPMOCKCHANNEL

  nsImapMockChannel();

private:
  ~nsImapMockChannel();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsImapMockChannel, nsIImapMockChannel)

nsImapMockChannel::nsImapMockChannel()
{
  /* member initializers and constructor code */
}

nsImapMockChannel::~nsImapMockChannel()
{
  /* destructor code */
}

/* attribute nsIProgressEventSink progressEventSink; */
NS_IMETHODIMP nsImapMockChannel::GetProgressEventSink(nsIProgressEventSink * *aProgressEventSink)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsImapMockChannel::SetProgressEventSink(nsIProgressEventSink *aProgressEventSink)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void GetChannelListener (out nsIStreamListener aChannelListener); */
NS_IMETHODIMP nsImapMockChannel::GetChannelListener(nsIStreamListener * *aChannelListener)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void GetChannelContext (out nsISupports aChannelContext); */
NS_IMETHODIMP nsImapMockChannel::GetChannelContext(nsISupports * *aChannelContext)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void Close (); */
NS_IMETHODIMP nsImapMockChannel::Close()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setImapProtocol (in nsIImapProtocol aProtocol); */
NS_IMETHODIMP nsImapMockChannel::SetImapProtocol(nsIImapProtocol *aProtocol)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [noscript] void setSecurityInfo (in nsISupports securityInfo); */
NS_IMETHODIMP nsImapMockChannel::SetSecurityInfo(nsISupports *securityInfo)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setURI (in nsIURI uri); */
NS_IMETHODIMP nsImapMockChannel::SetURI(nsIURI *uri)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIImapMockChannel_h__ */
