/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/local/public/nsIPop3IncomingServer.idl
 */

#ifndef __gen_nsIPop3IncomingServer_h__
#define __gen_nsIPop3IncomingServer_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIPop3Protocol; /* forward declaration */

class nsISupportsArray; /* forward declaration */

class nsIMsgFolder; /* forward declaration */

class nsIUrlListener; /* forward declaration */

class nsIMsgWindow; /* forward declaration */


/* starting interface:    nsIPop3IncomingServer */
#define NS_IPOP3INCOMINGSERVER_IID_STR "98d50234-6c8a-4875-815b-40e0178a13bd"

#define NS_IPOP3INCOMINGSERVER_IID \
  {0x98d50234, 0x6c8a, 0x4875, \
    { 0x81, 0x5b, 0x40, 0xe0, 0x17, 0x8a, 0x13, 0xbd }}

class NS_NO_VTABLE nsIPop3IncomingServer : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IPOP3INCOMINGSERVER_IID)

  /* attribute boolean leaveMessagesOnServer; */
  NS_IMETHOD GetLeaveMessagesOnServer(bool *aLeaveMessagesOnServer) = 0;
  NS_IMETHOD SetLeaveMessagesOnServer(bool aLeaveMessagesOnServer) = 0;

  /* attribute boolean headersOnly; */
  NS_IMETHOD GetHeadersOnly(bool *aHeadersOnly) = 0;
  NS_IMETHOD SetHeadersOnly(bool aHeadersOnly) = 0;

  /* attribute boolean deleteMailLeftOnServer; */
  NS_IMETHOD GetDeleteMailLeftOnServer(bool *aDeleteMailLeftOnServer) = 0;
  NS_IMETHOD SetDeleteMailLeftOnServer(bool aDeleteMailLeftOnServer) = 0;

  /* attribute boolean dotFix; */
  NS_IMETHOD GetDotFix(bool *aDotFix) = 0;
  NS_IMETHOD SetDotFix(bool aDotFix) = 0;

  /* attribute unsigned long pop3CapabilityFlags; */
  NS_IMETHOD GetPop3CapabilityFlags(uint32_t *aPop3CapabilityFlags) = 0;
  NS_IMETHOD SetPop3CapabilityFlags(uint32_t aPop3CapabilityFlags) = 0;

  /* attribute boolean deleteByAgeFromServer; */
  NS_IMETHOD GetDeleteByAgeFromServer(bool *aDeleteByAgeFromServer) = 0;
  NS_IMETHOD SetDeleteByAgeFromServer(bool aDeleteByAgeFromServer) = 0;

  /* attribute long numDaysToLeaveOnServer; */
  NS_IMETHOD GetNumDaysToLeaveOnServer(int32_t *aNumDaysToLeaveOnServer) = 0;
  NS_IMETHOD SetNumDaysToLeaveOnServer(int32_t aNumDaysToLeaveOnServer) = 0;

  /* attribute nsIPop3Protocol runningProtocol; */
  NS_IMETHOD GetRunningProtocol(nsIPop3Protocol * *aRunningProtocol) = 0;
  NS_IMETHOD SetRunningProtocol(nsIPop3Protocol *aRunningProtocol) = 0;

  /* void addUidlToMark (in string aUidl, in int32_t newStatus); */
  NS_IMETHOD AddUidlToMark(const char * aUidl, int32_t newStatus) = 0;

  /* void markMessages (); */
  NS_IMETHOD MarkMessages(void) = 0;

  /* attribute boolean authenticated; */
  NS_IMETHOD GetAuthenticated(bool *aAuthenticated) = 0;
  NS_IMETHOD SetAuthenticated(bool aAuthenticated) = 0;

  /* attribute ACString deferredToAccount; */
  NS_IMETHOD GetDeferredToAccount(nsACString & aDeferredToAccount) = 0;
  NS_IMETHOD SetDeferredToAccount(const nsACString & aDeferredToAccount) = 0;

  /* attribute boolean deferGetNewMail; */
  NS_IMETHOD GetDeferGetNewMail(bool *aDeferGetNewMail) = 0;
  NS_IMETHOD SetDeferGetNewMail(bool aDeferGetNewMail) = 0;

  /* void downloadMailFromServers (in nsISupportsArray aServers, in nsIMsgWindow aMsgWindow, in nsIMsgFolder aFolder, in nsIUrlListener aListener); */
  NS_IMETHOD DownloadMailFromServers(nsISupportsArray *aServers, nsIMsgWindow *aMsgWindow, nsIMsgFolder *aFolder, nsIUrlListener *aListener) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIPop3IncomingServer, NS_IPOP3INCOMINGSERVER_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIPOP3INCOMINGSERVER \
  NS_IMETHOD GetLeaveMessagesOnServer(bool *aLeaveMessagesOnServer); \
  NS_IMETHOD SetLeaveMessagesOnServer(bool aLeaveMessagesOnServer); \
  NS_IMETHOD GetHeadersOnly(bool *aHeadersOnly); \
  NS_IMETHOD SetHeadersOnly(bool aHeadersOnly); \
  NS_IMETHOD GetDeleteMailLeftOnServer(bool *aDeleteMailLeftOnServer); \
  NS_IMETHOD SetDeleteMailLeftOnServer(bool aDeleteMailLeftOnServer); \
  NS_IMETHOD GetDotFix(bool *aDotFix); \
  NS_IMETHOD SetDotFix(bool aDotFix); \
  NS_IMETHOD GetPop3CapabilityFlags(uint32_t *aPop3CapabilityFlags); \
  NS_IMETHOD SetPop3CapabilityFlags(uint32_t aPop3CapabilityFlags); \
  NS_IMETHOD GetDeleteByAgeFromServer(bool *aDeleteByAgeFromServer); \
  NS_IMETHOD SetDeleteByAgeFromServer(bool aDeleteByAgeFromServer); \
  NS_IMETHOD GetNumDaysToLeaveOnServer(int32_t *aNumDaysToLeaveOnServer); \
  NS_IMETHOD SetNumDaysToLeaveOnServer(int32_t aNumDaysToLeaveOnServer); \
  NS_IMETHOD GetRunningProtocol(nsIPop3Protocol * *aRunningProtocol); \
  NS_IMETHOD SetRunningProtocol(nsIPop3Protocol *aRunningProtocol); \
  NS_IMETHOD AddUidlToMark(const char * aUidl, int32_t newStatus); \
  NS_IMETHOD MarkMessages(void); \
  NS_IMETHOD GetAuthenticated(bool *aAuthenticated); \
  NS_IMETHOD SetAuthenticated(bool aAuthenticated); \
  NS_IMETHOD GetDeferredToAccount(nsACString & aDeferredToAccount); \
  NS_IMETHOD SetDeferredToAccount(const nsACString & aDeferredToAccount); \
  NS_IMETHOD GetDeferGetNewMail(bool *aDeferGetNewMail); \
  NS_IMETHOD SetDeferGetNewMail(bool aDeferGetNewMail); \
  NS_IMETHOD DownloadMailFromServers(nsISupportsArray *aServers, nsIMsgWindow *aMsgWindow, nsIMsgFolder *aFolder, nsIUrlListener *aListener); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIPOP3INCOMINGSERVER(_to) \
  NS_IMETHOD GetLeaveMessagesOnServer(bool *aLeaveMessagesOnServer) { return _to GetLeaveMessagesOnServer(aLeaveMessagesOnServer); } \
  NS_IMETHOD SetLeaveMessagesOnServer(bool aLeaveMessagesOnServer) { return _to SetLeaveMessagesOnServer(aLeaveMessagesOnServer); } \
  NS_IMETHOD GetHeadersOnly(bool *aHeadersOnly) { return _to GetHeadersOnly(aHeadersOnly); } \
  NS_IMETHOD SetHeadersOnly(bool aHeadersOnly) { return _to SetHeadersOnly(aHeadersOnly); } \
  NS_IMETHOD GetDeleteMailLeftOnServer(bool *aDeleteMailLeftOnServer) { return _to GetDeleteMailLeftOnServer(aDeleteMailLeftOnServer); } \
  NS_IMETHOD SetDeleteMailLeftOnServer(bool aDeleteMailLeftOnServer) { return _to SetDeleteMailLeftOnServer(aDeleteMailLeftOnServer); } \
  NS_IMETHOD GetDotFix(bool *aDotFix) { return _to GetDotFix(aDotFix); } \
  NS_IMETHOD SetDotFix(bool aDotFix) { return _to SetDotFix(aDotFix); } \
  NS_IMETHOD GetPop3CapabilityFlags(uint32_t *aPop3CapabilityFlags) { return _to GetPop3CapabilityFlags(aPop3CapabilityFlags); } \
  NS_IMETHOD SetPop3CapabilityFlags(uint32_t aPop3CapabilityFlags) { return _to SetPop3CapabilityFlags(aPop3CapabilityFlags); } \
  NS_IMETHOD GetDeleteByAgeFromServer(bool *aDeleteByAgeFromServer) { return _to GetDeleteByAgeFromServer(aDeleteByAgeFromServer); } \
  NS_IMETHOD SetDeleteByAgeFromServer(bool aDeleteByAgeFromServer) { return _to SetDeleteByAgeFromServer(aDeleteByAgeFromServer); } \
  NS_IMETHOD GetNumDaysToLeaveOnServer(int32_t *aNumDaysToLeaveOnServer) { return _to GetNumDaysToLeaveOnServer(aNumDaysToLeaveOnServer); } \
  NS_IMETHOD SetNumDaysToLeaveOnServer(int32_t aNumDaysToLeaveOnServer) { return _to SetNumDaysToLeaveOnServer(aNumDaysToLeaveOnServer); } \
  NS_IMETHOD GetRunningProtocol(nsIPop3Protocol * *aRunningProtocol) { return _to GetRunningProtocol(aRunningProtocol); } \
  NS_IMETHOD SetRunningProtocol(nsIPop3Protocol *aRunningProtocol) { return _to SetRunningProtocol(aRunningProtocol); } \
  NS_IMETHOD AddUidlToMark(const char * aUidl, int32_t newStatus) { return _to AddUidlToMark(aUidl, newStatus); } \
  NS_IMETHOD MarkMessages(void) { return _to MarkMessages(); } \
  NS_IMETHOD GetAuthenticated(bool *aAuthenticated) { return _to GetAuthenticated(aAuthenticated); } \
  NS_IMETHOD SetAuthenticated(bool aAuthenticated) { return _to SetAuthenticated(aAuthenticated); } \
  NS_IMETHOD GetDeferredToAccount(nsACString & aDeferredToAccount) { return _to GetDeferredToAccount(aDeferredToAccount); } \
  NS_IMETHOD SetDeferredToAccount(const nsACString & aDeferredToAccount) { return _to SetDeferredToAccount(aDeferredToAccount); } \
  NS_IMETHOD GetDeferGetNewMail(bool *aDeferGetNewMail) { return _to GetDeferGetNewMail(aDeferGetNewMail); } \
  NS_IMETHOD SetDeferGetNewMail(bool aDeferGetNewMail) { return _to SetDeferGetNewMail(aDeferGetNewMail); } \
  NS_IMETHOD DownloadMailFromServers(nsISupportsArray *aServers, nsIMsgWindow *aMsgWindow, nsIMsgFolder *aFolder, nsIUrlListener *aListener) { return _to DownloadMailFromServers(aServers, aMsgWindow, aFolder, aListener); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIPOP3INCOMINGSERVER(_to) \
  NS_IMETHOD GetLeaveMessagesOnServer(bool *aLeaveMessagesOnServer) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetLeaveMessagesOnServer(aLeaveMessagesOnServer); } \
  NS_IMETHOD SetLeaveMessagesOnServer(bool aLeaveMessagesOnServer) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetLeaveMessagesOnServer(aLeaveMessagesOnServer); } \
  NS_IMETHOD GetHeadersOnly(bool *aHeadersOnly) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetHeadersOnly(aHeadersOnly); } \
  NS_IMETHOD SetHeadersOnly(bool aHeadersOnly) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetHeadersOnly(aHeadersOnly); } \
  NS_IMETHOD GetDeleteMailLeftOnServer(bool *aDeleteMailLeftOnServer) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDeleteMailLeftOnServer(aDeleteMailLeftOnServer); } \
  NS_IMETHOD SetDeleteMailLeftOnServer(bool aDeleteMailLeftOnServer) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetDeleteMailLeftOnServer(aDeleteMailLeftOnServer); } \
  NS_IMETHOD GetDotFix(bool *aDotFix) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDotFix(aDotFix); } \
  NS_IMETHOD SetDotFix(bool aDotFix) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetDotFix(aDotFix); } \
  NS_IMETHOD GetPop3CapabilityFlags(uint32_t *aPop3CapabilityFlags) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetPop3CapabilityFlags(aPop3CapabilityFlags); } \
  NS_IMETHOD SetPop3CapabilityFlags(uint32_t aPop3CapabilityFlags) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetPop3CapabilityFlags(aPop3CapabilityFlags); } \
  NS_IMETHOD GetDeleteByAgeFromServer(bool *aDeleteByAgeFromServer) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDeleteByAgeFromServer(aDeleteByAgeFromServer); } \
  NS_IMETHOD SetDeleteByAgeFromServer(bool aDeleteByAgeFromServer) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetDeleteByAgeFromServer(aDeleteByAgeFromServer); } \
  NS_IMETHOD GetNumDaysToLeaveOnServer(int32_t *aNumDaysToLeaveOnServer) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNumDaysToLeaveOnServer(aNumDaysToLeaveOnServer); } \
  NS_IMETHOD SetNumDaysToLeaveOnServer(int32_t aNumDaysToLeaveOnServer) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetNumDaysToLeaveOnServer(aNumDaysToLeaveOnServer); } \
  NS_IMETHOD GetRunningProtocol(nsIPop3Protocol * *aRunningProtocol) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetRunningProtocol(aRunningProtocol); } \
  NS_IMETHOD SetRunningProtocol(nsIPop3Protocol *aRunningProtocol) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetRunningProtocol(aRunningProtocol); } \
  NS_IMETHOD AddUidlToMark(const char * aUidl, int32_t newStatus) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddUidlToMark(aUidl, newStatus); } \
  NS_IMETHOD MarkMessages(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->MarkMessages(); } \
  NS_IMETHOD GetAuthenticated(bool *aAuthenticated) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetAuthenticated(aAuthenticated); } \
  NS_IMETHOD SetAuthenticated(bool aAuthenticated) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetAuthenticated(aAuthenticated); } \
  NS_IMETHOD GetDeferredToAccount(nsACString & aDeferredToAccount) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDeferredToAccount(aDeferredToAccount); } \
  NS_IMETHOD SetDeferredToAccount(const nsACString & aDeferredToAccount) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetDeferredToAccount(aDeferredToAccount); } \
  NS_IMETHOD GetDeferGetNewMail(bool *aDeferGetNewMail) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDeferGetNewMail(aDeferGetNewMail); } \
  NS_IMETHOD SetDeferGetNewMail(bool aDeferGetNewMail) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetDeferGetNewMail(aDeferGetNewMail); } \
  NS_IMETHOD DownloadMailFromServers(nsISupportsArray *aServers, nsIMsgWindow *aMsgWindow, nsIMsgFolder *aFolder, nsIUrlListener *aListener) { return !_to ? NS_ERROR_NULL_POINTER : _to->DownloadMailFromServers(aServers, aMsgWindow, aFolder, aListener); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsPop3IncomingServer : public nsIPop3IncomingServer
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIPOP3INCOMINGSERVER

  nsPop3IncomingServer();

private:
  ~nsPop3IncomingServer();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsPop3IncomingServer, nsIPop3IncomingServer)

nsPop3IncomingServer::nsPop3IncomingServer()
{
  /* member initializers and constructor code */
}

nsPop3IncomingServer::~nsPop3IncomingServer()
{
  /* destructor code */
}

/* attribute boolean leaveMessagesOnServer; */
NS_IMETHODIMP nsPop3IncomingServer::GetLeaveMessagesOnServer(bool *aLeaveMessagesOnServer)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsPop3IncomingServer::SetLeaveMessagesOnServer(bool aLeaveMessagesOnServer)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean headersOnly; */
NS_IMETHODIMP nsPop3IncomingServer::GetHeadersOnly(bool *aHeadersOnly)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsPop3IncomingServer::SetHeadersOnly(bool aHeadersOnly)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean deleteMailLeftOnServer; */
NS_IMETHODIMP nsPop3IncomingServer::GetDeleteMailLeftOnServer(bool *aDeleteMailLeftOnServer)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsPop3IncomingServer::SetDeleteMailLeftOnServer(bool aDeleteMailLeftOnServer)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean dotFix; */
NS_IMETHODIMP nsPop3IncomingServer::GetDotFix(bool *aDotFix)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsPop3IncomingServer::SetDotFix(bool aDotFix)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute unsigned long pop3CapabilityFlags; */
NS_IMETHODIMP nsPop3IncomingServer::GetPop3CapabilityFlags(uint32_t *aPop3CapabilityFlags)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsPop3IncomingServer::SetPop3CapabilityFlags(uint32_t aPop3CapabilityFlags)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean deleteByAgeFromServer; */
NS_IMETHODIMP nsPop3IncomingServer::GetDeleteByAgeFromServer(bool *aDeleteByAgeFromServer)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsPop3IncomingServer::SetDeleteByAgeFromServer(bool aDeleteByAgeFromServer)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute long numDaysToLeaveOnServer; */
NS_IMETHODIMP nsPop3IncomingServer::GetNumDaysToLeaveOnServer(int32_t *aNumDaysToLeaveOnServer)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsPop3IncomingServer::SetNumDaysToLeaveOnServer(int32_t aNumDaysToLeaveOnServer)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsIPop3Protocol runningProtocol; */
NS_IMETHODIMP nsPop3IncomingServer::GetRunningProtocol(nsIPop3Protocol * *aRunningProtocol)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsPop3IncomingServer::SetRunningProtocol(nsIPop3Protocol *aRunningProtocol)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void addUidlToMark (in string aUidl, in int32_t newStatus); */
NS_IMETHODIMP nsPop3IncomingServer::AddUidlToMark(const char * aUidl, int32_t newStatus)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void markMessages (); */
NS_IMETHODIMP nsPop3IncomingServer::MarkMessages()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean authenticated; */
NS_IMETHODIMP nsPop3IncomingServer::GetAuthenticated(bool *aAuthenticated)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsPop3IncomingServer::SetAuthenticated(bool aAuthenticated)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute ACString deferredToAccount; */
NS_IMETHODIMP nsPop3IncomingServer::GetDeferredToAccount(nsACString & aDeferredToAccount)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsPop3IncomingServer::SetDeferredToAccount(const nsACString & aDeferredToAccount)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean deferGetNewMail; */
NS_IMETHODIMP nsPop3IncomingServer::GetDeferGetNewMail(bool *aDeferGetNewMail)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsPop3IncomingServer::SetDeferGetNewMail(bool aDeferGetNewMail)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void downloadMailFromServers (in nsISupportsArray aServers, in nsIMsgWindow aMsgWindow, in nsIMsgFolder aFolder, in nsIUrlListener aListener); */
NS_IMETHODIMP nsPop3IncomingServer::DownloadMailFromServers(nsISupportsArray *aServers, nsIMsgWindow *aMsgWindow, nsIMsgFolder *aFolder, nsIUrlListener *aListener)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIPop3IncomingServer_h__ */
