/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsIDOMSVGElement.idl"

/*
 * The definitions of this interface in SMIL Animation and SVG 1.1 differ in the
 * return type and semantics.
 *
 * A proposed SVG errata item at:
 *
 *   http://www.w3.org/2003/01/REC-SVG11-20030114-errata#elementtimecontrol-interface
 *
 * addresses this suggesting the interface definition from SMIL 3 be adopted
 * which is what we use here.
 */

[scriptable, uuid(276a6678-7844-4d5e-8dfe-938c46089b84)]
interface nsIDOMElementTimeControl : nsISupports
{ 
  void beginElement();
  void beginElementAt(in float offset);
  void endElement();
  void endElementAt(in float offset);
};
