/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
#include "nsISupports.idl"
#include "nsIMsgIncomingServer.idl"

[scriptable, uuid(E6B64B86-90CB-11d3-8B02-0060B0FC04D2)]
interface nsIIncomingServerListener : nsISupports {
  /**
   * Notification sent when a server is first loaded into the account manager.
   *
   * @param server Loaded server.
   */
  void onServerLoaded(in nsIMsgIncomingServer server);

  /**
   * Notification sent when a server is unloaded from the account manager.
   *
   * @param server Unloaded server.
   */
  void onServerUnloaded(in nsIMsgIncomingServer server);

  /**
   * Notification sent when a server hostname or username changes.
   *
   * @param server Server that was changed.
   */
  void onServerChanged(in nsIMsgIncomingServer server);
};

