/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"

interface nsIAtom;
interface nsIDOMElement;
interface nsIDOMDocument;

[scriptable, uuid(3697f9ed-d8bc-4c00-890f-7a702d5b4005)]
interface nsIXTFElementWrapper : nsISupports
{  
  readonly attribute nsIDOMElement elementNode;
  readonly attribute nsIDOMElement documentFrameElement;
  
  /**
   * Events can be unmasked by setting the corresponding bit as given
   * by the NOTIFY_* constants in nsIXTFElement:
   */
  attribute unsigned long notificationMask;

  /**
   * Sets the intrinsic state for the element.
   * @see nsIContent::IntrinsicState().
   */
  void setIntrinsicState(in unsigned long long newState);

  /**
   * This sets the name of the class attribute.
   * Should be called only during ::onCreated.
   * Note! nsIXTFAttributeHandler can't be used to handle class attribute.
   */
  void setClassAttributeName(in nsIAtom name);
};

