/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
#include "nsISupports.idl"
#include "nsIAutoSyncMsgStrategy.idl"

interface nsIMsgAccount;

[scriptable, uuid(d3bf91cc-37bb-4752-9994-1a8473e46a90)] 
interface nsIAutoSyncFolderStrategy : nsISupports {

  /**
   * Returns a relative-priority for the second folder by comparing with the first one.
   */
  nsAutoSyncStrategyDecisionType sort(in nsIMsgFolder aFolder1, in nsIMsgFolder aFolder2);
  
  /**
   * Tests whether the given folder should be excluded or not.
   */
  boolean isExcluded(in nsIMsgFolder aFolder);

};
