/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this file,
 * You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"

interface nsIDOMMozActivity;
interface nsIDOMMozActivityOptions;
interface nsIDOMWindow;

/**
  * Implemented by @mozilla.org/dom/activities/proxy;1
  */
[scriptable, uuid(3f9e0695-f466-4111-a8fa-ed5c0751c42b)]
interface nsIActivityProxy : nsISupports
{
    void startActivity(in nsIDOMMozActivity activity,
                       in nsIDOMMozActivityOptions options,
                       in nsIDOMWindow window);
    void cleanup();
};
