/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/base/public/nsIMsgUserFeedbackListener.idl
 */

#ifndef __gen_nsIMsgUserFeedbackListener_h__
#define __gen_nsIMsgUserFeedbackListener_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIMsgMailNewsUrl; /* forward declaration */


/* starting interface:    nsIMsgUserFeedbackListener */
#define NS_IMSGUSERFEEDBACKLISTENER_IID_STR "5e909ffa-77fe-4ce3-bf3c-06c54596d03d"

#define NS_IMSGUSERFEEDBACKLISTENER_IID \
  {0x5e909ffa, 0x77fe, 0x4ce3, \
    { 0xbf, 0x3c, 0x06, 0xc5, 0x45, 0x96, 0xd0, 0x3d }}

class NS_NO_VTABLE nsIMsgUserFeedbackListener : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IMSGUSERFEEDBACKLISTENER_IID)

  /* boolean onAlert (in AString aMessage, [optional] in nsIMsgMailNewsUrl aUrl); */
  NS_IMETHOD OnAlert(const nsAString & aMessage, nsIMsgMailNewsUrl *aUrl, bool *_retval) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIMsgUserFeedbackListener, NS_IMSGUSERFEEDBACKLISTENER_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGUSERFEEDBACKLISTENER \
  NS_IMETHOD OnAlert(const nsAString & aMessage, nsIMsgMailNewsUrl *aUrl, bool *_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGUSERFEEDBACKLISTENER(_to) \
  NS_IMETHOD OnAlert(const nsAString & aMessage, nsIMsgMailNewsUrl *aUrl, bool *_retval) { return _to OnAlert(aMessage, aUrl, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGUSERFEEDBACKLISTENER(_to) \
  NS_IMETHOD OnAlert(const nsAString & aMessage, nsIMsgMailNewsUrl *aUrl, bool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnAlert(aMessage, aUrl, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgUserFeedbackListener : public nsIMsgUserFeedbackListener
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGUSERFEEDBACKLISTENER

  nsMsgUserFeedbackListener();

private:
  ~nsMsgUserFeedbackListener();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgUserFeedbackListener, nsIMsgUserFeedbackListener)

nsMsgUserFeedbackListener::nsMsgUserFeedbackListener()
{
  /* member initializers and constructor code */
}

nsMsgUserFeedbackListener::~nsMsgUserFeedbackListener()
{
  /* destructor code */
}

/* boolean onAlert (in AString aMessage, [optional] in nsIMsgMailNewsUrl aUrl); */
NS_IMETHODIMP nsMsgUserFeedbackListener::OnAlert(const nsAString & aMessage, nsIMsgMailNewsUrl *aUrl, bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgUserFeedbackListener_h__ */
