/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/base/search/public/nsIMsgSearchNotify.idl
 */

#ifndef __gen_nsIMsgSearchNotify_h__
#define __gen_nsIMsgSearchNotify_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIMsgDBHdr; /* forward declaration */

class nsIMsgSearchSession; /* forward declaration */

class nsIMsgFolder; /* forward declaration */


/* starting interface:    nsIMsgSearchNotify */
#define NS_IMSGSEARCHNOTIFY_IID_STR "ca37784d-352b-4c39-8ccb-0abc1a93f681"

#define NS_IMSGSEARCHNOTIFY_IID \
  {0xca37784d, 0x352b, 0x4c39, \
    { 0x8c, 0xcb, 0x0a, 0xbc, 0x1a, 0x93, 0xf6, 0x81 }}

class NS_NO_VTABLE nsIMsgSearchNotify : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IMSGSEARCHNOTIFY_IID)

  /* void onSearchHit (in nsIMsgDBHdr header, in nsIMsgFolder folder); */
  NS_IMETHOD OnSearchHit(nsIMsgDBHdr *header, nsIMsgFolder *folder) = 0;

  /* void onSearchDone (in nsresult status); */
  NS_IMETHOD OnSearchDone(nsresult status) = 0;

  /* void onNewSearch (); */
  NS_IMETHOD OnNewSearch(void) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIMsgSearchNotify, NS_IMSGSEARCHNOTIFY_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGSEARCHNOTIFY \
  NS_IMETHOD OnSearchHit(nsIMsgDBHdr *header, nsIMsgFolder *folder); \
  NS_IMETHOD OnSearchDone(nsresult status); \
  NS_IMETHOD OnNewSearch(void); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGSEARCHNOTIFY(_to) \
  NS_IMETHOD OnSearchHit(nsIMsgDBHdr *header, nsIMsgFolder *folder) { return _to OnSearchHit(header, folder); } \
  NS_IMETHOD OnSearchDone(nsresult status) { return _to OnSearchDone(status); } \
  NS_IMETHOD OnNewSearch(void) { return _to OnNewSearch(); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGSEARCHNOTIFY(_to) \
  NS_IMETHOD OnSearchHit(nsIMsgDBHdr *header, nsIMsgFolder *folder) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnSearchHit(header, folder); } \
  NS_IMETHOD OnSearchDone(nsresult status) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnSearchDone(status); } \
  NS_IMETHOD OnNewSearch(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnNewSearch(); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgSearchNotify : public nsIMsgSearchNotify
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGSEARCHNOTIFY

  nsMsgSearchNotify();

private:
  ~nsMsgSearchNotify();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgSearchNotify, nsIMsgSearchNotify)

nsMsgSearchNotify::nsMsgSearchNotify()
{
  /* member initializers and constructor code */
}

nsMsgSearchNotify::~nsMsgSearchNotify()
{
  /* destructor code */
}

/* void onSearchHit (in nsIMsgDBHdr header, in nsIMsgFolder folder); */
NS_IMETHODIMP nsMsgSearchNotify::OnSearchHit(nsIMsgDBHdr *header, nsIMsgFolder *folder)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void onSearchDone (in nsresult status); */
NS_IMETHODIMP nsMsgSearchNotify::OnSearchDone(nsresult status)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void onNewSearch (); */
NS_IMETHODIMP nsMsgSearchNotify::OnNewSearch()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgSearchNotify_h__ */
