/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/import/public/nsIImportFieldMap.idl
 */

#ifndef __gen_nsIImportFieldMap_h__
#define __gen_nsIImportFieldMap_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIAddrDatabase; /* forward declaration */

class nsIMdbRow; /* forward declaration */

class nsIAbCard; /* forward declaration */


/* starting interface:    nsIImportFieldMap */
#define NS_IIMPORTFIELDMAP_IID_STR "0e376da3-e289-4d14-bdec-867764585eb7"

#define NS_IIMPORTFIELDMAP_IID \
  {0x0e376da3, 0xe289, 0x4d14, \
    { 0xbd, 0xec, 0x86, 0x77, 0x64, 0x58, 0x5e, 0xb7 }}

class NS_NO_VTABLE nsIImportFieldMap : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IIMPORTFIELDMAP_IID)

  /* attribute boolean skipFirstRecord; */
  NS_IMETHOD GetSkipFirstRecord(bool *aSkipFirstRecord) = 0;
  NS_IMETHOD SetSkipFirstRecord(bool aSkipFirstRecord) = 0;

  /* readonly attribute long numMozFields; */
  NS_IMETHOD GetNumMozFields(int32_t *aNumMozFields) = 0;

  /* readonly attribute long mapSize; */
  NS_IMETHOD GetMapSize(int32_t *aMapSize) = 0;

  /* wstring GetFieldDescription (in long index); */
  NS_IMETHOD GetFieldDescription(int32_t index, PRUnichar * *_retval) = 0;

  /* void SetFieldMapSize (in long size); */
  NS_IMETHOD SetFieldMapSize(int32_t size) = 0;

  /* void DefaultFieldMap (in long size); */
  NS_IMETHOD DefaultFieldMap(int32_t size) = 0;

  /* long GetFieldMap (in long index); */
  NS_IMETHOD GetFieldMap(int32_t index, int32_t *_retval) = 0;

  /* void SetFieldMap (in long index, in long fieldNum); */
  NS_IMETHOD SetFieldMap(int32_t index, int32_t fieldNum) = 0;

  /* void SetFieldMapByDescription (in long index, in wstring fieldDesc); */
  NS_IMETHOD SetFieldMapByDescription(int32_t index, const PRUnichar * fieldDesc) = 0;

  /* boolean GetFieldActive (in long index); */
  NS_IMETHOD GetFieldActive(int32_t index, bool *_retval) = 0;

  /* void SetFieldActive (in long index, in boolean active); */
  NS_IMETHOD SetFieldActive(int32_t index, bool active) = 0;

  /* void SetFieldValue (in nsIAddrDatabase database, in nsIMdbRow row, in long fieldNum, in wstring value); */
  NS_IMETHOD SetFieldValue(nsIAddrDatabase *database, nsIMdbRow *row, int32_t fieldNum, const PRUnichar * value) = 0;

  /* void SetFieldValueByDescription (in nsIAddrDatabase database, in nsIMdbRow row, in wstring fieldDesc, in wstring value); */
  NS_IMETHOD SetFieldValueByDescription(nsIAddrDatabase *database, nsIMdbRow *row, const PRUnichar * fieldDesc, const PRUnichar * value) = 0;

  /* wstring GetFieldValue (in nsIAbCard card, in long fieldNum); */
  NS_IMETHOD GetFieldValue(nsIAbCard *card, int32_t fieldNum, PRUnichar * *_retval) = 0;

  /* wstring GetFieldValueByDescription (in nsIAbCard card, in wstring fieldDesc); */
  NS_IMETHOD GetFieldValueByDescription(nsIAbCard *card, const PRUnichar * fieldDesc, PRUnichar * *_retval) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIImportFieldMap, NS_IIMPORTFIELDMAP_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIIMPORTFIELDMAP \
  NS_IMETHOD GetSkipFirstRecord(bool *aSkipFirstRecord); \
  NS_IMETHOD SetSkipFirstRecord(bool aSkipFirstRecord); \
  NS_IMETHOD GetNumMozFields(int32_t *aNumMozFields); \
  NS_IMETHOD GetMapSize(int32_t *aMapSize); \
  NS_IMETHOD GetFieldDescription(int32_t index, PRUnichar * *_retval); \
  NS_IMETHOD SetFieldMapSize(int32_t size); \
  NS_IMETHOD DefaultFieldMap(int32_t size); \
  NS_IMETHOD GetFieldMap(int32_t index, int32_t *_retval); \
  NS_IMETHOD SetFieldMap(int32_t index, int32_t fieldNum); \
  NS_IMETHOD SetFieldMapByDescription(int32_t index, const PRUnichar * fieldDesc); \
  NS_IMETHOD GetFieldActive(int32_t index, bool *_retval); \
  NS_IMETHOD SetFieldActive(int32_t index, bool active); \
  NS_IMETHOD SetFieldValue(nsIAddrDatabase *database, nsIMdbRow *row, int32_t fieldNum, const PRUnichar * value); \
  NS_IMETHOD SetFieldValueByDescription(nsIAddrDatabase *database, nsIMdbRow *row, const PRUnichar * fieldDesc, const PRUnichar * value); \
  NS_IMETHOD GetFieldValue(nsIAbCard *card, int32_t fieldNum, PRUnichar * *_retval); \
  NS_IMETHOD GetFieldValueByDescription(nsIAbCard *card, const PRUnichar * fieldDesc, PRUnichar * *_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIIMPORTFIELDMAP(_to) \
  NS_IMETHOD GetSkipFirstRecord(bool *aSkipFirstRecord) { return _to GetSkipFirstRecord(aSkipFirstRecord); } \
  NS_IMETHOD SetSkipFirstRecord(bool aSkipFirstRecord) { return _to SetSkipFirstRecord(aSkipFirstRecord); } \
  NS_IMETHOD GetNumMozFields(int32_t *aNumMozFields) { return _to GetNumMozFields(aNumMozFields); } \
  NS_IMETHOD GetMapSize(int32_t *aMapSize) { return _to GetMapSize(aMapSize); } \
  NS_IMETHOD GetFieldDescription(int32_t index, PRUnichar * *_retval) { return _to GetFieldDescription(index, _retval); } \
  NS_IMETHOD SetFieldMapSize(int32_t size) { return _to SetFieldMapSize(size); } \
  NS_IMETHOD DefaultFieldMap(int32_t size) { return _to DefaultFieldMap(size); } \
  NS_IMETHOD GetFieldMap(int32_t index, int32_t *_retval) { return _to GetFieldMap(index, _retval); } \
  NS_IMETHOD SetFieldMap(int32_t index, int32_t fieldNum) { return _to SetFieldMap(index, fieldNum); } \
  NS_IMETHOD SetFieldMapByDescription(int32_t index, const PRUnichar * fieldDesc) { return _to SetFieldMapByDescription(index, fieldDesc); } \
  NS_IMETHOD GetFieldActive(int32_t index, bool *_retval) { return _to GetFieldActive(index, _retval); } \
  NS_IMETHOD SetFieldActive(int32_t index, bool active) { return _to SetFieldActive(index, active); } \
  NS_IMETHOD SetFieldValue(nsIAddrDatabase *database, nsIMdbRow *row, int32_t fieldNum, const PRUnichar * value) { return _to SetFieldValue(database, row, fieldNum, value); } \
  NS_IMETHOD SetFieldValueByDescription(nsIAddrDatabase *database, nsIMdbRow *row, const PRUnichar * fieldDesc, const PRUnichar * value) { return _to SetFieldValueByDescription(database, row, fieldDesc, value); } \
  NS_IMETHOD GetFieldValue(nsIAbCard *card, int32_t fieldNum, PRUnichar * *_retval) { return _to GetFieldValue(card, fieldNum, _retval); } \
  NS_IMETHOD GetFieldValueByDescription(nsIAbCard *card, const PRUnichar * fieldDesc, PRUnichar * *_retval) { return _to GetFieldValueByDescription(card, fieldDesc, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIIMPORTFIELDMAP(_to) \
  NS_IMETHOD GetSkipFirstRecord(bool *aSkipFirstRecord) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSkipFirstRecord(aSkipFirstRecord); } \
  NS_IMETHOD SetSkipFirstRecord(bool aSkipFirstRecord) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetSkipFirstRecord(aSkipFirstRecord); } \
  NS_IMETHOD GetNumMozFields(int32_t *aNumMozFields) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNumMozFields(aNumMozFields); } \
  NS_IMETHOD GetMapSize(int32_t *aMapSize) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMapSize(aMapSize); } \
  NS_IMETHOD GetFieldDescription(int32_t index, PRUnichar * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFieldDescription(index, _retval); } \
  NS_IMETHOD SetFieldMapSize(int32_t size) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetFieldMapSize(size); } \
  NS_IMETHOD DefaultFieldMap(int32_t size) { return !_to ? NS_ERROR_NULL_POINTER : _to->DefaultFieldMap(size); } \
  NS_IMETHOD GetFieldMap(int32_t index, int32_t *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFieldMap(index, _retval); } \
  NS_IMETHOD SetFieldMap(int32_t index, int32_t fieldNum) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetFieldMap(index, fieldNum); } \
  NS_IMETHOD SetFieldMapByDescription(int32_t index, const PRUnichar * fieldDesc) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetFieldMapByDescription(index, fieldDesc); } \
  NS_IMETHOD GetFieldActive(int32_t index, bool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFieldActive(index, _retval); } \
  NS_IMETHOD SetFieldActive(int32_t index, bool active) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetFieldActive(index, active); } \
  NS_IMETHOD SetFieldValue(nsIAddrDatabase *database, nsIMdbRow *row, int32_t fieldNum, const PRUnichar * value) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetFieldValue(database, row, fieldNum, value); } \
  NS_IMETHOD SetFieldValueByDescription(nsIAddrDatabase *database, nsIMdbRow *row, const PRUnichar * fieldDesc, const PRUnichar * value) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetFieldValueByDescription(database, row, fieldDesc, value); } \
  NS_IMETHOD GetFieldValue(nsIAbCard *card, int32_t fieldNum, PRUnichar * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFieldValue(card, fieldNum, _retval); } \
  NS_IMETHOD GetFieldValueByDescription(nsIAbCard *card, const PRUnichar * fieldDesc, PRUnichar * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFieldValueByDescription(card, fieldDesc, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsImportFieldMap : public nsIImportFieldMap
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIIMPORTFIELDMAP

  nsImportFieldMap();

private:
  ~nsImportFieldMap();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsImportFieldMap, nsIImportFieldMap)

nsImportFieldMap::nsImportFieldMap()
{
  /* member initializers and constructor code */
}

nsImportFieldMap::~nsImportFieldMap()
{
  /* destructor code */
}

/* attribute boolean skipFirstRecord; */
NS_IMETHODIMP nsImportFieldMap::GetSkipFirstRecord(bool *aSkipFirstRecord)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsImportFieldMap::SetSkipFirstRecord(bool aSkipFirstRecord)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute long numMozFields; */
NS_IMETHODIMP nsImportFieldMap::GetNumMozFields(int32_t *aNumMozFields)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute long mapSize; */
NS_IMETHODIMP nsImportFieldMap::GetMapSize(int32_t *aMapSize)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* wstring GetFieldDescription (in long index); */
NS_IMETHODIMP nsImportFieldMap::GetFieldDescription(int32_t index, PRUnichar * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void SetFieldMapSize (in long size); */
NS_IMETHODIMP nsImportFieldMap::SetFieldMapSize(int32_t size)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void DefaultFieldMap (in long size); */
NS_IMETHODIMP nsImportFieldMap::DefaultFieldMap(int32_t size)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* long GetFieldMap (in long index); */
NS_IMETHODIMP nsImportFieldMap::GetFieldMap(int32_t index, int32_t *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void SetFieldMap (in long index, in long fieldNum); */
NS_IMETHODIMP nsImportFieldMap::SetFieldMap(int32_t index, int32_t fieldNum)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void SetFieldMapByDescription (in long index, in wstring fieldDesc); */
NS_IMETHODIMP nsImportFieldMap::SetFieldMapByDescription(int32_t index, const PRUnichar * fieldDesc)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean GetFieldActive (in long index); */
NS_IMETHODIMP nsImportFieldMap::GetFieldActive(int32_t index, bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void SetFieldActive (in long index, in boolean active); */
NS_IMETHODIMP nsImportFieldMap::SetFieldActive(int32_t index, bool active)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void SetFieldValue (in nsIAddrDatabase database, in nsIMdbRow row, in long fieldNum, in wstring value); */
NS_IMETHODIMP nsImportFieldMap::SetFieldValue(nsIAddrDatabase *database, nsIMdbRow *row, int32_t fieldNum, const PRUnichar * value)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void SetFieldValueByDescription (in nsIAddrDatabase database, in nsIMdbRow row, in wstring fieldDesc, in wstring value); */
NS_IMETHODIMP nsImportFieldMap::SetFieldValueByDescription(nsIAddrDatabase *database, nsIMdbRow *row, const PRUnichar * fieldDesc, const PRUnichar * value)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* wstring GetFieldValue (in nsIAbCard card, in long fieldNum); */
NS_IMETHODIMP nsImportFieldMap::GetFieldValue(nsIAbCard *card, int32_t fieldNum, PRUnichar * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* wstring GetFieldValueByDescription (in nsIAbCard card, in wstring fieldDesc); */
NS_IMETHODIMP nsImportFieldMap::GetFieldValueByDescription(nsIAbCard *card, const PRUnichar * fieldDesc, PRUnichar * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif



#endif /* __gen_nsIImportFieldMap_h__ */
