/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "domstubs.idl"

/**
 * The nsIDOMSVGUnitTypes interface is the interface to SVG unit types.
 *
 * For more information on this interface please see
 * http://www.w3.org/TR/SVG11/types.html
 *
 */

[scriptable, uuid(154b572f-3d0b-49c0-8b5d-8864d05bd3d1)]
interface nsIDOMSVGUnitTypes : nsISupports
{
  // Unit Types
  const unsigned short SVG_UNIT_TYPE_UNKNOWN           = 0;
  const unsigned short SVG_UNIT_TYPE_USERSPACEONUSE    = 1;
  const unsigned short SVG_UNIT_TYPE_OBJECTBOUNDINGBOX = 2;
};
