/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/addrbook/public/nsIAbLDAPReplicationData.idl
 */

#ifndef __gen_nsIAbLDAPReplicationData_h__
#define __gen_nsIAbLDAPReplicationData_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIAbLDAPDirectory; /* forward declaration */

class nsILDAPConnection; /* forward declaration */

class nsILDAPURL; /* forward declaration */

class nsIAbLDAPReplicationQuery; /* forward declaration */

class nsIWebProgressListener; /* forward declaration */


/* starting interface:    nsIAbLDAPProcessReplicationData */
#define NS_IABLDAPPROCESSREPLICATIONDATA_IID_STR "e628bbc9-8793-4f0b-bce4-990d399b1fca"

#define NS_IABLDAPPROCESSREPLICATIONDATA_IID \
  {0xe628bbc9, 0x8793, 0x4f0b, \
    { 0xbc, 0xe4, 0x99, 0x0d, 0x39, 0x9b, 0x1f, 0xca }}

class NS_NO_VTABLE nsIAbLDAPProcessReplicationData : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IABLDAPPROCESSREPLICATIONDATA_IID)

  /* readonly attribute int32_t replicationState; */
  NS_IMETHOD GetReplicationState(int32_t *aReplicationState) = 0;

  enum {
    kIdle = 0,
    kAnonymousBinding = 1,
    kAuthenticatedBinding = 2,
    kSyncServerBinding = 3,
    kSearchingAuthDN = 4,
    kDecidingProtocol = 5,
    kAuthenticating = 6,
    kReplicatingAll = 7,
    kSearchingRootDSE = 8,
    kFindingChanges = 9,
    kReplicatingChanges = 10,
    kReplicationDone = 11
  };

  /* readonly attribute int32_t protocolUsed; */
  NS_IMETHOD GetProtocolUsed(int32_t *aProtocolUsed) = 0;

  enum {
    kDefaultDownloadAll = 0,
    kChangeLogProtocol = 1,
    kLCUPProtocol = 2,
    kLastUpdatedTimeStampMethod = 3
  };

  /* void init (in nsIAbLDAPDirectory directory, in nsILDAPConnection connection, in nsILDAPURL url, in nsIAbLDAPReplicationQuery query, in nsIWebProgressListener progressListener); */
  NS_IMETHOD Init(nsIAbLDAPDirectory *directory, nsILDAPConnection *connection, nsILDAPURL *url, nsIAbLDAPReplicationQuery *query, nsIWebProgressListener *progressListener) = 0;

  /* void abort (); */
  NS_IMETHOD Abort(void) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIAbLDAPProcessReplicationData, NS_IABLDAPPROCESSREPLICATIONDATA_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIABLDAPPROCESSREPLICATIONDATA \
  NS_IMETHOD GetReplicationState(int32_t *aReplicationState); \
  NS_IMETHOD GetProtocolUsed(int32_t *aProtocolUsed); \
  NS_IMETHOD Init(nsIAbLDAPDirectory *directory, nsILDAPConnection *connection, nsILDAPURL *url, nsIAbLDAPReplicationQuery *query, nsIWebProgressListener *progressListener); \
  NS_IMETHOD Abort(void); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIABLDAPPROCESSREPLICATIONDATA(_to) \
  NS_IMETHOD GetReplicationState(int32_t *aReplicationState) { return _to GetReplicationState(aReplicationState); } \
  NS_IMETHOD GetProtocolUsed(int32_t *aProtocolUsed) { return _to GetProtocolUsed(aProtocolUsed); } \
  NS_IMETHOD Init(nsIAbLDAPDirectory *directory, nsILDAPConnection *connection, nsILDAPURL *url, nsIAbLDAPReplicationQuery *query, nsIWebProgressListener *progressListener) { return _to Init(directory, connection, url, query, progressListener); } \
  NS_IMETHOD Abort(void) { return _to Abort(); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIABLDAPPROCESSREPLICATIONDATA(_to) \
  NS_IMETHOD GetReplicationState(int32_t *aReplicationState) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetReplicationState(aReplicationState); } \
  NS_IMETHOD GetProtocolUsed(int32_t *aProtocolUsed) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetProtocolUsed(aProtocolUsed); } \
  NS_IMETHOD Init(nsIAbLDAPDirectory *directory, nsILDAPConnection *connection, nsILDAPURL *url, nsIAbLDAPReplicationQuery *query, nsIWebProgressListener *progressListener) { return !_to ? NS_ERROR_NULL_POINTER : _to->Init(directory, connection, url, query, progressListener); } \
  NS_IMETHOD Abort(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->Abort(); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsAbLDAPProcessReplicationData : public nsIAbLDAPProcessReplicationData
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIABLDAPPROCESSREPLICATIONDATA

  nsAbLDAPProcessReplicationData();

private:
  ~nsAbLDAPProcessReplicationData();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsAbLDAPProcessReplicationData, nsIAbLDAPProcessReplicationData)

nsAbLDAPProcessReplicationData::nsAbLDAPProcessReplicationData()
{
  /* member initializers and constructor code */
}

nsAbLDAPProcessReplicationData::~nsAbLDAPProcessReplicationData()
{
  /* destructor code */
}

/* readonly attribute int32_t replicationState; */
NS_IMETHODIMP nsAbLDAPProcessReplicationData::GetReplicationState(int32_t *aReplicationState)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute int32_t protocolUsed; */
NS_IMETHODIMP nsAbLDAPProcessReplicationData::GetProtocolUsed(int32_t *aProtocolUsed)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void init (in nsIAbLDAPDirectory directory, in nsILDAPConnection connection, in nsILDAPURL url, in nsIAbLDAPReplicationQuery query, in nsIWebProgressListener progressListener); */
NS_IMETHODIMP nsAbLDAPProcessReplicationData::Init(nsIAbLDAPDirectory *directory, nsILDAPConnection *connection, nsILDAPURL *url, nsIAbLDAPReplicationQuery *query, nsIWebProgressListener *progressListener)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void abort (); */
NS_IMETHODIMP nsAbLDAPProcessReplicationData::Abort()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIAbLDAPReplicationData_h__ */
