/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/base/public/nsMsgMessageFlags.idl
 */

#ifndef __gen_nsMsgMessageFlags_h__
#define __gen_nsMsgMessageFlags_h__

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
typedef uint32_t  nsMsgMessageFlagType;


/* starting interface:    nsMsgMessageFlags */
#define NS_MSGMESSAGEFLAGS_IID_STR "1ea3acdb-7b9f-4e35-9513-76e0a0cc6baa"

#define NS_MSGMESSAGEFLAGS_IID \
  {0x1ea3acdb, 0x7b9f, 0x4e35, \
    { 0x95, 0x13, 0x76, 0xe0, 0xa0, 0xcc, 0x6b, 0xaa }}

class NS_NO_VTABLE nsMsgMessageFlags {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_MSGMESSAGEFLAGS_IID)

  enum {
    Read = 1U,
    Replied = 2U,
    Marked = 4U,
    Expunged = 8U,
    HasRe = 16U,
    Elided = 32U,
    FeedMsg = 64U,
    Offline = 128U,
    Watched = 256U,
    SenderAuthed = 512U,
    Partial = 1024U,
    Queued = 2048U,
    Forwarded = 4096U,
    Priorities = 57344U,
    New = 65536U,
    Ignored = 262144U,
    IMAPDeleted = 2097152U,
    MDNReportNeeded = 4194304U,
    MDNReportSent = 8388608U,
    Template = 16777216U,
    Attachment = 268435456U,
    Labels = 234881024U,
    RuntimeOnly = 32U
  };

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsMsgMessageFlags, NS_MSGMESSAGEFLAGS_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSMSGMESSAGEFLAGS \

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSMSGMESSAGEFLAGS(_to) \

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSMSGMESSAGEFLAGS(_to) \

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public nsMsgMessageFlags
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSMSGMESSAGEFLAGS

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, nsMsgMessageFlags)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* End of implementation class template. */
#endif

typedef uint32_t  nsMsgProcessingFlagType;


/* starting interface:    nsMsgProcessingFlags */
#define NS_MSGPROCESSINGFLAGS_IID_STR "1f7d642b-de2a-45f0-a27f-9c9ce0b741d8"

#define NS_MSGPROCESSINGFLAGS_IID \
  {0x1f7d642b, 0xde2a, 0x45f0, \
    { 0xa2, 0x7f, 0x9c, 0x9c, 0xe0, 0xb7, 0x41, 0xd8 }}

class NS_NO_VTABLE nsMsgProcessingFlags {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_MSGPROCESSINGFLAGS_IID)

  enum {
    ClassifyJunk = 1U,
    ClassifyTraits = 2U,
    TraitsDone = 4U,
    FiltersDone = 8U,
    FilterToMove = 16U,
    NotReportedClassified = 32U,
    NumberOfFlags = 6U
  };

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsMsgProcessingFlags, NS_MSGPROCESSINGFLAGS_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSMSGPROCESSINGFLAGS \

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSMSGPROCESSINGFLAGS(_to) \

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSMSGPROCESSINGFLAGS(_to) \

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public nsMsgProcessingFlags
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSMSGPROCESSINGFLAGS

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, nsMsgProcessingFlags)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsMsgMessageFlags_h__ */
