/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/base/public/nsIMsgIdentity.idl
 */

#ifndef __gen_nsIMsgIdentity_h__
#define __gen_nsIMsgIdentity_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsIFile_h__
#include "nsIFile.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIMsgIdentity */
#define NS_IMSGIDENTITY_IID_STR "4a769f39-f8c2-41e6-962a-175a33107578"

#define NS_IMSGIDENTITY_IID \
  {0x4a769f39, 0xf8c2, 0x41e6, \
    { 0x96, 0x2a, 0x17, 0x5a, 0x33, 0x10, 0x75, 0x78 }}

class NS_NO_VTABLE nsIMsgIdentity : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IMSGIDENTITY_IID)

  /* attribute ACString key; */
  NS_IMETHOD GetKey(nsACString & aKey) = 0;
  NS_IMETHOD SetKey(const nsACString & aKey) = 0;

  /* attribute AString identityName; */
  NS_IMETHOD GetIdentityName(nsAString & aIdentityName) = 0;
  NS_IMETHOD SetIdentityName(const nsAString & aIdentityName) = 0;

  /* attribute AString fullName; */
  NS_IMETHOD GetFullName(nsAString & aFullName) = 0;
  NS_IMETHOD SetFullName(const nsAString & aFullName) = 0;

  /* attribute ACString email; */
  NS_IMETHOD GetEmail(nsACString & aEmail) = 0;
  NS_IMETHOD SetEmail(const nsACString & aEmail) = 0;

  /* attribute AUTF8String replyTo; */
  NS_IMETHOD GetReplyTo(nsACString & aReplyTo) = 0;
  NS_IMETHOD SetReplyTo(const nsACString & aReplyTo) = 0;

  /* attribute AString organization; */
  NS_IMETHOD GetOrganization(nsAString & aOrganization) = 0;
  NS_IMETHOD SetOrganization(const nsAString & aOrganization) = 0;

  /* attribute boolean composeHtml; */
  NS_IMETHOD GetComposeHtml(bool *aComposeHtml) = 0;
  NS_IMETHOD SetComposeHtml(bool aComposeHtml) = 0;

  /* attribute boolean attachSignature; */
  NS_IMETHOD GetAttachSignature(bool *aAttachSignature) = 0;
  NS_IMETHOD SetAttachSignature(bool aAttachSignature) = 0;

  /* attribute boolean attachVCard; */
  NS_IMETHOD GetAttachVCard(bool *aAttachVCard) = 0;
  NS_IMETHOD SetAttachVCard(bool aAttachVCard) = 0;

  /* attribute boolean autoQuote; */
  NS_IMETHOD GetAutoQuote(bool *aAutoQuote) = 0;
  NS_IMETHOD SetAutoQuote(bool aAutoQuote) = 0;

  /* attribute long replyOnTop; */
  NS_IMETHOD GetReplyOnTop(int32_t *aReplyOnTop) = 0;
  NS_IMETHOD SetReplyOnTop(int32_t aReplyOnTop) = 0;

  /* attribute boolean sigBottom; */
  NS_IMETHOD GetSigBottom(bool *aSigBottom) = 0;
  NS_IMETHOD SetSigBottom(bool aSigBottom) = 0;

  /* attribute boolean sigOnForward; */
  NS_IMETHOD GetSigOnForward(bool *aSigOnForward) = 0;
  NS_IMETHOD SetSigOnForward(bool aSigOnForward) = 0;

  /* attribute boolean sigOnReply; */
  NS_IMETHOD GetSigOnReply(bool *aSigOnReply) = 0;
  NS_IMETHOD SetSigOnReply(bool aSigOnReply) = 0;

  /* attribute nsIFile signature; */
  NS_IMETHOD GetSignature(nsIFile * *aSignature) = 0;
  NS_IMETHOD SetSignature(nsIFile *aSignature) = 0;

  /* attribute long signatureDate; */
  NS_IMETHOD GetSignatureDate(int32_t *aSignatureDate) = 0;
  NS_IMETHOD SetSignatureDate(int32_t aSignatureDate) = 0;

  /* attribute AString htmlSigText; */
  NS_IMETHOD GetHtmlSigText(nsAString & aHtmlSigText) = 0;
  NS_IMETHOD SetHtmlSigText(const nsAString & aHtmlSigText) = 0;

  /* attribute boolean htmlSigFormat; */
  NS_IMETHOD GetHtmlSigFormat(bool *aHtmlSigFormat) = 0;
  NS_IMETHOD SetHtmlSigFormat(bool aHtmlSigFormat) = 0;

  /* attribute boolean suppressSigSep; */
  NS_IMETHOD GetSuppressSigSep(bool *aSuppressSigSep) = 0;
  NS_IMETHOD SetSuppressSigSep(bool aSuppressSigSep) = 0;

  /* attribute ACString escapedVCard; */
  NS_IMETHOD GetEscapedVCard(nsACString & aEscapedVCard) = 0;
  NS_IMETHOD SetEscapedVCard(const nsACString & aEscapedVCard) = 0;

  /* attribute boolean doFcc; */
  NS_IMETHOD GetDoFcc(bool *aDoFcc) = 0;
  NS_IMETHOD SetDoFcc(bool aDoFcc) = 0;

  /* attribute ACString fccFolder; */
  NS_IMETHOD GetFccFolder(nsACString & aFccFolder) = 0;
  NS_IMETHOD SetFccFolder(const nsACString & aFccFolder) = 0;

  /* attribute boolean fccReplyFollowsParent; */
  NS_IMETHOD GetFccReplyFollowsParent(bool *aFccReplyFollowsParent) = 0;
  NS_IMETHOD SetFccReplyFollowsParent(bool aFccReplyFollowsParent) = 0;

  /* attribute ACString fccFolderPickerMode; */
  NS_IMETHOD GetFccFolderPickerMode(nsACString & aFccFolderPickerMode) = 0;
  NS_IMETHOD SetFccFolderPickerMode(const nsACString & aFccFolderPickerMode) = 0;

  /* attribute ACString draftsFolderPickerMode; */
  NS_IMETHOD GetDraftsFolderPickerMode(nsACString & aDraftsFolderPickerMode) = 0;
  NS_IMETHOD SetDraftsFolderPickerMode(const nsACString & aDraftsFolderPickerMode) = 0;

  /* attribute ACString archivesFolderPickerMode; */
  NS_IMETHOD GetArchivesFolderPickerMode(nsACString & aArchivesFolderPickerMode) = 0;
  NS_IMETHOD SetArchivesFolderPickerMode(const nsACString & aArchivesFolderPickerMode) = 0;

  /* attribute ACString tmplFolderPickerMode; */
  NS_IMETHOD GetTmplFolderPickerMode(nsACString & aTmplFolderPickerMode) = 0;
  NS_IMETHOD SetTmplFolderPickerMode(const nsACString & aTmplFolderPickerMode) = 0;

  /* attribute boolean bccSelf; */
  NS_IMETHOD GetBccSelf(bool *aBccSelf) = 0;
  NS_IMETHOD SetBccSelf(bool aBccSelf) = 0;

  /* attribute boolean bccOthers; */
  NS_IMETHOD GetBccOthers(bool *aBccOthers) = 0;
  NS_IMETHOD SetBccOthers(bool aBccOthers) = 0;

  /* attribute ACString bccList; */
  NS_IMETHOD GetBccList(nsACString & aBccList) = 0;
  NS_IMETHOD SetBccList(const nsACString & aBccList) = 0;

  /* attribute boolean doCc; */
  NS_IMETHOD GetDoCc(bool *aDoCc) = 0;
  NS_IMETHOD SetDoCc(bool aDoCc) = 0;

  /* attribute AUTF8String doCcList; */
  NS_IMETHOD GetDoCcList(nsACString & aDoCcList) = 0;
  NS_IMETHOD SetDoCcList(const nsACString & aDoCcList) = 0;

  /* attribute boolean doBcc; */
  NS_IMETHOD GetDoBcc(bool *aDoBcc) = 0;
  NS_IMETHOD SetDoBcc(bool aDoBcc) = 0;

  /* attribute AUTF8String doBccList; */
  NS_IMETHOD GetDoBccList(nsACString & aDoBccList) = 0;
  NS_IMETHOD SetDoBccList(const nsACString & aDoBccList) = 0;

  /* attribute ACString draftFolder; */
  NS_IMETHOD GetDraftFolder(nsACString & aDraftFolder) = 0;
  NS_IMETHOD SetDraftFolder(const nsACString & aDraftFolder) = 0;

  /* attribute ACString archiveFolder; */
  NS_IMETHOD GetArchiveFolder(nsACString & aArchiveFolder) = 0;
  NS_IMETHOD SetArchiveFolder(const nsACString & aArchiveFolder) = 0;

  /* attribute ACString stationeryFolder; */
  NS_IMETHOD GetStationeryFolder(nsACString & aStationeryFolder) = 0;
  NS_IMETHOD SetStationeryFolder(const nsACString & aStationeryFolder) = 0;

  /* attribute boolean archiveEnabled; */
  NS_IMETHOD GetArchiveEnabled(bool *aArchiveEnabled) = 0;
  NS_IMETHOD SetArchiveEnabled(bool aArchiveEnabled) = 0;

  /* attribute long archiveGranularity; */
  NS_IMETHOD GetArchiveGranularity(int32_t *aArchiveGranularity) = 0;
  NS_IMETHOD SetArchiveGranularity(int32_t aArchiveGranularity) = 0;

  enum {
    singleArchiveFolder = 0,
    perYearArchiveFolders = 1,
    perMonthArchiveFolders = 2
  };

  /* attribute boolean archiveKeepFolderStructure; */
  NS_IMETHOD GetArchiveKeepFolderStructure(bool *aArchiveKeepFolderStructure) = 0;
  NS_IMETHOD SetArchiveKeepFolderStructure(bool aArchiveKeepFolderStructure) = 0;

  /* attribute boolean showSaveMsgDlg; */
  NS_IMETHOD GetShowSaveMsgDlg(bool *aShowSaveMsgDlg) = 0;
  NS_IMETHOD SetShowSaveMsgDlg(bool aShowSaveMsgDlg) = 0;

  /* attribute ACString directoryServer; */
  NS_IMETHOD GetDirectoryServer(nsACString & aDirectoryServer) = 0;
  NS_IMETHOD SetDirectoryServer(const nsACString & aDirectoryServer) = 0;

  /* attribute boolean overrideGlobalPref; */
  NS_IMETHOD GetOverrideGlobalPref(bool *aOverrideGlobalPref) = 0;
  NS_IMETHOD SetOverrideGlobalPref(bool aOverrideGlobalPref) = 0;

  /* attribute boolean autocompleteToMyDomain; */
  NS_IMETHOD GetAutocompleteToMyDomain(bool *aAutocompleteToMyDomain) = 0;
  NS_IMETHOD SetAutocompleteToMyDomain(bool aAutocompleteToMyDomain) = 0;

  /* attribute boolean valid; */
  NS_IMETHOD GetValid(bool *aValid) = 0;
  NS_IMETHOD SetValid(bool aValid) = 0;

  /* void clearAllValues (); */
  NS_IMETHOD ClearAllValues(void) = 0;

  /* attribute ACString smtpServerKey; */
  NS_IMETHOD GetSmtpServerKey(nsACString & aSmtpServerKey) = 0;
  NS_IMETHOD SetSmtpServerKey(const nsACString & aSmtpServerKey) = 0;

  /* readonly attribute boolean requestReturnReceipt; */
  NS_IMETHOD GetRequestReturnReceipt(bool *aRequestReturnReceipt) = 0;

  /* readonly attribute long receiptHeaderType; */
  NS_IMETHOD GetReceiptHeaderType(int32_t *aReceiptHeaderType) = 0;

  /* readonly attribute boolean requestDSN; */
  NS_IMETHOD GetRequestDSN(bool *aRequestDSN) = 0;

  /* void copy (in nsIMsgIdentity identity); */
  NS_IMETHOD Copy(nsIMsgIdentity *identity) = 0;

  /* AString getUnicharAttribute (in string name); */
  NS_IMETHOD GetUnicharAttribute(const char * name, nsAString & _retval) = 0;

  /* void setUnicharAttribute (in string name, in AString value); */
  NS_IMETHOD SetUnicharAttribute(const char * name, const nsAString & value) = 0;

  /* ACString getCharAttribute (in string name); */
  NS_IMETHOD GetCharAttribute(const char * name, nsACString & _retval) = 0;

  /* void setCharAttribute (in string name, in ACString value); */
  NS_IMETHOD SetCharAttribute(const char * name, const nsACString & value) = 0;

  /* boolean getBoolAttribute (in string name); */
  NS_IMETHOD GetBoolAttribute(const char * name, bool *_retval) = 0;

  /* void setBoolAttribute (in string name, in boolean value); */
  NS_IMETHOD SetBoolAttribute(const char * name, bool value) = 0;

  /* long getIntAttribute (in string name); */
  NS_IMETHOD GetIntAttribute(const char * name, int32_t *_retval) = 0;

  /* void setIntAttribute (in string name, in long value); */
  NS_IMETHOD SetIntAttribute(const char * name, int32_t value) = 0;

  /* AString toString (); */
  NS_IMETHOD ToString(nsAString & _retval) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIMsgIdentity, NS_IMSGIDENTITY_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGIDENTITY \
  NS_IMETHOD GetKey(nsACString & aKey); \
  NS_IMETHOD SetKey(const nsACString & aKey); \
  NS_IMETHOD GetIdentityName(nsAString & aIdentityName); \
  NS_IMETHOD SetIdentityName(const nsAString & aIdentityName); \
  NS_IMETHOD GetFullName(nsAString & aFullName); \
  NS_IMETHOD SetFullName(const nsAString & aFullName); \
  NS_IMETHOD GetEmail(nsACString & aEmail); \
  NS_IMETHOD SetEmail(const nsACString & aEmail); \
  NS_IMETHOD GetReplyTo(nsACString & aReplyTo); \
  NS_IMETHOD SetReplyTo(const nsACString & aReplyTo); \
  NS_IMETHOD GetOrganization(nsAString & aOrganization); \
  NS_IMETHOD SetOrganization(const nsAString & aOrganization); \
  NS_IMETHOD GetComposeHtml(bool *aComposeHtml); \
  NS_IMETHOD SetComposeHtml(bool aComposeHtml); \
  NS_IMETHOD GetAttachSignature(bool *aAttachSignature); \
  NS_IMETHOD SetAttachSignature(bool aAttachSignature); \
  NS_IMETHOD GetAttachVCard(bool *aAttachVCard); \
  NS_IMETHOD SetAttachVCard(bool aAttachVCard); \
  NS_IMETHOD GetAutoQuote(bool *aAutoQuote); \
  NS_IMETHOD SetAutoQuote(bool aAutoQuote); \
  NS_IMETHOD GetReplyOnTop(int32_t *aReplyOnTop); \
  NS_IMETHOD SetReplyOnTop(int32_t aReplyOnTop); \
  NS_IMETHOD GetSigBottom(bool *aSigBottom); \
  NS_IMETHOD SetSigBottom(bool aSigBottom); \
  NS_IMETHOD GetSigOnForward(bool *aSigOnForward); \
  NS_IMETHOD SetSigOnForward(bool aSigOnForward); \
  NS_IMETHOD GetSigOnReply(bool *aSigOnReply); \
  NS_IMETHOD SetSigOnReply(bool aSigOnReply); \
  NS_IMETHOD GetSignature(nsIFile * *aSignature); \
  NS_IMETHOD SetSignature(nsIFile *aSignature); \
  NS_IMETHOD GetSignatureDate(int32_t *aSignatureDate); \
  NS_IMETHOD SetSignatureDate(int32_t aSignatureDate); \
  NS_IMETHOD GetHtmlSigText(nsAString & aHtmlSigText); \
  NS_IMETHOD SetHtmlSigText(const nsAString & aHtmlSigText); \
  NS_IMETHOD GetHtmlSigFormat(bool *aHtmlSigFormat); \
  NS_IMETHOD SetHtmlSigFormat(bool aHtmlSigFormat); \
  NS_IMETHOD GetSuppressSigSep(bool *aSuppressSigSep); \
  NS_IMETHOD SetSuppressSigSep(bool aSuppressSigSep); \
  NS_IMETHOD GetEscapedVCard(nsACString & aEscapedVCard); \
  NS_IMETHOD SetEscapedVCard(const nsACString & aEscapedVCard); \
  NS_IMETHOD GetDoFcc(bool *aDoFcc); \
  NS_IMETHOD SetDoFcc(bool aDoFcc); \
  NS_IMETHOD GetFccFolder(nsACString & aFccFolder); \
  NS_IMETHOD SetFccFolder(const nsACString & aFccFolder); \
  NS_IMETHOD GetFccReplyFollowsParent(bool *aFccReplyFollowsParent); \
  NS_IMETHOD SetFccReplyFollowsParent(bool aFccReplyFollowsParent); \
  NS_IMETHOD GetFccFolderPickerMode(nsACString & aFccFolderPickerMode); \
  NS_IMETHOD SetFccFolderPickerMode(const nsACString & aFccFolderPickerMode); \
  NS_IMETHOD GetDraftsFolderPickerMode(nsACString & aDraftsFolderPickerMode); \
  NS_IMETHOD SetDraftsFolderPickerMode(const nsACString & aDraftsFolderPickerMode); \
  NS_IMETHOD GetArchivesFolderPickerMode(nsACString & aArchivesFolderPickerMode); \
  NS_IMETHOD SetArchivesFolderPickerMode(const nsACString & aArchivesFolderPickerMode); \
  NS_IMETHOD GetTmplFolderPickerMode(nsACString & aTmplFolderPickerMode); \
  NS_IMETHOD SetTmplFolderPickerMode(const nsACString & aTmplFolderPickerMode); \
  NS_IMETHOD GetBccSelf(bool *aBccSelf); \
  NS_IMETHOD SetBccSelf(bool aBccSelf); \
  NS_IMETHOD GetBccOthers(bool *aBccOthers); \
  NS_IMETHOD SetBccOthers(bool aBccOthers); \
  NS_IMETHOD GetBccList(nsACString & aBccList); \
  NS_IMETHOD SetBccList(const nsACString & aBccList); \
  NS_IMETHOD GetDoCc(bool *aDoCc); \
  NS_IMETHOD SetDoCc(bool aDoCc); \
  NS_IMETHOD GetDoCcList(nsACString & aDoCcList); \
  NS_IMETHOD SetDoCcList(const nsACString & aDoCcList); \
  NS_IMETHOD GetDoBcc(bool *aDoBcc); \
  NS_IMETHOD SetDoBcc(bool aDoBcc); \
  NS_IMETHOD GetDoBccList(nsACString & aDoBccList); \
  NS_IMETHOD SetDoBccList(const nsACString & aDoBccList); \
  NS_IMETHOD GetDraftFolder(nsACString & aDraftFolder); \
  NS_IMETHOD SetDraftFolder(const nsACString & aDraftFolder); \
  NS_IMETHOD GetArchiveFolder(nsACString & aArchiveFolder); \
  NS_IMETHOD SetArchiveFolder(const nsACString & aArchiveFolder); \
  NS_IMETHOD GetStationeryFolder(nsACString & aStationeryFolder); \
  NS_IMETHOD SetStationeryFolder(const nsACString & aStationeryFolder); \
  NS_IMETHOD GetArchiveEnabled(bool *aArchiveEnabled); \
  NS_IMETHOD SetArchiveEnabled(bool aArchiveEnabled); \
  NS_IMETHOD GetArchiveGranularity(int32_t *aArchiveGranularity); \
  NS_IMETHOD SetArchiveGranularity(int32_t aArchiveGranularity); \
  NS_IMETHOD GetArchiveKeepFolderStructure(bool *aArchiveKeepFolderStructure); \
  NS_IMETHOD SetArchiveKeepFolderStructure(bool aArchiveKeepFolderStructure); \
  NS_IMETHOD GetShowSaveMsgDlg(bool *aShowSaveMsgDlg); \
  NS_IMETHOD SetShowSaveMsgDlg(bool aShowSaveMsgDlg); \
  NS_IMETHOD GetDirectoryServer(nsACString & aDirectoryServer); \
  NS_IMETHOD SetDirectoryServer(const nsACString & aDirectoryServer); \
  NS_IMETHOD GetOverrideGlobalPref(bool *aOverrideGlobalPref); \
  NS_IMETHOD SetOverrideGlobalPref(bool aOverrideGlobalPref); \
  NS_IMETHOD GetAutocompleteToMyDomain(bool *aAutocompleteToMyDomain); \
  NS_IMETHOD SetAutocompleteToMyDomain(bool aAutocompleteToMyDomain); \
  NS_IMETHOD GetValid(bool *aValid); \
  NS_IMETHOD SetValid(bool aValid); \
  NS_IMETHOD ClearAllValues(void); \
  NS_IMETHOD GetSmtpServerKey(nsACString & aSmtpServerKey); \
  NS_IMETHOD SetSmtpServerKey(const nsACString & aSmtpServerKey); \
  NS_IMETHOD GetRequestReturnReceipt(bool *aRequestReturnReceipt); \
  NS_IMETHOD GetReceiptHeaderType(int32_t *aReceiptHeaderType); \
  NS_IMETHOD GetRequestDSN(bool *aRequestDSN); \
  NS_IMETHOD Copy(nsIMsgIdentity *identity); \
  NS_IMETHOD GetUnicharAttribute(const char * name, nsAString & _retval); \
  NS_IMETHOD SetUnicharAttribute(const char * name, const nsAString & value); \
  NS_IMETHOD GetCharAttribute(const char * name, nsACString & _retval); \
  NS_IMETHOD SetCharAttribute(const char * name, const nsACString & value); \
  NS_IMETHOD GetBoolAttribute(const char * name, bool *_retval); \
  NS_IMETHOD SetBoolAttribute(const char * name, bool value); \
  NS_IMETHOD GetIntAttribute(const char * name, int32_t *_retval); \
  NS_IMETHOD SetIntAttribute(const char * name, int32_t value); \
  NS_IMETHOD ToString(nsAString & _retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGIDENTITY(_to) \
  NS_IMETHOD GetKey(nsACString & aKey) { return _to GetKey(aKey); } \
  NS_IMETHOD SetKey(const nsACString & aKey) { return _to SetKey(aKey); } \
  NS_IMETHOD GetIdentityName(nsAString & aIdentityName) { return _to GetIdentityName(aIdentityName); } \
  NS_IMETHOD SetIdentityName(const nsAString & aIdentityName) { return _to SetIdentityName(aIdentityName); } \
  NS_IMETHOD GetFullName(nsAString & aFullName) { return _to GetFullName(aFullName); } \
  NS_IMETHOD SetFullName(const nsAString & aFullName) { return _to SetFullName(aFullName); } \
  NS_IMETHOD GetEmail(nsACString & aEmail) { return _to GetEmail(aEmail); } \
  NS_IMETHOD SetEmail(const nsACString & aEmail) { return _to SetEmail(aEmail); } \
  NS_IMETHOD GetReplyTo(nsACString & aReplyTo) { return _to GetReplyTo(aReplyTo); } \
  NS_IMETHOD SetReplyTo(const nsACString & aReplyTo) { return _to SetReplyTo(aReplyTo); } \
  NS_IMETHOD GetOrganization(nsAString & aOrganization) { return _to GetOrganization(aOrganization); } \
  NS_IMETHOD SetOrganization(const nsAString & aOrganization) { return _to SetOrganization(aOrganization); } \
  NS_IMETHOD GetComposeHtml(bool *aComposeHtml) { return _to GetComposeHtml(aComposeHtml); } \
  NS_IMETHOD SetComposeHtml(bool aComposeHtml) { return _to SetComposeHtml(aComposeHtml); } \
  NS_IMETHOD GetAttachSignature(bool *aAttachSignature) { return _to GetAttachSignature(aAttachSignature); } \
  NS_IMETHOD SetAttachSignature(bool aAttachSignature) { return _to SetAttachSignature(aAttachSignature); } \
  NS_IMETHOD GetAttachVCard(bool *aAttachVCard) { return _to GetAttachVCard(aAttachVCard); } \
  NS_IMETHOD SetAttachVCard(bool aAttachVCard) { return _to SetAttachVCard(aAttachVCard); } \
  NS_IMETHOD GetAutoQuote(bool *aAutoQuote) { return _to GetAutoQuote(aAutoQuote); } \
  NS_IMETHOD SetAutoQuote(bool aAutoQuote) { return _to SetAutoQuote(aAutoQuote); } \
  NS_IMETHOD GetReplyOnTop(int32_t *aReplyOnTop) { return _to GetReplyOnTop(aReplyOnTop); } \
  NS_IMETHOD SetReplyOnTop(int32_t aReplyOnTop) { return _to SetReplyOnTop(aReplyOnTop); } \
  NS_IMETHOD GetSigBottom(bool *aSigBottom) { return _to GetSigBottom(aSigBottom); } \
  NS_IMETHOD SetSigBottom(bool aSigBottom) { return _to SetSigBottom(aSigBottom); } \
  NS_IMETHOD GetSigOnForward(bool *aSigOnForward) { return _to GetSigOnForward(aSigOnForward); } \
  NS_IMETHOD SetSigOnForward(bool aSigOnForward) { return _to SetSigOnForward(aSigOnForward); } \
  NS_IMETHOD GetSigOnReply(bool *aSigOnReply) { return _to GetSigOnReply(aSigOnReply); } \
  NS_IMETHOD SetSigOnReply(bool aSigOnReply) { return _to SetSigOnReply(aSigOnReply); } \
  NS_IMETHOD GetSignature(nsIFile * *aSignature) { return _to GetSignature(aSignature); } \
  NS_IMETHOD SetSignature(nsIFile *aSignature) { return _to SetSignature(aSignature); } \
  NS_IMETHOD GetSignatureDate(int32_t *aSignatureDate) { return _to GetSignatureDate(aSignatureDate); } \
  NS_IMETHOD SetSignatureDate(int32_t aSignatureDate) { return _to SetSignatureDate(aSignatureDate); } \
  NS_IMETHOD GetHtmlSigText(nsAString & aHtmlSigText) { return _to GetHtmlSigText(aHtmlSigText); } \
  NS_IMETHOD SetHtmlSigText(const nsAString & aHtmlSigText) { return _to SetHtmlSigText(aHtmlSigText); } \
  NS_IMETHOD GetHtmlSigFormat(bool *aHtmlSigFormat) { return _to GetHtmlSigFormat(aHtmlSigFormat); } \
  NS_IMETHOD SetHtmlSigFormat(bool aHtmlSigFormat) { return _to SetHtmlSigFormat(aHtmlSigFormat); } \
  NS_IMETHOD GetSuppressSigSep(bool *aSuppressSigSep) { return _to GetSuppressSigSep(aSuppressSigSep); } \
  NS_IMETHOD SetSuppressSigSep(bool aSuppressSigSep) { return _to SetSuppressSigSep(aSuppressSigSep); } \
  NS_IMETHOD GetEscapedVCard(nsACString & aEscapedVCard) { return _to GetEscapedVCard(aEscapedVCard); } \
  NS_IMETHOD SetEscapedVCard(const nsACString & aEscapedVCard) { return _to SetEscapedVCard(aEscapedVCard); } \
  NS_IMETHOD GetDoFcc(bool *aDoFcc) { return _to GetDoFcc(aDoFcc); } \
  NS_IMETHOD SetDoFcc(bool aDoFcc) { return _to SetDoFcc(aDoFcc); } \
  NS_IMETHOD GetFccFolder(nsACString & aFccFolder) { return _to GetFccFolder(aFccFolder); } \
  NS_IMETHOD SetFccFolder(const nsACString & aFccFolder) { return _to SetFccFolder(aFccFolder); } \
  NS_IMETHOD GetFccReplyFollowsParent(bool *aFccReplyFollowsParent) { return _to GetFccReplyFollowsParent(aFccReplyFollowsParent); } \
  NS_IMETHOD SetFccReplyFollowsParent(bool aFccReplyFollowsParent) { return _to SetFccReplyFollowsParent(aFccReplyFollowsParent); } \
  NS_IMETHOD GetFccFolderPickerMode(nsACString & aFccFolderPickerMode) { return _to GetFccFolderPickerMode(aFccFolderPickerMode); } \
  NS_IMETHOD SetFccFolderPickerMode(const nsACString & aFccFolderPickerMode) { return _to SetFccFolderPickerMode(aFccFolderPickerMode); } \
  NS_IMETHOD GetDraftsFolderPickerMode(nsACString & aDraftsFolderPickerMode) { return _to GetDraftsFolderPickerMode(aDraftsFolderPickerMode); } \
  NS_IMETHOD SetDraftsFolderPickerMode(const nsACString & aDraftsFolderPickerMode) { return _to SetDraftsFolderPickerMode(aDraftsFolderPickerMode); } \
  NS_IMETHOD GetArchivesFolderPickerMode(nsACString & aArchivesFolderPickerMode) { return _to GetArchivesFolderPickerMode(aArchivesFolderPickerMode); } \
  NS_IMETHOD SetArchivesFolderPickerMode(const nsACString & aArchivesFolderPickerMode) { return _to SetArchivesFolderPickerMode(aArchivesFolderPickerMode); } \
  NS_IMETHOD GetTmplFolderPickerMode(nsACString & aTmplFolderPickerMode) { return _to GetTmplFolderPickerMode(aTmplFolderPickerMode); } \
  NS_IMETHOD SetTmplFolderPickerMode(const nsACString & aTmplFolderPickerMode) { return _to SetTmplFolderPickerMode(aTmplFolderPickerMode); } \
  NS_IMETHOD GetBccSelf(bool *aBccSelf) { return _to GetBccSelf(aBccSelf); } \
  NS_IMETHOD SetBccSelf(bool aBccSelf) { return _to SetBccSelf(aBccSelf); } \
  NS_IMETHOD GetBccOthers(bool *aBccOthers) { return _to GetBccOthers(aBccOthers); } \
  NS_IMETHOD SetBccOthers(bool aBccOthers) { return _to SetBccOthers(aBccOthers); } \
  NS_IMETHOD GetBccList(nsACString & aBccList) { return _to GetBccList(aBccList); } \
  NS_IMETHOD SetBccList(const nsACString & aBccList) { return _to SetBccList(aBccList); } \
  NS_IMETHOD GetDoCc(bool *aDoCc) { return _to GetDoCc(aDoCc); } \
  NS_IMETHOD SetDoCc(bool aDoCc) { return _to SetDoCc(aDoCc); } \
  NS_IMETHOD GetDoCcList(nsACString & aDoCcList) { return _to GetDoCcList(aDoCcList); } \
  NS_IMETHOD SetDoCcList(const nsACString & aDoCcList) { return _to SetDoCcList(aDoCcList); } \
  NS_IMETHOD GetDoBcc(bool *aDoBcc) { return _to GetDoBcc(aDoBcc); } \
  NS_IMETHOD SetDoBcc(bool aDoBcc) { return _to SetDoBcc(aDoBcc); } \
  NS_IMETHOD GetDoBccList(nsACString & aDoBccList) { return _to GetDoBccList(aDoBccList); } \
  NS_IMETHOD SetDoBccList(const nsACString & aDoBccList) { return _to SetDoBccList(aDoBccList); } \
  NS_IMETHOD GetDraftFolder(nsACString & aDraftFolder) { return _to GetDraftFolder(aDraftFolder); } \
  NS_IMETHOD SetDraftFolder(const nsACString & aDraftFolder) { return _to SetDraftFolder(aDraftFolder); } \
  NS_IMETHOD GetArchiveFolder(nsACString & aArchiveFolder) { return _to GetArchiveFolder(aArchiveFolder); } \
  NS_IMETHOD SetArchiveFolder(const nsACString & aArchiveFolder) { return _to SetArchiveFolder(aArchiveFolder); } \
  NS_IMETHOD GetStationeryFolder(nsACString & aStationeryFolder) { return _to GetStationeryFolder(aStationeryFolder); } \
  NS_IMETHOD SetStationeryFolder(const nsACString & aStationeryFolder) { return _to SetStationeryFolder(aStationeryFolder); } \
  NS_IMETHOD GetArchiveEnabled(bool *aArchiveEnabled) { return _to GetArchiveEnabled(aArchiveEnabled); } \
  NS_IMETHOD SetArchiveEnabled(bool aArchiveEnabled) { return _to SetArchiveEnabled(aArchiveEnabled); } \
  NS_IMETHOD GetArchiveGranularity(int32_t *aArchiveGranularity) { return _to GetArchiveGranularity(aArchiveGranularity); } \
  NS_IMETHOD SetArchiveGranularity(int32_t aArchiveGranularity) { return _to SetArchiveGranularity(aArchiveGranularity); } \
  NS_IMETHOD GetArchiveKeepFolderStructure(bool *aArchiveKeepFolderStructure) { return _to GetArchiveKeepFolderStructure(aArchiveKeepFolderStructure); } \
  NS_IMETHOD SetArchiveKeepFolderStructure(bool aArchiveKeepFolderStructure) { return _to SetArchiveKeepFolderStructure(aArchiveKeepFolderStructure); } \
  NS_IMETHOD GetShowSaveMsgDlg(bool *aShowSaveMsgDlg) { return _to GetShowSaveMsgDlg(aShowSaveMsgDlg); } \
  NS_IMETHOD SetShowSaveMsgDlg(bool aShowSaveMsgDlg) { return _to SetShowSaveMsgDlg(aShowSaveMsgDlg); } \
  NS_IMETHOD GetDirectoryServer(nsACString & aDirectoryServer) { return _to GetDirectoryServer(aDirectoryServer); } \
  NS_IMETHOD SetDirectoryServer(const nsACString & aDirectoryServer) { return _to SetDirectoryServer(aDirectoryServer); } \
  NS_IMETHOD GetOverrideGlobalPref(bool *aOverrideGlobalPref) { return _to GetOverrideGlobalPref(aOverrideGlobalPref); } \
  NS_IMETHOD SetOverrideGlobalPref(bool aOverrideGlobalPref) { return _to SetOverrideGlobalPref(aOverrideGlobalPref); } \
  NS_IMETHOD GetAutocompleteToMyDomain(bool *aAutocompleteToMyDomain) { return _to GetAutocompleteToMyDomain(aAutocompleteToMyDomain); } \
  NS_IMETHOD SetAutocompleteToMyDomain(bool aAutocompleteToMyDomain) { return _to SetAutocompleteToMyDomain(aAutocompleteToMyDomain); } \
  NS_IMETHOD GetValid(bool *aValid) { return _to GetValid(aValid); } \
  NS_IMETHOD SetValid(bool aValid) { return _to SetValid(aValid); } \
  NS_IMETHOD ClearAllValues(void) { return _to ClearAllValues(); } \
  NS_IMETHOD GetSmtpServerKey(nsACString & aSmtpServerKey) { return _to GetSmtpServerKey(aSmtpServerKey); } \
  NS_IMETHOD SetSmtpServerKey(const nsACString & aSmtpServerKey) { return _to SetSmtpServerKey(aSmtpServerKey); } \
  NS_IMETHOD GetRequestReturnReceipt(bool *aRequestReturnReceipt) { return _to GetRequestReturnReceipt(aRequestReturnReceipt); } \
  NS_IMETHOD GetReceiptHeaderType(int32_t *aReceiptHeaderType) { return _to GetReceiptHeaderType(aReceiptHeaderType); } \
  NS_IMETHOD GetRequestDSN(bool *aRequestDSN) { return _to GetRequestDSN(aRequestDSN); } \
  NS_IMETHOD Copy(nsIMsgIdentity *identity) { return _to Copy(identity); } \
  NS_IMETHOD GetUnicharAttribute(const char * name, nsAString & _retval) { return _to GetUnicharAttribute(name, _retval); } \
  NS_IMETHOD SetUnicharAttribute(const char * name, const nsAString & value) { return _to SetUnicharAttribute(name, value); } \
  NS_IMETHOD GetCharAttribute(const char * name, nsACString & _retval) { return _to GetCharAttribute(name, _retval); } \
  NS_IMETHOD SetCharAttribute(const char * name, const nsACString & value) { return _to SetCharAttribute(name, value); } \
  NS_IMETHOD GetBoolAttribute(const char * name, bool *_retval) { return _to GetBoolAttribute(name, _retval); } \
  NS_IMETHOD SetBoolAttribute(const char * name, bool value) { return _to SetBoolAttribute(name, value); } \
  NS_IMETHOD GetIntAttribute(const char * name, int32_t *_retval) { return _to GetIntAttribute(name, _retval); } \
  NS_IMETHOD SetIntAttribute(const char * name, int32_t value) { return _to SetIntAttribute(name, value); } \
  NS_IMETHOD ToString(nsAString & _retval) { return _to ToString(_retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGIDENTITY(_to) \
  NS_IMETHOD GetKey(nsACString & aKey) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetKey(aKey); } \
  NS_IMETHOD SetKey(const nsACString & aKey) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetKey(aKey); } \
  NS_IMETHOD GetIdentityName(nsAString & aIdentityName) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetIdentityName(aIdentityName); } \
  NS_IMETHOD SetIdentityName(const nsAString & aIdentityName) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetIdentityName(aIdentityName); } \
  NS_IMETHOD GetFullName(nsAString & aFullName) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFullName(aFullName); } \
  NS_IMETHOD SetFullName(const nsAString & aFullName) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetFullName(aFullName); } \
  NS_IMETHOD GetEmail(nsACString & aEmail) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetEmail(aEmail); } \
  NS_IMETHOD SetEmail(const nsACString & aEmail) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetEmail(aEmail); } \
  NS_IMETHOD GetReplyTo(nsACString & aReplyTo) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetReplyTo(aReplyTo); } \
  NS_IMETHOD SetReplyTo(const nsACString & aReplyTo) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetReplyTo(aReplyTo); } \
  NS_IMETHOD GetOrganization(nsAString & aOrganization) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetOrganization(aOrganization); } \
  NS_IMETHOD SetOrganization(const nsAString & aOrganization) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetOrganization(aOrganization); } \
  NS_IMETHOD GetComposeHtml(bool *aComposeHtml) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetComposeHtml(aComposeHtml); } \
  NS_IMETHOD SetComposeHtml(bool aComposeHtml) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetComposeHtml(aComposeHtml); } \
  NS_IMETHOD GetAttachSignature(bool *aAttachSignature) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetAttachSignature(aAttachSignature); } \
  NS_IMETHOD SetAttachSignature(bool aAttachSignature) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetAttachSignature(aAttachSignature); } \
  NS_IMETHOD GetAttachVCard(bool *aAttachVCard) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetAttachVCard(aAttachVCard); } \
  NS_IMETHOD SetAttachVCard(bool aAttachVCard) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetAttachVCard(aAttachVCard); } \
  NS_IMETHOD GetAutoQuote(bool *aAutoQuote) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetAutoQuote(aAutoQuote); } \
  NS_IMETHOD SetAutoQuote(bool aAutoQuote) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetAutoQuote(aAutoQuote); } \
  NS_IMETHOD GetReplyOnTop(int32_t *aReplyOnTop) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetReplyOnTop(aReplyOnTop); } \
  NS_IMETHOD SetReplyOnTop(int32_t aReplyOnTop) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetReplyOnTop(aReplyOnTop); } \
  NS_IMETHOD GetSigBottom(bool *aSigBottom) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSigBottom(aSigBottom); } \
  NS_IMETHOD SetSigBottom(bool aSigBottom) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetSigBottom(aSigBottom); } \
  NS_IMETHOD GetSigOnForward(bool *aSigOnForward) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSigOnForward(aSigOnForward); } \
  NS_IMETHOD SetSigOnForward(bool aSigOnForward) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetSigOnForward(aSigOnForward); } \
  NS_IMETHOD GetSigOnReply(bool *aSigOnReply) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSigOnReply(aSigOnReply); } \
  NS_IMETHOD SetSigOnReply(bool aSigOnReply) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetSigOnReply(aSigOnReply); } \
  NS_IMETHOD GetSignature(nsIFile * *aSignature) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSignature(aSignature); } \
  NS_IMETHOD SetSignature(nsIFile *aSignature) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetSignature(aSignature); } \
  NS_IMETHOD GetSignatureDate(int32_t *aSignatureDate) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSignatureDate(aSignatureDate); } \
  NS_IMETHOD SetSignatureDate(int32_t aSignatureDate) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetSignatureDate(aSignatureDate); } \
  NS_IMETHOD GetHtmlSigText(nsAString & aHtmlSigText) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetHtmlSigText(aHtmlSigText); } \
  NS_IMETHOD SetHtmlSigText(const nsAString & aHtmlSigText) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetHtmlSigText(aHtmlSigText); } \
  NS_IMETHOD GetHtmlSigFormat(bool *aHtmlSigFormat) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetHtmlSigFormat(aHtmlSigFormat); } \
  NS_IMETHOD SetHtmlSigFormat(bool aHtmlSigFormat) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetHtmlSigFormat(aHtmlSigFormat); } \
  NS_IMETHOD GetSuppressSigSep(bool *aSuppressSigSep) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSuppressSigSep(aSuppressSigSep); } \
  NS_IMETHOD SetSuppressSigSep(bool aSuppressSigSep) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetSuppressSigSep(aSuppressSigSep); } \
  NS_IMETHOD GetEscapedVCard(nsACString & aEscapedVCard) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetEscapedVCard(aEscapedVCard); } \
  NS_IMETHOD SetEscapedVCard(const nsACString & aEscapedVCard) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetEscapedVCard(aEscapedVCard); } \
  NS_IMETHOD GetDoFcc(bool *aDoFcc) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDoFcc(aDoFcc); } \
  NS_IMETHOD SetDoFcc(bool aDoFcc) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetDoFcc(aDoFcc); } \
  NS_IMETHOD GetFccFolder(nsACString & aFccFolder) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFccFolder(aFccFolder); } \
  NS_IMETHOD SetFccFolder(const nsACString & aFccFolder) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetFccFolder(aFccFolder); } \
  NS_IMETHOD GetFccReplyFollowsParent(bool *aFccReplyFollowsParent) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFccReplyFollowsParent(aFccReplyFollowsParent); } \
  NS_IMETHOD SetFccReplyFollowsParent(bool aFccReplyFollowsParent) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetFccReplyFollowsParent(aFccReplyFollowsParent); } \
  NS_IMETHOD GetFccFolderPickerMode(nsACString & aFccFolderPickerMode) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFccFolderPickerMode(aFccFolderPickerMode); } \
  NS_IMETHOD SetFccFolderPickerMode(const nsACString & aFccFolderPickerMode) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetFccFolderPickerMode(aFccFolderPickerMode); } \
  NS_IMETHOD GetDraftsFolderPickerMode(nsACString & aDraftsFolderPickerMode) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDraftsFolderPickerMode(aDraftsFolderPickerMode); } \
  NS_IMETHOD SetDraftsFolderPickerMode(const nsACString & aDraftsFolderPickerMode) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetDraftsFolderPickerMode(aDraftsFolderPickerMode); } \
  NS_IMETHOD GetArchivesFolderPickerMode(nsACString & aArchivesFolderPickerMode) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetArchivesFolderPickerMode(aArchivesFolderPickerMode); } \
  NS_IMETHOD SetArchivesFolderPickerMode(const nsACString & aArchivesFolderPickerMode) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetArchivesFolderPickerMode(aArchivesFolderPickerMode); } \
  NS_IMETHOD GetTmplFolderPickerMode(nsACString & aTmplFolderPickerMode) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetTmplFolderPickerMode(aTmplFolderPickerMode); } \
  NS_IMETHOD SetTmplFolderPickerMode(const nsACString & aTmplFolderPickerMode) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetTmplFolderPickerMode(aTmplFolderPickerMode); } \
  NS_IMETHOD GetBccSelf(bool *aBccSelf) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetBccSelf(aBccSelf); } \
  NS_IMETHOD SetBccSelf(bool aBccSelf) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetBccSelf(aBccSelf); } \
  NS_IMETHOD GetBccOthers(bool *aBccOthers) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetBccOthers(aBccOthers); } \
  NS_IMETHOD SetBccOthers(bool aBccOthers) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetBccOthers(aBccOthers); } \
  NS_IMETHOD GetBccList(nsACString & aBccList) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetBccList(aBccList); } \
  NS_IMETHOD SetBccList(const nsACString & aBccList) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetBccList(aBccList); } \
  NS_IMETHOD GetDoCc(bool *aDoCc) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDoCc(aDoCc); } \
  NS_IMETHOD SetDoCc(bool aDoCc) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetDoCc(aDoCc); } \
  NS_IMETHOD GetDoCcList(nsACString & aDoCcList) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDoCcList(aDoCcList); } \
  NS_IMETHOD SetDoCcList(const nsACString & aDoCcList) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetDoCcList(aDoCcList); } \
  NS_IMETHOD GetDoBcc(bool *aDoBcc) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDoBcc(aDoBcc); } \
  NS_IMETHOD SetDoBcc(bool aDoBcc) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetDoBcc(aDoBcc); } \
  NS_IMETHOD GetDoBccList(nsACString & aDoBccList) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDoBccList(aDoBccList); } \
  NS_IMETHOD SetDoBccList(const nsACString & aDoBccList) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetDoBccList(aDoBccList); } \
  NS_IMETHOD GetDraftFolder(nsACString & aDraftFolder) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDraftFolder(aDraftFolder); } \
  NS_IMETHOD SetDraftFolder(const nsACString & aDraftFolder) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetDraftFolder(aDraftFolder); } \
  NS_IMETHOD GetArchiveFolder(nsACString & aArchiveFolder) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetArchiveFolder(aArchiveFolder); } \
  NS_IMETHOD SetArchiveFolder(const nsACString & aArchiveFolder) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetArchiveFolder(aArchiveFolder); } \
  NS_IMETHOD GetStationeryFolder(nsACString & aStationeryFolder) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetStationeryFolder(aStationeryFolder); } \
  NS_IMETHOD SetStationeryFolder(const nsACString & aStationeryFolder) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetStationeryFolder(aStationeryFolder); } \
  NS_IMETHOD GetArchiveEnabled(bool *aArchiveEnabled) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetArchiveEnabled(aArchiveEnabled); } \
  NS_IMETHOD SetArchiveEnabled(bool aArchiveEnabled) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetArchiveEnabled(aArchiveEnabled); } \
  NS_IMETHOD GetArchiveGranularity(int32_t *aArchiveGranularity) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetArchiveGranularity(aArchiveGranularity); } \
  NS_IMETHOD SetArchiveGranularity(int32_t aArchiveGranularity) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetArchiveGranularity(aArchiveGranularity); } \
  NS_IMETHOD GetArchiveKeepFolderStructure(bool *aArchiveKeepFolderStructure) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetArchiveKeepFolderStructure(aArchiveKeepFolderStructure); } \
  NS_IMETHOD SetArchiveKeepFolderStructure(bool aArchiveKeepFolderStructure) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetArchiveKeepFolderStructure(aArchiveKeepFolderStructure); } \
  NS_IMETHOD GetShowSaveMsgDlg(bool *aShowSaveMsgDlg) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetShowSaveMsgDlg(aShowSaveMsgDlg); } \
  NS_IMETHOD SetShowSaveMsgDlg(bool aShowSaveMsgDlg) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetShowSaveMsgDlg(aShowSaveMsgDlg); } \
  NS_IMETHOD GetDirectoryServer(nsACString & aDirectoryServer) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDirectoryServer(aDirectoryServer); } \
  NS_IMETHOD SetDirectoryServer(const nsACString & aDirectoryServer) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetDirectoryServer(aDirectoryServer); } \
  NS_IMETHOD GetOverrideGlobalPref(bool *aOverrideGlobalPref) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetOverrideGlobalPref(aOverrideGlobalPref); } \
  NS_IMETHOD SetOverrideGlobalPref(bool aOverrideGlobalPref) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetOverrideGlobalPref(aOverrideGlobalPref); } \
  NS_IMETHOD GetAutocompleteToMyDomain(bool *aAutocompleteToMyDomain) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetAutocompleteToMyDomain(aAutocompleteToMyDomain); } \
  NS_IMETHOD SetAutocompleteToMyDomain(bool aAutocompleteToMyDomain) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetAutocompleteToMyDomain(aAutocompleteToMyDomain); } \
  NS_IMETHOD GetValid(bool *aValid) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetValid(aValid); } \
  NS_IMETHOD SetValid(bool aValid) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetValid(aValid); } \
  NS_IMETHOD ClearAllValues(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->ClearAllValues(); } \
  NS_IMETHOD GetSmtpServerKey(nsACString & aSmtpServerKey) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSmtpServerKey(aSmtpServerKey); } \
  NS_IMETHOD SetSmtpServerKey(const nsACString & aSmtpServerKey) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetSmtpServerKey(aSmtpServerKey); } \
  NS_IMETHOD GetRequestReturnReceipt(bool *aRequestReturnReceipt) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetRequestReturnReceipt(aRequestReturnReceipt); } \
  NS_IMETHOD GetReceiptHeaderType(int32_t *aReceiptHeaderType) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetReceiptHeaderType(aReceiptHeaderType); } \
  NS_IMETHOD GetRequestDSN(bool *aRequestDSN) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetRequestDSN(aRequestDSN); } \
  NS_IMETHOD Copy(nsIMsgIdentity *identity) { return !_to ? NS_ERROR_NULL_POINTER : _to->Copy(identity); } \
  NS_IMETHOD GetUnicharAttribute(const char * name, nsAString & _retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetUnicharAttribute(name, _retval); } \
  NS_IMETHOD SetUnicharAttribute(const char * name, const nsAString & value) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetUnicharAttribute(name, value); } \
  NS_IMETHOD GetCharAttribute(const char * name, nsACString & _retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetCharAttribute(name, _retval); } \
  NS_IMETHOD SetCharAttribute(const char * name, const nsACString & value) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetCharAttribute(name, value); } \
  NS_IMETHOD GetBoolAttribute(const char * name, bool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetBoolAttribute(name, _retval); } \
  NS_IMETHOD SetBoolAttribute(const char * name, bool value) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetBoolAttribute(name, value); } \
  NS_IMETHOD GetIntAttribute(const char * name, int32_t *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetIntAttribute(name, _retval); } \
  NS_IMETHOD SetIntAttribute(const char * name, int32_t value) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetIntAttribute(name, value); } \
  NS_IMETHOD ToString(nsAString & _retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->ToString(_retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgIdentity : public nsIMsgIdentity
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGIDENTITY

  nsMsgIdentity();

private:
  ~nsMsgIdentity();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgIdentity, nsIMsgIdentity)

nsMsgIdentity::nsMsgIdentity()
{
  /* member initializers and constructor code */
}

nsMsgIdentity::~nsMsgIdentity()
{
  /* destructor code */
}

/* attribute ACString key; */
NS_IMETHODIMP nsMsgIdentity::GetKey(nsACString & aKey)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgIdentity::SetKey(const nsACString & aKey)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute AString identityName; */
NS_IMETHODIMP nsMsgIdentity::GetIdentityName(nsAString & aIdentityName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgIdentity::SetIdentityName(const nsAString & aIdentityName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute AString fullName; */
NS_IMETHODIMP nsMsgIdentity::GetFullName(nsAString & aFullName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgIdentity::SetFullName(const nsAString & aFullName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute ACString email; */
NS_IMETHODIMP nsMsgIdentity::GetEmail(nsACString & aEmail)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgIdentity::SetEmail(const nsACString & aEmail)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute AUTF8String replyTo; */
NS_IMETHODIMP nsMsgIdentity::GetReplyTo(nsACString & aReplyTo)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgIdentity::SetReplyTo(const nsACString & aReplyTo)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute AString organization; */
NS_IMETHODIMP nsMsgIdentity::GetOrganization(nsAString & aOrganization)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgIdentity::SetOrganization(const nsAString & aOrganization)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean composeHtml; */
NS_IMETHODIMP nsMsgIdentity::GetComposeHtml(bool *aComposeHtml)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgIdentity::SetComposeHtml(bool aComposeHtml)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean attachSignature; */
NS_IMETHODIMP nsMsgIdentity::GetAttachSignature(bool *aAttachSignature)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgIdentity::SetAttachSignature(bool aAttachSignature)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean attachVCard; */
NS_IMETHODIMP nsMsgIdentity::GetAttachVCard(bool *aAttachVCard)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgIdentity::SetAttachVCard(bool aAttachVCard)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean autoQuote; */
NS_IMETHODIMP nsMsgIdentity::GetAutoQuote(bool *aAutoQuote)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgIdentity::SetAutoQuote(bool aAutoQuote)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute long replyOnTop; */
NS_IMETHODIMP nsMsgIdentity::GetReplyOnTop(int32_t *aReplyOnTop)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgIdentity::SetReplyOnTop(int32_t aReplyOnTop)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean sigBottom; */
NS_IMETHODIMP nsMsgIdentity::GetSigBottom(bool *aSigBottom)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgIdentity::SetSigBottom(bool aSigBottom)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean sigOnForward; */
NS_IMETHODIMP nsMsgIdentity::GetSigOnForward(bool *aSigOnForward)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgIdentity::SetSigOnForward(bool aSigOnForward)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean sigOnReply; */
NS_IMETHODIMP nsMsgIdentity::GetSigOnReply(bool *aSigOnReply)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgIdentity::SetSigOnReply(bool aSigOnReply)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsIFile signature; */
NS_IMETHODIMP nsMsgIdentity::GetSignature(nsIFile * *aSignature)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgIdentity::SetSignature(nsIFile *aSignature)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute long signatureDate; */
NS_IMETHODIMP nsMsgIdentity::GetSignatureDate(int32_t *aSignatureDate)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgIdentity::SetSignatureDate(int32_t aSignatureDate)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute AString htmlSigText; */
NS_IMETHODIMP nsMsgIdentity::GetHtmlSigText(nsAString & aHtmlSigText)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgIdentity::SetHtmlSigText(const nsAString & aHtmlSigText)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean htmlSigFormat; */
NS_IMETHODIMP nsMsgIdentity::GetHtmlSigFormat(bool *aHtmlSigFormat)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgIdentity::SetHtmlSigFormat(bool aHtmlSigFormat)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean suppressSigSep; */
NS_IMETHODIMP nsMsgIdentity::GetSuppressSigSep(bool *aSuppressSigSep)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgIdentity::SetSuppressSigSep(bool aSuppressSigSep)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute ACString escapedVCard; */
NS_IMETHODIMP nsMsgIdentity::GetEscapedVCard(nsACString & aEscapedVCard)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgIdentity::SetEscapedVCard(const nsACString & aEscapedVCard)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean doFcc; */
NS_IMETHODIMP nsMsgIdentity::GetDoFcc(bool *aDoFcc)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgIdentity::SetDoFcc(bool aDoFcc)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute ACString fccFolder; */
NS_IMETHODIMP nsMsgIdentity::GetFccFolder(nsACString & aFccFolder)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgIdentity::SetFccFolder(const nsACString & aFccFolder)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean fccReplyFollowsParent; */
NS_IMETHODIMP nsMsgIdentity::GetFccReplyFollowsParent(bool *aFccReplyFollowsParent)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgIdentity::SetFccReplyFollowsParent(bool aFccReplyFollowsParent)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute ACString fccFolderPickerMode; */
NS_IMETHODIMP nsMsgIdentity::GetFccFolderPickerMode(nsACString & aFccFolderPickerMode)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgIdentity::SetFccFolderPickerMode(const nsACString & aFccFolderPickerMode)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute ACString draftsFolderPickerMode; */
NS_IMETHODIMP nsMsgIdentity::GetDraftsFolderPickerMode(nsACString & aDraftsFolderPickerMode)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgIdentity::SetDraftsFolderPickerMode(const nsACString & aDraftsFolderPickerMode)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute ACString archivesFolderPickerMode; */
NS_IMETHODIMP nsMsgIdentity::GetArchivesFolderPickerMode(nsACString & aArchivesFolderPickerMode)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgIdentity::SetArchivesFolderPickerMode(const nsACString & aArchivesFolderPickerMode)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute ACString tmplFolderPickerMode; */
NS_IMETHODIMP nsMsgIdentity::GetTmplFolderPickerMode(nsACString & aTmplFolderPickerMode)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgIdentity::SetTmplFolderPickerMode(const nsACString & aTmplFolderPickerMode)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean bccSelf; */
NS_IMETHODIMP nsMsgIdentity::GetBccSelf(bool *aBccSelf)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgIdentity::SetBccSelf(bool aBccSelf)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean bccOthers; */
NS_IMETHODIMP nsMsgIdentity::GetBccOthers(bool *aBccOthers)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgIdentity::SetBccOthers(bool aBccOthers)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute ACString bccList; */
NS_IMETHODIMP nsMsgIdentity::GetBccList(nsACString & aBccList)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgIdentity::SetBccList(const nsACString & aBccList)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean doCc; */
NS_IMETHODIMP nsMsgIdentity::GetDoCc(bool *aDoCc)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgIdentity::SetDoCc(bool aDoCc)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute AUTF8String doCcList; */
NS_IMETHODIMP nsMsgIdentity::GetDoCcList(nsACString & aDoCcList)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgIdentity::SetDoCcList(const nsACString & aDoCcList)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean doBcc; */
NS_IMETHODIMP nsMsgIdentity::GetDoBcc(bool *aDoBcc)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgIdentity::SetDoBcc(bool aDoBcc)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute AUTF8String doBccList; */
NS_IMETHODIMP nsMsgIdentity::GetDoBccList(nsACString & aDoBccList)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgIdentity::SetDoBccList(const nsACString & aDoBccList)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute ACString draftFolder; */
NS_IMETHODIMP nsMsgIdentity::GetDraftFolder(nsACString & aDraftFolder)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgIdentity::SetDraftFolder(const nsACString & aDraftFolder)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute ACString archiveFolder; */
NS_IMETHODIMP nsMsgIdentity::GetArchiveFolder(nsACString & aArchiveFolder)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgIdentity::SetArchiveFolder(const nsACString & aArchiveFolder)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute ACString stationeryFolder; */
NS_IMETHODIMP nsMsgIdentity::GetStationeryFolder(nsACString & aStationeryFolder)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgIdentity::SetStationeryFolder(const nsACString & aStationeryFolder)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean archiveEnabled; */
NS_IMETHODIMP nsMsgIdentity::GetArchiveEnabled(bool *aArchiveEnabled)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgIdentity::SetArchiveEnabled(bool aArchiveEnabled)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute long archiveGranularity; */
NS_IMETHODIMP nsMsgIdentity::GetArchiveGranularity(int32_t *aArchiveGranularity)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgIdentity::SetArchiveGranularity(int32_t aArchiveGranularity)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean archiveKeepFolderStructure; */
NS_IMETHODIMP nsMsgIdentity::GetArchiveKeepFolderStructure(bool *aArchiveKeepFolderStructure)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgIdentity::SetArchiveKeepFolderStructure(bool aArchiveKeepFolderStructure)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean showSaveMsgDlg; */
NS_IMETHODIMP nsMsgIdentity::GetShowSaveMsgDlg(bool *aShowSaveMsgDlg)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgIdentity::SetShowSaveMsgDlg(bool aShowSaveMsgDlg)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute ACString directoryServer; */
NS_IMETHODIMP nsMsgIdentity::GetDirectoryServer(nsACString & aDirectoryServer)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgIdentity::SetDirectoryServer(const nsACString & aDirectoryServer)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean overrideGlobalPref; */
NS_IMETHODIMP nsMsgIdentity::GetOverrideGlobalPref(bool *aOverrideGlobalPref)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgIdentity::SetOverrideGlobalPref(bool aOverrideGlobalPref)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean autocompleteToMyDomain; */
NS_IMETHODIMP nsMsgIdentity::GetAutocompleteToMyDomain(bool *aAutocompleteToMyDomain)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgIdentity::SetAutocompleteToMyDomain(bool aAutocompleteToMyDomain)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean valid; */
NS_IMETHODIMP nsMsgIdentity::GetValid(bool *aValid)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgIdentity::SetValid(bool aValid)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void clearAllValues (); */
NS_IMETHODIMP nsMsgIdentity::ClearAllValues()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute ACString smtpServerKey; */
NS_IMETHODIMP nsMsgIdentity::GetSmtpServerKey(nsACString & aSmtpServerKey)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgIdentity::SetSmtpServerKey(const nsACString & aSmtpServerKey)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean requestReturnReceipt; */
NS_IMETHODIMP nsMsgIdentity::GetRequestReturnReceipt(bool *aRequestReturnReceipt)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute long receiptHeaderType; */
NS_IMETHODIMP nsMsgIdentity::GetReceiptHeaderType(int32_t *aReceiptHeaderType)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean requestDSN; */
NS_IMETHODIMP nsMsgIdentity::GetRequestDSN(bool *aRequestDSN)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void copy (in nsIMsgIdentity identity); */
NS_IMETHODIMP nsMsgIdentity::Copy(nsIMsgIdentity *identity)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* AString getUnicharAttribute (in string name); */
NS_IMETHODIMP nsMsgIdentity::GetUnicharAttribute(const char * name, nsAString & _retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setUnicharAttribute (in string name, in AString value); */
NS_IMETHODIMP nsMsgIdentity::SetUnicharAttribute(const char * name, const nsAString & value)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* ACString getCharAttribute (in string name); */
NS_IMETHODIMP nsMsgIdentity::GetCharAttribute(const char * name, nsACString & _retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setCharAttribute (in string name, in ACString value); */
NS_IMETHODIMP nsMsgIdentity::SetCharAttribute(const char * name, const nsACString & value)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean getBoolAttribute (in string name); */
NS_IMETHODIMP nsMsgIdentity::GetBoolAttribute(const char * name, bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setBoolAttribute (in string name, in boolean value); */
NS_IMETHODIMP nsMsgIdentity::SetBoolAttribute(const char * name, bool value)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* long getIntAttribute (in string name); */
NS_IMETHODIMP nsMsgIdentity::GetIntAttribute(const char * name, int32_t *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setIntAttribute (in string name, in long value); */
NS_IMETHODIMP nsMsgIdentity::SetIntAttribute(const char * name, int32_t value)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* AString toString (); */
NS_IMETHODIMP nsMsgIdentity::ToString(nsAString & _retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgIdentity_h__ */
