/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/base/public/mozINewMailNotificationService.idl
 */

#ifndef __gen_mozINewMailNotificationService_h__
#define __gen_mozINewMailNotificationService_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class mozINewMailListener; /* forward declaration */

typedef int32_t  newMailListenerFlag;


/* starting interface:    mozINewMailNotificationService */
#define MOZINEWMAILNOTIFICATIONSERVICE_IID_STR "7fef9018-c9f1-4cbd-b57c-d6555cf3a668"

#define MOZINEWMAILNOTIFICATIONSERVICE_IID \
  {0x7fef9018, 0xc9f1, 0x4cbd, \
    { 0xb5, 0x7c, 0xd6, 0x55, 0x5c, 0xf3, 0xa6, 0x68 }}

class NS_NO_VTABLE mozINewMailNotificationService : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(MOZINEWMAILNOTIFICATIONSERVICE_IID)

  enum {
    count = 1,
    messages = 2
  };

  /* void addListener (in mozINewMailListener aListener, in newMailListenerFlag flags); */
  NS_IMETHOD AddListener(mozINewMailListener *aListener, newMailListenerFlag flags) = 0;

  /* void removeListener (in mozINewMailListener aListener); */
  NS_IMETHOD RemoveListener(mozINewMailListener *aListener) = 0;

  /* readonly attribute long messageCount; */
  NS_IMETHOD GetMessageCount(int32_t *aMessageCount) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(mozINewMailNotificationService, MOZINEWMAILNOTIFICATIONSERVICE_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_MOZINEWMAILNOTIFICATIONSERVICE \
  NS_IMETHOD AddListener(mozINewMailListener *aListener, newMailListenerFlag flags); \
  NS_IMETHOD RemoveListener(mozINewMailListener *aListener); \
  NS_IMETHOD GetMessageCount(int32_t *aMessageCount); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_MOZINEWMAILNOTIFICATIONSERVICE(_to) \
  NS_IMETHOD AddListener(mozINewMailListener *aListener, newMailListenerFlag flags) { return _to AddListener(aListener, flags); } \
  NS_IMETHOD RemoveListener(mozINewMailListener *aListener) { return _to RemoveListener(aListener); } \
  NS_IMETHOD GetMessageCount(int32_t *aMessageCount) { return _to GetMessageCount(aMessageCount); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_MOZINEWMAILNOTIFICATIONSERVICE(_to) \
  NS_IMETHOD AddListener(mozINewMailListener *aListener, newMailListenerFlag flags) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddListener(aListener, flags); } \
  NS_IMETHOD RemoveListener(mozINewMailListener *aListener) { return !_to ? NS_ERROR_NULL_POINTER : _to->RemoveListener(aListener); } \
  NS_IMETHOD GetMessageCount(int32_t *aMessageCount) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMessageCount(aMessageCount); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public mozINewMailNotificationService
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_MOZINEWMAILNOTIFICATIONSERVICE

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, mozINewMailNotificationService)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* void addListener (in mozINewMailListener aListener, in newMailListenerFlag flags); */
NS_IMETHODIMP _MYCLASS_::AddListener(mozINewMailListener *aListener, newMailListenerFlag flags)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void removeListener (in mozINewMailListener aListener); */
NS_IMETHODIMP _MYCLASS_::RemoveListener(mozINewMailListener *aListener)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute long messageCount; */
NS_IMETHODIMP _MYCLASS_::GetMessageCount(int32_t *aMessageCount)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_mozINewMailNotificationService_h__ */
