/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/compose/public/nsISmtpUrl.idl
 */

#ifndef __gen_nsISmtpUrl_h__
#define __gen_nsISmtpUrl_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsIMsgComposeParams_h__
#include "nsIMsgComposeParams.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIMsgIdentity; /* forward declaration */

class nsIPrompt; /* forward declaration */

class nsIAuthPrompt; /* forward declaration */

class nsISmtpServer; /* forward declaration */

class nsIInterfaceRequestor; /* forward declaration */

class nsIFile; /* forward declaration */


/* starting interface:    nsISmtpUrl */
#define NS_ISMTPURL_IID_STR "da22b8ac-059d-4f82-bf99-f5f3d3c8202d"

#define NS_ISMTPURL_IID \
  {0xda22b8ac, 0x059d, 0x4f82, \
    { 0xbf, 0x99, 0xf5, 0xf3, 0xd3, 0xc8, 0x20, 0x2d }}

class NS_NO_VTABLE nsISmtpUrl : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_ISMTPURL_IID)

  /* attribute string recipients; */
  NS_IMETHOD GetRecipients(char * *aRecipients) = 0;
  NS_IMETHOD SetRecipients(const char * aRecipients) = 0;

  /* attribute boolean PostMessage; */
  NS_IMETHOD GetPostMessage(bool *aPostMessage) = 0;
  NS_IMETHOD SetPostMessage(bool aPostMessage) = 0;

  /* attribute nsIFile postMessageFile; */
  NS_IMETHOD GetPostMessageFile(nsIFile * *aPostMessageFile) = 0;
  NS_IMETHOD SetPostMessageFile(nsIFile *aPostMessageFile) = 0;

  /* attribute boolean requestDSN; */
  NS_IMETHOD GetRequestDSN(bool *aRequestDSN) = 0;
  NS_IMETHOD SetRequestDSN(bool aRequestDSN) = 0;

  /* attribute ACString dsnEnvid; */
  NS_IMETHOD GetDsnEnvid(nsACString & aDsnEnvid) = 0;
  NS_IMETHOD SetDsnEnvid(const nsACString & aDsnEnvid) = 0;

  /* attribute nsIMsgIdentity senderIdentity; */
  NS_IMETHOD GetSenderIdentity(nsIMsgIdentity * *aSenderIdentity) = 0;
  NS_IMETHOD SetSenderIdentity(nsIMsgIdentity *aSenderIdentity) = 0;

  /* attribute nsIPrompt prompt; */
  NS_IMETHOD GetPrompt(nsIPrompt * *aPrompt) = 0;
  NS_IMETHOD SetPrompt(nsIPrompt *aPrompt) = 0;

  /* attribute nsIAuthPrompt authPrompt; */
  NS_IMETHOD GetAuthPrompt(nsIAuthPrompt * *aAuthPrompt) = 0;
  NS_IMETHOD SetAuthPrompt(nsIAuthPrompt *aAuthPrompt) = 0;

  /* attribute nsIInterfaceRequestor notificationCallbacks; */
  NS_IMETHOD GetNotificationCallbacks(nsIInterfaceRequestor * *aNotificationCallbacks) = 0;
  NS_IMETHOD SetNotificationCallbacks(nsIInterfaceRequestor *aNotificationCallbacks) = 0;

  /* attribute nsISmtpServer smtpServer; */
  NS_IMETHOD GetSmtpServer(nsISmtpServer * *aSmtpServer) = 0;
  NS_IMETHOD SetSmtpServer(nsISmtpServer *aSmtpServer) = 0;

  /* attribute boolean verifyLogon; */
  NS_IMETHOD GetVerifyLogon(bool *aVerifyLogon) = 0;
  NS_IMETHOD SetVerifyLogon(bool aVerifyLogon) = 0;

  enum {
    DEFAULT_SMTP_PORT = 25,
    DEFAULT_SMTPS_PORT = 465
  };

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsISmtpUrl, NS_ISMTPURL_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSISMTPURL \
  NS_IMETHOD GetRecipients(char * *aRecipients); \
  NS_IMETHOD SetRecipients(const char * aRecipients); \
  NS_IMETHOD GetPostMessage(bool *aPostMessage); \
  NS_IMETHOD SetPostMessage(bool aPostMessage); \
  NS_IMETHOD GetPostMessageFile(nsIFile * *aPostMessageFile); \
  NS_IMETHOD SetPostMessageFile(nsIFile *aPostMessageFile); \
  NS_IMETHOD GetRequestDSN(bool *aRequestDSN); \
  NS_IMETHOD SetRequestDSN(bool aRequestDSN); \
  NS_IMETHOD GetDsnEnvid(nsACString & aDsnEnvid); \
  NS_IMETHOD SetDsnEnvid(const nsACString & aDsnEnvid); \
  NS_IMETHOD GetSenderIdentity(nsIMsgIdentity * *aSenderIdentity); \
  NS_IMETHOD SetSenderIdentity(nsIMsgIdentity *aSenderIdentity); \
  NS_IMETHOD GetPrompt(nsIPrompt * *aPrompt); \
  NS_IMETHOD SetPrompt(nsIPrompt *aPrompt); \
  NS_IMETHOD GetAuthPrompt(nsIAuthPrompt * *aAuthPrompt); \
  NS_IMETHOD SetAuthPrompt(nsIAuthPrompt *aAuthPrompt); \
  NS_IMETHOD GetNotificationCallbacks(nsIInterfaceRequestor * *aNotificationCallbacks); \
  NS_IMETHOD SetNotificationCallbacks(nsIInterfaceRequestor *aNotificationCallbacks); \
  NS_IMETHOD GetSmtpServer(nsISmtpServer * *aSmtpServer); \
  NS_IMETHOD SetSmtpServer(nsISmtpServer *aSmtpServer); \
  NS_IMETHOD GetVerifyLogon(bool *aVerifyLogon); \
  NS_IMETHOD SetVerifyLogon(bool aVerifyLogon); \

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSISMTPURL(_to) \
  NS_IMETHOD GetRecipients(char * *aRecipients) { return _to GetRecipients(aRecipients); } \
  NS_IMETHOD SetRecipients(const char * aRecipients) { return _to SetRecipients(aRecipients); } \
  NS_IMETHOD GetPostMessage(bool *aPostMessage) { return _to GetPostMessage(aPostMessage); } \
  NS_IMETHOD SetPostMessage(bool aPostMessage) { return _to SetPostMessage(aPostMessage); } \
  NS_IMETHOD GetPostMessageFile(nsIFile * *aPostMessageFile) { return _to GetPostMessageFile(aPostMessageFile); } \
  NS_IMETHOD SetPostMessageFile(nsIFile *aPostMessageFile) { return _to SetPostMessageFile(aPostMessageFile); } \
  NS_IMETHOD GetRequestDSN(bool *aRequestDSN) { return _to GetRequestDSN(aRequestDSN); } \
  NS_IMETHOD SetRequestDSN(bool aRequestDSN) { return _to SetRequestDSN(aRequestDSN); } \
  NS_IMETHOD GetDsnEnvid(nsACString & aDsnEnvid) { return _to GetDsnEnvid(aDsnEnvid); } \
  NS_IMETHOD SetDsnEnvid(const nsACString & aDsnEnvid) { return _to SetDsnEnvid(aDsnEnvid); } \
  NS_IMETHOD GetSenderIdentity(nsIMsgIdentity * *aSenderIdentity) { return _to GetSenderIdentity(aSenderIdentity); } \
  NS_IMETHOD SetSenderIdentity(nsIMsgIdentity *aSenderIdentity) { return _to SetSenderIdentity(aSenderIdentity); } \
  NS_IMETHOD GetPrompt(nsIPrompt * *aPrompt) { return _to GetPrompt(aPrompt); } \
  NS_IMETHOD SetPrompt(nsIPrompt *aPrompt) { return _to SetPrompt(aPrompt); } \
  NS_IMETHOD GetAuthPrompt(nsIAuthPrompt * *aAuthPrompt) { return _to GetAuthPrompt(aAuthPrompt); } \
  NS_IMETHOD SetAuthPrompt(nsIAuthPrompt *aAuthPrompt) { return _to SetAuthPrompt(aAuthPrompt); } \
  NS_IMETHOD GetNotificationCallbacks(nsIInterfaceRequestor * *aNotificationCallbacks) { return _to GetNotificationCallbacks(aNotificationCallbacks); } \
  NS_IMETHOD SetNotificationCallbacks(nsIInterfaceRequestor *aNotificationCallbacks) { return _to SetNotificationCallbacks(aNotificationCallbacks); } \
  NS_IMETHOD GetSmtpServer(nsISmtpServer * *aSmtpServer) { return _to GetSmtpServer(aSmtpServer); } \
  NS_IMETHOD SetSmtpServer(nsISmtpServer *aSmtpServer) { return _to SetSmtpServer(aSmtpServer); } \
  NS_IMETHOD GetVerifyLogon(bool *aVerifyLogon) { return _to GetVerifyLogon(aVerifyLogon); } \
  NS_IMETHOD SetVerifyLogon(bool aVerifyLogon) { return _to SetVerifyLogon(aVerifyLogon); } \

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSISMTPURL(_to) \
  NS_IMETHOD GetRecipients(char * *aRecipients) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetRecipients(aRecipients); } \
  NS_IMETHOD SetRecipients(const char * aRecipients) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetRecipients(aRecipients); } \
  NS_IMETHOD GetPostMessage(bool *aPostMessage) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetPostMessage(aPostMessage); } \
  NS_IMETHOD SetPostMessage(bool aPostMessage) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetPostMessage(aPostMessage); } \
  NS_IMETHOD GetPostMessageFile(nsIFile * *aPostMessageFile) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetPostMessageFile(aPostMessageFile); } \
  NS_IMETHOD SetPostMessageFile(nsIFile *aPostMessageFile) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetPostMessageFile(aPostMessageFile); } \
  NS_IMETHOD GetRequestDSN(bool *aRequestDSN) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetRequestDSN(aRequestDSN); } \
  NS_IMETHOD SetRequestDSN(bool aRequestDSN) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetRequestDSN(aRequestDSN); } \
  NS_IMETHOD GetDsnEnvid(nsACString & aDsnEnvid) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDsnEnvid(aDsnEnvid); } \
  NS_IMETHOD SetDsnEnvid(const nsACString & aDsnEnvid) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetDsnEnvid(aDsnEnvid); } \
  NS_IMETHOD GetSenderIdentity(nsIMsgIdentity * *aSenderIdentity) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSenderIdentity(aSenderIdentity); } \
  NS_IMETHOD SetSenderIdentity(nsIMsgIdentity *aSenderIdentity) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetSenderIdentity(aSenderIdentity); } \
  NS_IMETHOD GetPrompt(nsIPrompt * *aPrompt) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetPrompt(aPrompt); } \
  NS_IMETHOD SetPrompt(nsIPrompt *aPrompt) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetPrompt(aPrompt); } \
  NS_IMETHOD GetAuthPrompt(nsIAuthPrompt * *aAuthPrompt) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetAuthPrompt(aAuthPrompt); } \
  NS_IMETHOD SetAuthPrompt(nsIAuthPrompt *aAuthPrompt) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetAuthPrompt(aAuthPrompt); } \
  NS_IMETHOD GetNotificationCallbacks(nsIInterfaceRequestor * *aNotificationCallbacks) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNotificationCallbacks(aNotificationCallbacks); } \
  NS_IMETHOD SetNotificationCallbacks(nsIInterfaceRequestor *aNotificationCallbacks) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetNotificationCallbacks(aNotificationCallbacks); } \
  NS_IMETHOD GetSmtpServer(nsISmtpServer * *aSmtpServer) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSmtpServer(aSmtpServer); } \
  NS_IMETHOD SetSmtpServer(nsISmtpServer *aSmtpServer) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetSmtpServer(aSmtpServer); } \
  NS_IMETHOD GetVerifyLogon(bool *aVerifyLogon) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetVerifyLogon(aVerifyLogon); } \
  NS_IMETHOD SetVerifyLogon(bool aVerifyLogon) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetVerifyLogon(aVerifyLogon); } \

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsSmtpUrl : public nsISmtpUrl
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSISMTPURL

  nsSmtpUrl();

private:
  ~nsSmtpUrl();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsSmtpUrl, nsISmtpUrl)

nsSmtpUrl::nsSmtpUrl()
{
  /* member initializers and constructor code */
}

nsSmtpUrl::~nsSmtpUrl()
{
  /* destructor code */
}

/* attribute string recipients; */
NS_IMETHODIMP nsSmtpUrl::GetRecipients(char * *aRecipients)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsSmtpUrl::SetRecipients(const char * aRecipients)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean PostMessage; */
NS_IMETHODIMP nsSmtpUrl::GetPostMessage(bool *aPostMessage)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsSmtpUrl::SetPostMessage(bool aPostMessage)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsIFile postMessageFile; */
NS_IMETHODIMP nsSmtpUrl::GetPostMessageFile(nsIFile * *aPostMessageFile)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsSmtpUrl::SetPostMessageFile(nsIFile *aPostMessageFile)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean requestDSN; */
NS_IMETHODIMP nsSmtpUrl::GetRequestDSN(bool *aRequestDSN)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsSmtpUrl::SetRequestDSN(bool aRequestDSN)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute ACString dsnEnvid; */
NS_IMETHODIMP nsSmtpUrl::GetDsnEnvid(nsACString & aDsnEnvid)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsSmtpUrl::SetDsnEnvid(const nsACString & aDsnEnvid)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsIMsgIdentity senderIdentity; */
NS_IMETHODIMP nsSmtpUrl::GetSenderIdentity(nsIMsgIdentity * *aSenderIdentity)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsSmtpUrl::SetSenderIdentity(nsIMsgIdentity *aSenderIdentity)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsIPrompt prompt; */
NS_IMETHODIMP nsSmtpUrl::GetPrompt(nsIPrompt * *aPrompt)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsSmtpUrl::SetPrompt(nsIPrompt *aPrompt)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsIAuthPrompt authPrompt; */
NS_IMETHODIMP nsSmtpUrl::GetAuthPrompt(nsIAuthPrompt * *aAuthPrompt)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsSmtpUrl::SetAuthPrompt(nsIAuthPrompt *aAuthPrompt)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsIInterfaceRequestor notificationCallbacks; */
NS_IMETHODIMP nsSmtpUrl::GetNotificationCallbacks(nsIInterfaceRequestor * *aNotificationCallbacks)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsSmtpUrl::SetNotificationCallbacks(nsIInterfaceRequestor *aNotificationCallbacks)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsISmtpServer smtpServer; */
NS_IMETHODIMP nsSmtpUrl::GetSmtpServer(nsISmtpServer * *aSmtpServer)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsSmtpUrl::SetSmtpServer(nsISmtpServer *aSmtpServer)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean verifyLogon; */
NS_IMETHODIMP nsSmtpUrl::GetVerifyLogon(bool *aVerifyLogon)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsSmtpUrl::SetVerifyLogon(bool aVerifyLogon)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


/* starting interface:    nsIMailtoUrl */
#define NS_IMAILTOURL_IID_STR "87c36c23-4bc2-4992-b338-69f88f6ed0a1"

#define NS_IMAILTOURL_IID \
  {0x87c36c23, 0x4bc2, 0x4992, \
    { 0xb3, 0x38, 0x69, 0xf8, 0x8f, 0x6e, 0xd0, 0xa1 }}

class NS_NO_VTABLE nsIMailtoUrl : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IMAILTOURL_IID)

  /* void getMessageContents (out AUTF8String aToPart, out AUTF8String aCcPart, out AUTF8String aBccPart, out AUTF8String aSubjectPart, out AUTF8String aBodyPart, out AUTF8String aHtmlPart, out ACString aReferencePart, out AUTF8String aNewsgroupPart, out MSG_ComposeFormat aFormat); */
  NS_IMETHOD GetMessageContents(nsACString & aToPart, nsACString & aCcPart, nsACString & aBccPart, nsACString & aSubjectPart, nsACString & aBodyPart, nsACString & aHtmlPart, nsACString & aReferencePart, nsACString & aNewsgroupPart, MSG_ComposeFormat *aFormat) = 0;

  /* readonly attribute AUTF8String fromPart; */
  NS_IMETHOD GetFromPart(nsACString & aFromPart) = 0;

  /* readonly attribute AUTF8String followUpToPart; */
  NS_IMETHOD GetFollowUpToPart(nsACString & aFollowUpToPart) = 0;

  /* readonly attribute AUTF8String organizationPart; */
  NS_IMETHOD GetOrganizationPart(nsACString & aOrganizationPart) = 0;

  /* readonly attribute AUTF8String replyToPart; */
  NS_IMETHOD GetReplyToPart(nsACString & aReplyToPart) = 0;

  /* readonly attribute AUTF8String priorityPart; */
  NS_IMETHOD GetPriorityPart(nsACString & aPriorityPart) = 0;

  /* readonly attribute AUTF8String newsHostPart; */
  NS_IMETHOD GetNewsHostPart(nsACString & aNewsHostPart) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIMailtoUrl, NS_IMAILTOURL_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMAILTOURL \
  NS_IMETHOD GetMessageContents(nsACString & aToPart, nsACString & aCcPart, nsACString & aBccPart, nsACString & aSubjectPart, nsACString & aBodyPart, nsACString & aHtmlPart, nsACString & aReferencePart, nsACString & aNewsgroupPart, MSG_ComposeFormat *aFormat); \
  NS_IMETHOD GetFromPart(nsACString & aFromPart); \
  NS_IMETHOD GetFollowUpToPart(nsACString & aFollowUpToPart); \
  NS_IMETHOD GetOrganizationPart(nsACString & aOrganizationPart); \
  NS_IMETHOD GetReplyToPart(nsACString & aReplyToPart); \
  NS_IMETHOD GetPriorityPart(nsACString & aPriorityPart); \
  NS_IMETHOD GetNewsHostPart(nsACString & aNewsHostPart); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMAILTOURL(_to) \
  NS_IMETHOD GetMessageContents(nsACString & aToPart, nsACString & aCcPart, nsACString & aBccPart, nsACString & aSubjectPart, nsACString & aBodyPart, nsACString & aHtmlPart, nsACString & aReferencePart, nsACString & aNewsgroupPart, MSG_ComposeFormat *aFormat) { return _to GetMessageContents(aToPart, aCcPart, aBccPart, aSubjectPart, aBodyPart, aHtmlPart, aReferencePart, aNewsgroupPart, aFormat); } \
  NS_IMETHOD GetFromPart(nsACString & aFromPart) { return _to GetFromPart(aFromPart); } \
  NS_IMETHOD GetFollowUpToPart(nsACString & aFollowUpToPart) { return _to GetFollowUpToPart(aFollowUpToPart); } \
  NS_IMETHOD GetOrganizationPart(nsACString & aOrganizationPart) { return _to GetOrganizationPart(aOrganizationPart); } \
  NS_IMETHOD GetReplyToPart(nsACString & aReplyToPart) { return _to GetReplyToPart(aReplyToPart); } \
  NS_IMETHOD GetPriorityPart(nsACString & aPriorityPart) { return _to GetPriorityPart(aPriorityPart); } \
  NS_IMETHOD GetNewsHostPart(nsACString & aNewsHostPart) { return _to GetNewsHostPart(aNewsHostPart); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMAILTOURL(_to) \
  NS_IMETHOD GetMessageContents(nsACString & aToPart, nsACString & aCcPart, nsACString & aBccPart, nsACString & aSubjectPart, nsACString & aBodyPart, nsACString & aHtmlPart, nsACString & aReferencePart, nsACString & aNewsgroupPart, MSG_ComposeFormat *aFormat) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMessageContents(aToPart, aCcPart, aBccPart, aSubjectPart, aBodyPart, aHtmlPart, aReferencePart, aNewsgroupPart, aFormat); } \
  NS_IMETHOD GetFromPart(nsACString & aFromPart) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFromPart(aFromPart); } \
  NS_IMETHOD GetFollowUpToPart(nsACString & aFollowUpToPart) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFollowUpToPart(aFollowUpToPart); } \
  NS_IMETHOD GetOrganizationPart(nsACString & aOrganizationPart) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetOrganizationPart(aOrganizationPart); } \
  NS_IMETHOD GetReplyToPart(nsACString & aReplyToPart) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetReplyToPart(aReplyToPart); } \
  NS_IMETHOD GetPriorityPart(nsACString & aPriorityPart) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetPriorityPart(aPriorityPart); } \
  NS_IMETHOD GetNewsHostPart(nsACString & aNewsHostPart) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNewsHostPart(aNewsHostPart); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMailtoUrl : public nsIMailtoUrl
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMAILTOURL

  nsMailtoUrl();

private:
  ~nsMailtoUrl();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMailtoUrl, nsIMailtoUrl)

nsMailtoUrl::nsMailtoUrl()
{
  /* member initializers and constructor code */
}

nsMailtoUrl::~nsMailtoUrl()
{
  /* destructor code */
}

/* void getMessageContents (out AUTF8String aToPart, out AUTF8String aCcPart, out AUTF8String aBccPart, out AUTF8String aSubjectPart, out AUTF8String aBodyPart, out AUTF8String aHtmlPart, out ACString aReferencePart, out AUTF8String aNewsgroupPart, out MSG_ComposeFormat aFormat); */
NS_IMETHODIMP nsMailtoUrl::GetMessageContents(nsACString & aToPart, nsACString & aCcPart, nsACString & aBccPart, nsACString & aSubjectPart, nsACString & aBodyPart, nsACString & aHtmlPart, nsACString & aReferencePart, nsACString & aNewsgroupPart, MSG_ComposeFormat *aFormat)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute AUTF8String fromPart; */
NS_IMETHODIMP nsMailtoUrl::GetFromPart(nsACString & aFromPart)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute AUTF8String followUpToPart; */
NS_IMETHODIMP nsMailtoUrl::GetFollowUpToPart(nsACString & aFollowUpToPart)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute AUTF8String organizationPart; */
NS_IMETHODIMP nsMailtoUrl::GetOrganizationPart(nsACString & aOrganizationPart)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute AUTF8String replyToPart; */
NS_IMETHODIMP nsMailtoUrl::GetReplyToPart(nsACString & aReplyToPart)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute AUTF8String priorityPart; */
NS_IMETHODIMP nsMailtoUrl::GetPriorityPart(nsACString & aPriorityPart)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute AUTF8String newsHostPart; */
NS_IMETHODIMP nsMailtoUrl::GetNewsHostPart(nsACString & aNewsHostPart)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsISmtpUrl_h__ */
