/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "domstubs.idl"

/**
 * Interface for a client side storage. See
 * http://www.whatwg.org/specs/web-apps/current-work/#scs-client-side and
 * http://www.w3.org/TR/IndexedDB/ for more information.
 *
 * Allows access to contextual storage areas.
 */

interface nsIIDBFactory;

[scriptable, uuid(94ca74e8-9cff-456e-a7a4-a4071a32ff58)]
interface nsIDOMStorageIndexedDB : nsISupports
{
  /**
   * Indexed Databases for the current browsing context.
   */
  readonly attribute nsIIDBFactory indexedDB;
  readonly attribute nsIIDBFactory mozIndexedDB;
};
