/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "domstubs.idl"

interface nsIDOMSVGMatrix;

[scriptable, uuid(29cc2e14-6d18-4710-bda9-a88d9d3bc8dc)]
interface nsIDOMSVGTransform : nsISupports
{
    // Transform Types
  const unsigned short SVG_TRANSFORM_UNKNOWN   = 0;
  const unsigned short SVG_TRANSFORM_MATRIX    = 1;
  const unsigned short SVG_TRANSFORM_TRANSLATE = 2;
  const unsigned short SVG_TRANSFORM_SCALE     = 3;
  const unsigned short SVG_TRANSFORM_ROTATE    = 4;
  const unsigned short SVG_TRANSFORM_SKEWX     = 5;
  const unsigned short SVG_TRANSFORM_SKEWY     = 6;

  readonly attribute unsigned short  type;
  readonly attribute nsIDOMSVGMatrix matrix;
  readonly attribute float           angle;

  void setMatrix(in nsIDOMSVGMatrix matrix);
  void setTranslate(in float tx, in float ty);
  void setScale(in float sx, in float sy);
  void setRotate(in float angle, in float cx, in float cy);
  void setSkewX(in float angle);
  void setSkewY(in float angle);
};
