/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/base/public/nsIFolderLookupService.idl
 */

#ifndef __gen_nsIFolderLookupService_h__
#define __gen_nsIFolderLookupService_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIMsgFolder; /* forward declaration */


/* starting interface:    nsIFolderLookupService */
#define NS_IFOLDERLOOKUPSERVICE_IID_STR "a1aaa404-9be7-461f-a715-e92512729923"

#define NS_IFOLDERLOOKUPSERVICE_IID \
  {0xa1aaa404, 0x9be7, 0x461f, \
    { 0xa7, 0x15, 0xe9, 0x25, 0x12, 0x72, 0x99, 0x23 }}

class NS_NO_VTABLE nsIFolderLookupService : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IFOLDERLOOKUPSERVICE_IID)

  /* nsIMsgFolder getFolderById (in ACString id); */
  NS_IMETHOD GetFolderById(const nsACString & id, nsIMsgFolder * *_retval) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIFolderLookupService, NS_IFOLDERLOOKUPSERVICE_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIFOLDERLOOKUPSERVICE \
  NS_IMETHOD GetFolderById(const nsACString & id, nsIMsgFolder * *_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIFOLDERLOOKUPSERVICE(_to) \
  NS_IMETHOD GetFolderById(const nsACString & id, nsIMsgFolder * *_retval) { return _to GetFolderById(id, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIFOLDERLOOKUPSERVICE(_to) \
  NS_IMETHOD GetFolderById(const nsACString & id, nsIMsgFolder * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFolderById(id, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsFolderLookupService : public nsIFolderLookupService
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIFOLDERLOOKUPSERVICE

  nsFolderLookupService();

private:
  ~nsFolderLookupService();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsFolderLookupService, nsIFolderLookupService)

nsFolderLookupService::nsFolderLookupService()
{
  /* member initializers and constructor code */
}

nsFolderLookupService::~nsFolderLookupService()
{
  /* destructor code */
}

/* nsIMsgFolder getFolderById (in ACString id); */
NS_IMETHODIMP nsFolderLookupService::GetFolderById(const nsACString & id, nsIMsgFolder * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIFolderLookupService_h__ */
