
/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsIDOMXULElement.idl"

[scriptable, uuid(31063E54-678C-442C-B487-D87F4C3E4751)]
interface nsIDOMXULDescriptionElement : nsIDOMXULElement {
  attribute boolean disabled;
  attribute boolean crop;
  attribute DOMString value;
};

