/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mozilla/dom/interfaces/html/nsIDOMHTMLPropertiesCollection.idl
 */

#ifndef __gen_nsIDOMHTMLPropertiesCollection_h__
#define __gen_nsIDOMHTMLPropertiesCollection_h__


#ifndef __gen_nsIDOMHTMLElement_h__
#include "nsIDOMHTMLElement.h"
#endif

#ifndef __gen_nsIDOMPropertyNodeList_h__
#include "nsIDOMPropertyNodeList.h"
#endif

#ifndef __gen_nsIDOMDOMStringList_h__
#include "nsIDOMDOMStringList.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIDOMHTMLPropertiesCollection */
#define NS_IDOMHTMLPROPERTIESCOLLECTION_IID_STR "da1101db-d1d7-465d-9fd6-49ec9960cb20"

#define NS_IDOMHTMLPROPERTIESCOLLECTION_IID \
  {0xda1101db, 0xd1d7, 0x465d, \
    { 0x9f, 0xd6, 0x49, 0xec, 0x99, 0x60, 0xcb, 0x20 }}

class NS_NO_VTABLE nsIDOMHTMLPropertiesCollection : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IDOMHTMLPROPERTIESCOLLECTION_IID)

  /* readonly attribute unsigned long length; */
  NS_IMETHOD GetLength(uint32_t *aLength) = 0;

  /* readonly attribute nsIDOMDOMStringList names; */
  NS_IMETHOD GetNames(nsIDOMDOMStringList * *aNames) = 0;

  /* [forward(getNodeAt),getter] nsIDOMNode item (in unsigned long index); */
  NS_IMETHOD Item(uint32_t index, nsIDOMNode * *_retval) = 0;

  /* nsIDOMPropertyNodeList namedItem (in DOMString name); */
  NS_IMETHOD NamedItem(const nsAString & name, nsIDOMPropertyNodeList * *_retval) = 0;

  /* [noscript,nostdcall,notxpcom] nsIContent getNodeAt (in unsigned long index); */
  virtual nsIContent * GetNodeAt(uint32_t index) = 0;

  /* [noscript,nostdcall,notxpcom] nsISupports getNamedItem (in DOMString name, out nsWrapperCachePtr cache); */
  virtual nsISupports * GetNamedItem(const nsAString & name, nsWrapperCache **cache) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIDOMHTMLPropertiesCollection, NS_IDOMHTMLPROPERTIESCOLLECTION_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIDOMHTMLPROPERTIESCOLLECTION \
  NS_IMETHOD GetLength(uint32_t *aLength); \
  NS_IMETHOD GetNames(nsIDOMDOMStringList * *aNames); \
  NS_IMETHOD Item(uint32_t index, nsIDOMNode * *_retval); \
  NS_IMETHOD NamedItem(const nsAString & name, nsIDOMPropertyNodeList * *_retval); \
  virtual nsIContent * GetNodeAt(uint32_t index); \
  virtual nsISupports * GetNamedItem(const nsAString & name, nsWrapperCache **cache); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIDOMHTMLPROPERTIESCOLLECTION(_to) \
  NS_IMETHOD GetLength(uint32_t *aLength) { return _to GetLength(aLength); } \
  NS_IMETHOD GetNames(nsIDOMDOMStringList * *aNames) { return _to GetNames(aNames); } \
  NS_IMETHOD Item(uint32_t index, nsIDOMNode * *_retval) { return _to Item(index, _retval); } \
  NS_IMETHOD NamedItem(const nsAString & name, nsIDOMPropertyNodeList * *_retval) { return _to NamedItem(name, _retval); } \
  virtual nsIContent * GetNodeAt(uint32_t index) { return _to GetNodeAt(index); } \
  virtual nsISupports * GetNamedItem(const nsAString & name, nsWrapperCache **cache) { return _to GetNamedItem(name, cache); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIDOMHTMLPROPERTIESCOLLECTION(_to) \
  NS_IMETHOD GetLength(uint32_t *aLength) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetLength(aLength); } \
  NS_IMETHOD GetNames(nsIDOMDOMStringList * *aNames) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNames(aNames); } \
  NS_IMETHOD Item(uint32_t index, nsIDOMNode * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->Item(index, _retval); } \
  NS_IMETHOD NamedItem(const nsAString & name, nsIDOMPropertyNodeList * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->NamedItem(name, _retval); } \
  virtual nsIContent * GetNodeAt(uint32_t index) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNodeAt(index); } \
  virtual nsISupports * GetNamedItem(const nsAString & name, nsWrapperCache **cache) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNamedItem(name, cache); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsDOMHTMLPropertiesCollection : public nsIDOMHTMLPropertiesCollection
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIDOMHTMLPROPERTIESCOLLECTION

  nsDOMHTMLPropertiesCollection();

private:
  ~nsDOMHTMLPropertiesCollection();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsDOMHTMLPropertiesCollection, nsIDOMHTMLPropertiesCollection)

nsDOMHTMLPropertiesCollection::nsDOMHTMLPropertiesCollection()
{
  /* member initializers and constructor code */
}

nsDOMHTMLPropertiesCollection::~nsDOMHTMLPropertiesCollection()
{
  /* destructor code */
}

/* readonly attribute unsigned long length; */
NS_IMETHODIMP nsDOMHTMLPropertiesCollection::GetLength(uint32_t *aLength)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute nsIDOMDOMStringList names; */
NS_IMETHODIMP nsDOMHTMLPropertiesCollection::GetNames(nsIDOMDOMStringList * *aNames)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [forward(getNodeAt),getter] nsIDOMNode item (in unsigned long index); */
NS_IMETHODIMP nsDOMHTMLPropertiesCollection::Item(uint32_t index, nsIDOMNode * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIDOMPropertyNodeList namedItem (in DOMString name); */
NS_IMETHODIMP nsDOMHTMLPropertiesCollection::NamedItem(const nsAString & name, nsIDOMPropertyNodeList * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [noscript,nostdcall,notxpcom] nsIContent getNodeAt (in unsigned long index); */
nsIContent * nsDOMHTMLPropertiesCollection::GetNodeAt(uint32_t index)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [noscript,nostdcall,notxpcom] nsISupports getNamedItem (in DOMString name, out nsWrapperCachePtr cache); */
nsISupports * nsDOMHTMLPropertiesCollection::GetNamedItem(const nsAString & name, nsWrapperCache **cache)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIDOMHTMLPropertiesCollection_h__ */
