/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* vim:set ts=2 sw=2 sts=2 et cindent: */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsIDOMEvent.idl"
#include "nsIVariant.idl"

[scriptable, builtinclass, uuid(34139b4f-ac78-4372-98d3-12d6dcf478ef)]
interface nsIDOMNotifyAudioAvailableEvent : nsIDOMEvent
{
  [implicit_jscontext]
  readonly attribute jsval  frameBuffer;

  readonly attribute float  time;

  void initAudioAvailableEvent(in DOMString typeArg,
                               in boolean canBubbleArg,
                               in boolean cancelableArg,
                               [array, size_is(frameBufferLength)] in float frameBufferPtr,
                               in unsigned long frameBufferLength,
                               in float time,
                               in boolean allowAudioData);
};
