/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/base/search/public/nsIMsgFilterHitNotify.idl
 */

#ifndef __gen_nsIMsgFilterHitNotify_h__
#define __gen_nsIMsgFilterHitNotify_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsMsgFilterCore_h__
#include "nsMsgFilterCore.h"
#endif

#ifndef __gen_nsIMsgFilter_h__
#include "nsIMsgFilter.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIMsgWindow; /* forward declaration */


/* starting interface:    nsIMsgFilterHitNotify */
#define NS_IMSGFILTERHITNOTIFY_IID_STR "c9f15174-1f3f-11d3-a51b-0060b0fc04b7"

#define NS_IMSGFILTERHITNOTIFY_IID \
  {0xc9f15174, 0x1f3f, 0x11d3, \
    { 0xa5, 0x1b, 0x00, 0x60, 0xb0, 0xfc, 0x04, 0xb7 }}

class NS_NO_VTABLE nsIMsgFilterHitNotify : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IMSGFILTERHITNOTIFY_IID)

  /* boolean applyFilterHit (in nsIMsgFilter filter, in nsIMsgWindow msgWindow); */
  NS_IMETHOD ApplyFilterHit(nsIMsgFilter *filter, nsIMsgWindow *msgWindow, bool *_retval) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIMsgFilterHitNotify, NS_IMSGFILTERHITNOTIFY_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGFILTERHITNOTIFY \
  NS_IMETHOD ApplyFilterHit(nsIMsgFilter *filter, nsIMsgWindow *msgWindow, bool *_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGFILTERHITNOTIFY(_to) \
  NS_IMETHOD ApplyFilterHit(nsIMsgFilter *filter, nsIMsgWindow *msgWindow, bool *_retval) { return _to ApplyFilterHit(filter, msgWindow, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGFILTERHITNOTIFY(_to) \
  NS_IMETHOD ApplyFilterHit(nsIMsgFilter *filter, nsIMsgWindow *msgWindow, bool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->ApplyFilterHit(filter, msgWindow, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgFilterHitNotify : public nsIMsgFilterHitNotify
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGFILTERHITNOTIFY

  nsMsgFilterHitNotify();

private:
  ~nsMsgFilterHitNotify();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgFilterHitNotify, nsIMsgFilterHitNotify)

nsMsgFilterHitNotify::nsMsgFilterHitNotify()
{
  /* member initializers and constructor code */
}

nsMsgFilterHitNotify::~nsMsgFilterHitNotify()
{
  /* destructor code */
}

/* boolean applyFilterHit (in nsIMsgFilter filter, in nsIMsgWindow msgWindow); */
NS_IMETHODIMP nsMsgFilterHitNotify::ApplyFilterHit(nsIMsgFilter *filter, nsIMsgWindow *msgWindow, bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgFilterHitNotify_h__ */
