/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/base/public/nsIStopwatch.idl
 */

#ifndef __gen_nsIStopwatch_h__
#define __gen_nsIStopwatch_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIStopwatch */
#define NS_ISTOPWATCH_IID_STR "7a671d6e-d48f-4a4f-b87e-644815a5e381"

#define NS_ISTOPWATCH_IID \
  {0x7a671d6e, 0xd48f, 0x4a4f, \
    { 0xb8, 0x7e, 0x64, 0x48, 0x15, 0xa5, 0xe3, 0x81 }}

class NS_NO_VTABLE nsIStopwatch : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_ISTOPWATCH_IID)

  /* void start (); */
  NS_IMETHOD Start(void) = 0;

  /* void stop (); */
  NS_IMETHOD Stop(void) = 0;

  /* void resume (); */
  NS_IMETHOD Resume(void) = 0;

  /* readonly attribute double cpuTimeSeconds; */
  NS_IMETHOD GetCpuTimeSeconds(double *aCpuTimeSeconds) = 0;

  /* readonly attribute double realTimeSeconds; */
  NS_IMETHOD GetRealTimeSeconds(double *aRealTimeSeconds) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIStopwatch, NS_ISTOPWATCH_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSISTOPWATCH \
  NS_IMETHOD Start(void); \
  NS_IMETHOD Stop(void); \
  NS_IMETHOD Resume(void); \
  NS_IMETHOD GetCpuTimeSeconds(double *aCpuTimeSeconds); \
  NS_IMETHOD GetRealTimeSeconds(double *aRealTimeSeconds); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSISTOPWATCH(_to) \
  NS_IMETHOD Start(void) { return _to Start(); } \
  NS_IMETHOD Stop(void) { return _to Stop(); } \
  NS_IMETHOD Resume(void) { return _to Resume(); } \
  NS_IMETHOD GetCpuTimeSeconds(double *aCpuTimeSeconds) { return _to GetCpuTimeSeconds(aCpuTimeSeconds); } \
  NS_IMETHOD GetRealTimeSeconds(double *aRealTimeSeconds) { return _to GetRealTimeSeconds(aRealTimeSeconds); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSISTOPWATCH(_to) \
  NS_IMETHOD Start(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->Start(); } \
  NS_IMETHOD Stop(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->Stop(); } \
  NS_IMETHOD Resume(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->Resume(); } \
  NS_IMETHOD GetCpuTimeSeconds(double *aCpuTimeSeconds) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetCpuTimeSeconds(aCpuTimeSeconds); } \
  NS_IMETHOD GetRealTimeSeconds(double *aRealTimeSeconds) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetRealTimeSeconds(aRealTimeSeconds); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsStopwatch : public nsIStopwatch
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSISTOPWATCH

  nsStopwatch();

private:
  ~nsStopwatch();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsStopwatch, nsIStopwatch)

nsStopwatch::nsStopwatch()
{
  /* member initializers and constructor code */
}

nsStopwatch::~nsStopwatch()
{
  /* destructor code */
}

/* void start (); */
NS_IMETHODIMP nsStopwatch::Start()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void stop (); */
NS_IMETHODIMP nsStopwatch::Stop()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void resume (); */
NS_IMETHODIMP nsStopwatch::Resume()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute double cpuTimeSeconds; */
NS_IMETHODIMP nsStopwatch::GetCpuTimeSeconds(double *aCpuTimeSeconds)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute double realTimeSeconds; */
NS_IMETHODIMP nsStopwatch::GetRealTimeSeconds(double *aRealTimeSeconds)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIStopwatch_h__ */
