/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/compose/public/nsIMsgSendListener.idl
 */

#ifndef __gen_nsIMsgSendListener_h__
#define __gen_nsIMsgSendListener_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIFile; /* forward declaration */


/* starting interface:    nsIMsgSendListener */
#define NS_IMSGSENDLISTENER_IID_STR "d34dc178-5e78-45e8-8658-a8f52d9ccf5f"

#define NS_IMSGSENDLISTENER_IID \
  {0xd34dc178, 0x5e78, 0x45e8, \
    { 0x86, 0x58, 0xa8, 0xf5, 0x2d, 0x9c, 0xcf, 0x5f }}

class NS_NO_VTABLE nsIMsgSendListener : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IMSGSENDLISTENER_IID)

  /* void onStartSending (in string aMsgID, in uint32_t aMsgSize); */
  NS_IMETHOD OnStartSending(const char * aMsgID, uint32_t aMsgSize) = 0;

  /* void onProgress (in string aMsgID, in uint32_t aProgress, in uint32_t aProgressMax); */
  NS_IMETHOD OnProgress(const char * aMsgID, uint32_t aProgress, uint32_t aProgressMax) = 0;

  /* void onStatus (in string aMsgID, in wstring aMsg); */
  NS_IMETHOD OnStatus(const char * aMsgID, const PRUnichar * aMsg) = 0;

  /* void onStopSending (in string aMsgID, in nsresult aStatus, in wstring aMsg, in nsIFile aReturnFile); */
  NS_IMETHOD OnStopSending(const char * aMsgID, nsresult aStatus, const PRUnichar * aMsg, nsIFile *aReturnFile) = 0;

  /* void onGetDraftFolderURI (in string aFolderURI); */
  NS_IMETHOD OnGetDraftFolderURI(const char * aFolderURI) = 0;

  /* void onSendNotPerformed (in string aMsgID, in nsresult aStatus); */
  NS_IMETHOD OnSendNotPerformed(const char * aMsgID, nsresult aStatus) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIMsgSendListener, NS_IMSGSENDLISTENER_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGSENDLISTENER \
  NS_IMETHOD OnStartSending(const char * aMsgID, uint32_t aMsgSize); \
  NS_IMETHOD OnProgress(const char * aMsgID, uint32_t aProgress, uint32_t aProgressMax); \
  NS_IMETHOD OnStatus(const char * aMsgID, const PRUnichar * aMsg); \
  NS_IMETHOD OnStopSending(const char * aMsgID, nsresult aStatus, const PRUnichar * aMsg, nsIFile *aReturnFile); \
  NS_IMETHOD OnGetDraftFolderURI(const char * aFolderURI); \
  NS_IMETHOD OnSendNotPerformed(const char * aMsgID, nsresult aStatus); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGSENDLISTENER(_to) \
  NS_IMETHOD OnStartSending(const char * aMsgID, uint32_t aMsgSize) { return _to OnStartSending(aMsgID, aMsgSize); } \
  NS_IMETHOD OnProgress(const char * aMsgID, uint32_t aProgress, uint32_t aProgressMax) { return _to OnProgress(aMsgID, aProgress, aProgressMax); } \
  NS_IMETHOD OnStatus(const char * aMsgID, const PRUnichar * aMsg) { return _to OnStatus(aMsgID, aMsg); } \
  NS_IMETHOD OnStopSending(const char * aMsgID, nsresult aStatus, const PRUnichar * aMsg, nsIFile *aReturnFile) { return _to OnStopSending(aMsgID, aStatus, aMsg, aReturnFile); } \
  NS_IMETHOD OnGetDraftFolderURI(const char * aFolderURI) { return _to OnGetDraftFolderURI(aFolderURI); } \
  NS_IMETHOD OnSendNotPerformed(const char * aMsgID, nsresult aStatus) { return _to OnSendNotPerformed(aMsgID, aStatus); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGSENDLISTENER(_to) \
  NS_IMETHOD OnStartSending(const char * aMsgID, uint32_t aMsgSize) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnStartSending(aMsgID, aMsgSize); } \
  NS_IMETHOD OnProgress(const char * aMsgID, uint32_t aProgress, uint32_t aProgressMax) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnProgress(aMsgID, aProgress, aProgressMax); } \
  NS_IMETHOD OnStatus(const char * aMsgID, const PRUnichar * aMsg) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnStatus(aMsgID, aMsg); } \
  NS_IMETHOD OnStopSending(const char * aMsgID, nsresult aStatus, const PRUnichar * aMsg, nsIFile *aReturnFile) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnStopSending(aMsgID, aStatus, aMsg, aReturnFile); } \
  NS_IMETHOD OnGetDraftFolderURI(const char * aFolderURI) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnGetDraftFolderURI(aFolderURI); } \
  NS_IMETHOD OnSendNotPerformed(const char * aMsgID, nsresult aStatus) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnSendNotPerformed(aMsgID, aStatus); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgSendListener : public nsIMsgSendListener
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGSENDLISTENER

  nsMsgSendListener();

private:
  ~nsMsgSendListener();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgSendListener, nsIMsgSendListener)

nsMsgSendListener::nsMsgSendListener()
{
  /* member initializers and constructor code */
}

nsMsgSendListener::~nsMsgSendListener()
{
  /* destructor code */
}

/* void onStartSending (in string aMsgID, in uint32_t aMsgSize); */
NS_IMETHODIMP nsMsgSendListener::OnStartSending(const char * aMsgID, uint32_t aMsgSize)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void onProgress (in string aMsgID, in uint32_t aProgress, in uint32_t aProgressMax); */
NS_IMETHODIMP nsMsgSendListener::OnProgress(const char * aMsgID, uint32_t aProgress, uint32_t aProgressMax)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void onStatus (in string aMsgID, in wstring aMsg); */
NS_IMETHODIMP nsMsgSendListener::OnStatus(const char * aMsgID, const PRUnichar * aMsg)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void onStopSending (in string aMsgID, in nsresult aStatus, in wstring aMsg, in nsIFile aReturnFile); */
NS_IMETHODIMP nsMsgSendListener::OnStopSending(const char * aMsgID, nsresult aStatus, const PRUnichar * aMsg, nsIFile *aReturnFile)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void onGetDraftFolderURI (in string aFolderURI); */
NS_IMETHODIMP nsMsgSendListener::OnGetDraftFolderURI(const char * aFolderURI)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void onSendNotPerformed (in string aMsgID, in nsresult aStatus); */
NS_IMETHODIMP nsMsgSendListener::OnSendNotPerformed(const char * aMsgID, nsresult aStatus)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgSendListener_h__ */
