/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/base/public/nsIMsgFolderCacheElement.idl
 */

#ifndef __gen_nsIMsgFolderCacheElement_h__
#define __gen_nsIMsgFolderCacheElement_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIMsgFolderCacheElement */
#define NS_IMSGFOLDERCACHEELEMENT_IID_STR "d7ed2508-a608-46cd-aa01-fbb019b0fa44"

#define NS_IMSGFOLDERCACHEELEMENT_IID \
  {0xd7ed2508, 0xa608, 0x46cd, \
    { 0xaa, 0x01, 0xfb, 0xb0, 0x19, 0xb0, 0xfa, 0x44 }}

class NS_NO_VTABLE nsIMsgFolderCacheElement : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IMSGFOLDERCACHEELEMENT_IID)

  /* attribute ACString key; */
  NS_IMETHOD GetKey(nsACString & aKey) = 0;
  NS_IMETHOD SetKey(const nsACString & aKey) = 0;

  /* ACString getStringProperty (in string propertyName); */
  NS_IMETHOD GetStringProperty(const char * propertyName, nsACString & _retval) = 0;

  /* long getInt32Property (in string propertyName); */
  NS_IMETHOD GetInt32Property(const char * propertyName, int32_t *_retval) = 0;

  /* void setStringProperty (in string propertyName, in ACString propertyValue); */
  NS_IMETHOD SetStringProperty(const char * propertyName, const nsACString & propertyValue) = 0;

  /* void setInt32Property (in string propertyName, in long propertyValue); */
  NS_IMETHOD SetInt32Property(const char * propertyName, int32_t propertyValue) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIMsgFolderCacheElement, NS_IMSGFOLDERCACHEELEMENT_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGFOLDERCACHEELEMENT \
  NS_IMETHOD GetKey(nsACString & aKey); \
  NS_IMETHOD SetKey(const nsACString & aKey); \
  NS_IMETHOD GetStringProperty(const char * propertyName, nsACString & _retval); \
  NS_IMETHOD GetInt32Property(const char * propertyName, int32_t *_retval); \
  NS_IMETHOD SetStringProperty(const char * propertyName, const nsACString & propertyValue); \
  NS_IMETHOD SetInt32Property(const char * propertyName, int32_t propertyValue); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGFOLDERCACHEELEMENT(_to) \
  NS_IMETHOD GetKey(nsACString & aKey) { return _to GetKey(aKey); } \
  NS_IMETHOD SetKey(const nsACString & aKey) { return _to SetKey(aKey); } \
  NS_IMETHOD GetStringProperty(const char * propertyName, nsACString & _retval) { return _to GetStringProperty(propertyName, _retval); } \
  NS_IMETHOD GetInt32Property(const char * propertyName, int32_t *_retval) { return _to GetInt32Property(propertyName, _retval); } \
  NS_IMETHOD SetStringProperty(const char * propertyName, const nsACString & propertyValue) { return _to SetStringProperty(propertyName, propertyValue); } \
  NS_IMETHOD SetInt32Property(const char * propertyName, int32_t propertyValue) { return _to SetInt32Property(propertyName, propertyValue); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGFOLDERCACHEELEMENT(_to) \
  NS_IMETHOD GetKey(nsACString & aKey) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetKey(aKey); } \
  NS_IMETHOD SetKey(const nsACString & aKey) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetKey(aKey); } \
  NS_IMETHOD GetStringProperty(const char * propertyName, nsACString & _retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetStringProperty(propertyName, _retval); } \
  NS_IMETHOD GetInt32Property(const char * propertyName, int32_t *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetInt32Property(propertyName, _retval); } \
  NS_IMETHOD SetStringProperty(const char * propertyName, const nsACString & propertyValue) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetStringProperty(propertyName, propertyValue); } \
  NS_IMETHOD SetInt32Property(const char * propertyName, int32_t propertyValue) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetInt32Property(propertyName, propertyValue); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgFolderCacheElement : public nsIMsgFolderCacheElement
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGFOLDERCACHEELEMENT

  nsMsgFolderCacheElement();

private:
  ~nsMsgFolderCacheElement();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgFolderCacheElement, nsIMsgFolderCacheElement)

nsMsgFolderCacheElement::nsMsgFolderCacheElement()
{
  /* member initializers and constructor code */
}

nsMsgFolderCacheElement::~nsMsgFolderCacheElement()
{
  /* destructor code */
}

/* attribute ACString key; */
NS_IMETHODIMP nsMsgFolderCacheElement::GetKey(nsACString & aKey)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgFolderCacheElement::SetKey(const nsACString & aKey)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* ACString getStringProperty (in string propertyName); */
NS_IMETHODIMP nsMsgFolderCacheElement::GetStringProperty(const char * propertyName, nsACString & _retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* long getInt32Property (in string propertyName); */
NS_IMETHODIMP nsMsgFolderCacheElement::GetInt32Property(const char * propertyName, int32_t *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setStringProperty (in string propertyName, in ACString propertyValue); */
NS_IMETHODIMP nsMsgFolderCacheElement::SetStringProperty(const char * propertyName, const nsACString & propertyValue)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setInt32Property (in string propertyName, in long propertyValue); */
NS_IMETHODIMP nsMsgFolderCacheElement::SetInt32Property(const char * propertyName, int32_t propertyValue)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgFolderCacheElement_h__ */
