/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/import/public/nsIImportSettings.idl
 */

#ifndef __gen_nsIImportSettings_h__
#define __gen_nsIImportSettings_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIMsgAccount; /* forward declaration */

class nsIFile; /* forward declaration */


/* starting interface:    nsIImportSettings */
#define NS_IIMPORTSETTINGS_IID_STR "1c0e3012-bc4d-4fb2-be6a-0335c7bab9ac"

#define NS_IIMPORTSETTINGS_IID \
  {0x1c0e3012, 0xbc4d, 0x4fb2, \
    { 0xbe, 0x6a, 0x03, 0x35, 0xc7, 0xba, 0xb9, 0xac }}

class NS_NO_VTABLE nsIImportSettings : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IIMPORTSETTINGS_IID)

  /* boolean AutoLocate (out wstring description, out nsIFile location); */
  NS_IMETHOD AutoLocate(PRUnichar * *description, nsIFile * *location, bool *_retval) = 0;

  /* void SetLocation (in nsIFile location); */
  NS_IMETHOD SetLocation(nsIFile *location) = 0;

  /* boolean Import (out nsIMsgAccount localMailAccount); */
  NS_IMETHOD Import(nsIMsgAccount * *localMailAccount, bool *_retval) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIImportSettings, NS_IIMPORTSETTINGS_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIIMPORTSETTINGS \
  NS_IMETHOD AutoLocate(PRUnichar * *description, nsIFile * *location, bool *_retval); \
  NS_IMETHOD SetLocation(nsIFile *location); \
  NS_IMETHOD Import(nsIMsgAccount * *localMailAccount, bool *_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIIMPORTSETTINGS(_to) \
  NS_IMETHOD AutoLocate(PRUnichar * *description, nsIFile * *location, bool *_retval) { return _to AutoLocate(description, location, _retval); } \
  NS_IMETHOD SetLocation(nsIFile *location) { return _to SetLocation(location); } \
  NS_IMETHOD Import(nsIMsgAccount * *localMailAccount, bool *_retval) { return _to Import(localMailAccount, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIIMPORTSETTINGS(_to) \
  NS_IMETHOD AutoLocate(PRUnichar * *description, nsIFile * *location, bool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->AutoLocate(description, location, _retval); } \
  NS_IMETHOD SetLocation(nsIFile *location) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetLocation(location); } \
  NS_IMETHOD Import(nsIMsgAccount * *localMailAccount, bool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->Import(localMailAccount, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsImportSettings : public nsIImportSettings
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIIMPORTSETTINGS

  nsImportSettings();

private:
  ~nsImportSettings();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsImportSettings, nsIImportSettings)

nsImportSettings::nsImportSettings()
{
  /* member initializers and constructor code */
}

nsImportSettings::~nsImportSettings()
{
  /* destructor code */
}

/* boolean AutoLocate (out wstring description, out nsIFile location); */
NS_IMETHODIMP nsImportSettings::AutoLocate(PRUnichar * *description, nsIFile * *location, bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void SetLocation (in nsIFile location); */
NS_IMETHODIMP nsImportSettings::SetLocation(nsIFile *location)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean Import (out nsIMsgAccount localMailAccount); */
NS_IMETHODIMP nsImportSettings::Import(nsIMsgAccount * *localMailAccount, bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif



#endif /* __gen_nsIImportSettings_h__ */
