# If there's no mozilla here, then take over:
if [ ! -r usr/bin/mozilla ]; then
  ( cd usr/bin ; ln -sf seamonkey mozilla )
fi
# Hopefully this won't break everything.  ;-)
if ! grep /usr/lib/seamonkey etc/ld.so.conf 1> /dev/null 2> /dev/null ; then
  echo "/usr/lib/seamonkey" >> etc/ld.so.conf
fi
if [ -x /sbin/ldconfig ]; then
  /sbin/ldconfig 2> /dev/null
fi
( cd usr/lib ; rm -rf seamonkey )
( cd usr/lib ; ln -sf seamonkey-2.14.1 seamonkey )
( cd usr/lib/pkgconfig ; rm -rf xpcom.pc )
( cd usr/lib/pkgconfig ; ln -sf seamonkey-xpcom.pc xpcom.pc )
( cd usr/lib/pkgconfig ; rm -rf plugin.pc )
( cd usr/lib/pkgconfig ; ln -sf seamonkey-plugin.pc plugin.pc )
( cd usr/lib/pkgconfig ; rm -rf js.pc )
( cd usr/lib/pkgconfig ; ln -sf seamonkey-js.pc js.pc )
( cd usr/lib/pkgconfig ; rm -rf libxul.pc )
( cd usr/lib/pkgconfig ; ln -sf seamonkey-libxul.pc libxul.pc )
( cd usr/include/seamonkey-2.14.1 ; rm -rf xpcom )
( cd usr/include/seamonkey-2.14.1 ; ln -sf . xpcom )
( cd usr/include/seamonkey-2.14.1 ; rm -rf plugin )
( cd usr/include/seamonkey-2.14.1 ; ln -sf . plugin )
( cd usr/include/seamonkey-2.14.1 ; rm -rf nss )
( cd usr/include/seamonkey-2.14.1 ; ln -sf . nss )
( cd usr/include ; rm -rf seamonkey )
( cd usr/include ; ln -sf seamonkey-2.14.1 seamonkey )
( cd usr/bin ; rm -rf seamonkey )
( cd usr/bin ; ln -sf /usr/lib/seamonkey-2.14.1/seamonkey seamonkey )
