/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsIDOMHTMLElement.idl"

/**
 * The nsIDOMHTMLUnknownElement interface is the interface to an unknown HTML
 * element.
 *
 * @see <http://www.whatwg.org/html/#htmlunknownelement>
 */
[scriptable, uuid(74ACC5C9-A18D-4AEC-AEFC-A719EF69499C)]
interface nsIDOMHTMLUnknownElement : nsIDOMHTMLElement
{
};
