/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "domstubs.idl"

[scriptable, uuid(6aff3102-320d-4986-9790-12316bb87cf9)]
interface nsIDOMRGBColor : nsISupports
{
  readonly attribute nsIDOMCSSPrimitiveValue  red;
  readonly attribute nsIDOMCSSPrimitiveValue  green;
  readonly attribute nsIDOMCSSPrimitiveValue  blue;
};
