/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"

[scriptable, uuid(3634327c-392b-4686-adf5-576e6cef9196)]
interface nsINewsDownloadDialogArgs: nsISupports {
  attribute AString groupName;
  attribute long articleCount;
  attribute string serverKey;
  attribute boolean hitOK;
  attribute boolean downloadAll;
};

%{ C++
#define DOWNLOAD_HEADERS_URL "chrome://messenger/content/downloadheaders.xul"
%}
