/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/news/public/nsINntpService.idl
 */

#ifndef __gen_nsINntpService_h__
#define __gen_nsINntpService_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsIUrlListener_h__
#include "nsIUrlListener.h"
#endif

#ifndef __gen_nsINntpIncomingServer_h__
#include "nsINntpIncomingServer.h"
#endif

#ifndef __gen_MailNewsTypes2_h__
#include "MailNewsTypes2.h"
#endif

#ifndef __gen_nsIMsgIdentity_h__
#include "nsIMsgIdentity.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIURI; /* forward declaration */

class nsIStreamListener; /* forward declaration */

class nsIFile; /* forward declaration */

class nsIMsgWindow; /* forward declaration */

class nsIMsgFolder; /* forward declaration */

class nsICacheSession; /* forward declaration */


/* starting interface:    nsINntpService */
#define NS_INNTPSERVICE_IID_STR "dc5cadb0-966c-4ef1-a4c8-cc1e48d1ac61"

#define NS_INNTPSERVICE_IID \
  {0xdc5cadb0, 0x966c, 0x4ef1, \
    { 0xa4, 0xc8, 0xcc, 0x1e, 0x48, 0xd1, 0xac, 0x61 }}

class NS_NO_VTABLE nsINntpService : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_INNTPSERVICE_IID)

  /* void generateNewsHeaderValsForPosting (in ACString newsgroupsList, out string newsgroupsHeaderVal, out string newshostHeaderVal); */
  NS_IMETHOD GenerateNewsHeaderValsForPosting(const nsACString & newsgroupsList, char * *newsgroupsHeaderVal, char * *newshostHeaderVal) = 0;

  /* nsIURI postMessage (in nsIFile aFileToPost, in string newsgroupNames, in string aAccountKey, in nsIUrlListener aUrlListener, in nsIMsgWindow aMsgWindow); */
  NS_IMETHOD PostMessage(nsIFile *aFileToPost, const char * newsgroupNames, const char * aAccountKey, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *_retval) = 0;

  /* nsIURI getNewNews (in nsINntpIncomingServer nntpServer, in string uri, in boolean getOld, in nsIUrlListener aUrlListener, in nsIMsgWindow aMsgWindow); */
  NS_IMETHOD GetNewNews(nsINntpIncomingServer *nntpServer, const char * uri, bool getOld, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *_retval) = 0;

  /* nsIURI cancelMessage (in string cancelURL, in string messageURI, in nsISupports aConsumer, in nsIUrlListener aUrlListener, in nsIMsgWindow aMsgWindow); */
  NS_IMETHOD CancelMessage(const char * cancelURL, const char * messageURI, nsISupports *aConsumer, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *_retval) = 0;

  /* void getListOfGroupsOnServer (in nsINntpIncomingServer nntpServer, in nsIMsgWindow aMsgWindow, in boolean getOnlyNew); */
  NS_IMETHOD GetListOfGroupsOnServer(nsINntpIncomingServer *nntpServer, nsIMsgWindow *aMsgWindow, bool getOnlyNew) = 0;

  /* nsIURI fetchMessage (in nsIMsgFolder newsFolder, in nsMsgKey key, in nsIMsgWindow aMsgWindow, in nsISupports aConsumer, in nsIUrlListener aUrlListener); */
  NS_IMETHOD FetchMessage(nsIMsgFolder *newsFolder, nsMsgKey key, nsIMsgWindow *aMsgWindow, nsISupports *aConsumer, nsIUrlListener *aUrlListener, nsIURI * *_retval) = 0;

  /* void downloadNewsgroupsForOffline (in nsIMsgWindow aMsgWindow, in nsIUrlListener aListener); */
  NS_IMETHOD DownloadNewsgroupsForOffline(nsIMsgWindow *aMsgWindow, nsIUrlListener *aListener) = 0;

  /* void decomposeNewsURI (in string uri, out nsIMsgFolder folder, out nsMsgKey key); */
  NS_IMETHOD DecomposeNewsURI(const char * uri, nsIMsgFolder * *folder, nsMsgKey *key) = 0;

  /* readonly attribute nsICacheSession cacheSession; */
  NS_IMETHOD GetCacheSession(nsICacheSession * *aCacheSession) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsINntpService, NS_INNTPSERVICE_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSINNTPSERVICE \
  NS_IMETHOD GenerateNewsHeaderValsForPosting(const nsACString & newsgroupsList, char * *newsgroupsHeaderVal, char * *newshostHeaderVal); \
  NS_IMETHOD PostMessage(nsIFile *aFileToPost, const char * newsgroupNames, const char * aAccountKey, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *_retval); \
  NS_IMETHOD GetNewNews(nsINntpIncomingServer *nntpServer, const char * uri, bool getOld, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *_retval); \
  NS_IMETHOD CancelMessage(const char * cancelURL, const char * messageURI, nsISupports *aConsumer, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *_retval); \
  NS_IMETHOD GetListOfGroupsOnServer(nsINntpIncomingServer *nntpServer, nsIMsgWindow *aMsgWindow, bool getOnlyNew); \
  NS_IMETHOD FetchMessage(nsIMsgFolder *newsFolder, nsMsgKey key, nsIMsgWindow *aMsgWindow, nsISupports *aConsumer, nsIUrlListener *aUrlListener, nsIURI * *_retval); \
  NS_IMETHOD DownloadNewsgroupsForOffline(nsIMsgWindow *aMsgWindow, nsIUrlListener *aListener); \
  NS_IMETHOD DecomposeNewsURI(const char * uri, nsIMsgFolder * *folder, nsMsgKey *key); \
  NS_IMETHOD GetCacheSession(nsICacheSession * *aCacheSession); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSINNTPSERVICE(_to) \
  NS_IMETHOD GenerateNewsHeaderValsForPosting(const nsACString & newsgroupsList, char * *newsgroupsHeaderVal, char * *newshostHeaderVal) { return _to GenerateNewsHeaderValsForPosting(newsgroupsList, newsgroupsHeaderVal, newshostHeaderVal); } \
  NS_IMETHOD PostMessage(nsIFile *aFileToPost, const char * newsgroupNames, const char * aAccountKey, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *_retval) { return _to PostMessage(aFileToPost, newsgroupNames, aAccountKey, aUrlListener, aMsgWindow, _retval); } \
  NS_IMETHOD GetNewNews(nsINntpIncomingServer *nntpServer, const char * uri, bool getOld, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *_retval) { return _to GetNewNews(nntpServer, uri, getOld, aUrlListener, aMsgWindow, _retval); } \
  NS_IMETHOD CancelMessage(const char * cancelURL, const char * messageURI, nsISupports *aConsumer, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *_retval) { return _to CancelMessage(cancelURL, messageURI, aConsumer, aUrlListener, aMsgWindow, _retval); } \
  NS_IMETHOD GetListOfGroupsOnServer(nsINntpIncomingServer *nntpServer, nsIMsgWindow *aMsgWindow, bool getOnlyNew) { return _to GetListOfGroupsOnServer(nntpServer, aMsgWindow, getOnlyNew); } \
  NS_IMETHOD FetchMessage(nsIMsgFolder *newsFolder, nsMsgKey key, nsIMsgWindow *aMsgWindow, nsISupports *aConsumer, nsIUrlListener *aUrlListener, nsIURI * *_retval) { return _to FetchMessage(newsFolder, key, aMsgWindow, aConsumer, aUrlListener, _retval); } \
  NS_IMETHOD DownloadNewsgroupsForOffline(nsIMsgWindow *aMsgWindow, nsIUrlListener *aListener) { return _to DownloadNewsgroupsForOffline(aMsgWindow, aListener); } \
  NS_IMETHOD DecomposeNewsURI(const char * uri, nsIMsgFolder * *folder, nsMsgKey *key) { return _to DecomposeNewsURI(uri, folder, key); } \
  NS_IMETHOD GetCacheSession(nsICacheSession * *aCacheSession) { return _to GetCacheSession(aCacheSession); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSINNTPSERVICE(_to) \
  NS_IMETHOD GenerateNewsHeaderValsForPosting(const nsACString & newsgroupsList, char * *newsgroupsHeaderVal, char * *newshostHeaderVal) { return !_to ? NS_ERROR_NULL_POINTER : _to->GenerateNewsHeaderValsForPosting(newsgroupsList, newsgroupsHeaderVal, newshostHeaderVal); } \
  NS_IMETHOD PostMessage(nsIFile *aFileToPost, const char * newsgroupNames, const char * aAccountKey, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->PostMessage(aFileToPost, newsgroupNames, aAccountKey, aUrlListener, aMsgWindow, _retval); } \
  NS_IMETHOD GetNewNews(nsINntpIncomingServer *nntpServer, const char * uri, bool getOld, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNewNews(nntpServer, uri, getOld, aUrlListener, aMsgWindow, _retval); } \
  NS_IMETHOD CancelMessage(const char * cancelURL, const char * messageURI, nsISupports *aConsumer, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->CancelMessage(cancelURL, messageURI, aConsumer, aUrlListener, aMsgWindow, _retval); } \
  NS_IMETHOD GetListOfGroupsOnServer(nsINntpIncomingServer *nntpServer, nsIMsgWindow *aMsgWindow, bool getOnlyNew) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetListOfGroupsOnServer(nntpServer, aMsgWindow, getOnlyNew); } \
  NS_IMETHOD FetchMessage(nsIMsgFolder *newsFolder, nsMsgKey key, nsIMsgWindow *aMsgWindow, nsISupports *aConsumer, nsIUrlListener *aUrlListener, nsIURI * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->FetchMessage(newsFolder, key, aMsgWindow, aConsumer, aUrlListener, _retval); } \
  NS_IMETHOD DownloadNewsgroupsForOffline(nsIMsgWindow *aMsgWindow, nsIUrlListener *aListener) { return !_to ? NS_ERROR_NULL_POINTER : _to->DownloadNewsgroupsForOffline(aMsgWindow, aListener); } \
  NS_IMETHOD DecomposeNewsURI(const char * uri, nsIMsgFolder * *folder, nsMsgKey *key) { return !_to ? NS_ERROR_NULL_POINTER : _to->DecomposeNewsURI(uri, folder, key); } \
  NS_IMETHOD GetCacheSession(nsICacheSession * *aCacheSession) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetCacheSession(aCacheSession); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsNntpService : public nsINntpService
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSINNTPSERVICE

  nsNntpService();

private:
  ~nsNntpService();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsNntpService, nsINntpService)

nsNntpService::nsNntpService()
{
  /* member initializers and constructor code */
}

nsNntpService::~nsNntpService()
{
  /* destructor code */
}

/* void generateNewsHeaderValsForPosting (in ACString newsgroupsList, out string newsgroupsHeaderVal, out string newshostHeaderVal); */
NS_IMETHODIMP nsNntpService::GenerateNewsHeaderValsForPosting(const nsACString & newsgroupsList, char * *newsgroupsHeaderVal, char * *newshostHeaderVal)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIURI postMessage (in nsIFile aFileToPost, in string newsgroupNames, in string aAccountKey, in nsIUrlListener aUrlListener, in nsIMsgWindow aMsgWindow); */
NS_IMETHODIMP nsNntpService::PostMessage(nsIFile *aFileToPost, const char * newsgroupNames, const char * aAccountKey, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIURI getNewNews (in nsINntpIncomingServer nntpServer, in string uri, in boolean getOld, in nsIUrlListener aUrlListener, in nsIMsgWindow aMsgWindow); */
NS_IMETHODIMP nsNntpService::GetNewNews(nsINntpIncomingServer *nntpServer, const char * uri, bool getOld, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIURI cancelMessage (in string cancelURL, in string messageURI, in nsISupports aConsumer, in nsIUrlListener aUrlListener, in nsIMsgWindow aMsgWindow); */
NS_IMETHODIMP nsNntpService::CancelMessage(const char * cancelURL, const char * messageURI, nsISupports *aConsumer, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void getListOfGroupsOnServer (in nsINntpIncomingServer nntpServer, in nsIMsgWindow aMsgWindow, in boolean getOnlyNew); */
NS_IMETHODIMP nsNntpService::GetListOfGroupsOnServer(nsINntpIncomingServer *nntpServer, nsIMsgWindow *aMsgWindow, bool getOnlyNew)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIURI fetchMessage (in nsIMsgFolder newsFolder, in nsMsgKey key, in nsIMsgWindow aMsgWindow, in nsISupports aConsumer, in nsIUrlListener aUrlListener); */
NS_IMETHODIMP nsNntpService::FetchMessage(nsIMsgFolder *newsFolder, nsMsgKey key, nsIMsgWindow *aMsgWindow, nsISupports *aConsumer, nsIUrlListener *aUrlListener, nsIURI * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void downloadNewsgroupsForOffline (in nsIMsgWindow aMsgWindow, in nsIUrlListener aListener); */
NS_IMETHODIMP nsNntpService::DownloadNewsgroupsForOffline(nsIMsgWindow *aMsgWindow, nsIUrlListener *aListener)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void decomposeNewsURI (in string uri, out nsIMsgFolder folder, out nsMsgKey key); */
NS_IMETHODIMP nsNntpService::DecomposeNewsURI(const char * uri, nsIMsgFolder * *folder, nsMsgKey *key)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute nsICacheSession cacheSession; */
NS_IMETHODIMP nsNntpService::GetCacheSession(nsICacheSession * *aCacheSession)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsINntpService_h__ */
