/* -*- Mode: IDL; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"
#include "nsMsgSearchCore.idl"
interface nsISupportsArray;

[scriptable, uuid(b07f1cb6-fae9-4d92-9edb-03f9ad249c66)]
interface nsIMsgSearchValidityTable : nsISupports {

    void setAvailable(in nsMsgSearchAttribValue attrib,
                      in nsMsgSearchOpValue op, in boolean active);
    void setEnabled(in nsMsgSearchAttribValue attrib,
                    in nsMsgSearchOpValue op, in boolean enabled);
    void setValidButNotShown(in nsMsgSearchAttribValue attrib,
                             in nsMsgSearchOpValue op, in boolean valid);

    boolean getAvailable(in nsMsgSearchAttribValue attrib,
                         in nsMsgSearchOpValue op);
    boolean getEnabled(in nsMsgSearchAttribValue attrib,
                       in nsMsgSearchOpValue op);
    boolean getValidButNotShown(in nsMsgSearchAttribValue attrib,
                                in nsMsgSearchOpValue op);

    [noscript] void validateTerms(in nsISupportsArray terms);

    readonly attribute long numAvailAttribs;

    void getAvailableAttributes(out unsigned long length,
                                [retval, array, size_is(length)]
                                out nsMsgSearchAttribValue attrs);

    void getAvailableOperators(in nsMsgSearchAttribValue attrib,
                               out unsigned long length,
                               [retval, array, size_is(length)]
                               out nsMsgSearchOpValue operators);

  void setDefaultAttrib(in nsMsgSearchAttribValue defaultAttrib);
};
