/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this file,
 * You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsIDOMEvent.idl"

[scriptable, builtinclass, uuid(ae59b379-1c58-4baa-bef4-21fca57fc4c2)]
interface nsIDOMUserProximityEvent : nsIDOMEvent
{
  [noscript] void initUserProximityEvent(in DOMString eventTypeArg,
                                         in boolean canBubbleArg,
                                         in boolean cancelableArg,
                                         in boolean near);

  readonly attribute boolean near;
};

dictionary UserProximityEventInit : EventInit
{
   boolean near;
};
