/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/local/public/nsIRssService.idl
 */

#ifndef __gen_nsIRssService_h__
#define __gen_nsIRssService_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIRssService */
#define NS_IRSSSERVICE_IID_STR "4b31bdd9-6f4c-46d4-a766-a94f11b599bc"

#define NS_IRSSSERVICE_IID \
  {0x4b31bdd9, 0x6f4c, 0x46d4, \
    { 0xa7, 0x66, 0xa9, 0x4f, 0x11, 0xb5, 0x99, 0xbc }}

class NS_NO_VTABLE nsIRssService : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IRSSSERVICE_IID)

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIRssService, NS_IRSSSERVICE_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIRSSSERVICE \
  /* no methods! */

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIRSSSERVICE(_to) \
  /* no methods! */

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIRSSSERVICE(_to) \
  /* no methods! */

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsRssService : public nsIRssService
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIRSSSERVICE

  nsRssService();

private:
  ~nsRssService();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsRssService, nsIRssService)

nsRssService::nsRssService()
{
  /* member initializers and constructor code */
}

nsRssService::~nsRssService()
{
  /* destructor code */
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIRssService_h__ */
