/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/local/public/nsIPop3Service.idl
 */

#ifndef __gen_nsIPop3Service_h__
#define __gen_nsIPop3Service_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsIUrlListener_h__
#include "nsIUrlListener.h"
#endif

#ifndef __gen_nsIPop3IncomingServer_h__
#include "nsIPop3IncomingServer.h"
#endif

#ifndef __gen_nsIMsgFolder_h__
#include "nsIMsgFolder.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIURI; /* forward declaration */

class nsIStreamListener; /* forward declaration */

class nsIMsgWindow; /* forward declaration */

class nsIMsgFolder; /* forward declaration */


/* starting interface:    nsIPop3ServiceListener */
#define NS_IPOP3SERVICELISTENER_IID_STR "7302fd8e-946f-4ae3-9468-0fb3a7706c51"

#define NS_IPOP3SERVICELISTENER_IID \
  {0x7302fd8e, 0x946f, 0x4ae3, \
    { 0x94, 0x68, 0x0f, 0xb3, 0xa7, 0x70, 0x6c, 0x51 }}

class NS_NO_VTABLE nsIPop3ServiceListener : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IPOP3SERVICELISTENER_IID)

  /* void onDownloadStarted (in nsIMsgFolder aFolder); */
  NS_IMETHOD OnDownloadStarted(nsIMsgFolder *aFolder) = 0;

  /* void onDownloadProgress (in nsIMsgFolder aFolder, in unsigned long aNumDownloaded, in unsigned long aTotalToDownload); */
  NS_IMETHOD OnDownloadProgress(nsIMsgFolder *aFolder, uint32_t aNumDownloaded, uint32_t aTotalToDownload) = 0;

  /* void onDownloadCompleted (in nsIMsgFolder aFolder, in unsigned long aNumberOfMessages); */
  NS_IMETHOD OnDownloadCompleted(nsIMsgFolder *aFolder, uint32_t aNumberOfMessages) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIPop3ServiceListener, NS_IPOP3SERVICELISTENER_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIPOP3SERVICELISTENER \
  NS_IMETHOD OnDownloadStarted(nsIMsgFolder *aFolder); \
  NS_IMETHOD OnDownloadProgress(nsIMsgFolder *aFolder, uint32_t aNumDownloaded, uint32_t aTotalToDownload); \
  NS_IMETHOD OnDownloadCompleted(nsIMsgFolder *aFolder, uint32_t aNumberOfMessages); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIPOP3SERVICELISTENER(_to) \
  NS_IMETHOD OnDownloadStarted(nsIMsgFolder *aFolder) { return _to OnDownloadStarted(aFolder); } \
  NS_IMETHOD OnDownloadProgress(nsIMsgFolder *aFolder, uint32_t aNumDownloaded, uint32_t aTotalToDownload) { return _to OnDownloadProgress(aFolder, aNumDownloaded, aTotalToDownload); } \
  NS_IMETHOD OnDownloadCompleted(nsIMsgFolder *aFolder, uint32_t aNumberOfMessages) { return _to OnDownloadCompleted(aFolder, aNumberOfMessages); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIPOP3SERVICELISTENER(_to) \
  NS_IMETHOD OnDownloadStarted(nsIMsgFolder *aFolder) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnDownloadStarted(aFolder); } \
  NS_IMETHOD OnDownloadProgress(nsIMsgFolder *aFolder, uint32_t aNumDownloaded, uint32_t aTotalToDownload) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnDownloadProgress(aFolder, aNumDownloaded, aTotalToDownload); } \
  NS_IMETHOD OnDownloadCompleted(nsIMsgFolder *aFolder, uint32_t aNumberOfMessages) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnDownloadCompleted(aFolder, aNumberOfMessages); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsPop3ServiceListener : public nsIPop3ServiceListener
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIPOP3SERVICELISTENER

  nsPop3ServiceListener();

private:
  ~nsPop3ServiceListener();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsPop3ServiceListener, nsIPop3ServiceListener)

nsPop3ServiceListener::nsPop3ServiceListener()
{
  /* member initializers and constructor code */
}

nsPop3ServiceListener::~nsPop3ServiceListener()
{
  /* destructor code */
}

/* void onDownloadStarted (in nsIMsgFolder aFolder); */
NS_IMETHODIMP nsPop3ServiceListener::OnDownloadStarted(nsIMsgFolder *aFolder)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void onDownloadProgress (in nsIMsgFolder aFolder, in unsigned long aNumDownloaded, in unsigned long aTotalToDownload); */
NS_IMETHODIMP nsPop3ServiceListener::OnDownloadProgress(nsIMsgFolder *aFolder, uint32_t aNumDownloaded, uint32_t aTotalToDownload)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void onDownloadCompleted (in nsIMsgFolder aFolder, in unsigned long aNumberOfMessages); */
NS_IMETHODIMP nsPop3ServiceListener::OnDownloadCompleted(nsIMsgFolder *aFolder, uint32_t aNumberOfMessages)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


/* starting interface:    nsIPop3Service */
#define NS_IPOP3SERVICE_IID_STR "96d3cc14-a842-4cdf-98f8-a4cc695f8b3b"

#define NS_IPOP3SERVICE_IID \
  {0x96d3cc14, 0xa842, 0x4cdf, \
    { 0x98, 0xf8, 0xa4, 0xcc, 0x69, 0x5f, 0x8b, 0x3b }}

class NS_NO_VTABLE nsIPop3Service : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IPOP3SERVICE_IID)

  /* nsIURI GetNewMail (in nsIMsgWindow aMsgWindow, in nsIUrlListener aUrlListener, in nsIMsgFolder aInbox, in nsIPop3IncomingServer popServer); */
  NS_IMETHOD GetNewMail(nsIMsgWindow *aMsgWindow, nsIUrlListener *aUrlListener, nsIMsgFolder *aInbox, nsIPop3IncomingServer *popServer, nsIURI * *_retval) = 0;

  /* nsIURI CheckForNewMail (in nsIMsgWindow aMsgWindow, in nsIUrlListener aUrlListener, in nsIMsgFolder inbox, in nsIPop3IncomingServer popServer); */
  NS_IMETHOD CheckForNewMail(nsIMsgWindow *aMsgWindow, nsIUrlListener *aUrlListener, nsIMsgFolder *inbox, nsIPop3IncomingServer *popServer, nsIURI * *_retval) = 0;

  /* nsIURI verifyLogon (in nsIMsgIncomingServer aServer, in nsIUrlListener aUrlListener, in nsIMsgWindow aMsgWindow); */
  NS_IMETHOD VerifyLogon(nsIMsgIncomingServer *aServer, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *_retval) = 0;

  /* void addListener (in nsIPop3ServiceListener aListener); */
  NS_IMETHOD AddListener(nsIPop3ServiceListener *aListener) = 0;

  /* void removeListener (in nsIPop3ServiceListener aListener); */
  NS_IMETHOD RemoveListener(nsIPop3ServiceListener *aListener) = 0;

  /* void notifyDownloadStarted (in nsIMsgFolder aFolder); */
  NS_IMETHOD NotifyDownloadStarted(nsIMsgFolder *aFolder) = 0;

  /* void notifyDownloadProgress (in nsIMsgFolder aFolder, in unsigned long aNumDownloaded, in unsigned long aTotalToDownload); */
  NS_IMETHOD NotifyDownloadProgress(nsIMsgFolder *aFolder, uint32_t aNumDownloaded, uint32_t aTotalToDownload) = 0;

  /* void notifyDownloadCompleted (in nsIMsgFolder aFolder, in unsigned long aNumberOfMessages); */
  NS_IMETHOD NotifyDownloadCompleted(nsIMsgFolder *aFolder, uint32_t aNumberOfMessages) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIPop3Service, NS_IPOP3SERVICE_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIPOP3SERVICE \
  NS_IMETHOD GetNewMail(nsIMsgWindow *aMsgWindow, nsIUrlListener *aUrlListener, nsIMsgFolder *aInbox, nsIPop3IncomingServer *popServer, nsIURI * *_retval); \
  NS_IMETHOD CheckForNewMail(nsIMsgWindow *aMsgWindow, nsIUrlListener *aUrlListener, nsIMsgFolder *inbox, nsIPop3IncomingServer *popServer, nsIURI * *_retval); \
  NS_IMETHOD VerifyLogon(nsIMsgIncomingServer *aServer, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *_retval); \
  NS_IMETHOD AddListener(nsIPop3ServiceListener *aListener); \
  NS_IMETHOD RemoveListener(nsIPop3ServiceListener *aListener); \
  NS_IMETHOD NotifyDownloadStarted(nsIMsgFolder *aFolder); \
  NS_IMETHOD NotifyDownloadProgress(nsIMsgFolder *aFolder, uint32_t aNumDownloaded, uint32_t aTotalToDownload); \
  NS_IMETHOD NotifyDownloadCompleted(nsIMsgFolder *aFolder, uint32_t aNumberOfMessages); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIPOP3SERVICE(_to) \
  NS_IMETHOD GetNewMail(nsIMsgWindow *aMsgWindow, nsIUrlListener *aUrlListener, nsIMsgFolder *aInbox, nsIPop3IncomingServer *popServer, nsIURI * *_retval) { return _to GetNewMail(aMsgWindow, aUrlListener, aInbox, popServer, _retval); } \
  NS_IMETHOD CheckForNewMail(nsIMsgWindow *aMsgWindow, nsIUrlListener *aUrlListener, nsIMsgFolder *inbox, nsIPop3IncomingServer *popServer, nsIURI * *_retval) { return _to CheckForNewMail(aMsgWindow, aUrlListener, inbox, popServer, _retval); } \
  NS_IMETHOD VerifyLogon(nsIMsgIncomingServer *aServer, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *_retval) { return _to VerifyLogon(aServer, aUrlListener, aMsgWindow, _retval); } \
  NS_IMETHOD AddListener(nsIPop3ServiceListener *aListener) { return _to AddListener(aListener); } \
  NS_IMETHOD RemoveListener(nsIPop3ServiceListener *aListener) { return _to RemoveListener(aListener); } \
  NS_IMETHOD NotifyDownloadStarted(nsIMsgFolder *aFolder) { return _to NotifyDownloadStarted(aFolder); } \
  NS_IMETHOD NotifyDownloadProgress(nsIMsgFolder *aFolder, uint32_t aNumDownloaded, uint32_t aTotalToDownload) { return _to NotifyDownloadProgress(aFolder, aNumDownloaded, aTotalToDownload); } \
  NS_IMETHOD NotifyDownloadCompleted(nsIMsgFolder *aFolder, uint32_t aNumberOfMessages) { return _to NotifyDownloadCompleted(aFolder, aNumberOfMessages); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIPOP3SERVICE(_to) \
  NS_IMETHOD GetNewMail(nsIMsgWindow *aMsgWindow, nsIUrlListener *aUrlListener, nsIMsgFolder *aInbox, nsIPop3IncomingServer *popServer, nsIURI * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNewMail(aMsgWindow, aUrlListener, aInbox, popServer, _retval); } \
  NS_IMETHOD CheckForNewMail(nsIMsgWindow *aMsgWindow, nsIUrlListener *aUrlListener, nsIMsgFolder *inbox, nsIPop3IncomingServer *popServer, nsIURI * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->CheckForNewMail(aMsgWindow, aUrlListener, inbox, popServer, _retval); } \
  NS_IMETHOD VerifyLogon(nsIMsgIncomingServer *aServer, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->VerifyLogon(aServer, aUrlListener, aMsgWindow, _retval); } \
  NS_IMETHOD AddListener(nsIPop3ServiceListener *aListener) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddListener(aListener); } \
  NS_IMETHOD RemoveListener(nsIPop3ServiceListener *aListener) { return !_to ? NS_ERROR_NULL_POINTER : _to->RemoveListener(aListener); } \
  NS_IMETHOD NotifyDownloadStarted(nsIMsgFolder *aFolder) { return !_to ? NS_ERROR_NULL_POINTER : _to->NotifyDownloadStarted(aFolder); } \
  NS_IMETHOD NotifyDownloadProgress(nsIMsgFolder *aFolder, uint32_t aNumDownloaded, uint32_t aTotalToDownload) { return !_to ? NS_ERROR_NULL_POINTER : _to->NotifyDownloadProgress(aFolder, aNumDownloaded, aTotalToDownload); } \
  NS_IMETHOD NotifyDownloadCompleted(nsIMsgFolder *aFolder, uint32_t aNumberOfMessages) { return !_to ? NS_ERROR_NULL_POINTER : _to->NotifyDownloadCompleted(aFolder, aNumberOfMessages); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsPop3Service : public nsIPop3Service
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIPOP3SERVICE

  nsPop3Service();

private:
  ~nsPop3Service();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsPop3Service, nsIPop3Service)

nsPop3Service::nsPop3Service()
{
  /* member initializers and constructor code */
}

nsPop3Service::~nsPop3Service()
{
  /* destructor code */
}

/* nsIURI GetNewMail (in nsIMsgWindow aMsgWindow, in nsIUrlListener aUrlListener, in nsIMsgFolder aInbox, in nsIPop3IncomingServer popServer); */
NS_IMETHODIMP nsPop3Service::GetNewMail(nsIMsgWindow *aMsgWindow, nsIUrlListener *aUrlListener, nsIMsgFolder *aInbox, nsIPop3IncomingServer *popServer, nsIURI * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIURI CheckForNewMail (in nsIMsgWindow aMsgWindow, in nsIUrlListener aUrlListener, in nsIMsgFolder inbox, in nsIPop3IncomingServer popServer); */
NS_IMETHODIMP nsPop3Service::CheckForNewMail(nsIMsgWindow *aMsgWindow, nsIUrlListener *aUrlListener, nsIMsgFolder *inbox, nsIPop3IncomingServer *popServer, nsIURI * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIURI verifyLogon (in nsIMsgIncomingServer aServer, in nsIUrlListener aUrlListener, in nsIMsgWindow aMsgWindow); */
NS_IMETHODIMP nsPop3Service::VerifyLogon(nsIMsgIncomingServer *aServer, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void addListener (in nsIPop3ServiceListener aListener); */
NS_IMETHODIMP nsPop3Service::AddListener(nsIPop3ServiceListener *aListener)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void removeListener (in nsIPop3ServiceListener aListener); */
NS_IMETHODIMP nsPop3Service::RemoveListener(nsIPop3ServiceListener *aListener)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void notifyDownloadStarted (in nsIMsgFolder aFolder); */
NS_IMETHODIMP nsPop3Service::NotifyDownloadStarted(nsIMsgFolder *aFolder)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void notifyDownloadProgress (in nsIMsgFolder aFolder, in unsigned long aNumDownloaded, in unsigned long aTotalToDownload); */
NS_IMETHODIMP nsPop3Service::NotifyDownloadProgress(nsIMsgFolder *aFolder, uint32_t aNumDownloaded, uint32_t aTotalToDownload)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void notifyDownloadCompleted (in nsIMsgFolder aFolder, in unsigned long aNumberOfMessages); */
NS_IMETHODIMP nsPop3Service::NotifyDownloadCompleted(nsIMsgFolder *aFolder, uint32_t aNumberOfMessages)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIPop3Service_h__ */
