/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/extensions/smime/public/nsISMimeJSHelper.idl
 */

#ifndef __gen_nsISMimeJSHelper_h__
#define __gen_nsISMimeJSHelper_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIMsgCompFields; /* forward declaration */

class nsIX509Cert; /* forward declaration */


/* starting interface:    nsISMimeJSHelper */
#define NS_ISMIMEJSHELPER_IID_STR "a54e3c8f-a000-4901-898f-fafb297b1546"

#define NS_ISMIMEJSHELPER_IID \
  {0xa54e3c8f, 0xa000, 0x4901, \
    { 0x89, 0x8f, 0xfa, 0xfb, 0x29, 0x7b, 0x15, 0x46 }}

class NS_NO_VTABLE nsISMimeJSHelper : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_ISMIMEJSHELPER_IID)

  /* void getRecipientCertsInfo (in nsIMsgCompFields compFields, out unsigned long count, [array, size_is (count)] out wstring emailAddresses, [array, size_is (count)] out long certVerification, [array, size_is (count)] out wstring certIssuedInfos, [array, size_is (count)] out wstring certExpiresInfos, [array, size_is (count)] out nsIX509Cert certs, out boolean canEncrypt); */
  NS_IMETHOD GetRecipientCertsInfo(nsIMsgCompFields *compFields, uint32_t *count, PRUnichar * **emailAddresses, int32_t **certVerification, PRUnichar * **certIssuedInfos, PRUnichar * **certExpiresInfos, nsIX509Cert * **certs, bool *canEncrypt) = 0;

  /* void getNoCertAddresses (in nsIMsgCompFields compFields, out unsigned long count, [array, size_is (count)] out wstring emailAddresses); */
  NS_IMETHOD GetNoCertAddresses(nsIMsgCompFields *compFields, uint32_t *count, PRUnichar * **emailAddresses) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsISMimeJSHelper, NS_ISMIMEJSHELPER_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSISMIMEJSHELPER \
  NS_IMETHOD GetRecipientCertsInfo(nsIMsgCompFields *compFields, uint32_t *count, PRUnichar * **emailAddresses, int32_t **certVerification, PRUnichar * **certIssuedInfos, PRUnichar * **certExpiresInfos, nsIX509Cert * **certs, bool *canEncrypt); \
  NS_IMETHOD GetNoCertAddresses(nsIMsgCompFields *compFields, uint32_t *count, PRUnichar * **emailAddresses); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSISMIMEJSHELPER(_to) \
  NS_IMETHOD GetRecipientCertsInfo(nsIMsgCompFields *compFields, uint32_t *count, PRUnichar * **emailAddresses, int32_t **certVerification, PRUnichar * **certIssuedInfos, PRUnichar * **certExpiresInfos, nsIX509Cert * **certs, bool *canEncrypt) { return _to GetRecipientCertsInfo(compFields, count, emailAddresses, certVerification, certIssuedInfos, certExpiresInfos, certs, canEncrypt); } \
  NS_IMETHOD GetNoCertAddresses(nsIMsgCompFields *compFields, uint32_t *count, PRUnichar * **emailAddresses) { return _to GetNoCertAddresses(compFields, count, emailAddresses); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSISMIMEJSHELPER(_to) \
  NS_IMETHOD GetRecipientCertsInfo(nsIMsgCompFields *compFields, uint32_t *count, PRUnichar * **emailAddresses, int32_t **certVerification, PRUnichar * **certIssuedInfos, PRUnichar * **certExpiresInfos, nsIX509Cert * **certs, bool *canEncrypt) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetRecipientCertsInfo(compFields, count, emailAddresses, certVerification, certIssuedInfos, certExpiresInfos, certs, canEncrypt); } \
  NS_IMETHOD GetNoCertAddresses(nsIMsgCompFields *compFields, uint32_t *count, PRUnichar * **emailAddresses) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNoCertAddresses(compFields, count, emailAddresses); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsSMimeJSHelper : public nsISMimeJSHelper
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSISMIMEJSHELPER

  nsSMimeJSHelper();

private:
  ~nsSMimeJSHelper();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsSMimeJSHelper, nsISMimeJSHelper)

nsSMimeJSHelper::nsSMimeJSHelper()
{
  /* member initializers and constructor code */
}

nsSMimeJSHelper::~nsSMimeJSHelper()
{
  /* destructor code */
}

/* void getRecipientCertsInfo (in nsIMsgCompFields compFields, out unsigned long count, [array, size_is (count)] out wstring emailAddresses, [array, size_is (count)] out long certVerification, [array, size_is (count)] out wstring certIssuedInfos, [array, size_is (count)] out wstring certExpiresInfos, [array, size_is (count)] out nsIX509Cert certs, out boolean canEncrypt); */
NS_IMETHODIMP nsSMimeJSHelper::GetRecipientCertsInfo(nsIMsgCompFields *compFields, uint32_t *count, PRUnichar * **emailAddresses, int32_t **certVerification, PRUnichar * **certIssuedInfos, PRUnichar * **certExpiresInfos, nsIX509Cert * **certs, bool *canEncrypt)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void getNoCertAddresses (in nsIMsgCompFields compFields, out unsigned long count, [array, size_is (count)] out wstring emailAddresses); */
NS_IMETHODIMP nsSMimeJSHelper::GetNoCertAddresses(nsIMsgCompFields *compFields, uint32_t *count, PRUnichar * **emailAddresses)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsISMimeJSHelper_h__ */
