/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* vim:set ts=2 sw=2 sts=2 et cindent: */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsIProtocolProxyService.idl"

/**
 * An extension of nsIProtocolProxyService
 */
[scriptable, uuid(dbd9565d-29b1-437a-bff5-2fc339e2c5df)]
interface nsIProtocolProxyService2 : nsIProtocolProxyService
{
  /**
   * Call this method to cause the PAC file (if any is configured) to be
   * reloaded.  The PAC file is loaded asynchronously.
   */
  void reloadPAC();
};
