/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/base/search/public/nsIMsgSearchScopeTerm.idl
 */

#ifndef __gen_nsIMsgSearchScopeTerm_h__
#define __gen_nsIMsgSearchScopeTerm_h__


#ifndef __gen_nsIMsgSearchSession_h__
#include "nsIMsgSearchSession.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIFile; /* forward declaration */

class nsIMsgFolder; /* forward declaration */

class nsIMsgDBHdr; /* forward declaration */

class nsILineInputStream; /* forward declaration */


/* starting interface:    nsIMsgSearchScopeTerm */
#define NS_IMSGSEARCHSCOPETERM_IID_STR "934672c3-9b8f-488a-935d-87b4023fa0be"

#define NS_IMSGSEARCHSCOPETERM_IID \
  {0x934672c3, 0x9b8f, 0x488a, \
    { 0x93, 0x5d, 0x87, 0xb4, 0x02, 0x3f, 0xa0, 0xbe }}

class NS_NO_VTABLE nsIMsgSearchScopeTerm : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IMSGSEARCHSCOPETERM_IID)

  /* nsIInputStream getInputStream (in nsIMsgDBHdr aHdr); */
  NS_IMETHOD GetInputStream(nsIMsgDBHdr *aHdr, nsIInputStream * *_retval) = 0;

  /* void closeInputStream (); */
  NS_IMETHOD CloseInputStream(void) = 0;

  /* readonly attribute nsIMsgFolder folder; */
  NS_IMETHOD GetFolder(nsIMsgFolder * *aFolder) = 0;

  /* readonly attribute nsIMsgSearchSession searchSession; */
  NS_IMETHOD GetSearchSession(nsIMsgSearchSession * *aSearchSession) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIMsgSearchScopeTerm, NS_IMSGSEARCHSCOPETERM_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGSEARCHSCOPETERM \
  NS_IMETHOD GetInputStream(nsIMsgDBHdr *aHdr, nsIInputStream * *_retval); \
  NS_IMETHOD CloseInputStream(void); \
  NS_IMETHOD GetFolder(nsIMsgFolder * *aFolder); \
  NS_IMETHOD GetSearchSession(nsIMsgSearchSession * *aSearchSession); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGSEARCHSCOPETERM(_to) \
  NS_IMETHOD GetInputStream(nsIMsgDBHdr *aHdr, nsIInputStream * *_retval) { return _to GetInputStream(aHdr, _retval); } \
  NS_IMETHOD CloseInputStream(void) { return _to CloseInputStream(); } \
  NS_IMETHOD GetFolder(nsIMsgFolder * *aFolder) { return _to GetFolder(aFolder); } \
  NS_IMETHOD GetSearchSession(nsIMsgSearchSession * *aSearchSession) { return _to GetSearchSession(aSearchSession); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGSEARCHSCOPETERM(_to) \
  NS_IMETHOD GetInputStream(nsIMsgDBHdr *aHdr, nsIInputStream * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetInputStream(aHdr, _retval); } \
  NS_IMETHOD CloseInputStream(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->CloseInputStream(); } \
  NS_IMETHOD GetFolder(nsIMsgFolder * *aFolder) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFolder(aFolder); } \
  NS_IMETHOD GetSearchSession(nsIMsgSearchSession * *aSearchSession) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSearchSession(aSearchSession); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgSearchScopeTerm : public nsIMsgSearchScopeTerm
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGSEARCHSCOPETERM

  nsMsgSearchScopeTerm();

private:
  ~nsMsgSearchScopeTerm();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgSearchScopeTerm, nsIMsgSearchScopeTerm)

nsMsgSearchScopeTerm::nsMsgSearchScopeTerm()
{
  /* member initializers and constructor code */
}

nsMsgSearchScopeTerm::~nsMsgSearchScopeTerm()
{
  /* destructor code */
}

/* nsIInputStream getInputStream (in nsIMsgDBHdr aHdr); */
NS_IMETHODIMP nsMsgSearchScopeTerm::GetInputStream(nsIMsgDBHdr *aHdr, nsIInputStream * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void closeInputStream (); */
NS_IMETHODIMP nsMsgSearchScopeTerm::CloseInputStream()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute nsIMsgFolder folder; */
NS_IMETHODIMP nsMsgSearchScopeTerm::GetFolder(nsIMsgFolder * *aFolder)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute nsIMsgSearchSession searchSession; */
NS_IMETHODIMP nsMsgSearchScopeTerm::GetSearchSession(nsIMsgSearchSession * *aSearchSession)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgSearchScopeTerm_h__ */
