/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/base/public/mozINewMailListener.idl
 */

#ifndef __gen_mozINewMailListener_h__
#define __gen_mozINewMailListener_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    mozINewMailListener */
#define MOZINEWMAILLISTENER_IID_STR "e15f104f-a16d-4e51-a362-4b4c5efe05b9"

#define MOZINEWMAILLISTENER_IID \
  {0xe15f104f, 0xa16d, 0x4e51, \
    { 0xa3, 0x62, 0x4b, 0x4c, 0x5e, 0xfe, 0x05, 0xb9 }}

class NS_NO_VTABLE mozINewMailListener : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(MOZINEWMAILLISTENER_IID)

  /* void onCountChanged (in unsigned long count); */
  NS_IMETHOD OnCountChanged(uint32_t count) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(mozINewMailListener, MOZINEWMAILLISTENER_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_MOZINEWMAILLISTENER \
  NS_IMETHOD OnCountChanged(uint32_t count); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_MOZINEWMAILLISTENER(_to) \
  NS_IMETHOD OnCountChanged(uint32_t count) { return _to OnCountChanged(count); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_MOZINEWMAILLISTENER(_to) \
  NS_IMETHOD OnCountChanged(uint32_t count) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnCountChanged(count); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public mozINewMailListener
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_MOZINEWMAILLISTENER

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, mozINewMailListener)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* void onCountChanged (in unsigned long count); */
NS_IMETHODIMP _MYCLASS_::OnCountChanged(uint32_t count)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_mozINewMailListener_h__ */
