/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"
#include "nsIFile.idl"

%{C++
      
#define NS_PROFILE_CID                                 \
  { /* {02b0625b-e7f3-11d2-9f5a-006008a6efe9} */       \
    0x02b0625b,                                        \
    0xe7f3,                                            \
    0x11d2,                                            \
    { 0x9f, 0x5a, 0x00, 0x60, 0x08, 0xa6, 0xef, 0xe9 } \
  }

#define NS_PROFILE_CONTRACTID	\
	"@mozilla.org/profile/manager;1"

#define NS_PROFILE_STARTUP_CATEGORY \
        "profile-startup-category"
%}

/**
 * nsIProfile
 * 
 * @version 1.0
 */

[scriptable, uuid(02b0625a-e7f3-11d2-9f5a-006008a6efe9)]
interface nsIProfile : nsISupports {
    
    readonly attribute long profileCount;
    void getProfileList(out unsigned long length, [retval, array, size_is(length)] out wstring profileNames); 
    boolean profileExists(in wstring profileName);

    attribute wstring currentProfile;

    const unsigned long SHUTDOWN_PERSIST      = 0x00000001;
    const unsigned long SHUTDOWN_CLEANSE      = 0x00000002;
    
    void shutDownCurrentProfile(in unsigned long shutDownType);

    void createNewProfile(in wstring profileName, 
                          in wstring nativeProfileDir, 
                          in wstring langcode,
                          in boolean useExistingDir);    

    void renameProfile(in wstring oldName, in wstring newName);
    void deleteProfile(in wstring name, in boolean canDeleteFiles);
    void cloneProfile(in wstring profileName);
};
