/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this file,
 * You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "domstubs.idl"

[scriptable, uuid(995DFF99-ED70-4780-AC9A-4B58CD491186)]
interface nsIDOMDeviceStorageCursor : nsISupports
{
    void continue();
};
