/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/addrbook/public/nsIAbBooleanExpression.idl
 */

#ifndef __gen_nsIAbBooleanExpression_h__
#define __gen_nsIAbBooleanExpression_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIArray; /* forward declaration */

typedef int32_t  nsAbBooleanConditionType;


/* starting interface:    nsIAbBooleanConditionTypes */
#define NS_IABBOOLEANCONDITIONTYPES_IID_STR "f51387b1-5aef-4a1c-830e-7cd3b02366ce"

#define NS_IABBOOLEANCONDITIONTYPES_IID \
  {0xf51387b1, 0x5aef, 0x4a1c, \
    { 0x83, 0x0e, 0x7c, 0xd3, 0xb0, 0x23, 0x66, 0xce }}

class NS_NO_VTABLE nsIAbBooleanConditionTypes {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IABBOOLEANCONDITIONTYPES_IID)

  enum {
    Exists = 0,
    DoesNotExist = 1,
    Contains = 2,
    DoesNotContain = 3,
    Is = 4,
    IsNot = 5,
    BeginsWith = 6,
    EndsWith = 7,
    LessThan = 8,
    GreaterThan = 9,
    SoundsLike = 10,
    RegExp = 11
  };

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIAbBooleanConditionTypes, NS_IABBOOLEANCONDITIONTYPES_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIABBOOLEANCONDITIONTYPES \

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIABBOOLEANCONDITIONTYPES(_to) \

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIABBOOLEANCONDITIONTYPES(_to) \

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsAbBooleanConditionTypes : public nsIAbBooleanConditionTypes
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIABBOOLEANCONDITIONTYPES

  nsAbBooleanConditionTypes();

private:
  ~nsAbBooleanConditionTypes();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsAbBooleanConditionTypes, nsIAbBooleanConditionTypes)

nsAbBooleanConditionTypes::nsAbBooleanConditionTypes()
{
  /* member initializers and constructor code */
}

nsAbBooleanConditionTypes::~nsAbBooleanConditionTypes()
{
  /* destructor code */
}

/* End of implementation class template. */
#endif

typedef int32_t  nsAbBooleanOperationType;


/* starting interface:    nsIAbBooleanOperationTypes */
#define NS_IABBOOLEANOPERATIONTYPES_IID_STR "9bdd2e51-2be4-49a4-a558-36d1a812231a"

#define NS_IABBOOLEANOPERATIONTYPES_IID \
  {0x9bdd2e51, 0x2be4, 0x49a4, \
    { 0xa5, 0x58, 0x36, 0xd1, 0xa8, 0x12, 0x23, 0x1a }}

class NS_NO_VTABLE nsIAbBooleanOperationTypes {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IABBOOLEANOPERATIONTYPES_IID)

  enum {
    AND = 0,
    OR = 1,
    NOT = 2
  };

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIAbBooleanOperationTypes, NS_IABBOOLEANOPERATIONTYPES_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIABBOOLEANOPERATIONTYPES \

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIABBOOLEANOPERATIONTYPES(_to) \

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIABBOOLEANOPERATIONTYPES(_to) \

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsAbBooleanOperationTypes : public nsIAbBooleanOperationTypes
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIABBOOLEANOPERATIONTYPES

  nsAbBooleanOperationTypes();

private:
  ~nsAbBooleanOperationTypes();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsAbBooleanOperationTypes, nsIAbBooleanOperationTypes)

nsAbBooleanOperationTypes::nsAbBooleanOperationTypes()
{
  /* member initializers and constructor code */
}

nsAbBooleanOperationTypes::~nsAbBooleanOperationTypes()
{
  /* destructor code */
}

/* End of implementation class template. */
#endif


/* starting interface:    nsIAbBooleanConditionString */
#define NS_IABBOOLEANCONDITIONSTRING_IID_STR "c3869d72-cfd0-45f0-a0ec-3f67d83c7110"

#define NS_IABBOOLEANCONDITIONSTRING_IID \
  {0xc3869d72, 0xcfd0, 0x45f0, \
    { 0xa0, 0xec, 0x3f, 0x67, 0xd8, 0x3c, 0x71, 0x10 }}

class NS_NO_VTABLE nsIAbBooleanConditionString : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IABBOOLEANCONDITIONSTRING_IID)

  /* attribute nsAbBooleanConditionType condition; */
  NS_IMETHOD GetCondition(nsAbBooleanConditionType *aCondition) = 0;
  NS_IMETHOD SetCondition(nsAbBooleanConditionType aCondition) = 0;

  /* attribute string name; */
  NS_IMETHOD GetName(char * *aName) = 0;
  NS_IMETHOD SetName(const char * aName) = 0;

  /* attribute wstring value; */
  NS_IMETHOD GetValue(PRUnichar * *aValue) = 0;
  NS_IMETHOD SetValue(const PRUnichar * aValue) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIAbBooleanConditionString, NS_IABBOOLEANCONDITIONSTRING_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIABBOOLEANCONDITIONSTRING \
  NS_IMETHOD GetCondition(nsAbBooleanConditionType *aCondition); \
  NS_IMETHOD SetCondition(nsAbBooleanConditionType aCondition); \
  NS_IMETHOD GetName(char * *aName); \
  NS_IMETHOD SetName(const char * aName); \
  NS_IMETHOD GetValue(PRUnichar * *aValue); \
  NS_IMETHOD SetValue(const PRUnichar * aValue); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIABBOOLEANCONDITIONSTRING(_to) \
  NS_IMETHOD GetCondition(nsAbBooleanConditionType *aCondition) { return _to GetCondition(aCondition); } \
  NS_IMETHOD SetCondition(nsAbBooleanConditionType aCondition) { return _to SetCondition(aCondition); } \
  NS_IMETHOD GetName(char * *aName) { return _to GetName(aName); } \
  NS_IMETHOD SetName(const char * aName) { return _to SetName(aName); } \
  NS_IMETHOD GetValue(PRUnichar * *aValue) { return _to GetValue(aValue); } \
  NS_IMETHOD SetValue(const PRUnichar * aValue) { return _to SetValue(aValue); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIABBOOLEANCONDITIONSTRING(_to) \
  NS_IMETHOD GetCondition(nsAbBooleanConditionType *aCondition) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetCondition(aCondition); } \
  NS_IMETHOD SetCondition(nsAbBooleanConditionType aCondition) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetCondition(aCondition); } \
  NS_IMETHOD GetName(char * *aName) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetName(aName); } \
  NS_IMETHOD SetName(const char * aName) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetName(aName); } \
  NS_IMETHOD GetValue(PRUnichar * *aValue) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetValue(aValue); } \
  NS_IMETHOD SetValue(const PRUnichar * aValue) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetValue(aValue); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsAbBooleanConditionString : public nsIAbBooleanConditionString
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIABBOOLEANCONDITIONSTRING

  nsAbBooleanConditionString();

private:
  ~nsAbBooleanConditionString();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsAbBooleanConditionString, nsIAbBooleanConditionString)

nsAbBooleanConditionString::nsAbBooleanConditionString()
{
  /* member initializers and constructor code */
}

nsAbBooleanConditionString::~nsAbBooleanConditionString()
{
  /* destructor code */
}

/* attribute nsAbBooleanConditionType condition; */
NS_IMETHODIMP nsAbBooleanConditionString::GetCondition(nsAbBooleanConditionType *aCondition)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsAbBooleanConditionString::SetCondition(nsAbBooleanConditionType aCondition)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute string name; */
NS_IMETHODIMP nsAbBooleanConditionString::GetName(char * *aName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsAbBooleanConditionString::SetName(const char * aName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute wstring value; */
NS_IMETHODIMP nsAbBooleanConditionString::GetValue(PRUnichar * *aValue)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsAbBooleanConditionString::SetValue(const PRUnichar * aValue)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


/* starting interface:    nsIAbBooleanExpression */
#define NS_IABBOOLEANEXPRESSION_IID_STR "223a9462-1aeb-4c1f-b069-5fc6278989b2"

#define NS_IABBOOLEANEXPRESSION_IID \
  {0x223a9462, 0x1aeb, 0x4c1f, \
    { 0xb0, 0x69, 0x5f, 0xc6, 0x27, 0x89, 0x89, 0xb2 }}

class NS_NO_VTABLE nsIAbBooleanExpression : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IABBOOLEANEXPRESSION_IID)

  /* attribute nsAbBooleanOperationType operation; */
  NS_IMETHOD GetOperation(nsAbBooleanOperationType *aOperation) = 0;
  NS_IMETHOD SetOperation(nsAbBooleanOperationType aOperation) = 0;

  /* attribute nsIArray expressions; */
  NS_IMETHOD GetExpressions(nsIArray * *aExpressions) = 0;
  NS_IMETHOD SetExpressions(nsIArray *aExpressions) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIAbBooleanExpression, NS_IABBOOLEANEXPRESSION_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIABBOOLEANEXPRESSION \
  NS_IMETHOD GetOperation(nsAbBooleanOperationType *aOperation); \
  NS_IMETHOD SetOperation(nsAbBooleanOperationType aOperation); \
  NS_IMETHOD GetExpressions(nsIArray * *aExpressions); \
  NS_IMETHOD SetExpressions(nsIArray *aExpressions); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIABBOOLEANEXPRESSION(_to) \
  NS_IMETHOD GetOperation(nsAbBooleanOperationType *aOperation) { return _to GetOperation(aOperation); } \
  NS_IMETHOD SetOperation(nsAbBooleanOperationType aOperation) { return _to SetOperation(aOperation); } \
  NS_IMETHOD GetExpressions(nsIArray * *aExpressions) { return _to GetExpressions(aExpressions); } \
  NS_IMETHOD SetExpressions(nsIArray *aExpressions) { return _to SetExpressions(aExpressions); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIABBOOLEANEXPRESSION(_to) \
  NS_IMETHOD GetOperation(nsAbBooleanOperationType *aOperation) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetOperation(aOperation); } \
  NS_IMETHOD SetOperation(nsAbBooleanOperationType aOperation) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetOperation(aOperation); } \
  NS_IMETHOD GetExpressions(nsIArray * *aExpressions) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetExpressions(aExpressions); } \
  NS_IMETHOD SetExpressions(nsIArray *aExpressions) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetExpressions(aExpressions); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsAbBooleanExpression : public nsIAbBooleanExpression
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIABBOOLEANEXPRESSION

  nsAbBooleanExpression();

private:
  ~nsAbBooleanExpression();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsAbBooleanExpression, nsIAbBooleanExpression)

nsAbBooleanExpression::nsAbBooleanExpression()
{
  /* member initializers and constructor code */
}

nsAbBooleanExpression::~nsAbBooleanExpression()
{
  /* destructor code */
}

/* attribute nsAbBooleanOperationType operation; */
NS_IMETHODIMP nsAbBooleanExpression::GetOperation(nsAbBooleanOperationType *aOperation)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsAbBooleanExpression::SetOperation(nsAbBooleanOperationType aOperation)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsIArray expressions; */
NS_IMETHODIMP nsAbBooleanExpression::GetExpressions(nsIArray * *aExpressions)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsAbBooleanExpression::SetExpressions(nsIArray *aExpressions)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIAbBooleanExpression_h__ */
