/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/compose/public/nsIMsgSendLater.idl
 */

#ifndef __gen_nsIMsgSendLater_h__
#define __gen_nsIMsgSendLater_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsIStreamListener_h__
#include "nsIStreamListener.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIMsgStatusFeedback; /* forward declaration */

class nsIMsgIdentity; /* forward declaration */

class nsIMsgSendLaterListener; /* forward declaration */

class nsIMsgFolder; /* forward declaration */


/* starting interface:    nsIMsgSendLater */
#define NS_IMSGSENDLATER_IID_STR "fa324a4b-4b87-4e9a-a3c0-af9071a358df"

#define NS_IMSGSENDLATER_IID \
  {0xfa324a4b, 0x4b87, 0x4e9a, \
    { 0xa3, 0xc0, 0xaf, 0x90, 0x71, 0xa3, 0x58, 0xdf }}

class NS_NO_VTABLE nsIMsgSendLater : public nsIStreamListener {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IMSGSENDLATER_IID)

  /* attribute nsIMsgStatusFeedback statusFeedback; */
  NS_IMETHOD GetStatusFeedback(nsIMsgStatusFeedback * *aStatusFeedback) = 0;
  NS_IMETHOD SetStatusFeedback(nsIMsgStatusFeedback *aStatusFeedback) = 0;

  /* void sendUnsentMessages (in nsIMsgIdentity aIdentity); */
  NS_IMETHOD SendUnsentMessages(nsIMsgIdentity *aIdentity) = 0;

  /* void addListener (in nsIMsgSendLaterListener aListener); */
  NS_IMETHOD AddListener(nsIMsgSendLaterListener *aListener) = 0;

  /* void removeListener (in nsIMsgSendLaterListener aListener); */
  NS_IMETHOD RemoveListener(nsIMsgSendLaterListener *aListener) = 0;

  /* nsIMsgFolder getUnsentMessagesFolder (in nsIMsgIdentity userIdentity); */
  NS_IMETHOD GetUnsentMessagesFolder(nsIMsgIdentity *userIdentity, nsIMsgFolder * *_retval) = 0;

  /* boolean hasUnsentMessages ([optional] in nsIMsgIdentity aIdentity); */
  NS_IMETHOD HasUnsentMessages(nsIMsgIdentity *aIdentity, bool *_retval) = 0;

  /* readonly attribute boolean sendingMessages; */
  NS_IMETHOD GetSendingMessages(bool *aSendingMessages) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIMsgSendLater, NS_IMSGSENDLATER_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGSENDLATER \
  NS_IMETHOD GetStatusFeedback(nsIMsgStatusFeedback * *aStatusFeedback); \
  NS_IMETHOD SetStatusFeedback(nsIMsgStatusFeedback *aStatusFeedback); \
  NS_IMETHOD SendUnsentMessages(nsIMsgIdentity *aIdentity); \
  NS_IMETHOD AddListener(nsIMsgSendLaterListener *aListener); \
  NS_IMETHOD RemoveListener(nsIMsgSendLaterListener *aListener); \
  NS_IMETHOD GetUnsentMessagesFolder(nsIMsgIdentity *userIdentity, nsIMsgFolder * *_retval); \
  NS_IMETHOD HasUnsentMessages(nsIMsgIdentity *aIdentity, bool *_retval); \
  NS_IMETHOD GetSendingMessages(bool *aSendingMessages); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGSENDLATER(_to) \
  NS_IMETHOD GetStatusFeedback(nsIMsgStatusFeedback * *aStatusFeedback) { return _to GetStatusFeedback(aStatusFeedback); } \
  NS_IMETHOD SetStatusFeedback(nsIMsgStatusFeedback *aStatusFeedback) { return _to SetStatusFeedback(aStatusFeedback); } \
  NS_IMETHOD SendUnsentMessages(nsIMsgIdentity *aIdentity) { return _to SendUnsentMessages(aIdentity); } \
  NS_IMETHOD AddListener(nsIMsgSendLaterListener *aListener) { return _to AddListener(aListener); } \
  NS_IMETHOD RemoveListener(nsIMsgSendLaterListener *aListener) { return _to RemoveListener(aListener); } \
  NS_IMETHOD GetUnsentMessagesFolder(nsIMsgIdentity *userIdentity, nsIMsgFolder * *_retval) { return _to GetUnsentMessagesFolder(userIdentity, _retval); } \
  NS_IMETHOD HasUnsentMessages(nsIMsgIdentity *aIdentity, bool *_retval) { return _to HasUnsentMessages(aIdentity, _retval); } \
  NS_IMETHOD GetSendingMessages(bool *aSendingMessages) { return _to GetSendingMessages(aSendingMessages); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGSENDLATER(_to) \
  NS_IMETHOD GetStatusFeedback(nsIMsgStatusFeedback * *aStatusFeedback) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetStatusFeedback(aStatusFeedback); } \
  NS_IMETHOD SetStatusFeedback(nsIMsgStatusFeedback *aStatusFeedback) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetStatusFeedback(aStatusFeedback); } \
  NS_IMETHOD SendUnsentMessages(nsIMsgIdentity *aIdentity) { return !_to ? NS_ERROR_NULL_POINTER : _to->SendUnsentMessages(aIdentity); } \
  NS_IMETHOD AddListener(nsIMsgSendLaterListener *aListener) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddListener(aListener); } \
  NS_IMETHOD RemoveListener(nsIMsgSendLaterListener *aListener) { return !_to ? NS_ERROR_NULL_POINTER : _to->RemoveListener(aListener); } \
  NS_IMETHOD GetUnsentMessagesFolder(nsIMsgIdentity *userIdentity, nsIMsgFolder * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetUnsentMessagesFolder(userIdentity, _retval); } \
  NS_IMETHOD HasUnsentMessages(nsIMsgIdentity *aIdentity, bool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->HasUnsentMessages(aIdentity, _retval); } \
  NS_IMETHOD GetSendingMessages(bool *aSendingMessages) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSendingMessages(aSendingMessages); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgSendLater : public nsIMsgSendLater
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGSENDLATER

  nsMsgSendLater();

private:
  ~nsMsgSendLater();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgSendLater, nsIMsgSendLater)

nsMsgSendLater::nsMsgSendLater()
{
  /* member initializers and constructor code */
}

nsMsgSendLater::~nsMsgSendLater()
{
  /* destructor code */
}

/* attribute nsIMsgStatusFeedback statusFeedback; */
NS_IMETHODIMP nsMsgSendLater::GetStatusFeedback(nsIMsgStatusFeedback * *aStatusFeedback)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgSendLater::SetStatusFeedback(nsIMsgStatusFeedback *aStatusFeedback)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void sendUnsentMessages (in nsIMsgIdentity aIdentity); */
NS_IMETHODIMP nsMsgSendLater::SendUnsentMessages(nsIMsgIdentity *aIdentity)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void addListener (in nsIMsgSendLaterListener aListener); */
NS_IMETHODIMP nsMsgSendLater::AddListener(nsIMsgSendLaterListener *aListener)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void removeListener (in nsIMsgSendLaterListener aListener); */
NS_IMETHODIMP nsMsgSendLater::RemoveListener(nsIMsgSendLaterListener *aListener)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIMsgFolder getUnsentMessagesFolder (in nsIMsgIdentity userIdentity); */
NS_IMETHODIMP nsMsgSendLater::GetUnsentMessagesFolder(nsIMsgIdentity *userIdentity, nsIMsgFolder * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean hasUnsentMessages ([optional] in nsIMsgIdentity aIdentity); */
NS_IMETHODIMP nsMsgSendLater::HasUnsentMessages(nsIMsgIdentity *aIdentity, bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean sendingMessages; */
NS_IMETHODIMP nsMsgSendLater::GetSendingMessages(bool *aSendingMessages)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgSendLater_h__ */
