/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/import/public/nsIImportABDescriptor.idl
 */

#ifndef __gen_nsIImportABDescriptor_h__
#define __gen_nsIImportABDescriptor_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIFile; /* forward declaration */


/* starting interface:    nsIImportABDescriptor */
#define NS_IIMPORTABDESCRIPTOR_IID_STR "2d8983b2-cea6-4ae2-9145-eb772481fa18"

#define NS_IIMPORTABDESCRIPTOR_IID \
  {0x2d8983b2, 0xcea6, 0x4ae2, \
    { 0x91, 0x45, 0xeb, 0x77, 0x24, 0x81, 0xfa, 0x18 }}

class NS_NO_VTABLE nsIImportABDescriptor : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IIMPORTABDESCRIPTOR_IID)

  /* attribute unsigned long identifier; */
  NS_IMETHOD GetIdentifier(uint32_t *aIdentifier) = 0;
  NS_IMETHOD SetIdentifier(uint32_t aIdentifier) = 0;

  /* attribute unsigned long ref; */
  NS_IMETHOD GetRef(uint32_t *aRef) = 0;
  NS_IMETHOD SetRef(uint32_t aRef) = 0;

  /* attribute unsigned long size; */
  NS_IMETHOD GetSize(uint32_t *aSize) = 0;
  NS_IMETHOD SetSize(uint32_t aSize) = 0;

  /* attribute AString preferredName; */
  NS_IMETHOD GetPreferredName(nsAString & aPreferredName) = 0;
  NS_IMETHOD SetPreferredName(const nsAString & aPreferredName) = 0;

  /* attribute nsIFile abFile; */
  NS_IMETHOD GetAbFile(nsIFile * *aAbFile) = 0;
  NS_IMETHOD SetAbFile(nsIFile *aAbFile) = 0;

  /* attribute boolean import; */
  NS_IMETHOD GetImport(bool *aImport) = 0;
  NS_IMETHOD SetImport(bool aImport) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIImportABDescriptor, NS_IIMPORTABDESCRIPTOR_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIIMPORTABDESCRIPTOR \
  NS_IMETHOD GetIdentifier(uint32_t *aIdentifier); \
  NS_IMETHOD SetIdentifier(uint32_t aIdentifier); \
  NS_IMETHOD GetRef(uint32_t *aRef); \
  NS_IMETHOD SetRef(uint32_t aRef); \
  NS_IMETHOD GetSize(uint32_t *aSize); \
  NS_IMETHOD SetSize(uint32_t aSize); \
  NS_IMETHOD GetPreferredName(nsAString & aPreferredName); \
  NS_IMETHOD SetPreferredName(const nsAString & aPreferredName); \
  NS_IMETHOD GetAbFile(nsIFile * *aAbFile); \
  NS_IMETHOD SetAbFile(nsIFile *aAbFile); \
  NS_IMETHOD GetImport(bool *aImport); \
  NS_IMETHOD SetImport(bool aImport); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIIMPORTABDESCRIPTOR(_to) \
  NS_IMETHOD GetIdentifier(uint32_t *aIdentifier) { return _to GetIdentifier(aIdentifier); } \
  NS_IMETHOD SetIdentifier(uint32_t aIdentifier) { return _to SetIdentifier(aIdentifier); } \
  NS_IMETHOD GetRef(uint32_t *aRef) { return _to GetRef(aRef); } \
  NS_IMETHOD SetRef(uint32_t aRef) { return _to SetRef(aRef); } \
  NS_IMETHOD GetSize(uint32_t *aSize) { return _to GetSize(aSize); } \
  NS_IMETHOD SetSize(uint32_t aSize) { return _to SetSize(aSize); } \
  NS_IMETHOD GetPreferredName(nsAString & aPreferredName) { return _to GetPreferredName(aPreferredName); } \
  NS_IMETHOD SetPreferredName(const nsAString & aPreferredName) { return _to SetPreferredName(aPreferredName); } \
  NS_IMETHOD GetAbFile(nsIFile * *aAbFile) { return _to GetAbFile(aAbFile); } \
  NS_IMETHOD SetAbFile(nsIFile *aAbFile) { return _to SetAbFile(aAbFile); } \
  NS_IMETHOD GetImport(bool *aImport) { return _to GetImport(aImport); } \
  NS_IMETHOD SetImport(bool aImport) { return _to SetImport(aImport); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIIMPORTABDESCRIPTOR(_to) \
  NS_IMETHOD GetIdentifier(uint32_t *aIdentifier) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetIdentifier(aIdentifier); } \
  NS_IMETHOD SetIdentifier(uint32_t aIdentifier) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetIdentifier(aIdentifier); } \
  NS_IMETHOD GetRef(uint32_t *aRef) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetRef(aRef); } \
  NS_IMETHOD SetRef(uint32_t aRef) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetRef(aRef); } \
  NS_IMETHOD GetSize(uint32_t *aSize) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSize(aSize); } \
  NS_IMETHOD SetSize(uint32_t aSize) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetSize(aSize); } \
  NS_IMETHOD GetPreferredName(nsAString & aPreferredName) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetPreferredName(aPreferredName); } \
  NS_IMETHOD SetPreferredName(const nsAString & aPreferredName) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetPreferredName(aPreferredName); } \
  NS_IMETHOD GetAbFile(nsIFile * *aAbFile) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetAbFile(aAbFile); } \
  NS_IMETHOD SetAbFile(nsIFile *aAbFile) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetAbFile(aAbFile); } \
  NS_IMETHOD GetImport(bool *aImport) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetImport(aImport); } \
  NS_IMETHOD SetImport(bool aImport) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetImport(aImport); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsImportABDescriptor : public nsIImportABDescriptor
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIIMPORTABDESCRIPTOR

  nsImportABDescriptor();

private:
  ~nsImportABDescriptor();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsImportABDescriptor, nsIImportABDescriptor)

nsImportABDescriptor::nsImportABDescriptor()
{
  /* member initializers and constructor code */
}

nsImportABDescriptor::~nsImportABDescriptor()
{
  /* destructor code */
}

/* attribute unsigned long identifier; */
NS_IMETHODIMP nsImportABDescriptor::GetIdentifier(uint32_t *aIdentifier)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsImportABDescriptor::SetIdentifier(uint32_t aIdentifier)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute unsigned long ref; */
NS_IMETHODIMP nsImportABDescriptor::GetRef(uint32_t *aRef)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsImportABDescriptor::SetRef(uint32_t aRef)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute unsigned long size; */
NS_IMETHODIMP nsImportABDescriptor::GetSize(uint32_t *aSize)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsImportABDescriptor::SetSize(uint32_t aSize)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute AString preferredName; */
NS_IMETHODIMP nsImportABDescriptor::GetPreferredName(nsAString & aPreferredName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsImportABDescriptor::SetPreferredName(const nsAString & aPreferredName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsIFile abFile; */
NS_IMETHODIMP nsImportABDescriptor::GetAbFile(nsIFile * *aAbFile)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsImportABDescriptor::SetAbFile(nsIFile *aAbFile)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean import; */
NS_IMETHODIMP nsImportABDescriptor::GetImport(bool *aImport)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsImportABDescriptor::SetImport(bool aImport)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIImportABDescriptor_h__ */
