/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"

/*
 * This interface can be used to give access to a private 'inner'
 * interface when an xtf element is accessed through its wrapper (or
 * more precisely: accessed through one of the wrapper-generated
 * nsXTFInterfaceAggregator proxies). For JS-implemented XTF elements
 * the inner interface can be used to gain access to the underlying
 * JSObject using xpconnect's "wrappedJSObject" mechanism (see
 * nsIXPConnect.idl).
 */

[scriptable, uuid(13ef3d54-1dd1-4a5c-a8d5-a04a327fb9b6)]
interface nsIXTFPrivate : nsISupports
{
  readonly attribute nsISupports inner;
};
