/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/base/public/nsIMessengerOSIntegration.idl
 */

#ifndef __gen_nsIMessengerOSIntegration_h__
#define __gen_nsIMessengerOSIntegration_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIMessengerOSIntegration */
#define NS_IMESSENGEROSINTEGRATION_IID_STR "d9e45fee-1dd1-11b2-938c-9147855ed837"

#define NS_IMESSENGEROSINTEGRATION_IID \
  {0xd9e45fee, 0x1dd1, 0x11b2, \
    { 0x93, 0x8c, 0x91, 0x47, 0x85, 0x5e, 0xd8, 0x37 }}

class NS_NO_VTABLE nsIMessengerOSIntegration : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IMESSENGEROSINTEGRATION_IID)

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIMessengerOSIntegration, NS_IMESSENGEROSINTEGRATION_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMESSENGEROSINTEGRATION \
  /* no methods! */

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMESSENGEROSINTEGRATION(_to) \
  /* no methods! */

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMESSENGEROSINTEGRATION(_to) \
  /* no methods! */

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMessengerOSIntegration : public nsIMessengerOSIntegration
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMESSENGEROSINTEGRATION

  nsMessengerOSIntegration();

private:
  ~nsMessengerOSIntegration();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMessengerOSIntegration, nsIMessengerOSIntegration)

nsMessengerOSIntegration::nsMessengerOSIntegration()
{
  /* member initializers and constructor code */
}

nsMessengerOSIntegration::~nsMessengerOSIntegration()
{
  /* destructor code */
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMessengerOSIntegration_h__ */
