/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */


/* This is a private interface used exclusively by SMIME. NO ONE outside of extensions/smime
   should have any knowledge nor should be referring to this interface. 
*/

#include "nsISupports.idl"

[scriptable, uuid(338E91F9-5970-4f81-B771-0822A32B1161)]
interface nsIMsgSMIMECompFields : nsISupports 
{
  attribute boolean signMessage;
  attribute boolean requireEncryptMessage;
};
