/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */


#include "nsIAbDirectoryQuery.idl"

[scriptable, uuid(b8034849-1e98-4d39-819c-15ba61a7434f)]
interface nsIAbDirectoryQueryProxy : nsIAbDirectoryQuery
{
    void initiate();
};

