/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/ldap/xpcom/public/nsILDAPOperation.idl
 */

#ifndef __gen_nsILDAPOperation_h__
#define __gen_nsILDAPOperation_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsILDAPConnection_h__
#include "nsILDAPConnection.h"
#endif

#ifndef __gen_nsIAuthModule_h__
#include "nsIAuthModule.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsILDAPMessage; /* forward declaration */

class nsILDAPMessageListener; /* forward declaration */

class nsILDAPModification; /* forward declaration */

class nsIMutableArray; /* forward declaration */

class nsIArray; /* forward declaration */

#define NS_LDAPOPERATION_CONTRACTID "@mozilla.org/network/ldap-operation;1" 
typedef uint32_t  PRIntervalTime;


/* starting interface:    nsILDAPOperation */
#define NS_ILDAPOPERATION_IID_STR "4dfb1b19-fc8f-4525-92e7-f97b78a9747a"

#define NS_ILDAPOPERATION_IID \
  {0x4dfb1b19, 0xfc8f, 0x4525, \
    { 0x92, 0xe7, 0xf9, 0x7b, 0x78, 0xa9, 0x74, 0x7a }}

class NS_NO_VTABLE nsILDAPOperation : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_ILDAPOPERATION_IID)

  /* readonly attribute nsILDAPConnection connection; */
  NS_IMETHOD GetConnection(nsILDAPConnection * *aConnection) = 0;

  /* readonly attribute nsILDAPMessageListener messageListener; */
  NS_IMETHOD GetMessageListener(nsILDAPMessageListener * *aMessageListener) = 0;

  /* readonly attribute long messageID; */
  NS_IMETHOD GetMessageID(int32_t *aMessageID) = 0;

  /* attribute nsISupports closure; */
  NS_IMETHOD GetClosure(nsISupports * *aClosure) = 0;
  NS_IMETHOD SetClosure(nsISupports *aClosure) = 0;

  enum {
    NO_LIMIT = 0
  };

  /* attribute nsIMutableArray serverControls; */
  NS_IMETHOD GetServerControls(nsIMutableArray * *aServerControls) = 0;
  NS_IMETHOD SetServerControls(nsIMutableArray *aServerControls) = 0;

  /* attribute nsIMutableArray clientControls; */
  NS_IMETHOD GetClientControls(nsIMutableArray * *aClientControls) = 0;
  NS_IMETHOD SetClientControls(nsIMutableArray *aClientControls) = 0;

  /* void init (in nsILDAPConnection aConnection, in nsILDAPMessageListener aMessageListener, in nsISupports aClosure); */
  NS_IMETHOD Init(nsILDAPConnection *aConnection, nsILDAPMessageListener *aMessageListener, nsISupports *aClosure) = 0;

  /* void simpleBind (in AUTF8String passwd); */
  NS_IMETHOD SimpleBind(const nsACString & passwd) = 0;

  /* void saslBind (in ACString service, in ACString mechanism, in nsIAuthModule authModule); */
  NS_IMETHOD SaslBind(const nsACString & service, const nsACString & mechanism, nsIAuthModule *authModule) = 0;

  /* void saslStep (in string token, in unsigned long tokenLen); */
  NS_IMETHOD SaslStep(const char * token, uint32_t tokenLen) = 0;

  /* void addExt (in AUTF8String aBaseDn, in nsIArray aMods); */
  NS_IMETHOD AddExt(const nsACString & aBaseDn, nsIArray *aMods) = 0;

  /* void deleteExt (in AUTF8String aBaseDn); */
  NS_IMETHOD DeleteExt(const nsACString & aBaseDn) = 0;

  /* void modifyExt (in AUTF8String aBaseDn, in nsIArray aMods); */
  NS_IMETHOD ModifyExt(const nsACString & aBaseDn, nsIArray *aMods) = 0;

  /* void rename (in AUTF8String aBaseDn, in AUTF8String aNewRDn, in AUTF8String aNewParent, in boolean aDeleteOldRDn); */
  NS_IMETHOD Rename(const nsACString & aBaseDn, const nsACString & aNewRDn, const nsACString & aNewParent, bool aDeleteOldRDn) = 0;

  /* void searchExt (in AUTF8String aBaseDn, in int32_t aScope, in AUTF8String aFilter, in ACString aAttributes, in PRIntervalTime aTimeOut, in int32_t aSizeLimit); */
  NS_IMETHOD SearchExt(const nsACString & aBaseDn, int32_t aScope, const nsACString & aFilter, const nsACString & aAttributes, PRIntervalTime aTimeOut, int32_t aSizeLimit) = 0;

  /* void abandonExt (); */
  NS_IMETHOD AbandonExt(void) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsILDAPOperation, NS_ILDAPOPERATION_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSILDAPOPERATION \
  NS_IMETHOD GetConnection(nsILDAPConnection * *aConnection); \
  NS_IMETHOD GetMessageListener(nsILDAPMessageListener * *aMessageListener); \
  NS_IMETHOD GetMessageID(int32_t *aMessageID); \
  NS_IMETHOD GetClosure(nsISupports * *aClosure); \
  NS_IMETHOD SetClosure(nsISupports *aClosure); \
  NS_IMETHOD GetServerControls(nsIMutableArray * *aServerControls); \
  NS_IMETHOD SetServerControls(nsIMutableArray *aServerControls); \
  NS_IMETHOD GetClientControls(nsIMutableArray * *aClientControls); \
  NS_IMETHOD SetClientControls(nsIMutableArray *aClientControls); \
  NS_IMETHOD Init(nsILDAPConnection *aConnection, nsILDAPMessageListener *aMessageListener, nsISupports *aClosure); \
  NS_IMETHOD SimpleBind(const nsACString & passwd); \
  NS_IMETHOD SaslBind(const nsACString & service, const nsACString & mechanism, nsIAuthModule *authModule); \
  NS_IMETHOD SaslStep(const char * token, uint32_t tokenLen); \
  NS_IMETHOD AddExt(const nsACString & aBaseDn, nsIArray *aMods); \
  NS_IMETHOD DeleteExt(const nsACString & aBaseDn); \
  NS_IMETHOD ModifyExt(const nsACString & aBaseDn, nsIArray *aMods); \
  NS_IMETHOD Rename(const nsACString & aBaseDn, const nsACString & aNewRDn, const nsACString & aNewParent, bool aDeleteOldRDn); \
  NS_IMETHOD SearchExt(const nsACString & aBaseDn, int32_t aScope, const nsACString & aFilter, const nsACString & aAttributes, PRIntervalTime aTimeOut, int32_t aSizeLimit); \
  NS_IMETHOD AbandonExt(void); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSILDAPOPERATION(_to) \
  NS_IMETHOD GetConnection(nsILDAPConnection * *aConnection) { return _to GetConnection(aConnection); } \
  NS_IMETHOD GetMessageListener(nsILDAPMessageListener * *aMessageListener) { return _to GetMessageListener(aMessageListener); } \
  NS_IMETHOD GetMessageID(int32_t *aMessageID) { return _to GetMessageID(aMessageID); } \
  NS_IMETHOD GetClosure(nsISupports * *aClosure) { return _to GetClosure(aClosure); } \
  NS_IMETHOD SetClosure(nsISupports *aClosure) { return _to SetClosure(aClosure); } \
  NS_IMETHOD GetServerControls(nsIMutableArray * *aServerControls) { return _to GetServerControls(aServerControls); } \
  NS_IMETHOD SetServerControls(nsIMutableArray *aServerControls) { return _to SetServerControls(aServerControls); } \
  NS_IMETHOD GetClientControls(nsIMutableArray * *aClientControls) { return _to GetClientControls(aClientControls); } \
  NS_IMETHOD SetClientControls(nsIMutableArray *aClientControls) { return _to SetClientControls(aClientControls); } \
  NS_IMETHOD Init(nsILDAPConnection *aConnection, nsILDAPMessageListener *aMessageListener, nsISupports *aClosure) { return _to Init(aConnection, aMessageListener, aClosure); } \
  NS_IMETHOD SimpleBind(const nsACString & passwd) { return _to SimpleBind(passwd); } \
  NS_IMETHOD SaslBind(const nsACString & service, const nsACString & mechanism, nsIAuthModule *authModule) { return _to SaslBind(service, mechanism, authModule); } \
  NS_IMETHOD SaslStep(const char * token, uint32_t tokenLen) { return _to SaslStep(token, tokenLen); } \
  NS_IMETHOD AddExt(const nsACString & aBaseDn, nsIArray *aMods) { return _to AddExt(aBaseDn, aMods); } \
  NS_IMETHOD DeleteExt(const nsACString & aBaseDn) { return _to DeleteExt(aBaseDn); } \
  NS_IMETHOD ModifyExt(const nsACString & aBaseDn, nsIArray *aMods) { return _to ModifyExt(aBaseDn, aMods); } \
  NS_IMETHOD Rename(const nsACString & aBaseDn, const nsACString & aNewRDn, const nsACString & aNewParent, bool aDeleteOldRDn) { return _to Rename(aBaseDn, aNewRDn, aNewParent, aDeleteOldRDn); } \
  NS_IMETHOD SearchExt(const nsACString & aBaseDn, int32_t aScope, const nsACString & aFilter, const nsACString & aAttributes, PRIntervalTime aTimeOut, int32_t aSizeLimit) { return _to SearchExt(aBaseDn, aScope, aFilter, aAttributes, aTimeOut, aSizeLimit); } \
  NS_IMETHOD AbandonExt(void) { return _to AbandonExt(); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSILDAPOPERATION(_to) \
  NS_IMETHOD GetConnection(nsILDAPConnection * *aConnection) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetConnection(aConnection); } \
  NS_IMETHOD GetMessageListener(nsILDAPMessageListener * *aMessageListener) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMessageListener(aMessageListener); } \
  NS_IMETHOD GetMessageID(int32_t *aMessageID) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMessageID(aMessageID); } \
  NS_IMETHOD GetClosure(nsISupports * *aClosure) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetClosure(aClosure); } \
  NS_IMETHOD SetClosure(nsISupports *aClosure) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetClosure(aClosure); } \
  NS_IMETHOD GetServerControls(nsIMutableArray * *aServerControls) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetServerControls(aServerControls); } \
  NS_IMETHOD SetServerControls(nsIMutableArray *aServerControls) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetServerControls(aServerControls); } \
  NS_IMETHOD GetClientControls(nsIMutableArray * *aClientControls) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetClientControls(aClientControls); } \
  NS_IMETHOD SetClientControls(nsIMutableArray *aClientControls) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetClientControls(aClientControls); } \
  NS_IMETHOD Init(nsILDAPConnection *aConnection, nsILDAPMessageListener *aMessageListener, nsISupports *aClosure) { return !_to ? NS_ERROR_NULL_POINTER : _to->Init(aConnection, aMessageListener, aClosure); } \
  NS_IMETHOD SimpleBind(const nsACString & passwd) { return !_to ? NS_ERROR_NULL_POINTER : _to->SimpleBind(passwd); } \
  NS_IMETHOD SaslBind(const nsACString & service, const nsACString & mechanism, nsIAuthModule *authModule) { return !_to ? NS_ERROR_NULL_POINTER : _to->SaslBind(service, mechanism, authModule); } \
  NS_IMETHOD SaslStep(const char * token, uint32_t tokenLen) { return !_to ? NS_ERROR_NULL_POINTER : _to->SaslStep(token, tokenLen); } \
  NS_IMETHOD AddExt(const nsACString & aBaseDn, nsIArray *aMods) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddExt(aBaseDn, aMods); } \
  NS_IMETHOD DeleteExt(const nsACString & aBaseDn) { return !_to ? NS_ERROR_NULL_POINTER : _to->DeleteExt(aBaseDn); } \
  NS_IMETHOD ModifyExt(const nsACString & aBaseDn, nsIArray *aMods) { return !_to ? NS_ERROR_NULL_POINTER : _to->ModifyExt(aBaseDn, aMods); } \
  NS_IMETHOD Rename(const nsACString & aBaseDn, const nsACString & aNewRDn, const nsACString & aNewParent, bool aDeleteOldRDn) { return !_to ? NS_ERROR_NULL_POINTER : _to->Rename(aBaseDn, aNewRDn, aNewParent, aDeleteOldRDn); } \
  NS_IMETHOD SearchExt(const nsACString & aBaseDn, int32_t aScope, const nsACString & aFilter, const nsACString & aAttributes, PRIntervalTime aTimeOut, int32_t aSizeLimit) { return !_to ? NS_ERROR_NULL_POINTER : _to->SearchExt(aBaseDn, aScope, aFilter, aAttributes, aTimeOut, aSizeLimit); } \
  NS_IMETHOD AbandonExt(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->AbandonExt(); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsLDAPOperation : public nsILDAPOperation
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSILDAPOPERATION

  nsLDAPOperation();

private:
  ~nsLDAPOperation();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsLDAPOperation, nsILDAPOperation)

nsLDAPOperation::nsLDAPOperation()
{
  /* member initializers and constructor code */
}

nsLDAPOperation::~nsLDAPOperation()
{
  /* destructor code */
}

/* readonly attribute nsILDAPConnection connection; */
NS_IMETHODIMP nsLDAPOperation::GetConnection(nsILDAPConnection * *aConnection)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute nsILDAPMessageListener messageListener; */
NS_IMETHODIMP nsLDAPOperation::GetMessageListener(nsILDAPMessageListener * *aMessageListener)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute long messageID; */
NS_IMETHODIMP nsLDAPOperation::GetMessageID(int32_t *aMessageID)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsISupports closure; */
NS_IMETHODIMP nsLDAPOperation::GetClosure(nsISupports * *aClosure)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsLDAPOperation::SetClosure(nsISupports *aClosure)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsIMutableArray serverControls; */
NS_IMETHODIMP nsLDAPOperation::GetServerControls(nsIMutableArray * *aServerControls)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsLDAPOperation::SetServerControls(nsIMutableArray *aServerControls)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsIMutableArray clientControls; */
NS_IMETHODIMP nsLDAPOperation::GetClientControls(nsIMutableArray * *aClientControls)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsLDAPOperation::SetClientControls(nsIMutableArray *aClientControls)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void init (in nsILDAPConnection aConnection, in nsILDAPMessageListener aMessageListener, in nsISupports aClosure); */
NS_IMETHODIMP nsLDAPOperation::Init(nsILDAPConnection *aConnection, nsILDAPMessageListener *aMessageListener, nsISupports *aClosure)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void simpleBind (in AUTF8String passwd); */
NS_IMETHODIMP nsLDAPOperation::SimpleBind(const nsACString & passwd)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void saslBind (in ACString service, in ACString mechanism, in nsIAuthModule authModule); */
NS_IMETHODIMP nsLDAPOperation::SaslBind(const nsACString & service, const nsACString & mechanism, nsIAuthModule *authModule)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void saslStep (in string token, in unsigned long tokenLen); */
NS_IMETHODIMP nsLDAPOperation::SaslStep(const char * token, uint32_t tokenLen)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void addExt (in AUTF8String aBaseDn, in nsIArray aMods); */
NS_IMETHODIMP nsLDAPOperation::AddExt(const nsACString & aBaseDn, nsIArray *aMods)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void deleteExt (in AUTF8String aBaseDn); */
NS_IMETHODIMP nsLDAPOperation::DeleteExt(const nsACString & aBaseDn)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void modifyExt (in AUTF8String aBaseDn, in nsIArray aMods); */
NS_IMETHODIMP nsLDAPOperation::ModifyExt(const nsACString & aBaseDn, nsIArray *aMods)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void rename (in AUTF8String aBaseDn, in AUTF8String aNewRDn, in AUTF8String aNewParent, in boolean aDeleteOldRDn); */
NS_IMETHODIMP nsLDAPOperation::Rename(const nsACString & aBaseDn, const nsACString & aNewRDn, const nsACString & aNewParent, bool aDeleteOldRDn)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void searchExt (in AUTF8String aBaseDn, in int32_t aScope, in AUTF8String aFilter, in ACString aAttributes, in PRIntervalTime aTimeOut, in int32_t aSizeLimit); */
NS_IMETHODIMP nsLDAPOperation::SearchExt(const nsACString & aBaseDn, int32_t aScope, const nsACString & aFilter, const nsACString & aAttributes, PRIntervalTime aTimeOut, int32_t aSizeLimit)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void abandonExt (); */
NS_IMETHODIMP nsLDAPOperation::AbandonExt()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsILDAPOperation_h__ */
