/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/local/public/nsILocalMailIncomingServer.idl
 */

#ifndef __gen_nsILocalMailIncomingServer_h__
#define __gen_nsILocalMailIncomingServer_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIURI; /* forward declaration */

class nsIMsgWindow; /* forward declaration */

class nsIUrlListener; /* forward declaration */

class nsIMsgFolder; /* forward declaration */

class nsIFile; /* forward declaration */


/* starting interface:    nsILocalMailIncomingServer */
#define NS_ILOCALMAILINCOMINGSERVER_IID_STR "e710d72c-9328-4bcb-8b8f-dd7ac18e2156"

#define NS_ILOCALMAILINCOMINGSERVER_IID \
  {0xe710d72c, 0x9328, 0x4bcb, \
    { 0x8b, 0x8f, 0xdd, 0x7a, 0xc1, 0x8e, 0x21, 0x56 }}

class NS_NO_VTABLE nsILocalMailIncomingServer : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_ILOCALMAILINCOMINGSERVER_IID)

  /* void createDefaultMailboxes (in nsIFile aPath); */
  NS_IMETHOD CreateDefaultMailboxes(nsIFile *aPath) = 0;

  /* void setFlagsOnDefaultMailboxes (); */
  NS_IMETHOD SetFlagsOnDefaultMailboxes(void) = 0;

  /* nsIURI getNewMail (in nsIMsgWindow aMsgWindow, in nsIUrlListener aUrlListener, in nsIMsgFolder aInbox); */
  NS_IMETHOD GetNewMail(nsIMsgWindow *aMsgWindow, nsIUrlListener *aUrlListener, nsIMsgFolder *aInbox, nsIURI * *_retval) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsILocalMailIncomingServer, NS_ILOCALMAILINCOMINGSERVER_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSILOCALMAILINCOMINGSERVER \
  NS_IMETHOD CreateDefaultMailboxes(nsIFile *aPath); \
  NS_IMETHOD SetFlagsOnDefaultMailboxes(void); \
  NS_IMETHOD GetNewMail(nsIMsgWindow *aMsgWindow, nsIUrlListener *aUrlListener, nsIMsgFolder *aInbox, nsIURI * *_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSILOCALMAILINCOMINGSERVER(_to) \
  NS_IMETHOD CreateDefaultMailboxes(nsIFile *aPath) { return _to CreateDefaultMailboxes(aPath); } \
  NS_IMETHOD SetFlagsOnDefaultMailboxes(void) { return _to SetFlagsOnDefaultMailboxes(); } \
  NS_IMETHOD GetNewMail(nsIMsgWindow *aMsgWindow, nsIUrlListener *aUrlListener, nsIMsgFolder *aInbox, nsIURI * *_retval) { return _to GetNewMail(aMsgWindow, aUrlListener, aInbox, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSILOCALMAILINCOMINGSERVER(_to) \
  NS_IMETHOD CreateDefaultMailboxes(nsIFile *aPath) { return !_to ? NS_ERROR_NULL_POINTER : _to->CreateDefaultMailboxes(aPath); } \
  NS_IMETHOD SetFlagsOnDefaultMailboxes(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetFlagsOnDefaultMailboxes(); } \
  NS_IMETHOD GetNewMail(nsIMsgWindow *aMsgWindow, nsIUrlListener *aUrlListener, nsIMsgFolder *aInbox, nsIURI * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNewMail(aMsgWindow, aUrlListener, aInbox, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsLocalMailIncomingServer : public nsILocalMailIncomingServer
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSILOCALMAILINCOMINGSERVER

  nsLocalMailIncomingServer();

private:
  ~nsLocalMailIncomingServer();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsLocalMailIncomingServer, nsILocalMailIncomingServer)

nsLocalMailIncomingServer::nsLocalMailIncomingServer()
{
  /* member initializers and constructor code */
}

nsLocalMailIncomingServer::~nsLocalMailIncomingServer()
{
  /* destructor code */
}

/* void createDefaultMailboxes (in nsIFile aPath); */
NS_IMETHODIMP nsLocalMailIncomingServer::CreateDefaultMailboxes(nsIFile *aPath)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setFlagsOnDefaultMailboxes (); */
NS_IMETHODIMP nsLocalMailIncomingServer::SetFlagsOnDefaultMailboxes()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIURI getNewMail (in nsIMsgWindow aMsgWindow, in nsIUrlListener aUrlListener, in nsIMsgFolder aInbox); */
NS_IMETHODIMP nsLocalMailIncomingServer::GetNewMail(nsIMsgWindow *aMsgWindow, nsIUrlListener *aUrlListener, nsIMsgFolder *aInbox, nsIURI * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsILocalMailIncomingServer_h__ */
