/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsIDOMCSSRule.idl"

[scriptable, uuid(a6cf90bd-15b3-11d2-932e-00805f8add32)]
interface nsIDOMCSSPageRule : nsIDOMCSSRule
{
           attribute DOMString        selectorText;
                                        // raises(DOMException) on setting

  readonly attribute nsIDOMCSSStyleDeclaration  style;
};
