/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */


#include "nsISupports.idl"

interface nsIAutoCompleteResult;
interface nsIDOMHTMLInputElement;

[scriptable, uuid(997c0c05-5d1d-47e5-9cbc-765c0b8ec699)]

interface nsIFormAutoComplete: nsISupports {
    /**
     * Generate results for a form input autocomplete menu.
     */
    nsIAutoCompleteResult autoCompleteSearch(
                                    in AString aInputName,
                                    in AString aSearchString,
                                    in nsIDOMHTMLInputElement aField,
                                    in nsIAutoCompleteResult aPreviousResult);
};
