/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"
#include "nsIMsgFolder.idl"
#include "nsICopyMessageListener.idl"

[scriptable, uuid(7741DAEC-2125-11d3-8A90-0060B0FC04D2)]

interface nsICopyMessageStreamListener: nsISupports
{
  void Init(in nsIMsgFolder srcFolder, in nsICopyMessageListener destination, in nsISupports listenerData);
  void StartMessage();
  void EndMessage(in nsMsgKey key);
  void EndCopy(in nsISupports url, in nsresult aStatus);
};
