/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/compose/public/nsIMsgSendLaterListener.idl
 */

#ifndef __gen_nsIMsgSendLaterListener_h__
#define __gen_nsIMsgSendLaterListener_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIMsgDBHdr; /* forward declaration */

class nsIMsgIdentity; /* forward declaration */


/* starting interface:    nsIMsgSendLaterListener */
#define NS_IMSGSENDLATERLISTENER_IID_STR "a7bc603b-d0da-4959-a82f-4b99c138b9f4"

#define NS_IMSGSENDLATERLISTENER_IID \
  {0xa7bc603b, 0xd0da, 0x4959, \
    { 0xa8, 0x2f, 0x4b, 0x99, 0xc1, 0x38, 0xb9, 0xf4 }}

class NS_NO_VTABLE nsIMsgSendLaterListener : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IMSGSENDLATERLISTENER_IID)

  /* void onStartSending (in unsigned long aTotalMessageCount); */
  NS_IMETHOD OnStartSending(uint32_t aTotalMessageCount) = 0;

  /* void onMessageStartSending (in unsigned long aCurrentMessage, in unsigned long aTotalMessageCount, in nsIMsgDBHdr aMessageHeader, in nsIMsgIdentity aIdentity); */
  NS_IMETHOD OnMessageStartSending(uint32_t aCurrentMessage, uint32_t aTotalMessageCount, nsIMsgDBHdr *aMessageHeader, nsIMsgIdentity *aIdentity) = 0;

  /* void onMessageSendProgress (in unsigned long aCurrentMessage, in unsigned long aTotalMessageCount, in unsigned long aMessageSendPercent, in unsigned long aMessageCopyPercent); */
  NS_IMETHOD OnMessageSendProgress(uint32_t aCurrentMessage, uint32_t aTotalMessageCount, uint32_t aMessageSendPercent, uint32_t aMessageCopyPercent) = 0;

  /* void onMessageSendError (in unsigned long aCurrentMessage, in nsIMsgDBHdr aMessageHeader, in nsresult aStatus, in wstring aMsg); */
  NS_IMETHOD OnMessageSendError(uint32_t aCurrentMessage, nsIMsgDBHdr *aMessageHeader, nsresult aStatus, const PRUnichar * aMsg) = 0;

  /* void onStopSending (in nsresult aStatus, in wstring aMsg, in unsigned long aTotalTried, in unsigned long aSuccessful); */
  NS_IMETHOD OnStopSending(nsresult aStatus, const PRUnichar * aMsg, uint32_t aTotalTried, uint32_t aSuccessful) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIMsgSendLaterListener, NS_IMSGSENDLATERLISTENER_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGSENDLATERLISTENER \
  NS_IMETHOD OnStartSending(uint32_t aTotalMessageCount); \
  NS_IMETHOD OnMessageStartSending(uint32_t aCurrentMessage, uint32_t aTotalMessageCount, nsIMsgDBHdr *aMessageHeader, nsIMsgIdentity *aIdentity); \
  NS_IMETHOD OnMessageSendProgress(uint32_t aCurrentMessage, uint32_t aTotalMessageCount, uint32_t aMessageSendPercent, uint32_t aMessageCopyPercent); \
  NS_IMETHOD OnMessageSendError(uint32_t aCurrentMessage, nsIMsgDBHdr *aMessageHeader, nsresult aStatus, const PRUnichar * aMsg); \
  NS_IMETHOD OnStopSending(nsresult aStatus, const PRUnichar * aMsg, uint32_t aTotalTried, uint32_t aSuccessful); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGSENDLATERLISTENER(_to) \
  NS_IMETHOD OnStartSending(uint32_t aTotalMessageCount) { return _to OnStartSending(aTotalMessageCount); } \
  NS_IMETHOD OnMessageStartSending(uint32_t aCurrentMessage, uint32_t aTotalMessageCount, nsIMsgDBHdr *aMessageHeader, nsIMsgIdentity *aIdentity) { return _to OnMessageStartSending(aCurrentMessage, aTotalMessageCount, aMessageHeader, aIdentity); } \
  NS_IMETHOD OnMessageSendProgress(uint32_t aCurrentMessage, uint32_t aTotalMessageCount, uint32_t aMessageSendPercent, uint32_t aMessageCopyPercent) { return _to OnMessageSendProgress(aCurrentMessage, aTotalMessageCount, aMessageSendPercent, aMessageCopyPercent); } \
  NS_IMETHOD OnMessageSendError(uint32_t aCurrentMessage, nsIMsgDBHdr *aMessageHeader, nsresult aStatus, const PRUnichar * aMsg) { return _to OnMessageSendError(aCurrentMessage, aMessageHeader, aStatus, aMsg); } \
  NS_IMETHOD OnStopSending(nsresult aStatus, const PRUnichar * aMsg, uint32_t aTotalTried, uint32_t aSuccessful) { return _to OnStopSending(aStatus, aMsg, aTotalTried, aSuccessful); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGSENDLATERLISTENER(_to) \
  NS_IMETHOD OnStartSending(uint32_t aTotalMessageCount) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnStartSending(aTotalMessageCount); } \
  NS_IMETHOD OnMessageStartSending(uint32_t aCurrentMessage, uint32_t aTotalMessageCount, nsIMsgDBHdr *aMessageHeader, nsIMsgIdentity *aIdentity) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnMessageStartSending(aCurrentMessage, aTotalMessageCount, aMessageHeader, aIdentity); } \
  NS_IMETHOD OnMessageSendProgress(uint32_t aCurrentMessage, uint32_t aTotalMessageCount, uint32_t aMessageSendPercent, uint32_t aMessageCopyPercent) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnMessageSendProgress(aCurrentMessage, aTotalMessageCount, aMessageSendPercent, aMessageCopyPercent); } \
  NS_IMETHOD OnMessageSendError(uint32_t aCurrentMessage, nsIMsgDBHdr *aMessageHeader, nsresult aStatus, const PRUnichar * aMsg) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnMessageSendError(aCurrentMessage, aMessageHeader, aStatus, aMsg); } \
  NS_IMETHOD OnStopSending(nsresult aStatus, const PRUnichar * aMsg, uint32_t aTotalTried, uint32_t aSuccessful) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnStopSending(aStatus, aMsg, aTotalTried, aSuccessful); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgSendLaterListener : public nsIMsgSendLaterListener
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGSENDLATERLISTENER

  nsMsgSendLaterListener();

private:
  ~nsMsgSendLaterListener();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgSendLaterListener, nsIMsgSendLaterListener)

nsMsgSendLaterListener::nsMsgSendLaterListener()
{
  /* member initializers and constructor code */
}

nsMsgSendLaterListener::~nsMsgSendLaterListener()
{
  /* destructor code */
}

/* void onStartSending (in unsigned long aTotalMessageCount); */
NS_IMETHODIMP nsMsgSendLaterListener::OnStartSending(uint32_t aTotalMessageCount)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void onMessageStartSending (in unsigned long aCurrentMessage, in unsigned long aTotalMessageCount, in nsIMsgDBHdr aMessageHeader, in nsIMsgIdentity aIdentity); */
NS_IMETHODIMP nsMsgSendLaterListener::OnMessageStartSending(uint32_t aCurrentMessage, uint32_t aTotalMessageCount, nsIMsgDBHdr *aMessageHeader, nsIMsgIdentity *aIdentity)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void onMessageSendProgress (in unsigned long aCurrentMessage, in unsigned long aTotalMessageCount, in unsigned long aMessageSendPercent, in unsigned long aMessageCopyPercent); */
NS_IMETHODIMP nsMsgSendLaterListener::OnMessageSendProgress(uint32_t aCurrentMessage, uint32_t aTotalMessageCount, uint32_t aMessageSendPercent, uint32_t aMessageCopyPercent)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void onMessageSendError (in unsigned long aCurrentMessage, in nsIMsgDBHdr aMessageHeader, in nsresult aStatus, in wstring aMsg); */
NS_IMETHODIMP nsMsgSendLaterListener::OnMessageSendError(uint32_t aCurrentMessage, nsIMsgDBHdr *aMessageHeader, nsresult aStatus, const PRUnichar * aMsg)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void onStopSending (in nsresult aStatus, in wstring aMsg, in unsigned long aTotalTried, in unsigned long aSuccessful); */
NS_IMETHODIMP nsMsgSendLaterListener::OnStopSending(nsresult aStatus, const PRUnichar * aMsg, uint32_t aTotalTried, uint32_t aSuccessful)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgSendLaterListener_h__ */
