/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/imap/public/nsIAutoSyncMsgStrategy.idl
 */

#ifndef __gen_nsIAutoSyncMsgStrategy_h__
#define __gen_nsIAutoSyncMsgStrategy_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIMsgFolder; /* forward declaration */

class nsIMsgDBHdr; /* forward declaration */

typedef int32_t  nsAutoSyncStrategyDecisionType;


/* starting interface:    nsAutoSyncStrategyDecisions */
#define NS_AUTOSYNCSTRATEGYDECISIONS_IID_STR "0365bec5-3753-43c2-b13e-441747815f37"

#define NS_AUTOSYNCSTRATEGYDECISIONS_IID \
  {0x0365bec5, 0x3753, 0x43c2, \
    { 0xb1, 0x3e, 0x44, 0x17, 0x47, 0x81, 0x5f, 0x37 }}

class NS_NO_VTABLE nsAutoSyncStrategyDecisions {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_AUTOSYNCSTRATEGYDECISIONS_IID)

  enum {
    Same = 1,
    Higher = 2,
    Lower = 4
  };

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsAutoSyncStrategyDecisions, NS_AUTOSYNCSTRATEGYDECISIONS_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSAUTOSYNCSTRATEGYDECISIONS \

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSAUTOSYNCSTRATEGYDECISIONS(_to) \

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSAUTOSYNCSTRATEGYDECISIONS(_to) \

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public nsAutoSyncStrategyDecisions
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSAUTOSYNCSTRATEGYDECISIONS

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, nsAutoSyncStrategyDecisions)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* End of implementation class template. */
#endif


/* starting interface:    nsIAutoSyncMsgStrategy */
#define NS_IAUTOSYNCMSGSTRATEGY_IID_STR "9cb4baff-3112-4cf8-8463-f81b0aa78f93"

#define NS_IAUTOSYNCMSGSTRATEGY_IID \
  {0x9cb4baff, 0x3112, 0x4cf8, \
    { 0x84, 0x63, 0xf8, 0x1b, 0x0a, 0xa7, 0x8f, 0x93 }}

class NS_NO_VTABLE nsIAutoSyncMsgStrategy : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IAUTOSYNCMSGSTRATEGY_IID)

  /* nsAutoSyncStrategyDecisionType sort (in nsIMsgFolder aFolder, in nsIMsgDBHdr aMsgHdr1, in nsIMsgDBHdr aMsgHdr2); */
  NS_IMETHOD Sort(nsIMsgFolder *aFolder, nsIMsgDBHdr *aMsgHdr1, nsIMsgDBHdr *aMsgHdr2, nsAutoSyncStrategyDecisionType *_retval) = 0;

  /* boolean isExcluded (in nsIMsgFolder aFolder, in nsIMsgDBHdr aMsgHdr); */
  NS_IMETHOD IsExcluded(nsIMsgFolder *aFolder, nsIMsgDBHdr *aMsgHdr, bool *_retval) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIAutoSyncMsgStrategy, NS_IAUTOSYNCMSGSTRATEGY_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIAUTOSYNCMSGSTRATEGY \
  NS_IMETHOD Sort(nsIMsgFolder *aFolder, nsIMsgDBHdr *aMsgHdr1, nsIMsgDBHdr *aMsgHdr2, nsAutoSyncStrategyDecisionType *_retval); \
  NS_IMETHOD IsExcluded(nsIMsgFolder *aFolder, nsIMsgDBHdr *aMsgHdr, bool *_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIAUTOSYNCMSGSTRATEGY(_to) \
  NS_IMETHOD Sort(nsIMsgFolder *aFolder, nsIMsgDBHdr *aMsgHdr1, nsIMsgDBHdr *aMsgHdr2, nsAutoSyncStrategyDecisionType *_retval) { return _to Sort(aFolder, aMsgHdr1, aMsgHdr2, _retval); } \
  NS_IMETHOD IsExcluded(nsIMsgFolder *aFolder, nsIMsgDBHdr *aMsgHdr, bool *_retval) { return _to IsExcluded(aFolder, aMsgHdr, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIAUTOSYNCMSGSTRATEGY(_to) \
  NS_IMETHOD Sort(nsIMsgFolder *aFolder, nsIMsgDBHdr *aMsgHdr1, nsIMsgDBHdr *aMsgHdr2, nsAutoSyncStrategyDecisionType *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->Sort(aFolder, aMsgHdr1, aMsgHdr2, _retval); } \
  NS_IMETHOD IsExcluded(nsIMsgFolder *aFolder, nsIMsgDBHdr *aMsgHdr, bool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->IsExcluded(aFolder, aMsgHdr, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsAutoSyncMsgStrategy : public nsIAutoSyncMsgStrategy
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIAUTOSYNCMSGSTRATEGY

  nsAutoSyncMsgStrategy();

private:
  ~nsAutoSyncMsgStrategy();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsAutoSyncMsgStrategy, nsIAutoSyncMsgStrategy)

nsAutoSyncMsgStrategy::nsAutoSyncMsgStrategy()
{
  /* member initializers and constructor code */
}

nsAutoSyncMsgStrategy::~nsAutoSyncMsgStrategy()
{
  /* destructor code */
}

/* nsAutoSyncStrategyDecisionType sort (in nsIMsgFolder aFolder, in nsIMsgDBHdr aMsgHdr1, in nsIMsgDBHdr aMsgHdr2); */
NS_IMETHODIMP nsAutoSyncMsgStrategy::Sort(nsIMsgFolder *aFolder, nsIMsgDBHdr *aMsgHdr1, nsIMsgDBHdr *aMsgHdr2, nsAutoSyncStrategyDecisionType *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean isExcluded (in nsIMsgFolder aFolder, in nsIMsgDBHdr aMsgHdr); */
NS_IMETHODIMP nsAutoSyncMsgStrategy::IsExcluded(nsIMsgFolder *aFolder, nsIMsgDBHdr *aMsgHdr, bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIAutoSyncMsgStrategy_h__ */
