/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/compose/public/nsIURLFetcher.idl
 */

#ifndef __gen_nsIURLFetcher_h__
#define __gen_nsIURLFetcher_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsIURI_h__
#include "nsIURI.h"
#endif

#ifndef __gen_nsIFileStreams_h__
#include "nsIFileStreams.h"
#endif

#ifndef __gen_nsIFile_h__
#include "nsIFile.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

//
// Callback declarations for URL completion
//
// For completion of send/message creation operations...
typedef nsresult (*nsAttachSaveCompletionCallback) (nsresult aStatus,
                                                    const nsACString &aContentType,
                                                    const nsACString &aCharset,
                                                    int32_t totalSize, const PRUnichar* aMsg, 
                                                    void *tagData);

/* starting interface:    nsIURLFetcher */
#define NS_IURLFETCHER_IID_STR "4f3ad52d-888d-487d-961c-9c727c35434c"

#define NS_IURLFETCHER_IID \
  {0x4f3ad52d, 0x888d, 0x487d, \
    { 0x96, 0x1c, 0x9c, 0x72, 0x7c, 0x35, 0x43, 0x4c }}

class NS_NO_VTABLE nsIURLFetcher : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IURLFETCHER_IID)

  /* boolean stillRunning (); */
  NS_IMETHOD StillRunning(bool *_retval) = 0;

  /* void fireURLRequest (in nsIURI aURL, in nsIFile localFile, in nsIOutputStream fileStream, in nsAttachSaveCompletionCallback cb, in voidPtr tagData); */
  NS_IMETHOD FireURLRequest(nsIURI *aURL, nsIFile *localFile, nsIOutputStream *fileStream, nsAttachSaveCompletionCallback cb, void *tagData) = 0;

  /* void initialize (in nsIFile localFile, in nsIOutputStream fileStream, in nsAttachSaveCompletionCallback cb, in voidPtr tagData); */
  NS_IMETHOD Initialize(nsIFile *localFile, nsIOutputStream *fileStream, nsAttachSaveCompletionCallback cb, void *tagData) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIURLFetcher, NS_IURLFETCHER_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIURLFETCHER \
  NS_IMETHOD StillRunning(bool *_retval); \
  NS_IMETHOD FireURLRequest(nsIURI *aURL, nsIFile *localFile, nsIOutputStream *fileStream, nsAttachSaveCompletionCallback cb, void *tagData); \
  NS_IMETHOD Initialize(nsIFile *localFile, nsIOutputStream *fileStream, nsAttachSaveCompletionCallback cb, void *tagData); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIURLFETCHER(_to) \
  NS_IMETHOD StillRunning(bool *_retval) { return _to StillRunning(_retval); } \
  NS_IMETHOD FireURLRequest(nsIURI *aURL, nsIFile *localFile, nsIOutputStream *fileStream, nsAttachSaveCompletionCallback cb, void *tagData) { return _to FireURLRequest(aURL, localFile, fileStream, cb, tagData); } \
  NS_IMETHOD Initialize(nsIFile *localFile, nsIOutputStream *fileStream, nsAttachSaveCompletionCallback cb, void *tagData) { return _to Initialize(localFile, fileStream, cb, tagData); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIURLFETCHER(_to) \
  NS_IMETHOD StillRunning(bool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->StillRunning(_retval); } \
  NS_IMETHOD FireURLRequest(nsIURI *aURL, nsIFile *localFile, nsIOutputStream *fileStream, nsAttachSaveCompletionCallback cb, void *tagData) { return !_to ? NS_ERROR_NULL_POINTER : _to->FireURLRequest(aURL, localFile, fileStream, cb, tagData); } \
  NS_IMETHOD Initialize(nsIFile *localFile, nsIOutputStream *fileStream, nsAttachSaveCompletionCallback cb, void *tagData) { return !_to ? NS_ERROR_NULL_POINTER : _to->Initialize(localFile, fileStream, cb, tagData); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsURLFetcher : public nsIURLFetcher
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIURLFETCHER

  nsURLFetcher();

private:
  ~nsURLFetcher();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsURLFetcher, nsIURLFetcher)

nsURLFetcher::nsURLFetcher()
{
  /* member initializers and constructor code */
}

nsURLFetcher::~nsURLFetcher()
{
  /* destructor code */
}

/* boolean stillRunning (); */
NS_IMETHODIMP nsURLFetcher::StillRunning(bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void fireURLRequest (in nsIURI aURL, in nsIFile localFile, in nsIOutputStream fileStream, in nsAttachSaveCompletionCallback cb, in voidPtr tagData); */
NS_IMETHODIMP nsURLFetcher::FireURLRequest(nsIURI *aURL, nsIFile *localFile, nsIOutputStream *fileStream, nsAttachSaveCompletionCallback cb, void *tagData)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void initialize (in nsIFile localFile, in nsIOutputStream fileStream, in nsAttachSaveCompletionCallback cb, in voidPtr tagData); */
NS_IMETHODIMP nsURLFetcher::Initialize(nsIFile *localFile, nsIOutputStream *fileStream, nsAttachSaveCompletionCallback cb, void *tagData)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIURLFetcher_h__ */
