/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/base/search/public/nsIMsgSearchTerm.idl
 */

#ifndef __gen_nsIMsgSearchTerm_h__
#define __gen_nsIMsgSearchTerm_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsMsgSearchCore_h__
#include "nsMsgSearchCore.h"
#endif

#ifndef __gen_nsIMsgSearchValue_h__
#include "nsIMsgSearchValue.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIMsgDBHdr; /* forward declaration */

class nsIMsgDatabase; /* forward declaration */

class nsIMsgSearchScopeTerm; /* forward declaration */


/* starting interface:    nsIMsgSearchTerm */
#define NS_IMSGSEARCHTERM_IID_STR "dfd25cbe-2e86-4ff0-b78e-494bc65d344e"

#define NS_IMSGSEARCHTERM_IID \
  {0xdfd25cbe, 0x2e86, 0x4ff0, \
    { 0xb7, 0x8e, 0x49, 0x4b, 0xc6, 0x5d, 0x34, 0x4e }}

class NS_NO_VTABLE nsIMsgSearchTerm : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IMSGSEARCHTERM_IID)

  /* attribute nsMsgSearchAttribValue attrib; */
  NS_IMETHOD GetAttrib(nsMsgSearchAttribValue *aAttrib) = 0;
  NS_IMETHOD SetAttrib(nsMsgSearchAttribValue aAttrib) = 0;

  /* attribute nsMsgSearchOpValue op; */
  NS_IMETHOD GetOp(nsMsgSearchOpValue *aOp) = 0;
  NS_IMETHOD SetOp(nsMsgSearchOpValue aOp) = 0;

  /* attribute nsIMsgSearchValue value; */
  NS_IMETHOD GetValue(nsIMsgSearchValue * *aValue) = 0;
  NS_IMETHOD SetValue(nsIMsgSearchValue *aValue) = 0;

  /* attribute boolean booleanAnd; */
  NS_IMETHOD GetBooleanAnd(bool *aBooleanAnd) = 0;
  NS_IMETHOD SetBooleanAnd(bool aBooleanAnd) = 0;

  /* attribute ACString arbitraryHeader; */
  NS_IMETHOD GetArbitraryHeader(nsACString & aArbitraryHeader) = 0;
  NS_IMETHOD SetArbitraryHeader(const nsACString & aArbitraryHeader) = 0;

  /* attribute ACString hdrProperty; */
  NS_IMETHOD GetHdrProperty(nsACString & aHdrProperty) = 0;
  NS_IMETHOD SetHdrProperty(const nsACString & aHdrProperty) = 0;

  /* attribute ACString customId; */
  NS_IMETHOD GetCustomId(nsACString & aCustomId) = 0;
  NS_IMETHOD SetCustomId(const nsACString & aCustomId) = 0;

  /* attribute boolean beginsGrouping; */
  NS_IMETHOD GetBeginsGrouping(bool *aBeginsGrouping) = 0;
  NS_IMETHOD SetBeginsGrouping(bool aBeginsGrouping) = 0;

  /* attribute boolean endsGrouping; */
  NS_IMETHOD GetEndsGrouping(bool *aEndsGrouping) = 0;
  NS_IMETHOD SetEndsGrouping(bool aEndsGrouping) = 0;

  /* boolean matchRfc822String (in string aString, in string charset, in boolean charsetOverride); */
  NS_IMETHOD MatchRfc822String(const char * aString, const char * charset, bool charsetOverride, bool *_retval) = 0;

  /* boolean matchRfc2047String (in string aString, in string charset, in boolean charsetOverride); */
  NS_IMETHOD MatchRfc2047String(const char * aString, const char * charset, bool charsetOverride, bool *_retval) = 0;

  /* boolean matchDate (in PRTime aTime); */
  NS_IMETHOD MatchDate(PRTime aTime, bool *_retval) = 0;

  /* boolean matchStatus (in unsigned long aStatus); */
  NS_IMETHOD MatchStatus(uint32_t aStatus, bool *_retval) = 0;

  /* boolean matchPriority (in nsMsgPriorityValue priority); */
  NS_IMETHOD MatchPriority(nsMsgPriorityValue priority, bool *_retval) = 0;

  /* boolean matchAge (in PRTime days); */
  NS_IMETHOD MatchAge(PRTime days, bool *_retval) = 0;

  /* boolean matchSize (in unsigned long size); */
  NS_IMETHOD MatchSize(uint32_t size, bool *_retval) = 0;

  /* boolean matchLabel (in nsMsgLabelValue aLabelValue); */
  NS_IMETHOD MatchLabel(nsMsgLabelValue aLabelValue, bool *_retval) = 0;

  /* boolean matchJunkStatus (in string aJunkScore); */
  NS_IMETHOD MatchJunkStatus(const char * aJunkScore, bool *_retval) = 0;

  /* boolean matchJunkPercent (in unsigned long aJunkPercent); */
  NS_IMETHOD MatchJunkPercent(uint32_t aJunkPercent, bool *_retval) = 0;

  /* boolean matchJunkScoreOrigin (in string aJunkScoreOrigin); */
  NS_IMETHOD MatchJunkScoreOrigin(const char * aJunkScoreOrigin, bool *_retval) = 0;

  /* boolean matchBody (in nsIMsgSearchScopeTerm aScopeTerm, in unsigned long long aOffset, in unsigned long aLength, in string aCharset, in nsIMsgDBHdr aMsg, in nsIMsgDatabase aDb); */
  NS_IMETHOD MatchBody(nsIMsgSearchScopeTerm *aScopeTerm, uint64_t aOffset, uint32_t aLength, const char * aCharset, nsIMsgDBHdr *aMsg, nsIMsgDatabase *aDb, bool *_retval) = 0;

  /* [noscript] boolean matchArbitraryHeader (in nsIMsgSearchScopeTerm aScopeTerm, in unsigned long aLength, in string aCharset, in boolean aCharsetOverride, in nsIMsgDBHdr aMsg, in nsIMsgDatabase aDb, in string aHeaders, in unsigned long aHeaderLength, in boolean aForFilters); */
  NS_IMETHOD MatchArbitraryHeader(nsIMsgSearchScopeTerm *aScopeTerm, uint32_t aLength, const char * aCharset, bool aCharsetOverride, nsIMsgDBHdr *aMsg, nsIMsgDatabase *aDb, const char * aHeaders, uint32_t aHeaderLength, bool aForFilters, bool *_retval) = 0;

  /* boolean matchHdrProperty (in nsIMsgDBHdr msg); */
  NS_IMETHOD MatchHdrProperty(nsIMsgDBHdr *msg, bool *_retval) = 0;

  /* boolean matchUint32HdrProperty (in nsIMsgDBHdr msg); */
  NS_IMETHOD MatchUint32HdrProperty(nsIMsgDBHdr *msg, bool *_retval) = 0;

  /* boolean matchFolderFlag (in nsIMsgDBHdr msg); */
  NS_IMETHOD MatchFolderFlag(nsIMsgDBHdr *msg, bool *_retval) = 0;

  /* readonly attribute boolean matchAllBeforeDeciding; */
  NS_IMETHOD GetMatchAllBeforeDeciding(bool *aMatchAllBeforeDeciding) = 0;

  /* readonly attribute ACString termAsString; */
  NS_IMETHOD GetTermAsString(nsACString & aTermAsString) = 0;

  /* boolean matchKeyword (in ACString keyword); */
  NS_IMETHOD MatchKeyword(const nsACString & keyword, bool *_retval) = 0;

  /* attribute boolean matchAll; */
  NS_IMETHOD GetMatchAll(bool *aMatchAll) = 0;
  NS_IMETHOD SetMatchAll(bool aMatchAll) = 0;

  /* boolean matchCustom (in nsIMsgDBHdr msg); */
  NS_IMETHOD MatchCustom(nsIMsgDBHdr *msg, bool *_retval) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIMsgSearchTerm, NS_IMSGSEARCHTERM_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGSEARCHTERM \
  NS_IMETHOD GetAttrib(nsMsgSearchAttribValue *aAttrib); \
  NS_IMETHOD SetAttrib(nsMsgSearchAttribValue aAttrib); \
  NS_IMETHOD GetOp(nsMsgSearchOpValue *aOp); \
  NS_IMETHOD SetOp(nsMsgSearchOpValue aOp); \
  NS_IMETHOD GetValue(nsIMsgSearchValue * *aValue); \
  NS_IMETHOD SetValue(nsIMsgSearchValue *aValue); \
  NS_IMETHOD GetBooleanAnd(bool *aBooleanAnd); \
  NS_IMETHOD SetBooleanAnd(bool aBooleanAnd); \
  NS_IMETHOD GetArbitraryHeader(nsACString & aArbitraryHeader); \
  NS_IMETHOD SetArbitraryHeader(const nsACString & aArbitraryHeader); \
  NS_IMETHOD GetHdrProperty(nsACString & aHdrProperty); \
  NS_IMETHOD SetHdrProperty(const nsACString & aHdrProperty); \
  NS_IMETHOD GetCustomId(nsACString & aCustomId); \
  NS_IMETHOD SetCustomId(const nsACString & aCustomId); \
  NS_IMETHOD GetBeginsGrouping(bool *aBeginsGrouping); \
  NS_IMETHOD SetBeginsGrouping(bool aBeginsGrouping); \
  NS_IMETHOD GetEndsGrouping(bool *aEndsGrouping); \
  NS_IMETHOD SetEndsGrouping(bool aEndsGrouping); \
  NS_IMETHOD MatchRfc822String(const char * aString, const char * charset, bool charsetOverride, bool *_retval); \
  NS_IMETHOD MatchRfc2047String(const char * aString, const char * charset, bool charsetOverride, bool *_retval); \
  NS_IMETHOD MatchDate(PRTime aTime, bool *_retval); \
  NS_IMETHOD MatchStatus(uint32_t aStatus, bool *_retval); \
  NS_IMETHOD MatchPriority(nsMsgPriorityValue priority, bool *_retval); \
  NS_IMETHOD MatchAge(PRTime days, bool *_retval); \
  NS_IMETHOD MatchSize(uint32_t size, bool *_retval); \
  NS_IMETHOD MatchLabel(nsMsgLabelValue aLabelValue, bool *_retval); \
  NS_IMETHOD MatchJunkStatus(const char * aJunkScore, bool *_retval); \
  NS_IMETHOD MatchJunkPercent(uint32_t aJunkPercent, bool *_retval); \
  NS_IMETHOD MatchJunkScoreOrigin(const char * aJunkScoreOrigin, bool *_retval); \
  NS_IMETHOD MatchBody(nsIMsgSearchScopeTerm *aScopeTerm, uint64_t aOffset, uint32_t aLength, const char * aCharset, nsIMsgDBHdr *aMsg, nsIMsgDatabase *aDb, bool *_retval); \
  NS_IMETHOD MatchArbitraryHeader(nsIMsgSearchScopeTerm *aScopeTerm, uint32_t aLength, const char * aCharset, bool aCharsetOverride, nsIMsgDBHdr *aMsg, nsIMsgDatabase *aDb, const char * aHeaders, uint32_t aHeaderLength, bool aForFilters, bool *_retval); \
  NS_IMETHOD MatchHdrProperty(nsIMsgDBHdr *msg, bool *_retval); \
  NS_IMETHOD MatchUint32HdrProperty(nsIMsgDBHdr *msg, bool *_retval); \
  NS_IMETHOD MatchFolderFlag(nsIMsgDBHdr *msg, bool *_retval); \
  NS_IMETHOD GetMatchAllBeforeDeciding(bool *aMatchAllBeforeDeciding); \
  NS_IMETHOD GetTermAsString(nsACString & aTermAsString); \
  NS_IMETHOD MatchKeyword(const nsACString & keyword, bool *_retval); \
  NS_IMETHOD GetMatchAll(bool *aMatchAll); \
  NS_IMETHOD SetMatchAll(bool aMatchAll); \
  NS_IMETHOD MatchCustom(nsIMsgDBHdr *msg, bool *_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGSEARCHTERM(_to) \
  NS_IMETHOD GetAttrib(nsMsgSearchAttribValue *aAttrib) { return _to GetAttrib(aAttrib); } \
  NS_IMETHOD SetAttrib(nsMsgSearchAttribValue aAttrib) { return _to SetAttrib(aAttrib); } \
  NS_IMETHOD GetOp(nsMsgSearchOpValue *aOp) { return _to GetOp(aOp); } \
  NS_IMETHOD SetOp(nsMsgSearchOpValue aOp) { return _to SetOp(aOp); } \
  NS_IMETHOD GetValue(nsIMsgSearchValue * *aValue) { return _to GetValue(aValue); } \
  NS_IMETHOD SetValue(nsIMsgSearchValue *aValue) { return _to SetValue(aValue); } \
  NS_IMETHOD GetBooleanAnd(bool *aBooleanAnd) { return _to GetBooleanAnd(aBooleanAnd); } \
  NS_IMETHOD SetBooleanAnd(bool aBooleanAnd) { return _to SetBooleanAnd(aBooleanAnd); } \
  NS_IMETHOD GetArbitraryHeader(nsACString & aArbitraryHeader) { return _to GetArbitraryHeader(aArbitraryHeader); } \
  NS_IMETHOD SetArbitraryHeader(const nsACString & aArbitraryHeader) { return _to SetArbitraryHeader(aArbitraryHeader); } \
  NS_IMETHOD GetHdrProperty(nsACString & aHdrProperty) { return _to GetHdrProperty(aHdrProperty); } \
  NS_IMETHOD SetHdrProperty(const nsACString & aHdrProperty) { return _to SetHdrProperty(aHdrProperty); } \
  NS_IMETHOD GetCustomId(nsACString & aCustomId) { return _to GetCustomId(aCustomId); } \
  NS_IMETHOD SetCustomId(const nsACString & aCustomId) { return _to SetCustomId(aCustomId); } \
  NS_IMETHOD GetBeginsGrouping(bool *aBeginsGrouping) { return _to GetBeginsGrouping(aBeginsGrouping); } \
  NS_IMETHOD SetBeginsGrouping(bool aBeginsGrouping) { return _to SetBeginsGrouping(aBeginsGrouping); } \
  NS_IMETHOD GetEndsGrouping(bool *aEndsGrouping) { return _to GetEndsGrouping(aEndsGrouping); } \
  NS_IMETHOD SetEndsGrouping(bool aEndsGrouping) { return _to SetEndsGrouping(aEndsGrouping); } \
  NS_IMETHOD MatchRfc822String(const char * aString, const char * charset, bool charsetOverride, bool *_retval) { return _to MatchRfc822String(aString, charset, charsetOverride, _retval); } \
  NS_IMETHOD MatchRfc2047String(const char * aString, const char * charset, bool charsetOverride, bool *_retval) { return _to MatchRfc2047String(aString, charset, charsetOverride, _retval); } \
  NS_IMETHOD MatchDate(PRTime aTime, bool *_retval) { return _to MatchDate(aTime, _retval); } \
  NS_IMETHOD MatchStatus(uint32_t aStatus, bool *_retval) { return _to MatchStatus(aStatus, _retval); } \
  NS_IMETHOD MatchPriority(nsMsgPriorityValue priority, bool *_retval) { return _to MatchPriority(priority, _retval); } \
  NS_IMETHOD MatchAge(PRTime days, bool *_retval) { return _to MatchAge(days, _retval); } \
  NS_IMETHOD MatchSize(uint32_t size, bool *_retval) { return _to MatchSize(size, _retval); } \
  NS_IMETHOD MatchLabel(nsMsgLabelValue aLabelValue, bool *_retval) { return _to MatchLabel(aLabelValue, _retval); } \
  NS_IMETHOD MatchJunkStatus(const char * aJunkScore, bool *_retval) { return _to MatchJunkStatus(aJunkScore, _retval); } \
  NS_IMETHOD MatchJunkPercent(uint32_t aJunkPercent, bool *_retval) { return _to MatchJunkPercent(aJunkPercent, _retval); } \
  NS_IMETHOD MatchJunkScoreOrigin(const char * aJunkScoreOrigin, bool *_retval) { return _to MatchJunkScoreOrigin(aJunkScoreOrigin, _retval); } \
  NS_IMETHOD MatchBody(nsIMsgSearchScopeTerm *aScopeTerm, uint64_t aOffset, uint32_t aLength, const char * aCharset, nsIMsgDBHdr *aMsg, nsIMsgDatabase *aDb, bool *_retval) { return _to MatchBody(aScopeTerm, aOffset, aLength, aCharset, aMsg, aDb, _retval); } \
  NS_IMETHOD MatchArbitraryHeader(nsIMsgSearchScopeTerm *aScopeTerm, uint32_t aLength, const char * aCharset, bool aCharsetOverride, nsIMsgDBHdr *aMsg, nsIMsgDatabase *aDb, const char * aHeaders, uint32_t aHeaderLength, bool aForFilters, bool *_retval) { return _to MatchArbitraryHeader(aScopeTerm, aLength, aCharset, aCharsetOverride, aMsg, aDb, aHeaders, aHeaderLength, aForFilters, _retval); } \
  NS_IMETHOD MatchHdrProperty(nsIMsgDBHdr *msg, bool *_retval) { return _to MatchHdrProperty(msg, _retval); } \
  NS_IMETHOD MatchUint32HdrProperty(nsIMsgDBHdr *msg, bool *_retval) { return _to MatchUint32HdrProperty(msg, _retval); } \
  NS_IMETHOD MatchFolderFlag(nsIMsgDBHdr *msg, bool *_retval) { return _to MatchFolderFlag(msg, _retval); } \
  NS_IMETHOD GetMatchAllBeforeDeciding(bool *aMatchAllBeforeDeciding) { return _to GetMatchAllBeforeDeciding(aMatchAllBeforeDeciding); } \
  NS_IMETHOD GetTermAsString(nsACString & aTermAsString) { return _to GetTermAsString(aTermAsString); } \
  NS_IMETHOD MatchKeyword(const nsACString & keyword, bool *_retval) { return _to MatchKeyword(keyword, _retval); } \
  NS_IMETHOD GetMatchAll(bool *aMatchAll) { return _to GetMatchAll(aMatchAll); } \
  NS_IMETHOD SetMatchAll(bool aMatchAll) { return _to SetMatchAll(aMatchAll); } \
  NS_IMETHOD MatchCustom(nsIMsgDBHdr *msg, bool *_retval) { return _to MatchCustom(msg, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGSEARCHTERM(_to) \
  NS_IMETHOD GetAttrib(nsMsgSearchAttribValue *aAttrib) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetAttrib(aAttrib); } \
  NS_IMETHOD SetAttrib(nsMsgSearchAttribValue aAttrib) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetAttrib(aAttrib); } \
  NS_IMETHOD GetOp(nsMsgSearchOpValue *aOp) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetOp(aOp); } \
  NS_IMETHOD SetOp(nsMsgSearchOpValue aOp) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetOp(aOp); } \
  NS_IMETHOD GetValue(nsIMsgSearchValue * *aValue) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetValue(aValue); } \
  NS_IMETHOD SetValue(nsIMsgSearchValue *aValue) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetValue(aValue); } \
  NS_IMETHOD GetBooleanAnd(bool *aBooleanAnd) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetBooleanAnd(aBooleanAnd); } \
  NS_IMETHOD SetBooleanAnd(bool aBooleanAnd) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetBooleanAnd(aBooleanAnd); } \
  NS_IMETHOD GetArbitraryHeader(nsACString & aArbitraryHeader) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetArbitraryHeader(aArbitraryHeader); } \
  NS_IMETHOD SetArbitraryHeader(const nsACString & aArbitraryHeader) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetArbitraryHeader(aArbitraryHeader); } \
  NS_IMETHOD GetHdrProperty(nsACString & aHdrProperty) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetHdrProperty(aHdrProperty); } \
  NS_IMETHOD SetHdrProperty(const nsACString & aHdrProperty) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetHdrProperty(aHdrProperty); } \
  NS_IMETHOD GetCustomId(nsACString & aCustomId) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetCustomId(aCustomId); } \
  NS_IMETHOD SetCustomId(const nsACString & aCustomId) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetCustomId(aCustomId); } \
  NS_IMETHOD GetBeginsGrouping(bool *aBeginsGrouping) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetBeginsGrouping(aBeginsGrouping); } \
  NS_IMETHOD SetBeginsGrouping(bool aBeginsGrouping) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetBeginsGrouping(aBeginsGrouping); } \
  NS_IMETHOD GetEndsGrouping(bool *aEndsGrouping) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetEndsGrouping(aEndsGrouping); } \
  NS_IMETHOD SetEndsGrouping(bool aEndsGrouping) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetEndsGrouping(aEndsGrouping); } \
  NS_IMETHOD MatchRfc822String(const char * aString, const char * charset, bool charsetOverride, bool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->MatchRfc822String(aString, charset, charsetOverride, _retval); } \
  NS_IMETHOD MatchRfc2047String(const char * aString, const char * charset, bool charsetOverride, bool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->MatchRfc2047String(aString, charset, charsetOverride, _retval); } \
  NS_IMETHOD MatchDate(PRTime aTime, bool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->MatchDate(aTime, _retval); } \
  NS_IMETHOD MatchStatus(uint32_t aStatus, bool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->MatchStatus(aStatus, _retval); } \
  NS_IMETHOD MatchPriority(nsMsgPriorityValue priority, bool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->MatchPriority(priority, _retval); } \
  NS_IMETHOD MatchAge(PRTime days, bool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->MatchAge(days, _retval); } \
  NS_IMETHOD MatchSize(uint32_t size, bool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->MatchSize(size, _retval); } \
  NS_IMETHOD MatchLabel(nsMsgLabelValue aLabelValue, bool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->MatchLabel(aLabelValue, _retval); } \
  NS_IMETHOD MatchJunkStatus(const char * aJunkScore, bool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->MatchJunkStatus(aJunkScore, _retval); } \
  NS_IMETHOD MatchJunkPercent(uint32_t aJunkPercent, bool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->MatchJunkPercent(aJunkPercent, _retval); } \
  NS_IMETHOD MatchJunkScoreOrigin(const char * aJunkScoreOrigin, bool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->MatchJunkScoreOrigin(aJunkScoreOrigin, _retval); } \
  NS_IMETHOD MatchBody(nsIMsgSearchScopeTerm *aScopeTerm, uint64_t aOffset, uint32_t aLength, const char * aCharset, nsIMsgDBHdr *aMsg, nsIMsgDatabase *aDb, bool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->MatchBody(aScopeTerm, aOffset, aLength, aCharset, aMsg, aDb, _retval); } \
  NS_IMETHOD MatchArbitraryHeader(nsIMsgSearchScopeTerm *aScopeTerm, uint32_t aLength, const char * aCharset, bool aCharsetOverride, nsIMsgDBHdr *aMsg, nsIMsgDatabase *aDb, const char * aHeaders, uint32_t aHeaderLength, bool aForFilters, bool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->MatchArbitraryHeader(aScopeTerm, aLength, aCharset, aCharsetOverride, aMsg, aDb, aHeaders, aHeaderLength, aForFilters, _retval); } \
  NS_IMETHOD MatchHdrProperty(nsIMsgDBHdr *msg, bool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->MatchHdrProperty(msg, _retval); } \
  NS_IMETHOD MatchUint32HdrProperty(nsIMsgDBHdr *msg, bool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->MatchUint32HdrProperty(msg, _retval); } \
  NS_IMETHOD MatchFolderFlag(nsIMsgDBHdr *msg, bool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->MatchFolderFlag(msg, _retval); } \
  NS_IMETHOD GetMatchAllBeforeDeciding(bool *aMatchAllBeforeDeciding) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMatchAllBeforeDeciding(aMatchAllBeforeDeciding); } \
  NS_IMETHOD GetTermAsString(nsACString & aTermAsString) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetTermAsString(aTermAsString); } \
  NS_IMETHOD MatchKeyword(const nsACString & keyword, bool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->MatchKeyword(keyword, _retval); } \
  NS_IMETHOD GetMatchAll(bool *aMatchAll) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMatchAll(aMatchAll); } \
  NS_IMETHOD SetMatchAll(bool aMatchAll) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMatchAll(aMatchAll); } \
  NS_IMETHOD MatchCustom(nsIMsgDBHdr *msg, bool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->MatchCustom(msg, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgSearchTerm : public nsIMsgSearchTerm
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGSEARCHTERM

  nsMsgSearchTerm();

private:
  ~nsMsgSearchTerm();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgSearchTerm, nsIMsgSearchTerm)

nsMsgSearchTerm::nsMsgSearchTerm()
{
  /* member initializers and constructor code */
}

nsMsgSearchTerm::~nsMsgSearchTerm()
{
  /* destructor code */
}

/* attribute nsMsgSearchAttribValue attrib; */
NS_IMETHODIMP nsMsgSearchTerm::GetAttrib(nsMsgSearchAttribValue *aAttrib)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgSearchTerm::SetAttrib(nsMsgSearchAttribValue aAttrib)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsMsgSearchOpValue op; */
NS_IMETHODIMP nsMsgSearchTerm::GetOp(nsMsgSearchOpValue *aOp)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgSearchTerm::SetOp(nsMsgSearchOpValue aOp)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsIMsgSearchValue value; */
NS_IMETHODIMP nsMsgSearchTerm::GetValue(nsIMsgSearchValue * *aValue)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgSearchTerm::SetValue(nsIMsgSearchValue *aValue)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean booleanAnd; */
NS_IMETHODIMP nsMsgSearchTerm::GetBooleanAnd(bool *aBooleanAnd)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgSearchTerm::SetBooleanAnd(bool aBooleanAnd)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute ACString arbitraryHeader; */
NS_IMETHODIMP nsMsgSearchTerm::GetArbitraryHeader(nsACString & aArbitraryHeader)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgSearchTerm::SetArbitraryHeader(const nsACString & aArbitraryHeader)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute ACString hdrProperty; */
NS_IMETHODIMP nsMsgSearchTerm::GetHdrProperty(nsACString & aHdrProperty)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgSearchTerm::SetHdrProperty(const nsACString & aHdrProperty)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute ACString customId; */
NS_IMETHODIMP nsMsgSearchTerm::GetCustomId(nsACString & aCustomId)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgSearchTerm::SetCustomId(const nsACString & aCustomId)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean beginsGrouping; */
NS_IMETHODIMP nsMsgSearchTerm::GetBeginsGrouping(bool *aBeginsGrouping)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgSearchTerm::SetBeginsGrouping(bool aBeginsGrouping)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean endsGrouping; */
NS_IMETHODIMP nsMsgSearchTerm::GetEndsGrouping(bool *aEndsGrouping)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgSearchTerm::SetEndsGrouping(bool aEndsGrouping)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean matchRfc822String (in string aString, in string charset, in boolean charsetOverride); */
NS_IMETHODIMP nsMsgSearchTerm::MatchRfc822String(const char * aString, const char * charset, bool charsetOverride, bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean matchRfc2047String (in string aString, in string charset, in boolean charsetOverride); */
NS_IMETHODIMP nsMsgSearchTerm::MatchRfc2047String(const char * aString, const char * charset, bool charsetOverride, bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean matchDate (in PRTime aTime); */
NS_IMETHODIMP nsMsgSearchTerm::MatchDate(PRTime aTime, bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean matchStatus (in unsigned long aStatus); */
NS_IMETHODIMP nsMsgSearchTerm::MatchStatus(uint32_t aStatus, bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean matchPriority (in nsMsgPriorityValue priority); */
NS_IMETHODIMP nsMsgSearchTerm::MatchPriority(nsMsgPriorityValue priority, bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean matchAge (in PRTime days); */
NS_IMETHODIMP nsMsgSearchTerm::MatchAge(PRTime days, bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean matchSize (in unsigned long size); */
NS_IMETHODIMP nsMsgSearchTerm::MatchSize(uint32_t size, bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean matchLabel (in nsMsgLabelValue aLabelValue); */
NS_IMETHODIMP nsMsgSearchTerm::MatchLabel(nsMsgLabelValue aLabelValue, bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean matchJunkStatus (in string aJunkScore); */
NS_IMETHODIMP nsMsgSearchTerm::MatchJunkStatus(const char * aJunkScore, bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean matchJunkPercent (in unsigned long aJunkPercent); */
NS_IMETHODIMP nsMsgSearchTerm::MatchJunkPercent(uint32_t aJunkPercent, bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean matchJunkScoreOrigin (in string aJunkScoreOrigin); */
NS_IMETHODIMP nsMsgSearchTerm::MatchJunkScoreOrigin(const char * aJunkScoreOrigin, bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean matchBody (in nsIMsgSearchScopeTerm aScopeTerm, in unsigned long long aOffset, in unsigned long aLength, in string aCharset, in nsIMsgDBHdr aMsg, in nsIMsgDatabase aDb); */
NS_IMETHODIMP nsMsgSearchTerm::MatchBody(nsIMsgSearchScopeTerm *aScopeTerm, uint64_t aOffset, uint32_t aLength, const char * aCharset, nsIMsgDBHdr *aMsg, nsIMsgDatabase *aDb, bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [noscript] boolean matchArbitraryHeader (in nsIMsgSearchScopeTerm aScopeTerm, in unsigned long aLength, in string aCharset, in boolean aCharsetOverride, in nsIMsgDBHdr aMsg, in nsIMsgDatabase aDb, in string aHeaders, in unsigned long aHeaderLength, in boolean aForFilters); */
NS_IMETHODIMP nsMsgSearchTerm::MatchArbitraryHeader(nsIMsgSearchScopeTerm *aScopeTerm, uint32_t aLength, const char * aCharset, bool aCharsetOverride, nsIMsgDBHdr *aMsg, nsIMsgDatabase *aDb, const char * aHeaders, uint32_t aHeaderLength, bool aForFilters, bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean matchHdrProperty (in nsIMsgDBHdr msg); */
NS_IMETHODIMP nsMsgSearchTerm::MatchHdrProperty(nsIMsgDBHdr *msg, bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean matchUint32HdrProperty (in nsIMsgDBHdr msg); */
NS_IMETHODIMP nsMsgSearchTerm::MatchUint32HdrProperty(nsIMsgDBHdr *msg, bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean matchFolderFlag (in nsIMsgDBHdr msg); */
NS_IMETHODIMP nsMsgSearchTerm::MatchFolderFlag(nsIMsgDBHdr *msg, bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean matchAllBeforeDeciding; */
NS_IMETHODIMP nsMsgSearchTerm::GetMatchAllBeforeDeciding(bool *aMatchAllBeforeDeciding)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute ACString termAsString; */
NS_IMETHODIMP nsMsgSearchTerm::GetTermAsString(nsACString & aTermAsString)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean matchKeyword (in ACString keyword); */
NS_IMETHODIMP nsMsgSearchTerm::MatchKeyword(const nsACString & keyword, bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean matchAll; */
NS_IMETHODIMP nsMsgSearchTerm::GetMatchAll(bool *aMatchAll)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgSearchTerm::SetMatchAll(bool aMatchAll)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean matchCustom (in nsIMsgDBHdr msg); */
NS_IMETHODIMP nsMsgSearchTerm::MatchCustom(nsIMsgDBHdr *msg, bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgSearchTerm_h__ */
