/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "domstubs.idl"

interface nsIDOMDOMStringList;

[scriptable, uuid(f394a721-66e9-46fc-bb24-b980bb732dd0)]
interface nsIDOMOfflineResourceList : nsISupports
{
  /**
   * Get the list of dynamically-managed entries.
   */
  readonly attribute nsIDOMDOMStringList mozItems;

  /**
   * Check that an entry exists in the list of dynamically-managed entries.
   *
   * @param uri
   *        The resource to check.
   */
  boolean mozHasItem(in DOMString uri);

  /**
   * Get the number of dynamically-managed entries.
   * @status DEPRECATED
   *         Clients should use the "items" attribute.
   */
  readonly attribute unsigned long mozLength;

  /**
   * Get the URI of a dynamically-managed entry.
   * @status DEPRECATED
   *         Clients should use the "items" attribute.
   */
  DOMString mozItem(in unsigned long index);

  /**
   * Add an item to the list of dynamically-managed entries.  The resource
   * will be fetched into the application cache.
   *
   * @param uri
   *        The resource to add.
   */
  void mozAdd(in DOMString uri);

  /**
   * Remove an item from the list of dynamically-managed entries.  If this
   * was the last reference to a URI in the application cache, the cache
   * entry will be removed.
   *
   * @param uri
   *        The resource to remove.
   */
  void mozRemove(in DOMString uri);

  /**
   * State of the application cache this object is associated with.
   */

  /* This object is not associated with an application cache. */
  const unsigned short UNCACHED = 0;

  /* The application cache is not being updated. */
  const unsigned short IDLE = 1;

  /* The manifest is being fetched and checked for updates */
  const unsigned short CHECKING = 2;

  /* Resources are being downloaded to be added to the cache */
  const unsigned short DOWNLOADING = 3;

  /* There is a new version of the application cache available */
  const unsigned short UPDATEREADY = 4;

  /* The application cache group is now obsolete. */
  const unsigned short OBSOLETE = 5;

  readonly attribute unsigned short status;

  /**
   * Begin the application update process on the associated application cache.
   */
  void update();

  /**
   * Swap in the newest version of the application cache, or disassociate
   * from the cache if the cache group is obsolete.
   */
  void swapCache();

  /* Events */
  attribute nsIDOMEventListener onchecking;
  attribute nsIDOMEventListener onerror;
  attribute nsIDOMEventListener onnoupdate;
  attribute nsIDOMEventListener ondownloading;
  attribute nsIDOMEventListener onprogress;
  attribute nsIDOMEventListener onupdateready;
  attribute nsIDOMEventListener oncached;
  attribute nsIDOMEventListener onobsolete;
};
