/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/compose/public/nsIMsgQuote.idl
 */

#ifndef __gen_nsIMsgQuote_h__
#define __gen_nsIMsgQuote_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsIMsgQuotingOutputStreamListener_h__
#include "nsIMsgQuotingOutputStreamListener.h"
#endif

#ifndef __gen_nsIChannel_h__
#include "nsIChannel.h"
#endif

#ifndef __gen_nsIMimeStreamConverter_h__
#include "nsIMimeStreamConverter.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIMsgDBHdr; /* forward declaration */


/* starting interface:    nsIMsgQuote */
#define NS_IMSGQUOTE_IID_STR "f79b1d55-f546-4ed5-9f75-9428e35c4eff"

#define NS_IMSGQUOTE_IID \
  {0xf79b1d55, 0xf546, 0x4ed5, \
    { 0x9f, 0x75, 0x94, 0x28, 0xe3, 0x5c, 0x4e, 0xff }}

class NS_NO_VTABLE nsIMsgQuote : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IMSGQUOTE_IID)

  /* void quoteMessage (in string msgURI, in boolean quoteHeaders, in nsIMsgQuotingOutputStreamListener streamListener, in string charset, in boolean headersOnly, in nsIMsgDBHdr aOrigHdr); */
  NS_IMETHOD QuoteMessage(const char * msgURI, bool quoteHeaders, nsIMsgQuotingOutputStreamListener *streamListener, const char * charset, bool headersOnly, nsIMsgDBHdr *aOrigHdr) = 0;

  /* readonly attribute nsIMimeStreamConverterListener quoteListener; */
  NS_IMETHOD GetQuoteListener(nsIMimeStreamConverterListener * *aQuoteListener) = 0;

  /* readonly attribute nsIChannel quoteChannel; */
  NS_IMETHOD GetQuoteChannel(nsIChannel * *aQuoteChannel) = 0;

  /* readonly attribute nsIMsgQuotingOutputStreamListener streamListener; */
  NS_IMETHOD GetStreamListener(nsIMsgQuotingOutputStreamListener * *aStreamListener) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIMsgQuote, NS_IMSGQUOTE_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGQUOTE \
  NS_IMETHOD QuoteMessage(const char * msgURI, bool quoteHeaders, nsIMsgQuotingOutputStreamListener *streamListener, const char * charset, bool headersOnly, nsIMsgDBHdr *aOrigHdr); \
  NS_IMETHOD GetQuoteListener(nsIMimeStreamConverterListener * *aQuoteListener); \
  NS_IMETHOD GetQuoteChannel(nsIChannel * *aQuoteChannel); \
  NS_IMETHOD GetStreamListener(nsIMsgQuotingOutputStreamListener * *aStreamListener); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGQUOTE(_to) \
  NS_IMETHOD QuoteMessage(const char * msgURI, bool quoteHeaders, nsIMsgQuotingOutputStreamListener *streamListener, const char * charset, bool headersOnly, nsIMsgDBHdr *aOrigHdr) { return _to QuoteMessage(msgURI, quoteHeaders, streamListener, charset, headersOnly, aOrigHdr); } \
  NS_IMETHOD GetQuoteListener(nsIMimeStreamConverterListener * *aQuoteListener) { return _to GetQuoteListener(aQuoteListener); } \
  NS_IMETHOD GetQuoteChannel(nsIChannel * *aQuoteChannel) { return _to GetQuoteChannel(aQuoteChannel); } \
  NS_IMETHOD GetStreamListener(nsIMsgQuotingOutputStreamListener * *aStreamListener) { return _to GetStreamListener(aStreamListener); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGQUOTE(_to) \
  NS_IMETHOD QuoteMessage(const char * msgURI, bool quoteHeaders, nsIMsgQuotingOutputStreamListener *streamListener, const char * charset, bool headersOnly, nsIMsgDBHdr *aOrigHdr) { return !_to ? NS_ERROR_NULL_POINTER : _to->QuoteMessage(msgURI, quoteHeaders, streamListener, charset, headersOnly, aOrigHdr); } \
  NS_IMETHOD GetQuoteListener(nsIMimeStreamConverterListener * *aQuoteListener) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetQuoteListener(aQuoteListener); } \
  NS_IMETHOD GetQuoteChannel(nsIChannel * *aQuoteChannel) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetQuoteChannel(aQuoteChannel); } \
  NS_IMETHOD GetStreamListener(nsIMsgQuotingOutputStreamListener * *aStreamListener) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetStreamListener(aStreamListener); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgQuote : public nsIMsgQuote
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGQUOTE

  nsMsgQuote();

private:
  ~nsMsgQuote();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgQuote, nsIMsgQuote)

nsMsgQuote::nsMsgQuote()
{
  /* member initializers and constructor code */
}

nsMsgQuote::~nsMsgQuote()
{
  /* destructor code */
}

/* void quoteMessage (in string msgURI, in boolean quoteHeaders, in nsIMsgQuotingOutputStreamListener streamListener, in string charset, in boolean headersOnly, in nsIMsgDBHdr aOrigHdr); */
NS_IMETHODIMP nsMsgQuote::QuoteMessage(const char * msgURI, bool quoteHeaders, nsIMsgQuotingOutputStreamListener *streamListener, const char * charset, bool headersOnly, nsIMsgDBHdr *aOrigHdr)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute nsIMimeStreamConverterListener quoteListener; */
NS_IMETHODIMP nsMsgQuote::GetQuoteListener(nsIMimeStreamConverterListener * *aQuoteListener)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute nsIChannel quoteChannel; */
NS_IMETHODIMP nsMsgQuote::GetQuoteChannel(nsIChannel * *aQuoteChannel)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute nsIMsgQuotingOutputStreamListener streamListener; */
NS_IMETHODIMP nsMsgQuote::GetStreamListener(nsIMsgQuotingOutputStreamListener * *aStreamListener)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


/* starting interface:    nsIMsgQuoteListener */
#define NS_IMSGQUOTELISTENER_IID_STR "1ec75ad9-88de-11d3-989d-001083010e9b"

#define NS_IMSGQUOTELISTENER_IID \
  {0x1ec75ad9, 0x88de, 0x11d3, \
    { 0x98, 0x9d, 0x00, 0x10, 0x83, 0x01, 0x0e, 0x9b }}

class NS_NO_VTABLE nsIMsgQuoteListener : public nsIMimeStreamConverterListener {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IMSGQUOTELISTENER_IID)

  /* attribute nsIMsgQuote msgQuote; */
  NS_IMETHOD GetMsgQuote(nsIMsgQuote * *aMsgQuote) = 0;
  NS_IMETHOD SetMsgQuote(nsIMsgQuote *aMsgQuote) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIMsgQuoteListener, NS_IMSGQUOTELISTENER_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGQUOTELISTENER \
  NS_IMETHOD GetMsgQuote(nsIMsgQuote * *aMsgQuote); \
  NS_IMETHOD SetMsgQuote(nsIMsgQuote *aMsgQuote); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGQUOTELISTENER(_to) \
  NS_IMETHOD GetMsgQuote(nsIMsgQuote * *aMsgQuote) { return _to GetMsgQuote(aMsgQuote); } \
  NS_IMETHOD SetMsgQuote(nsIMsgQuote *aMsgQuote) { return _to SetMsgQuote(aMsgQuote); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGQUOTELISTENER(_to) \
  NS_IMETHOD GetMsgQuote(nsIMsgQuote * *aMsgQuote) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMsgQuote(aMsgQuote); } \
  NS_IMETHOD SetMsgQuote(nsIMsgQuote *aMsgQuote) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMsgQuote(aMsgQuote); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgQuoteListener : public nsIMsgQuoteListener
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGQUOTELISTENER

  nsMsgQuoteListener();

private:
  ~nsMsgQuoteListener();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgQuoteListener, nsIMsgQuoteListener)

nsMsgQuoteListener::nsMsgQuoteListener()
{
  /* member initializers and constructor code */
}

nsMsgQuoteListener::~nsMsgQuoteListener()
{
  /* destructor code */
}

/* attribute nsIMsgQuote msgQuote; */
NS_IMETHODIMP nsMsgQuoteListener::GetMsgQuote(nsIMsgQuote * *aMsgQuote)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgQuoteListener::SetMsgQuote(nsIMsgQuote *aMsgQuote)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgQuote_h__ */
