/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/local/public/nsIMsgLocalMailFolder.idl
 */

#ifndef __gen_nsIMsgLocalMailFolder_h__
#define __gen_nsIMsgLocalMailFolder_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIArray; /* forward declaration */

class nsIMsgWindow; /* forward declaration */

class nsIUrlListener; /* forward declaration */

class nsIMsgDatabase; /* forward declaration */

class nsIMsgDBHdr; /* forward declaration */

class nsIMsgFolder; /* forward declaration */

class nsIMsgCopyServiceListener; /* forward declaration */

/* flags for markMsgsOnPop3Server */
#define POP3_NONE 0
#define POP3_DELETE 1
#define POP3_FETCH_BODY 2
#define POP3_FORCE_DEL 3
struct nsLocalFolderScanState;

/* starting interface:    nsIMsgLocalMailFolder */
#define NS_IMSGLOCALMAILFOLDER_IID_STR "ebf7576c-e15f-4aba-b021-cc6e9266e90b"

#define NS_IMSGLOCALMAILFOLDER_IID \
  {0xebf7576c, 0xe15f, 0x4aba, \
    { 0xb0, 0x21, 0xcc, 0x6e, 0x92, 0x66, 0xe9, 0x0b }}

class NS_NO_VTABLE nsIMsgLocalMailFolder : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IMSGLOCALMAILFOLDER_IID)

  /* void setFlagsOnDefaultMailboxes (in unsigned long flags); */
  NS_IMETHOD SetFlagsOnDefaultMailboxes(uint32_t flags) = 0;

  /* nsIMsgDatabase getDatabaseWOReparse (); */
  NS_IMETHOD GetDatabaseWOReparse(nsIMsgDatabase * *_retval) = 0;

  /* nsIMsgDatabase getDatabaseWithReparse (in nsIUrlListener aReparseUrlListener, in nsIMsgWindow aMsgWindow); */
  NS_IMETHOD GetDatabaseWithReparse(nsIUrlListener *aReparseUrlListener, nsIMsgWindow *aMsgWindow, nsIMsgDatabase * *_retval) = 0;

  /* void parseFolder (in nsIMsgWindow aMsgWindow, in nsIUrlListener listener); */
  NS_IMETHOD ParseFolder(nsIMsgWindow *aMsgWindow, nsIUrlListener *listener) = 0;

  /* void copyFolderLocal (in nsIMsgFolder srcFolder, in boolean isMove, in nsIMsgWindow msgWindow, in nsIMsgCopyServiceListener listener); */
  NS_IMETHOD CopyFolderLocal(nsIMsgFolder *srcFolder, bool isMove, nsIMsgWindow *msgWindow, nsIMsgCopyServiceListener *listener) = 0;

  /* void copyAllSubFolders (in nsIMsgFolder srcFolder, in nsIMsgWindow msgWindow, in nsIMsgCopyServiceListener listener); */
  NS_IMETHOD CopyAllSubFolders(nsIMsgFolder *srcFolder, nsIMsgWindow *msgWindow, nsIMsgCopyServiceListener *listener) = 0;

  /* void onCopyCompleted (in nsISupports aSrcSupport, in boolean aMoveCopySucceeded); */
  NS_IMETHOD OnCopyCompleted(nsISupports *aSrcSupport, bool aMoveCopySucceeded) = 0;

  /* attribute boolean checkForNewMessagesAfterParsing; */
  NS_IMETHOD GetCheckForNewMessagesAfterParsing(bool *aCheckForNewMessagesAfterParsing) = 0;
  NS_IMETHOD SetCheckForNewMessagesAfterParsing(bool aCheckForNewMessagesAfterParsing) = 0;

  /* void markMsgsOnPop3Server (in nsIArray aMessages, in int32_t aMark); */
  NS_IMETHOD MarkMsgsOnPop3Server(nsIArray *aMessages, int32_t aMark) = 0;

  /* void refreshSizeOnDisk (); */
  NS_IMETHOD RefreshSizeOnDisk(void) = 0;

  /* nsIMsgFolder createLocalSubfolder (in AString aFolderName); */
  NS_IMETHOD CreateLocalSubfolder(const nsAString & aFolderName, nsIMsgFolder * *_retval) = 0;

  /* nsIMsgDBHdr addMessage (in string aMessage); */
  NS_IMETHOD AddMessage(const char * aMessage, nsIMsgDBHdr * *_retval) = 0;

  /* nsIArray addMessageBatch (in uint32_t aMessageCount, [array, size_is (aMessageCount)] in string aMessages); */
  NS_IMETHOD AddMessageBatch(uint32_t aMessageCount, const char * *aMessages, nsIArray * *_retval) = 0;

  /* void deleteDownloadMsg (in nsIMsgDBHdr aMsgHdr, out boolean aDoSelect); */
  NS_IMETHOD DeleteDownloadMsg(nsIMsgDBHdr *aMsgHdr, bool *aDoSelect) = 0;

  /* void selectDownloadMsg (); */
  NS_IMETHOD SelectDownloadMsg(void) = 0;

  /* void notifyDelete (); */
  NS_IMETHOD NotifyDelete(void) = 0;

  /* [noscript] void getFolderScanState (in nsLocalFolderScanState aState); */
  NS_IMETHOD GetFolderScanState(nsLocalFolderScanState *aState) = 0;

  /* [noscript] void getUidlFromFolder (in nsLocalFolderScanState aState, in nsIMsgDBHdr aMsgHdr); */
  NS_IMETHOD GetUidlFromFolder(nsLocalFolderScanState *aState, nsIMsgDBHdr *aMsgHdr) = 0;

  /* boolean warnIfLocalFileTooBig (in nsIMsgWindow aWindow); */
  NS_IMETHOD WarnIfLocalFileTooBig(nsIMsgWindow *aWindow, bool *_retval) = 0;

  /* void updateNewMsgHdr (in nsIMsgDBHdr aOldHdr, in nsIMsgDBHdr aNewHdr); */
  NS_IMETHOD UpdateNewMsgHdr(nsIMsgDBHdr *aOldHdr, nsIMsgDBHdr *aNewHdr) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIMsgLocalMailFolder, NS_IMSGLOCALMAILFOLDER_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGLOCALMAILFOLDER \
  NS_IMETHOD SetFlagsOnDefaultMailboxes(uint32_t flags); \
  NS_IMETHOD GetDatabaseWOReparse(nsIMsgDatabase * *_retval); \
  NS_IMETHOD GetDatabaseWithReparse(nsIUrlListener *aReparseUrlListener, nsIMsgWindow *aMsgWindow, nsIMsgDatabase * *_retval); \
  NS_IMETHOD ParseFolder(nsIMsgWindow *aMsgWindow, nsIUrlListener *listener); \
  NS_IMETHOD CopyFolderLocal(nsIMsgFolder *srcFolder, bool isMove, nsIMsgWindow *msgWindow, nsIMsgCopyServiceListener *listener); \
  NS_IMETHOD CopyAllSubFolders(nsIMsgFolder *srcFolder, nsIMsgWindow *msgWindow, nsIMsgCopyServiceListener *listener); \
  NS_IMETHOD OnCopyCompleted(nsISupports *aSrcSupport, bool aMoveCopySucceeded); \
  NS_IMETHOD GetCheckForNewMessagesAfterParsing(bool *aCheckForNewMessagesAfterParsing); \
  NS_IMETHOD SetCheckForNewMessagesAfterParsing(bool aCheckForNewMessagesAfterParsing); \
  NS_IMETHOD MarkMsgsOnPop3Server(nsIArray *aMessages, int32_t aMark); \
  NS_IMETHOD RefreshSizeOnDisk(void); \
  NS_IMETHOD CreateLocalSubfolder(const nsAString & aFolderName, nsIMsgFolder * *_retval); \
  NS_IMETHOD AddMessage(const char * aMessage, nsIMsgDBHdr * *_retval); \
  NS_IMETHOD AddMessageBatch(uint32_t aMessageCount, const char * *aMessages, nsIArray * *_retval); \
  NS_IMETHOD DeleteDownloadMsg(nsIMsgDBHdr *aMsgHdr, bool *aDoSelect); \
  NS_IMETHOD SelectDownloadMsg(void); \
  NS_IMETHOD NotifyDelete(void); \
  NS_IMETHOD GetFolderScanState(nsLocalFolderScanState *aState); \
  NS_IMETHOD GetUidlFromFolder(nsLocalFolderScanState *aState, nsIMsgDBHdr *aMsgHdr); \
  NS_IMETHOD WarnIfLocalFileTooBig(nsIMsgWindow *aWindow, bool *_retval); \
  NS_IMETHOD UpdateNewMsgHdr(nsIMsgDBHdr *aOldHdr, nsIMsgDBHdr *aNewHdr); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGLOCALMAILFOLDER(_to) \
  NS_IMETHOD SetFlagsOnDefaultMailboxes(uint32_t flags) { return _to SetFlagsOnDefaultMailboxes(flags); } \
  NS_IMETHOD GetDatabaseWOReparse(nsIMsgDatabase * *_retval) { return _to GetDatabaseWOReparse(_retval); } \
  NS_IMETHOD GetDatabaseWithReparse(nsIUrlListener *aReparseUrlListener, nsIMsgWindow *aMsgWindow, nsIMsgDatabase * *_retval) { return _to GetDatabaseWithReparse(aReparseUrlListener, aMsgWindow, _retval); } \
  NS_IMETHOD ParseFolder(nsIMsgWindow *aMsgWindow, nsIUrlListener *listener) { return _to ParseFolder(aMsgWindow, listener); } \
  NS_IMETHOD CopyFolderLocal(nsIMsgFolder *srcFolder, bool isMove, nsIMsgWindow *msgWindow, nsIMsgCopyServiceListener *listener) { return _to CopyFolderLocal(srcFolder, isMove, msgWindow, listener); } \
  NS_IMETHOD CopyAllSubFolders(nsIMsgFolder *srcFolder, nsIMsgWindow *msgWindow, nsIMsgCopyServiceListener *listener) { return _to CopyAllSubFolders(srcFolder, msgWindow, listener); } \
  NS_IMETHOD OnCopyCompleted(nsISupports *aSrcSupport, bool aMoveCopySucceeded) { return _to OnCopyCompleted(aSrcSupport, aMoveCopySucceeded); } \
  NS_IMETHOD GetCheckForNewMessagesAfterParsing(bool *aCheckForNewMessagesAfterParsing) { return _to GetCheckForNewMessagesAfterParsing(aCheckForNewMessagesAfterParsing); } \
  NS_IMETHOD SetCheckForNewMessagesAfterParsing(bool aCheckForNewMessagesAfterParsing) { return _to SetCheckForNewMessagesAfterParsing(aCheckForNewMessagesAfterParsing); } \
  NS_IMETHOD MarkMsgsOnPop3Server(nsIArray *aMessages, int32_t aMark) { return _to MarkMsgsOnPop3Server(aMessages, aMark); } \
  NS_IMETHOD RefreshSizeOnDisk(void) { return _to RefreshSizeOnDisk(); } \
  NS_IMETHOD CreateLocalSubfolder(const nsAString & aFolderName, nsIMsgFolder * *_retval) { return _to CreateLocalSubfolder(aFolderName, _retval); } \
  NS_IMETHOD AddMessage(const char * aMessage, nsIMsgDBHdr * *_retval) { return _to AddMessage(aMessage, _retval); } \
  NS_IMETHOD AddMessageBatch(uint32_t aMessageCount, const char * *aMessages, nsIArray * *_retval) { return _to AddMessageBatch(aMessageCount, aMessages, _retval); } \
  NS_IMETHOD DeleteDownloadMsg(nsIMsgDBHdr *aMsgHdr, bool *aDoSelect) { return _to DeleteDownloadMsg(aMsgHdr, aDoSelect); } \
  NS_IMETHOD SelectDownloadMsg(void) { return _to SelectDownloadMsg(); } \
  NS_IMETHOD NotifyDelete(void) { return _to NotifyDelete(); } \
  NS_IMETHOD GetFolderScanState(nsLocalFolderScanState *aState) { return _to GetFolderScanState(aState); } \
  NS_IMETHOD GetUidlFromFolder(nsLocalFolderScanState *aState, nsIMsgDBHdr *aMsgHdr) { return _to GetUidlFromFolder(aState, aMsgHdr); } \
  NS_IMETHOD WarnIfLocalFileTooBig(nsIMsgWindow *aWindow, bool *_retval) { return _to WarnIfLocalFileTooBig(aWindow, _retval); } \
  NS_IMETHOD UpdateNewMsgHdr(nsIMsgDBHdr *aOldHdr, nsIMsgDBHdr *aNewHdr) { return _to UpdateNewMsgHdr(aOldHdr, aNewHdr); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGLOCALMAILFOLDER(_to) \
  NS_IMETHOD SetFlagsOnDefaultMailboxes(uint32_t flags) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetFlagsOnDefaultMailboxes(flags); } \
  NS_IMETHOD GetDatabaseWOReparse(nsIMsgDatabase * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDatabaseWOReparse(_retval); } \
  NS_IMETHOD GetDatabaseWithReparse(nsIUrlListener *aReparseUrlListener, nsIMsgWindow *aMsgWindow, nsIMsgDatabase * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDatabaseWithReparse(aReparseUrlListener, aMsgWindow, _retval); } \
  NS_IMETHOD ParseFolder(nsIMsgWindow *aMsgWindow, nsIUrlListener *listener) { return !_to ? NS_ERROR_NULL_POINTER : _to->ParseFolder(aMsgWindow, listener); } \
  NS_IMETHOD CopyFolderLocal(nsIMsgFolder *srcFolder, bool isMove, nsIMsgWindow *msgWindow, nsIMsgCopyServiceListener *listener) { return !_to ? NS_ERROR_NULL_POINTER : _to->CopyFolderLocal(srcFolder, isMove, msgWindow, listener); } \
  NS_IMETHOD CopyAllSubFolders(nsIMsgFolder *srcFolder, nsIMsgWindow *msgWindow, nsIMsgCopyServiceListener *listener) { return !_to ? NS_ERROR_NULL_POINTER : _to->CopyAllSubFolders(srcFolder, msgWindow, listener); } \
  NS_IMETHOD OnCopyCompleted(nsISupports *aSrcSupport, bool aMoveCopySucceeded) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnCopyCompleted(aSrcSupport, aMoveCopySucceeded); } \
  NS_IMETHOD GetCheckForNewMessagesAfterParsing(bool *aCheckForNewMessagesAfterParsing) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetCheckForNewMessagesAfterParsing(aCheckForNewMessagesAfterParsing); } \
  NS_IMETHOD SetCheckForNewMessagesAfterParsing(bool aCheckForNewMessagesAfterParsing) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetCheckForNewMessagesAfterParsing(aCheckForNewMessagesAfterParsing); } \
  NS_IMETHOD MarkMsgsOnPop3Server(nsIArray *aMessages, int32_t aMark) { return !_to ? NS_ERROR_NULL_POINTER : _to->MarkMsgsOnPop3Server(aMessages, aMark); } \
  NS_IMETHOD RefreshSizeOnDisk(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->RefreshSizeOnDisk(); } \
  NS_IMETHOD CreateLocalSubfolder(const nsAString & aFolderName, nsIMsgFolder * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->CreateLocalSubfolder(aFolderName, _retval); } \
  NS_IMETHOD AddMessage(const char * aMessage, nsIMsgDBHdr * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddMessage(aMessage, _retval); } \
  NS_IMETHOD AddMessageBatch(uint32_t aMessageCount, const char * *aMessages, nsIArray * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddMessageBatch(aMessageCount, aMessages, _retval); } \
  NS_IMETHOD DeleteDownloadMsg(nsIMsgDBHdr *aMsgHdr, bool *aDoSelect) { return !_to ? NS_ERROR_NULL_POINTER : _to->DeleteDownloadMsg(aMsgHdr, aDoSelect); } \
  NS_IMETHOD SelectDownloadMsg(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->SelectDownloadMsg(); } \
  NS_IMETHOD NotifyDelete(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->NotifyDelete(); } \
  NS_IMETHOD GetFolderScanState(nsLocalFolderScanState *aState) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFolderScanState(aState); } \
  NS_IMETHOD GetUidlFromFolder(nsLocalFolderScanState *aState, nsIMsgDBHdr *aMsgHdr) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetUidlFromFolder(aState, aMsgHdr); } \
  NS_IMETHOD WarnIfLocalFileTooBig(nsIMsgWindow *aWindow, bool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->WarnIfLocalFileTooBig(aWindow, _retval); } \
  NS_IMETHOD UpdateNewMsgHdr(nsIMsgDBHdr *aOldHdr, nsIMsgDBHdr *aNewHdr) { return !_to ? NS_ERROR_NULL_POINTER : _to->UpdateNewMsgHdr(aOldHdr, aNewHdr); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgLocalMailFolder : public nsIMsgLocalMailFolder
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGLOCALMAILFOLDER

  nsMsgLocalMailFolder();

private:
  ~nsMsgLocalMailFolder();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgLocalMailFolder, nsIMsgLocalMailFolder)

nsMsgLocalMailFolder::nsMsgLocalMailFolder()
{
  /* member initializers and constructor code */
}

nsMsgLocalMailFolder::~nsMsgLocalMailFolder()
{
  /* destructor code */
}

/* void setFlagsOnDefaultMailboxes (in unsigned long flags); */
NS_IMETHODIMP nsMsgLocalMailFolder::SetFlagsOnDefaultMailboxes(uint32_t flags)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIMsgDatabase getDatabaseWOReparse (); */
NS_IMETHODIMP nsMsgLocalMailFolder::GetDatabaseWOReparse(nsIMsgDatabase * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIMsgDatabase getDatabaseWithReparse (in nsIUrlListener aReparseUrlListener, in nsIMsgWindow aMsgWindow); */
NS_IMETHODIMP nsMsgLocalMailFolder::GetDatabaseWithReparse(nsIUrlListener *aReparseUrlListener, nsIMsgWindow *aMsgWindow, nsIMsgDatabase * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void parseFolder (in nsIMsgWindow aMsgWindow, in nsIUrlListener listener); */
NS_IMETHODIMP nsMsgLocalMailFolder::ParseFolder(nsIMsgWindow *aMsgWindow, nsIUrlListener *listener)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void copyFolderLocal (in nsIMsgFolder srcFolder, in boolean isMove, in nsIMsgWindow msgWindow, in nsIMsgCopyServiceListener listener); */
NS_IMETHODIMP nsMsgLocalMailFolder::CopyFolderLocal(nsIMsgFolder *srcFolder, bool isMove, nsIMsgWindow *msgWindow, nsIMsgCopyServiceListener *listener)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void copyAllSubFolders (in nsIMsgFolder srcFolder, in nsIMsgWindow msgWindow, in nsIMsgCopyServiceListener listener); */
NS_IMETHODIMP nsMsgLocalMailFolder::CopyAllSubFolders(nsIMsgFolder *srcFolder, nsIMsgWindow *msgWindow, nsIMsgCopyServiceListener *listener)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void onCopyCompleted (in nsISupports aSrcSupport, in boolean aMoveCopySucceeded); */
NS_IMETHODIMP nsMsgLocalMailFolder::OnCopyCompleted(nsISupports *aSrcSupport, bool aMoveCopySucceeded)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean checkForNewMessagesAfterParsing; */
NS_IMETHODIMP nsMsgLocalMailFolder::GetCheckForNewMessagesAfterParsing(bool *aCheckForNewMessagesAfterParsing)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgLocalMailFolder::SetCheckForNewMessagesAfterParsing(bool aCheckForNewMessagesAfterParsing)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void markMsgsOnPop3Server (in nsIArray aMessages, in int32_t aMark); */
NS_IMETHODIMP nsMsgLocalMailFolder::MarkMsgsOnPop3Server(nsIArray *aMessages, int32_t aMark)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void refreshSizeOnDisk (); */
NS_IMETHODIMP nsMsgLocalMailFolder::RefreshSizeOnDisk()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIMsgFolder createLocalSubfolder (in AString aFolderName); */
NS_IMETHODIMP nsMsgLocalMailFolder::CreateLocalSubfolder(const nsAString & aFolderName, nsIMsgFolder * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIMsgDBHdr addMessage (in string aMessage); */
NS_IMETHODIMP nsMsgLocalMailFolder::AddMessage(const char * aMessage, nsIMsgDBHdr * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIArray addMessageBatch (in uint32_t aMessageCount, [array, size_is (aMessageCount)] in string aMessages); */
NS_IMETHODIMP nsMsgLocalMailFolder::AddMessageBatch(uint32_t aMessageCount, const char * *aMessages, nsIArray * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void deleteDownloadMsg (in nsIMsgDBHdr aMsgHdr, out boolean aDoSelect); */
NS_IMETHODIMP nsMsgLocalMailFolder::DeleteDownloadMsg(nsIMsgDBHdr *aMsgHdr, bool *aDoSelect)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void selectDownloadMsg (); */
NS_IMETHODIMP nsMsgLocalMailFolder::SelectDownloadMsg()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void notifyDelete (); */
NS_IMETHODIMP nsMsgLocalMailFolder::NotifyDelete()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [noscript] void getFolderScanState (in nsLocalFolderScanState aState); */
NS_IMETHODIMP nsMsgLocalMailFolder::GetFolderScanState(nsLocalFolderScanState *aState)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [noscript] void getUidlFromFolder (in nsLocalFolderScanState aState, in nsIMsgDBHdr aMsgHdr); */
NS_IMETHODIMP nsMsgLocalMailFolder::GetUidlFromFolder(nsLocalFolderScanState *aState, nsIMsgDBHdr *aMsgHdr)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean warnIfLocalFileTooBig (in nsIMsgWindow aWindow); */
NS_IMETHODIMP nsMsgLocalMailFolder::WarnIfLocalFileTooBig(nsIMsgWindow *aWindow, bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void updateNewMsgHdr (in nsIMsgDBHdr aOldHdr, in nsIMsgDBHdr aNewHdr); */
NS_IMETHODIMP nsMsgLocalMailFolder::UpdateNewMsgHdr(nsIMsgDBHdr *aOldHdr, nsIMsgDBHdr *aNewHdr)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgLocalMailFolder_h__ */
