/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/suite/common/public/nsISidebarPanel.idl
 */

#ifndef __gen_nsISidebarPanel_h__
#define __gen_nsISidebarPanel_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsISidebarPanel */
#define NS_ISIDEBARPANEL_IID_STR "e0f4c5ee-2b35-4e99-81d2-ab956c4de0d1"

#define NS_ISIDEBARPANEL_IID \
  {0xe0f4c5ee, 0x2b35, 0x4e99, \
    { 0x81, 0xd2, 0xab, 0x95, 0x6c, 0x4d, 0xe0, 0xd1 }}

class NS_NO_VTABLE nsISidebarPanel : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_ISIDEBARPANEL_IID)

  /* void addPanel (in DOMString aTitle, in DOMString aContentURL, in DOMString aCustomizeURL); */
  NS_IMETHOD AddPanel(const nsAString & aTitle, const nsAString & aContentURL, const nsAString & aCustomizeURL) = 0;

  /* void addPersistentPanel (in DOMString aTitle, in DOMString aContentURL, in DOMString aCustomizeURL); */
  NS_IMETHOD AddPersistentPanel(const nsAString & aTitle, const nsAString & aContentURL, const nsAString & aCustomizeURL) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsISidebarPanel, NS_ISIDEBARPANEL_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSISIDEBARPANEL \
  NS_IMETHOD AddPanel(const nsAString & aTitle, const nsAString & aContentURL, const nsAString & aCustomizeURL); \
  NS_IMETHOD AddPersistentPanel(const nsAString & aTitle, const nsAString & aContentURL, const nsAString & aCustomizeURL); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSISIDEBARPANEL(_to) \
  NS_IMETHOD AddPanel(const nsAString & aTitle, const nsAString & aContentURL, const nsAString & aCustomizeURL) { return _to AddPanel(aTitle, aContentURL, aCustomizeURL); } \
  NS_IMETHOD AddPersistentPanel(const nsAString & aTitle, const nsAString & aContentURL, const nsAString & aCustomizeURL) { return _to AddPersistentPanel(aTitle, aContentURL, aCustomizeURL); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSISIDEBARPANEL(_to) \
  NS_IMETHOD AddPanel(const nsAString & aTitle, const nsAString & aContentURL, const nsAString & aCustomizeURL) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddPanel(aTitle, aContentURL, aCustomizeURL); } \
  NS_IMETHOD AddPersistentPanel(const nsAString & aTitle, const nsAString & aContentURL, const nsAString & aCustomizeURL) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddPersistentPanel(aTitle, aContentURL, aCustomizeURL); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsSidebarPanel : public nsISidebarPanel
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSISIDEBARPANEL

  nsSidebarPanel();

private:
  ~nsSidebarPanel();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsSidebarPanel, nsISidebarPanel)

nsSidebarPanel::nsSidebarPanel()
{
  /* member initializers and constructor code */
}

nsSidebarPanel::~nsSidebarPanel()
{
  /* destructor code */
}

/* void addPanel (in DOMString aTitle, in DOMString aContentURL, in DOMString aCustomizeURL); */
NS_IMETHODIMP nsSidebarPanel::AddPanel(const nsAString & aTitle, const nsAString & aContentURL, const nsAString & aCustomizeURL)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void addPersistentPanel (in DOMString aTitle, in DOMString aContentURL, in DOMString aCustomizeURL); */
NS_IMETHODIMP nsSidebarPanel::AddPersistentPanel(const nsAString & aTitle, const nsAString & aContentURL, const nsAString & aCustomizeURL)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsISidebarPanel_h__ */
