/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsIDOMDocument.idl"

interface nsIDOMSVGSVGElement;

[scriptable, uuid(4AEBF9E7-F275-4147-AA90-601626476132)]
interface nsIDOMSVGDocument : nsIDOMDocument
{
  readonly attribute DOMString domain;
  readonly attribute DOMString URL;
  readonly attribute nsIDOMSVGSVGElement rootElement;
};
