/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/ldap/xpcom/public/nsILDAPModification.idl
 */

#ifndef __gen_nsILDAPModification_h__
#define __gen_nsILDAPModification_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsILDAPBERValue; /* forward declaration */

class nsIArray; /* forward declaration */


/* starting interface:    nsILDAPModification */
#define NS_ILDAPMODIFICATION_IID_STR "f64ef501-0623-11d6-a7f2-b65476fc49dc"

#define NS_ILDAPMODIFICATION_IID \
  {0xf64ef501, 0x0623, 0x11d6, \
    { 0xa7, 0xf2, 0xb6, 0x54, 0x76, 0xfc, 0x49, 0xdc }}

class NS_NO_VTABLE nsILDAPModification : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_ILDAPMODIFICATION_IID)

  /* attribute long operation; */
  NS_IMETHOD GetOperation(int32_t *aOperation) = 0;
  NS_IMETHOD SetOperation(int32_t aOperation) = 0;

  enum {
    MOD_ADD = 0,
    MOD_DELETE = 1,
    MOD_REPLACE = 2,
    MOD_BVALUES = 128
  };

  /* attribute ACString type; */
  NS_IMETHOD GetType(nsACString & aType) = 0;
  NS_IMETHOD SetType(const nsACString & aType) = 0;

  /* attribute nsIArray values; */
  NS_IMETHOD GetValues(nsIArray * *aValues) = 0;
  NS_IMETHOD SetValues(nsIArray *aValues) = 0;

  /* void setUpModification (in long aOperation, in ACString aType, in nsIArray aValues); */
  NS_IMETHOD SetUpModification(int32_t aOperation, const nsACString & aType, nsIArray *aValues) = 0;

  /* void setUpModificationOneValue (in long aOperation, in ACString aType, in nsILDAPBERValue aValue); */
  NS_IMETHOD SetUpModificationOneValue(int32_t aOperation, const nsACString & aType, nsILDAPBERValue *aValue) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsILDAPModification, NS_ILDAPMODIFICATION_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSILDAPMODIFICATION \
  NS_IMETHOD GetOperation(int32_t *aOperation); \
  NS_IMETHOD SetOperation(int32_t aOperation); \
  NS_IMETHOD GetType(nsACString & aType); \
  NS_IMETHOD SetType(const nsACString & aType); \
  NS_IMETHOD GetValues(nsIArray * *aValues); \
  NS_IMETHOD SetValues(nsIArray *aValues); \
  NS_IMETHOD SetUpModification(int32_t aOperation, const nsACString & aType, nsIArray *aValues); \
  NS_IMETHOD SetUpModificationOneValue(int32_t aOperation, const nsACString & aType, nsILDAPBERValue *aValue); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSILDAPMODIFICATION(_to) \
  NS_IMETHOD GetOperation(int32_t *aOperation) { return _to GetOperation(aOperation); } \
  NS_IMETHOD SetOperation(int32_t aOperation) { return _to SetOperation(aOperation); } \
  NS_IMETHOD GetType(nsACString & aType) { return _to GetType(aType); } \
  NS_IMETHOD SetType(const nsACString & aType) { return _to SetType(aType); } \
  NS_IMETHOD GetValues(nsIArray * *aValues) { return _to GetValues(aValues); } \
  NS_IMETHOD SetValues(nsIArray *aValues) { return _to SetValues(aValues); } \
  NS_IMETHOD SetUpModification(int32_t aOperation, const nsACString & aType, nsIArray *aValues) { return _to SetUpModification(aOperation, aType, aValues); } \
  NS_IMETHOD SetUpModificationOneValue(int32_t aOperation, const nsACString & aType, nsILDAPBERValue *aValue) { return _to SetUpModificationOneValue(aOperation, aType, aValue); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSILDAPMODIFICATION(_to) \
  NS_IMETHOD GetOperation(int32_t *aOperation) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetOperation(aOperation); } \
  NS_IMETHOD SetOperation(int32_t aOperation) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetOperation(aOperation); } \
  NS_IMETHOD GetType(nsACString & aType) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetType(aType); } \
  NS_IMETHOD SetType(const nsACString & aType) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetType(aType); } \
  NS_IMETHOD GetValues(nsIArray * *aValues) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetValues(aValues); } \
  NS_IMETHOD SetValues(nsIArray *aValues) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetValues(aValues); } \
  NS_IMETHOD SetUpModification(int32_t aOperation, const nsACString & aType, nsIArray *aValues) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetUpModification(aOperation, aType, aValues); } \
  NS_IMETHOD SetUpModificationOneValue(int32_t aOperation, const nsACString & aType, nsILDAPBERValue *aValue) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetUpModificationOneValue(aOperation, aType, aValue); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsLDAPModification : public nsILDAPModification
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSILDAPMODIFICATION

  nsLDAPModification();

private:
  ~nsLDAPModification();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsLDAPModification, nsILDAPModification)

nsLDAPModification::nsLDAPModification()
{
  /* member initializers and constructor code */
}

nsLDAPModification::~nsLDAPModification()
{
  /* destructor code */
}

/* attribute long operation; */
NS_IMETHODIMP nsLDAPModification::GetOperation(int32_t *aOperation)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsLDAPModification::SetOperation(int32_t aOperation)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute ACString type; */
NS_IMETHODIMP nsLDAPModification::GetType(nsACString & aType)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsLDAPModification::SetType(const nsACString & aType)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsIArray values; */
NS_IMETHODIMP nsLDAPModification::GetValues(nsIArray * *aValues)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsLDAPModification::SetValues(nsIArray *aValues)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setUpModification (in long aOperation, in ACString aType, in nsIArray aValues); */
NS_IMETHODIMP nsLDAPModification::SetUpModification(int32_t aOperation, const nsACString & aType, nsIArray *aValues)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setUpModificationOneValue (in long aOperation, in ACString aType, in nsILDAPBERValue aValue); */
NS_IMETHODIMP nsLDAPModification::SetUpModificationOneValue(int32_t aOperation, const nsACString & aType, nsILDAPBERValue *aValue)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsILDAPModification_h__ */
