/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/base/public/nsIMsgCopyServiceListener.idl
 */

#ifndef __gen_nsIMsgCopyServiceListener_h__
#define __gen_nsIMsgCopyServiceListener_h__


#ifndef __gen_nsrootidl_h__
#include "nsrootidl.h"
#endif

#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIMsgCopyServiceListener */
#define NS_IMSGCOPYSERVICELISTENER_IID_STR "ca620e0e-927f-4fbe-a108-9ecf31a7ecc7"

#define NS_IMSGCOPYSERVICELISTENER_IID \
  {0xca620e0e, 0x927f, 0x4fbe, \
    { 0xa1, 0x08, 0x9e, 0xcf, 0x31, 0xa7, 0xec, 0xc7 }}

class NS_NO_VTABLE nsIMsgCopyServiceListener : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IMSGCOPYSERVICELISTENER_IID)

  /* void OnStartCopy (); */
  NS_IMETHOD OnStartCopy(void) = 0;

  /* void OnProgress (in uint32_t aProgress, in uint32_t aProgressMax); */
  NS_IMETHOD OnProgress(uint32_t aProgress, uint32_t aProgressMax) = 0;

  /* void SetMessageKey (in uint32_t aKey); */
  NS_IMETHOD SetMessageKey(uint32_t aKey) = 0;

  /* void GetMessageId (out ACString aMessageId); */
  NS_IMETHOD GetMessageId(nsACString & aMessageId) = 0;

  /* void OnStopCopy (in nsresult aStatus); */
  NS_IMETHOD OnStopCopy(nsresult aStatus) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIMsgCopyServiceListener, NS_IMSGCOPYSERVICELISTENER_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGCOPYSERVICELISTENER \
  NS_IMETHOD OnStartCopy(void); \
  NS_IMETHOD OnProgress(uint32_t aProgress, uint32_t aProgressMax); \
  NS_IMETHOD SetMessageKey(uint32_t aKey); \
  NS_IMETHOD GetMessageId(nsACString & aMessageId); \
  NS_IMETHOD OnStopCopy(nsresult aStatus); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGCOPYSERVICELISTENER(_to) \
  NS_IMETHOD OnStartCopy(void) { return _to OnStartCopy(); } \
  NS_IMETHOD OnProgress(uint32_t aProgress, uint32_t aProgressMax) { return _to OnProgress(aProgress, aProgressMax); } \
  NS_IMETHOD SetMessageKey(uint32_t aKey) { return _to SetMessageKey(aKey); } \
  NS_IMETHOD GetMessageId(nsACString & aMessageId) { return _to GetMessageId(aMessageId); } \
  NS_IMETHOD OnStopCopy(nsresult aStatus) { return _to OnStopCopy(aStatus); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGCOPYSERVICELISTENER(_to) \
  NS_IMETHOD OnStartCopy(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnStartCopy(); } \
  NS_IMETHOD OnProgress(uint32_t aProgress, uint32_t aProgressMax) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnProgress(aProgress, aProgressMax); } \
  NS_IMETHOD SetMessageKey(uint32_t aKey) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMessageKey(aKey); } \
  NS_IMETHOD GetMessageId(nsACString & aMessageId) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMessageId(aMessageId); } \
  NS_IMETHOD OnStopCopy(nsresult aStatus) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnStopCopy(aStatus); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgCopyServiceListener : public nsIMsgCopyServiceListener
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGCOPYSERVICELISTENER

  nsMsgCopyServiceListener();

private:
  ~nsMsgCopyServiceListener();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgCopyServiceListener, nsIMsgCopyServiceListener)

nsMsgCopyServiceListener::nsMsgCopyServiceListener()
{
  /* member initializers and constructor code */
}

nsMsgCopyServiceListener::~nsMsgCopyServiceListener()
{
  /* destructor code */
}

/* void OnStartCopy (); */
NS_IMETHODIMP nsMsgCopyServiceListener::OnStartCopy()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void OnProgress (in uint32_t aProgress, in uint32_t aProgressMax); */
NS_IMETHODIMP nsMsgCopyServiceListener::OnProgress(uint32_t aProgress, uint32_t aProgressMax)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void SetMessageKey (in uint32_t aKey); */
NS_IMETHODIMP nsMsgCopyServiceListener::SetMessageKey(uint32_t aKey)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void GetMessageId (out ACString aMessageId); */
NS_IMETHODIMP nsMsgCopyServiceListener::GetMessageId(nsACString & aMessageId)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void OnStopCopy (in nsresult aStatus); */
NS_IMETHODIMP nsMsgCopyServiceListener::OnStopCopy(nsresult aStatus)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgCopyServiceListener_h__ */
