/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/imap/public/nsIImapHeaderXferInfo.idl
 */

#ifndef __gen_nsIImapHeaderXferInfo_h__
#define __gen_nsIImapHeaderXferInfo_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_MailNewsTypes2_h__
#include "MailNewsTypes2.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIImapHeaderInfo */
#define NS_IIMAPHEADERINFO_IID_STR "38f8f784-b092-11d6-ba4b-00108335942a"

#define NS_IIMAPHEADERINFO_IID \
  {0x38f8f784, 0xb092, 0x11d6, \
    { 0xba, 0x4b, 0x00, 0x10, 0x83, 0x35, 0x94, 0x2a }}

class NS_NO_VTABLE nsIImapHeaderInfo : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IIMAPHEADERINFO_IID)

  /* attribute nsMsgKey msgUid; */
  NS_IMETHOD GetMsgUid(nsMsgKey *aMsgUid) = 0;
  NS_IMETHOD SetMsgUid(nsMsgKey aMsgUid) = 0;

  /* attribute long msgSize; */
  NS_IMETHOD GetMsgSize(int32_t *aMsgSize) = 0;
  NS_IMETHOD SetMsgSize(int32_t aMsgSize) = 0;

  /* [noscript] void getMsgHdrs ([shared] out string aMsgHdrs); */
  NS_IMETHOD GetMsgHdrs(const char * *aMsgHdrs) = 0;

  /* void cacheLine (in string line, in unsigned long uid); */
  NS_IMETHOD CacheLine(const char * line, uint32_t uid) = 0;

  /* void resetCache (); */
  NS_IMETHOD ResetCache(void) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIImapHeaderInfo, NS_IIMAPHEADERINFO_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIIMAPHEADERINFO \
  NS_IMETHOD GetMsgUid(nsMsgKey *aMsgUid); \
  NS_IMETHOD SetMsgUid(nsMsgKey aMsgUid); \
  NS_IMETHOD GetMsgSize(int32_t *aMsgSize); \
  NS_IMETHOD SetMsgSize(int32_t aMsgSize); \
  NS_IMETHOD GetMsgHdrs(const char * *aMsgHdrs); \
  NS_IMETHOD CacheLine(const char * line, uint32_t uid); \
  NS_IMETHOD ResetCache(void); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIIMAPHEADERINFO(_to) \
  NS_IMETHOD GetMsgUid(nsMsgKey *aMsgUid) { return _to GetMsgUid(aMsgUid); } \
  NS_IMETHOD SetMsgUid(nsMsgKey aMsgUid) { return _to SetMsgUid(aMsgUid); } \
  NS_IMETHOD GetMsgSize(int32_t *aMsgSize) { return _to GetMsgSize(aMsgSize); } \
  NS_IMETHOD SetMsgSize(int32_t aMsgSize) { return _to SetMsgSize(aMsgSize); } \
  NS_IMETHOD GetMsgHdrs(const char * *aMsgHdrs) { return _to GetMsgHdrs(aMsgHdrs); } \
  NS_IMETHOD CacheLine(const char * line, uint32_t uid) { return _to CacheLine(line, uid); } \
  NS_IMETHOD ResetCache(void) { return _to ResetCache(); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIIMAPHEADERINFO(_to) \
  NS_IMETHOD GetMsgUid(nsMsgKey *aMsgUid) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMsgUid(aMsgUid); } \
  NS_IMETHOD SetMsgUid(nsMsgKey aMsgUid) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMsgUid(aMsgUid); } \
  NS_IMETHOD GetMsgSize(int32_t *aMsgSize) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMsgSize(aMsgSize); } \
  NS_IMETHOD SetMsgSize(int32_t aMsgSize) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMsgSize(aMsgSize); } \
  NS_IMETHOD GetMsgHdrs(const char * *aMsgHdrs) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMsgHdrs(aMsgHdrs); } \
  NS_IMETHOD CacheLine(const char * line, uint32_t uid) { return !_to ? NS_ERROR_NULL_POINTER : _to->CacheLine(line, uid); } \
  NS_IMETHOD ResetCache(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->ResetCache(); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsImapHeaderInfo : public nsIImapHeaderInfo
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIIMAPHEADERINFO

  nsImapHeaderInfo();

private:
  ~nsImapHeaderInfo();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsImapHeaderInfo, nsIImapHeaderInfo)

nsImapHeaderInfo::nsImapHeaderInfo()
{
  /* member initializers and constructor code */
}

nsImapHeaderInfo::~nsImapHeaderInfo()
{
  /* destructor code */
}

/* attribute nsMsgKey msgUid; */
NS_IMETHODIMP nsImapHeaderInfo::GetMsgUid(nsMsgKey *aMsgUid)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsImapHeaderInfo::SetMsgUid(nsMsgKey aMsgUid)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute long msgSize; */
NS_IMETHODIMP nsImapHeaderInfo::GetMsgSize(int32_t *aMsgSize)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsImapHeaderInfo::SetMsgSize(int32_t aMsgSize)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [noscript] void getMsgHdrs ([shared] out string aMsgHdrs); */
NS_IMETHODIMP nsImapHeaderInfo::GetMsgHdrs(const char * *aMsgHdrs)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void cacheLine (in string line, in unsigned long uid); */
NS_IMETHODIMP nsImapHeaderInfo::CacheLine(const char * line, uint32_t uid)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void resetCache (); */
NS_IMETHODIMP nsImapHeaderInfo::ResetCache()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


/* starting interface:    nsIImapHeaderXferInfo */
#define NS_IIMAPHEADERXFERINFO_IID_STR "f0842eda-af29-4ecd-82e1-fba91bd65d66"

#define NS_IIMAPHEADERXFERINFO_IID \
  {0xf0842eda, 0xaf29, 0x4ecd, \
    { 0x82, 0xe1, 0xfb, 0xa9, 0x1b, 0xd6, 0x5d, 0x66 }}

class NS_NO_VTABLE nsIImapHeaderXferInfo : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IIMAPHEADERXFERINFO_IID)

  /* readonly attribute long numHeaders; */
  NS_IMETHOD GetNumHeaders(int32_t *aNumHeaders) = 0;

  /* nsIImapHeaderInfo getHeader (in long hdrIndex); */
  NS_IMETHOD GetHeader(int32_t hdrIndex, nsIImapHeaderInfo * *_retval) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIImapHeaderXferInfo, NS_IIMAPHEADERXFERINFO_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIIMAPHEADERXFERINFO \
  NS_IMETHOD GetNumHeaders(int32_t *aNumHeaders); \
  NS_IMETHOD GetHeader(int32_t hdrIndex, nsIImapHeaderInfo * *_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIIMAPHEADERXFERINFO(_to) \
  NS_IMETHOD GetNumHeaders(int32_t *aNumHeaders) { return _to GetNumHeaders(aNumHeaders); } \
  NS_IMETHOD GetHeader(int32_t hdrIndex, nsIImapHeaderInfo * *_retval) { return _to GetHeader(hdrIndex, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIIMAPHEADERXFERINFO(_to) \
  NS_IMETHOD GetNumHeaders(int32_t *aNumHeaders) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNumHeaders(aNumHeaders); } \
  NS_IMETHOD GetHeader(int32_t hdrIndex, nsIImapHeaderInfo * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetHeader(hdrIndex, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsImapHeaderXferInfo : public nsIImapHeaderXferInfo
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIIMAPHEADERXFERINFO

  nsImapHeaderXferInfo();

private:
  ~nsImapHeaderXferInfo();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsImapHeaderXferInfo, nsIImapHeaderXferInfo)

nsImapHeaderXferInfo::nsImapHeaderXferInfo()
{
  /* member initializers and constructor code */
}

nsImapHeaderXferInfo::~nsImapHeaderXferInfo()
{
  /* destructor code */
}

/* readonly attribute long numHeaders; */
NS_IMETHODIMP nsImapHeaderXferInfo::GetNumHeaders(int32_t *aNumHeaders)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIImapHeaderInfo getHeader (in long hdrIndex); */
NS_IMETHODIMP nsImapHeaderXferInfo::GetHeader(int32_t hdrIndex, nsIImapHeaderInfo * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIImapHeaderXferInfo_h__ */
