/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsIDOMSVGElement.idl"

[scriptable, uuid(749982A4-743B-4EC6-8BB2-FA602976EA58)]
interface nsIDOMSVGMetadataElement
  : nsIDOMSVGElement
{
};
