/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/base/public/nsIMsgFolderListener.idl
 */

#ifndef __gen_nsIMsgFolderListener_h__
#define __gen_nsIMsgFolderListener_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_MailNewsTypes2_h__
#include "MailNewsTypes2.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIMsgDBHdr; /* forward declaration */

class nsIMsgFolder; /* forward declaration */

class nsIArray; /* forward declaration */


/* starting interface:    nsIMsgFolderListener */
#define NS_IMSGFOLDERLISTENER_IID_STR "2f87be72-0565-4e64-a824-0eb9c258f884"

#define NS_IMSGFOLDERLISTENER_IID \
  {0x2f87be72, 0x0565, 0x4e64, \
    { 0xa8, 0x24, 0x0e, 0xb9, 0xc2, 0x58, 0xf8, 0x84 }}

class NS_NO_VTABLE nsIMsgFolderListener : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IMSGFOLDERLISTENER_IID)

  /* void msgAdded (in nsIMsgDBHdr aMsg); */
  NS_IMETHOD MsgAdded(nsIMsgDBHdr *aMsg) = 0;

  /* void msgsClassified (in nsIArray aMsgs, in boolean aJunkProcessed, in boolean aTraitProcessed); */
  NS_IMETHOD MsgsClassified(nsIArray *aMsgs, bool aJunkProcessed, bool aTraitProcessed) = 0;

  /* void msgsDeleted (in nsIArray aMsgs); */
  NS_IMETHOD MsgsDeleted(nsIArray *aMsgs) = 0;

  /* void msgsMoveCopyCompleted (in boolean aMove, in nsIArray aSrcMsgs, in nsIMsgFolder aDestFolder, in nsIArray aDestMsgs); */
  NS_IMETHOD MsgsMoveCopyCompleted(bool aMove, nsIArray *aSrcMsgs, nsIMsgFolder *aDestFolder, nsIArray *aDestMsgs) = 0;

  /* void msgKeyChanged (in nsMsgKey aOldKey, in nsIMsgDBHdr aNewHdr); */
  NS_IMETHOD MsgKeyChanged(nsMsgKey aOldKey, nsIMsgDBHdr *aNewHdr) = 0;

  /* void folderAdded (in nsIMsgFolder aFolder); */
  NS_IMETHOD FolderAdded(nsIMsgFolder *aFolder) = 0;

  /* void folderDeleted (in nsIMsgFolder aFolder); */
  NS_IMETHOD FolderDeleted(nsIMsgFolder *aFolder) = 0;

  /* void folderMoveCopyCompleted (in boolean aMove, in nsIMsgFolder aSrcFolder, in nsIMsgFolder aDestFolder); */
  NS_IMETHOD FolderMoveCopyCompleted(bool aMove, nsIMsgFolder *aSrcFolder, nsIMsgFolder *aDestFolder) = 0;

  /* void folderRenamed (in nsIMsgFolder aOrigFolder, in nsIMsgFolder aNewFolder); */
  NS_IMETHOD FolderRenamed(nsIMsgFolder *aOrigFolder, nsIMsgFolder *aNewFolder) = 0;

  /* void itemEvent (in nsISupports aItem, in ACString aEvent, in nsISupports aData); */
  NS_IMETHOD ItemEvent(nsISupports *aItem, const nsACString & aEvent, nsISupports *aData) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIMsgFolderListener, NS_IMSGFOLDERLISTENER_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGFOLDERLISTENER \
  NS_IMETHOD MsgAdded(nsIMsgDBHdr *aMsg); \
  NS_IMETHOD MsgsClassified(nsIArray *aMsgs, bool aJunkProcessed, bool aTraitProcessed); \
  NS_IMETHOD MsgsDeleted(nsIArray *aMsgs); \
  NS_IMETHOD MsgsMoveCopyCompleted(bool aMove, nsIArray *aSrcMsgs, nsIMsgFolder *aDestFolder, nsIArray *aDestMsgs); \
  NS_IMETHOD MsgKeyChanged(nsMsgKey aOldKey, nsIMsgDBHdr *aNewHdr); \
  NS_IMETHOD FolderAdded(nsIMsgFolder *aFolder); \
  NS_IMETHOD FolderDeleted(nsIMsgFolder *aFolder); \
  NS_IMETHOD FolderMoveCopyCompleted(bool aMove, nsIMsgFolder *aSrcFolder, nsIMsgFolder *aDestFolder); \
  NS_IMETHOD FolderRenamed(nsIMsgFolder *aOrigFolder, nsIMsgFolder *aNewFolder); \
  NS_IMETHOD ItemEvent(nsISupports *aItem, const nsACString & aEvent, nsISupports *aData); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGFOLDERLISTENER(_to) \
  NS_IMETHOD MsgAdded(nsIMsgDBHdr *aMsg) { return _to MsgAdded(aMsg); } \
  NS_IMETHOD MsgsClassified(nsIArray *aMsgs, bool aJunkProcessed, bool aTraitProcessed) { return _to MsgsClassified(aMsgs, aJunkProcessed, aTraitProcessed); } \
  NS_IMETHOD MsgsDeleted(nsIArray *aMsgs) { return _to MsgsDeleted(aMsgs); } \
  NS_IMETHOD MsgsMoveCopyCompleted(bool aMove, nsIArray *aSrcMsgs, nsIMsgFolder *aDestFolder, nsIArray *aDestMsgs) { return _to MsgsMoveCopyCompleted(aMove, aSrcMsgs, aDestFolder, aDestMsgs); } \
  NS_IMETHOD MsgKeyChanged(nsMsgKey aOldKey, nsIMsgDBHdr *aNewHdr) { return _to MsgKeyChanged(aOldKey, aNewHdr); } \
  NS_IMETHOD FolderAdded(nsIMsgFolder *aFolder) { return _to FolderAdded(aFolder); } \
  NS_IMETHOD FolderDeleted(nsIMsgFolder *aFolder) { return _to FolderDeleted(aFolder); } \
  NS_IMETHOD FolderMoveCopyCompleted(bool aMove, nsIMsgFolder *aSrcFolder, nsIMsgFolder *aDestFolder) { return _to FolderMoveCopyCompleted(aMove, aSrcFolder, aDestFolder); } \
  NS_IMETHOD FolderRenamed(nsIMsgFolder *aOrigFolder, nsIMsgFolder *aNewFolder) { return _to FolderRenamed(aOrigFolder, aNewFolder); } \
  NS_IMETHOD ItemEvent(nsISupports *aItem, const nsACString & aEvent, nsISupports *aData) { return _to ItemEvent(aItem, aEvent, aData); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGFOLDERLISTENER(_to) \
  NS_IMETHOD MsgAdded(nsIMsgDBHdr *aMsg) { return !_to ? NS_ERROR_NULL_POINTER : _to->MsgAdded(aMsg); } \
  NS_IMETHOD MsgsClassified(nsIArray *aMsgs, bool aJunkProcessed, bool aTraitProcessed) { return !_to ? NS_ERROR_NULL_POINTER : _to->MsgsClassified(aMsgs, aJunkProcessed, aTraitProcessed); } \
  NS_IMETHOD MsgsDeleted(nsIArray *aMsgs) { return !_to ? NS_ERROR_NULL_POINTER : _to->MsgsDeleted(aMsgs); } \
  NS_IMETHOD MsgsMoveCopyCompleted(bool aMove, nsIArray *aSrcMsgs, nsIMsgFolder *aDestFolder, nsIArray *aDestMsgs) { return !_to ? NS_ERROR_NULL_POINTER : _to->MsgsMoveCopyCompleted(aMove, aSrcMsgs, aDestFolder, aDestMsgs); } \
  NS_IMETHOD MsgKeyChanged(nsMsgKey aOldKey, nsIMsgDBHdr *aNewHdr) { return !_to ? NS_ERROR_NULL_POINTER : _to->MsgKeyChanged(aOldKey, aNewHdr); } \
  NS_IMETHOD FolderAdded(nsIMsgFolder *aFolder) { return !_to ? NS_ERROR_NULL_POINTER : _to->FolderAdded(aFolder); } \
  NS_IMETHOD FolderDeleted(nsIMsgFolder *aFolder) { return !_to ? NS_ERROR_NULL_POINTER : _to->FolderDeleted(aFolder); } \
  NS_IMETHOD FolderMoveCopyCompleted(bool aMove, nsIMsgFolder *aSrcFolder, nsIMsgFolder *aDestFolder) { return !_to ? NS_ERROR_NULL_POINTER : _to->FolderMoveCopyCompleted(aMove, aSrcFolder, aDestFolder); } \
  NS_IMETHOD FolderRenamed(nsIMsgFolder *aOrigFolder, nsIMsgFolder *aNewFolder) { return !_to ? NS_ERROR_NULL_POINTER : _to->FolderRenamed(aOrigFolder, aNewFolder); } \
  NS_IMETHOD ItemEvent(nsISupports *aItem, const nsACString & aEvent, nsISupports *aData) { return !_to ? NS_ERROR_NULL_POINTER : _to->ItemEvent(aItem, aEvent, aData); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgFolderListener : public nsIMsgFolderListener
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGFOLDERLISTENER

  nsMsgFolderListener();

private:
  ~nsMsgFolderListener();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgFolderListener, nsIMsgFolderListener)

nsMsgFolderListener::nsMsgFolderListener()
{
  /* member initializers and constructor code */
}

nsMsgFolderListener::~nsMsgFolderListener()
{
  /* destructor code */
}

/* void msgAdded (in nsIMsgDBHdr aMsg); */
NS_IMETHODIMP nsMsgFolderListener::MsgAdded(nsIMsgDBHdr *aMsg)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void msgsClassified (in nsIArray aMsgs, in boolean aJunkProcessed, in boolean aTraitProcessed); */
NS_IMETHODIMP nsMsgFolderListener::MsgsClassified(nsIArray *aMsgs, bool aJunkProcessed, bool aTraitProcessed)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void msgsDeleted (in nsIArray aMsgs); */
NS_IMETHODIMP nsMsgFolderListener::MsgsDeleted(nsIArray *aMsgs)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void msgsMoveCopyCompleted (in boolean aMove, in nsIArray aSrcMsgs, in nsIMsgFolder aDestFolder, in nsIArray aDestMsgs); */
NS_IMETHODIMP nsMsgFolderListener::MsgsMoveCopyCompleted(bool aMove, nsIArray *aSrcMsgs, nsIMsgFolder *aDestFolder, nsIArray *aDestMsgs)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void msgKeyChanged (in nsMsgKey aOldKey, in nsIMsgDBHdr aNewHdr); */
NS_IMETHODIMP nsMsgFolderListener::MsgKeyChanged(nsMsgKey aOldKey, nsIMsgDBHdr *aNewHdr)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void folderAdded (in nsIMsgFolder aFolder); */
NS_IMETHODIMP nsMsgFolderListener::FolderAdded(nsIMsgFolder *aFolder)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void folderDeleted (in nsIMsgFolder aFolder); */
NS_IMETHODIMP nsMsgFolderListener::FolderDeleted(nsIMsgFolder *aFolder)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void folderMoveCopyCompleted (in boolean aMove, in nsIMsgFolder aSrcFolder, in nsIMsgFolder aDestFolder); */
NS_IMETHODIMP nsMsgFolderListener::FolderMoveCopyCompleted(bool aMove, nsIMsgFolder *aSrcFolder, nsIMsgFolder *aDestFolder)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void folderRenamed (in nsIMsgFolder aOrigFolder, in nsIMsgFolder aNewFolder); */
NS_IMETHODIMP nsMsgFolderListener::FolderRenamed(nsIMsgFolder *aOrigFolder, nsIMsgFolder *aNewFolder)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void itemEvent (in nsISupports aItem, in ACString aEvent, in nsISupports aData); */
NS_IMETHODIMP nsMsgFolderListener::ItemEvent(nsISupports *aItem, const nsACString & aEvent, nsISupports *aData)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgFolderListener_h__ */
