/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/base/public/nsIMsgMailSession.idl
 */

#ifndef __gen_nsIMsgMailSession_h__
#define __gen_nsIMsgMailSession_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsIFolderListener_h__
#include "nsIFolderListener.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIFile; /* forward declaration */

class nsIMsgWindow; /* forward declaration */

class nsIMsgUserFeedbackListener; /* forward declaration */

class nsIMsgMailNewsUrl; /* forward declaration */


/* starting interface:    nsIMsgMailSession */
#define NS_IMSGMAILSESSION_IID_STR "577ead34-553e-4cd6-b484-76ff6662082d"

#define NS_IMSGMAILSESSION_IID \
  {0x577ead34, 0x553e, 0x4cd6, \
    { 0xb4, 0x84, 0x76, 0xff, 0x66, 0x62, 0x08, 0x2d }}

class NS_NO_VTABLE nsIMsgMailSession : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IMSGMAILSESSION_IID)

  /* void Shutdown (); */
  NS_IMETHOD Shutdown(void) = 0;

  /* void AddFolderListener (in nsIFolderListener aListener, in folderListenerNotifyFlagValue aNotifyFlags); */
  NS_IMETHOD AddFolderListener(nsIFolderListener *aListener, folderListenerNotifyFlagValue aNotifyFlags) = 0;

  /* void RemoveFolderListener (in nsIFolderListener aListener); */
  NS_IMETHOD RemoveFolderListener(nsIFolderListener *aListener) = 0;

  /* void addUserFeedbackListener (in nsIMsgUserFeedbackListener aListener); */
  NS_IMETHOD AddUserFeedbackListener(nsIMsgUserFeedbackListener *aListener) = 0;

  /* void removeUserFeedbackListener (in nsIMsgUserFeedbackListener aListener); */
  NS_IMETHOD RemoveUserFeedbackListener(nsIMsgUserFeedbackListener *aListener) = 0;

  /* void alertUser (in AString aMessage, [optional] in nsIMsgMailNewsUrl aUrl); */
  NS_IMETHOD AlertUser(const nsAString & aMessage, nsIMsgMailNewsUrl *aUrl) = 0;

  /* readonly attribute nsIMsgWindow topmostMsgWindow; */
  NS_IMETHOD GetTopmostMsgWindow(nsIMsgWindow * *aTopmostMsgWindow) = 0;

  /* void AddMsgWindow (in nsIMsgWindow msgWindow); */
  NS_IMETHOD AddMsgWindow(nsIMsgWindow *msgWindow) = 0;

  /* void RemoveMsgWindow (in nsIMsgWindow msgWindow); */
  NS_IMETHOD RemoveMsgWindow(nsIMsgWindow *msgWindow) = 0;

  /* boolean IsFolderOpenInWindow (in nsIMsgFolder folder); */
  NS_IMETHOD IsFolderOpenInWindow(nsIMsgFolder *folder, bool *_retval) = 0;

  /* string ConvertMsgURIToMsgURL (in string aURI, in nsIMsgWindow aMsgWindow); */
  NS_IMETHOD ConvertMsgURIToMsgURL(const char * aURI, nsIMsgWindow *aMsgWindow, char * *_retval) = 0;

  /* nsIFile getDataFilesDir (in string dirName); */
  NS_IMETHOD GetDataFilesDir(const char * dirName, nsIFile * *_retval) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIMsgMailSession, NS_IMSGMAILSESSION_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGMAILSESSION \
  NS_IMETHOD Shutdown(void); \
  NS_IMETHOD AddFolderListener(nsIFolderListener *aListener, folderListenerNotifyFlagValue aNotifyFlags); \
  NS_IMETHOD RemoveFolderListener(nsIFolderListener *aListener); \
  NS_IMETHOD AddUserFeedbackListener(nsIMsgUserFeedbackListener *aListener); \
  NS_IMETHOD RemoveUserFeedbackListener(nsIMsgUserFeedbackListener *aListener); \
  NS_IMETHOD AlertUser(const nsAString & aMessage, nsIMsgMailNewsUrl *aUrl); \
  NS_IMETHOD GetTopmostMsgWindow(nsIMsgWindow * *aTopmostMsgWindow); \
  NS_IMETHOD AddMsgWindow(nsIMsgWindow *msgWindow); \
  NS_IMETHOD RemoveMsgWindow(nsIMsgWindow *msgWindow); \
  NS_IMETHOD IsFolderOpenInWindow(nsIMsgFolder *folder, bool *_retval); \
  NS_IMETHOD ConvertMsgURIToMsgURL(const char * aURI, nsIMsgWindow *aMsgWindow, char * *_retval); \
  NS_IMETHOD GetDataFilesDir(const char * dirName, nsIFile * *_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGMAILSESSION(_to) \
  NS_IMETHOD Shutdown(void) { return _to Shutdown(); } \
  NS_IMETHOD AddFolderListener(nsIFolderListener *aListener, folderListenerNotifyFlagValue aNotifyFlags) { return _to AddFolderListener(aListener, aNotifyFlags); } \
  NS_IMETHOD RemoveFolderListener(nsIFolderListener *aListener) { return _to RemoveFolderListener(aListener); } \
  NS_IMETHOD AddUserFeedbackListener(nsIMsgUserFeedbackListener *aListener) { return _to AddUserFeedbackListener(aListener); } \
  NS_IMETHOD RemoveUserFeedbackListener(nsIMsgUserFeedbackListener *aListener) { return _to RemoveUserFeedbackListener(aListener); } \
  NS_IMETHOD AlertUser(const nsAString & aMessage, nsIMsgMailNewsUrl *aUrl) { return _to AlertUser(aMessage, aUrl); } \
  NS_IMETHOD GetTopmostMsgWindow(nsIMsgWindow * *aTopmostMsgWindow) { return _to GetTopmostMsgWindow(aTopmostMsgWindow); } \
  NS_IMETHOD AddMsgWindow(nsIMsgWindow *msgWindow) { return _to AddMsgWindow(msgWindow); } \
  NS_IMETHOD RemoveMsgWindow(nsIMsgWindow *msgWindow) { return _to RemoveMsgWindow(msgWindow); } \
  NS_IMETHOD IsFolderOpenInWindow(nsIMsgFolder *folder, bool *_retval) { return _to IsFolderOpenInWindow(folder, _retval); } \
  NS_IMETHOD ConvertMsgURIToMsgURL(const char * aURI, nsIMsgWindow *aMsgWindow, char * *_retval) { return _to ConvertMsgURIToMsgURL(aURI, aMsgWindow, _retval); } \
  NS_IMETHOD GetDataFilesDir(const char * dirName, nsIFile * *_retval) { return _to GetDataFilesDir(dirName, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGMAILSESSION(_to) \
  NS_IMETHOD Shutdown(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->Shutdown(); } \
  NS_IMETHOD AddFolderListener(nsIFolderListener *aListener, folderListenerNotifyFlagValue aNotifyFlags) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddFolderListener(aListener, aNotifyFlags); } \
  NS_IMETHOD RemoveFolderListener(nsIFolderListener *aListener) { return !_to ? NS_ERROR_NULL_POINTER : _to->RemoveFolderListener(aListener); } \
  NS_IMETHOD AddUserFeedbackListener(nsIMsgUserFeedbackListener *aListener) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddUserFeedbackListener(aListener); } \
  NS_IMETHOD RemoveUserFeedbackListener(nsIMsgUserFeedbackListener *aListener) { return !_to ? NS_ERROR_NULL_POINTER : _to->RemoveUserFeedbackListener(aListener); } \
  NS_IMETHOD AlertUser(const nsAString & aMessage, nsIMsgMailNewsUrl *aUrl) { return !_to ? NS_ERROR_NULL_POINTER : _to->AlertUser(aMessage, aUrl); } \
  NS_IMETHOD GetTopmostMsgWindow(nsIMsgWindow * *aTopmostMsgWindow) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetTopmostMsgWindow(aTopmostMsgWindow); } \
  NS_IMETHOD AddMsgWindow(nsIMsgWindow *msgWindow) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddMsgWindow(msgWindow); } \
  NS_IMETHOD RemoveMsgWindow(nsIMsgWindow *msgWindow) { return !_to ? NS_ERROR_NULL_POINTER : _to->RemoveMsgWindow(msgWindow); } \
  NS_IMETHOD IsFolderOpenInWindow(nsIMsgFolder *folder, bool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->IsFolderOpenInWindow(folder, _retval); } \
  NS_IMETHOD ConvertMsgURIToMsgURL(const char * aURI, nsIMsgWindow *aMsgWindow, char * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->ConvertMsgURIToMsgURL(aURI, aMsgWindow, _retval); } \
  NS_IMETHOD GetDataFilesDir(const char * dirName, nsIFile * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDataFilesDir(dirName, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgMailSession : public nsIMsgMailSession
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGMAILSESSION

  nsMsgMailSession();

private:
  ~nsMsgMailSession();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgMailSession, nsIMsgMailSession)

nsMsgMailSession::nsMsgMailSession()
{
  /* member initializers and constructor code */
}

nsMsgMailSession::~nsMsgMailSession()
{
  /* destructor code */
}

/* void Shutdown (); */
NS_IMETHODIMP nsMsgMailSession::Shutdown()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void AddFolderListener (in nsIFolderListener aListener, in folderListenerNotifyFlagValue aNotifyFlags); */
NS_IMETHODIMP nsMsgMailSession::AddFolderListener(nsIFolderListener *aListener, folderListenerNotifyFlagValue aNotifyFlags)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void RemoveFolderListener (in nsIFolderListener aListener); */
NS_IMETHODIMP nsMsgMailSession::RemoveFolderListener(nsIFolderListener *aListener)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void addUserFeedbackListener (in nsIMsgUserFeedbackListener aListener); */
NS_IMETHODIMP nsMsgMailSession::AddUserFeedbackListener(nsIMsgUserFeedbackListener *aListener)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void removeUserFeedbackListener (in nsIMsgUserFeedbackListener aListener); */
NS_IMETHODIMP nsMsgMailSession::RemoveUserFeedbackListener(nsIMsgUserFeedbackListener *aListener)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void alertUser (in AString aMessage, [optional] in nsIMsgMailNewsUrl aUrl); */
NS_IMETHODIMP nsMsgMailSession::AlertUser(const nsAString & aMessage, nsIMsgMailNewsUrl *aUrl)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute nsIMsgWindow topmostMsgWindow; */
NS_IMETHODIMP nsMsgMailSession::GetTopmostMsgWindow(nsIMsgWindow * *aTopmostMsgWindow)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void AddMsgWindow (in nsIMsgWindow msgWindow); */
NS_IMETHODIMP nsMsgMailSession::AddMsgWindow(nsIMsgWindow *msgWindow)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void RemoveMsgWindow (in nsIMsgWindow msgWindow); */
NS_IMETHODIMP nsMsgMailSession::RemoveMsgWindow(nsIMsgWindow *msgWindow)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean IsFolderOpenInWindow (in nsIMsgFolder folder); */
NS_IMETHODIMP nsMsgMailSession::IsFolderOpenInWindow(nsIMsgFolder *folder, bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* string ConvertMsgURIToMsgURL (in string aURI, in nsIMsgWindow aMsgWindow); */
NS_IMETHODIMP nsMsgMailSession::ConvertMsgURIToMsgURL(const char * aURI, nsIMsgWindow *aMsgWindow, char * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIFile getDataFilesDir (in string dirName); */
NS_IMETHODIMP nsMsgMailSession::GetDataFilesDir(const char * dirName, nsIFile * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgMailSession_h__ */
