/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/imap/public/nsIImapFlagAndUidState.idl
 */

#ifndef __gen_nsIImapFlagAndUidState_h__
#define __gen_nsIImapFlagAndUidState_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIImapFlagAndUidState */
#define NS_IIMAPFLAGANDUIDSTATE_IID_STR "290412eb-5824-4087-8984-05450c9397be"

#define NS_IIMAPFLAGANDUIDSTATE_IID \
  {0x290412eb, 0x5824, 0x4087, \
    { 0x89, 0x84, 0x05, 0x45, 0x0c, 0x93, 0x97, 0xbe }}

class NS_NO_VTABLE nsIImapFlagAndUidState : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IIMAPFLAGANDUIDSTATE_IID)

  /* readonly attribute long numberOfMessages; */
  NS_IMETHOD GetNumberOfMessages(int32_t *aNumberOfMessages) = 0;

  /* readonly attribute long numberOfRecentMessages; */
  NS_IMETHOD GetNumberOfRecentMessages(int32_t *aNumberOfRecentMessages) = 0;

  /* readonly attribute long numberOfDeletedMessages; */
  NS_IMETHOD GetNumberOfDeletedMessages(int32_t *aNumberOfDeletedMessages) = 0;

  /* readonly attribute boolean partialUIDFetch; */
  NS_IMETHOD GetPartialUIDFetch(bool *aPartialUIDFetch) = 0;

  /* readonly attribute unsigned short supportedUserFlags; */
  NS_IMETHOD GetSupportedUserFlags(uint16_t *aSupportedUserFlags) = 0;

  /* void orSupportedUserFlags (in unsigned short aFlags); */
  NS_IMETHOD OrSupportedUserFlags(uint16_t aFlags) = 0;

  /* void getUidOfMessage (in long zeroBasedIndex, out unsigned long result); */
  NS_IMETHOD GetUidOfMessage(int32_t zeroBasedIndex, uint32_t *result) = 0;

  /* void getMessageFlags (in long zeroBasedIndex, out unsigned short result); */
  NS_IMETHOD GetMessageFlags(int32_t zeroBasedIndex, uint16_t *result) = 0;

  /* void setMessageFlags (in long zeroBasedIndex, in unsigned short flags); */
  NS_IMETHOD SetMessageFlags(int32_t zeroBasedIndex, uint16_t flags) = 0;

  /* void expungeByIndex (in unsigned long zeroBasedIndex); */
  NS_IMETHOD ExpungeByIndex(uint32_t zeroBasedIndex) = 0;

  /* void addUidFlagPair (in unsigned long uid, in unsigned short flags, in unsigned long zeroBasedIndex); */
  NS_IMETHOD AddUidFlagPair(uint32_t uid, uint16_t flags, uint32_t zeroBasedIndex) = 0;

  /* void addUidCustomFlagPair (in unsigned long uid, in string customFlag); */
  NS_IMETHOD AddUidCustomFlagPair(uint32_t uid, const char * customFlag) = 0;

  /* string getCustomFlags (in unsigned long uid); */
  NS_IMETHOD GetCustomFlags(uint32_t uid, char * *_retval) = 0;

  /* void reset (); */
  NS_IMETHOD Reset(void) = 0;

  /* void clearCustomFlags (in unsigned long uid); */
  NS_IMETHOD ClearCustomFlags(uint32_t uid) = 0;

  /* void setCustomAttribute (in unsigned long aUid, in ACString aCustomAttributeName, in ACString aCustomAttributeValue); */
  NS_IMETHOD SetCustomAttribute(uint32_t aUid, const nsACString & aCustomAttributeName, const nsACString & aCustomAttributeValue) = 0;

  /* ACString getCustomAttribute (in unsigned long aUid, in ACString aCustomAttributeName); */
  NS_IMETHOD GetCustomAttribute(uint32_t aUid, const nsACString & aCustomAttributeName, nsACString & _retval) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIImapFlagAndUidState, NS_IIMAPFLAGANDUIDSTATE_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIIMAPFLAGANDUIDSTATE \
  NS_IMETHOD GetNumberOfMessages(int32_t *aNumberOfMessages); \
  NS_IMETHOD GetNumberOfRecentMessages(int32_t *aNumberOfRecentMessages); \
  NS_IMETHOD GetNumberOfDeletedMessages(int32_t *aNumberOfDeletedMessages); \
  NS_IMETHOD GetPartialUIDFetch(bool *aPartialUIDFetch); \
  NS_IMETHOD GetSupportedUserFlags(uint16_t *aSupportedUserFlags); \
  NS_IMETHOD OrSupportedUserFlags(uint16_t aFlags); \
  NS_IMETHOD GetUidOfMessage(int32_t zeroBasedIndex, uint32_t *result); \
  NS_IMETHOD GetMessageFlags(int32_t zeroBasedIndex, uint16_t *result); \
  NS_IMETHOD SetMessageFlags(int32_t zeroBasedIndex, uint16_t flags); \
  NS_IMETHOD ExpungeByIndex(uint32_t zeroBasedIndex); \
  NS_IMETHOD AddUidFlagPair(uint32_t uid, uint16_t flags, uint32_t zeroBasedIndex); \
  NS_IMETHOD AddUidCustomFlagPair(uint32_t uid, const char * customFlag); \
  NS_IMETHOD GetCustomFlags(uint32_t uid, char * *_retval); \
  NS_IMETHOD Reset(void); \
  NS_IMETHOD ClearCustomFlags(uint32_t uid); \
  NS_IMETHOD SetCustomAttribute(uint32_t aUid, const nsACString & aCustomAttributeName, const nsACString & aCustomAttributeValue); \
  NS_IMETHOD GetCustomAttribute(uint32_t aUid, const nsACString & aCustomAttributeName, nsACString & _retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIIMAPFLAGANDUIDSTATE(_to) \
  NS_IMETHOD GetNumberOfMessages(int32_t *aNumberOfMessages) { return _to GetNumberOfMessages(aNumberOfMessages); } \
  NS_IMETHOD GetNumberOfRecentMessages(int32_t *aNumberOfRecentMessages) { return _to GetNumberOfRecentMessages(aNumberOfRecentMessages); } \
  NS_IMETHOD GetNumberOfDeletedMessages(int32_t *aNumberOfDeletedMessages) { return _to GetNumberOfDeletedMessages(aNumberOfDeletedMessages); } \
  NS_IMETHOD GetPartialUIDFetch(bool *aPartialUIDFetch) { return _to GetPartialUIDFetch(aPartialUIDFetch); } \
  NS_IMETHOD GetSupportedUserFlags(uint16_t *aSupportedUserFlags) { return _to GetSupportedUserFlags(aSupportedUserFlags); } \
  NS_IMETHOD OrSupportedUserFlags(uint16_t aFlags) { return _to OrSupportedUserFlags(aFlags); } \
  NS_IMETHOD GetUidOfMessage(int32_t zeroBasedIndex, uint32_t *result) { return _to GetUidOfMessage(zeroBasedIndex, result); } \
  NS_IMETHOD GetMessageFlags(int32_t zeroBasedIndex, uint16_t *result) { return _to GetMessageFlags(zeroBasedIndex, result); } \
  NS_IMETHOD SetMessageFlags(int32_t zeroBasedIndex, uint16_t flags) { return _to SetMessageFlags(zeroBasedIndex, flags); } \
  NS_IMETHOD ExpungeByIndex(uint32_t zeroBasedIndex) { return _to ExpungeByIndex(zeroBasedIndex); } \
  NS_IMETHOD AddUidFlagPair(uint32_t uid, uint16_t flags, uint32_t zeroBasedIndex) { return _to AddUidFlagPair(uid, flags, zeroBasedIndex); } \
  NS_IMETHOD AddUidCustomFlagPair(uint32_t uid, const char * customFlag) { return _to AddUidCustomFlagPair(uid, customFlag); } \
  NS_IMETHOD GetCustomFlags(uint32_t uid, char * *_retval) { return _to GetCustomFlags(uid, _retval); } \
  NS_IMETHOD Reset(void) { return _to Reset(); } \
  NS_IMETHOD ClearCustomFlags(uint32_t uid) { return _to ClearCustomFlags(uid); } \
  NS_IMETHOD SetCustomAttribute(uint32_t aUid, const nsACString & aCustomAttributeName, const nsACString & aCustomAttributeValue) { return _to SetCustomAttribute(aUid, aCustomAttributeName, aCustomAttributeValue); } \
  NS_IMETHOD GetCustomAttribute(uint32_t aUid, const nsACString & aCustomAttributeName, nsACString & _retval) { return _to GetCustomAttribute(aUid, aCustomAttributeName, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIIMAPFLAGANDUIDSTATE(_to) \
  NS_IMETHOD GetNumberOfMessages(int32_t *aNumberOfMessages) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNumberOfMessages(aNumberOfMessages); } \
  NS_IMETHOD GetNumberOfRecentMessages(int32_t *aNumberOfRecentMessages) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNumberOfRecentMessages(aNumberOfRecentMessages); } \
  NS_IMETHOD GetNumberOfDeletedMessages(int32_t *aNumberOfDeletedMessages) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNumberOfDeletedMessages(aNumberOfDeletedMessages); } \
  NS_IMETHOD GetPartialUIDFetch(bool *aPartialUIDFetch) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetPartialUIDFetch(aPartialUIDFetch); } \
  NS_IMETHOD GetSupportedUserFlags(uint16_t *aSupportedUserFlags) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSupportedUserFlags(aSupportedUserFlags); } \
  NS_IMETHOD OrSupportedUserFlags(uint16_t aFlags) { return !_to ? NS_ERROR_NULL_POINTER : _to->OrSupportedUserFlags(aFlags); } \
  NS_IMETHOD GetUidOfMessage(int32_t zeroBasedIndex, uint32_t *result) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetUidOfMessage(zeroBasedIndex, result); } \
  NS_IMETHOD GetMessageFlags(int32_t zeroBasedIndex, uint16_t *result) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMessageFlags(zeroBasedIndex, result); } \
  NS_IMETHOD SetMessageFlags(int32_t zeroBasedIndex, uint16_t flags) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMessageFlags(zeroBasedIndex, flags); } \
  NS_IMETHOD ExpungeByIndex(uint32_t zeroBasedIndex) { return !_to ? NS_ERROR_NULL_POINTER : _to->ExpungeByIndex(zeroBasedIndex); } \
  NS_IMETHOD AddUidFlagPair(uint32_t uid, uint16_t flags, uint32_t zeroBasedIndex) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddUidFlagPair(uid, flags, zeroBasedIndex); } \
  NS_IMETHOD AddUidCustomFlagPair(uint32_t uid, const char * customFlag) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddUidCustomFlagPair(uid, customFlag); } \
  NS_IMETHOD GetCustomFlags(uint32_t uid, char * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetCustomFlags(uid, _retval); } \
  NS_IMETHOD Reset(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->Reset(); } \
  NS_IMETHOD ClearCustomFlags(uint32_t uid) { return !_to ? NS_ERROR_NULL_POINTER : _to->ClearCustomFlags(uid); } \
  NS_IMETHOD SetCustomAttribute(uint32_t aUid, const nsACString & aCustomAttributeName, const nsACString & aCustomAttributeValue) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetCustomAttribute(aUid, aCustomAttributeName, aCustomAttributeValue); } \
  NS_IMETHOD GetCustomAttribute(uint32_t aUid, const nsACString & aCustomAttributeName, nsACString & _retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetCustomAttribute(aUid, aCustomAttributeName, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsImapFlagAndUidState : public nsIImapFlagAndUidState
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIIMAPFLAGANDUIDSTATE

  nsImapFlagAndUidState();

private:
  ~nsImapFlagAndUidState();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsImapFlagAndUidState, nsIImapFlagAndUidState)

nsImapFlagAndUidState::nsImapFlagAndUidState()
{
  /* member initializers and constructor code */
}

nsImapFlagAndUidState::~nsImapFlagAndUidState()
{
  /* destructor code */
}

/* readonly attribute long numberOfMessages; */
NS_IMETHODIMP nsImapFlagAndUidState::GetNumberOfMessages(int32_t *aNumberOfMessages)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute long numberOfRecentMessages; */
NS_IMETHODIMP nsImapFlagAndUidState::GetNumberOfRecentMessages(int32_t *aNumberOfRecentMessages)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute long numberOfDeletedMessages; */
NS_IMETHODIMP nsImapFlagAndUidState::GetNumberOfDeletedMessages(int32_t *aNumberOfDeletedMessages)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean partialUIDFetch; */
NS_IMETHODIMP nsImapFlagAndUidState::GetPartialUIDFetch(bool *aPartialUIDFetch)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute unsigned short supportedUserFlags; */
NS_IMETHODIMP nsImapFlagAndUidState::GetSupportedUserFlags(uint16_t *aSupportedUserFlags)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void orSupportedUserFlags (in unsigned short aFlags); */
NS_IMETHODIMP nsImapFlagAndUidState::OrSupportedUserFlags(uint16_t aFlags)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void getUidOfMessage (in long zeroBasedIndex, out unsigned long result); */
NS_IMETHODIMP nsImapFlagAndUidState::GetUidOfMessage(int32_t zeroBasedIndex, uint32_t *result)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void getMessageFlags (in long zeroBasedIndex, out unsigned short result); */
NS_IMETHODIMP nsImapFlagAndUidState::GetMessageFlags(int32_t zeroBasedIndex, uint16_t *result)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setMessageFlags (in long zeroBasedIndex, in unsigned short flags); */
NS_IMETHODIMP nsImapFlagAndUidState::SetMessageFlags(int32_t zeroBasedIndex, uint16_t flags)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void expungeByIndex (in unsigned long zeroBasedIndex); */
NS_IMETHODIMP nsImapFlagAndUidState::ExpungeByIndex(uint32_t zeroBasedIndex)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void addUidFlagPair (in unsigned long uid, in unsigned short flags, in unsigned long zeroBasedIndex); */
NS_IMETHODIMP nsImapFlagAndUidState::AddUidFlagPair(uint32_t uid, uint16_t flags, uint32_t zeroBasedIndex)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void addUidCustomFlagPair (in unsigned long uid, in string customFlag); */
NS_IMETHODIMP nsImapFlagAndUidState::AddUidCustomFlagPair(uint32_t uid, const char * customFlag)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* string getCustomFlags (in unsigned long uid); */
NS_IMETHODIMP nsImapFlagAndUidState::GetCustomFlags(uint32_t uid, char * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void reset (); */
NS_IMETHODIMP nsImapFlagAndUidState::Reset()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void clearCustomFlags (in unsigned long uid); */
NS_IMETHODIMP nsImapFlagAndUidState::ClearCustomFlags(uint32_t uid)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setCustomAttribute (in unsigned long aUid, in ACString aCustomAttributeName, in ACString aCustomAttributeValue); */
NS_IMETHODIMP nsImapFlagAndUidState::SetCustomAttribute(uint32_t aUid, const nsACString & aCustomAttributeName, const nsACString & aCustomAttributeValue)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* ACString getCustomAttribute (in unsigned long aUid, in ACString aCustomAttributeName); */
NS_IMETHODIMP nsImapFlagAndUidState::GetCustomAttribute(uint32_t aUid, const nsACString & aCustomAttributeName, nsACString & _retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIImapFlagAndUidState_h__ */
