/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/compose/public/nsIMsgQuotingOutputStreamListener.idl
 */

#ifndef __gen_nsIMsgQuotingOutputStreamListener_h__
#define __gen_nsIMsgQuotingOutputStreamListener_h__


#ifndef __gen_nsIStreamListener_h__
#include "nsIStreamListener.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIMimeHeaders; /* forward declaration */


/* starting interface:    nsIMsgQuotingOutputStreamListener */
#define NS_IMSGQUOTINGOUTPUTSTREAMLISTENER_IID_STR "1fe345e6-2428-4a43-a0c6-d2acea0d4da4"

#define NS_IMSGQUOTINGOUTPUTSTREAMLISTENER_IID \
  {0x1fe345e6, 0x2428, 0x4a43, \
    { 0xa0, 0xc6, 0xd2, 0xac, 0xea, 0x0d, 0x4d, 0xa4 }}

class NS_NO_VTABLE nsIMsgQuotingOutputStreamListener : public nsIStreamListener {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IMSGQUOTINGOUTPUTSTREAMLISTENER_IID)

  /* void setMimeHeaders (in nsIMimeHeaders headers); */
  NS_IMETHOD SetMimeHeaders(nsIMimeHeaders *headers) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIMsgQuotingOutputStreamListener, NS_IMSGQUOTINGOUTPUTSTREAMLISTENER_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGQUOTINGOUTPUTSTREAMLISTENER \
  NS_IMETHOD SetMimeHeaders(nsIMimeHeaders *headers); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGQUOTINGOUTPUTSTREAMLISTENER(_to) \
  NS_IMETHOD SetMimeHeaders(nsIMimeHeaders *headers) { return _to SetMimeHeaders(headers); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGQUOTINGOUTPUTSTREAMLISTENER(_to) \
  NS_IMETHOD SetMimeHeaders(nsIMimeHeaders *headers) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMimeHeaders(headers); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgQuotingOutputStreamListener : public nsIMsgQuotingOutputStreamListener
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGQUOTINGOUTPUTSTREAMLISTENER

  nsMsgQuotingOutputStreamListener();

private:
  ~nsMsgQuotingOutputStreamListener();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgQuotingOutputStreamListener, nsIMsgQuotingOutputStreamListener)

nsMsgQuotingOutputStreamListener::nsMsgQuotingOutputStreamListener()
{
  /* member initializers and constructor code */
}

nsMsgQuotingOutputStreamListener::~nsMsgQuotingOutputStreamListener()
{
  /* destructor code */
}

/* void setMimeHeaders (in nsIMimeHeaders headers); */
NS_IMETHODIMP nsMsgQuotingOutputStreamListener::SetMimeHeaders(nsIMimeHeaders *headers)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgQuotingOutputStreamListener_h__ */
