/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/import/public/nsIImportFilters.idl
 */

#ifndef __gen_nsIImportFilters_h__
#define __gen_nsIImportFilters_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIMsgAccount; /* forward declaration */

class nsIFile; /* forward declaration */


/* starting interface:    nsIImportFilters */
#define NS_IIMPORTFILTERS_IID_STR "f2680ccf-d110-4b5b-954d-e072d4a16129"

#define NS_IIMPORTFILTERS_IID \
  {0xf2680ccf, 0xd110, 0x4b5b, \
    { 0x95, 0x4d, 0xe0, 0x72, 0xd4, 0xa1, 0x61, 0x29 }}

class NS_NO_VTABLE nsIImportFilters : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IIMPORTFILTERS_IID)

  /* boolean AutoLocate (out wstring aDescription, out nsIFile aLocation); */
  NS_IMETHOD AutoLocate(PRUnichar * *aDescription, nsIFile * *aLocation, bool *_retval) = 0;

  /* void SetLocation (in nsIFile aLocation); */
  NS_IMETHOD SetLocation(nsIFile *aLocation) = 0;

  /* boolean Import (out wstring aError); */
  NS_IMETHOD Import(PRUnichar * *aError, bool *_retval) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIImportFilters, NS_IIMPORTFILTERS_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIIMPORTFILTERS \
  NS_IMETHOD AutoLocate(PRUnichar * *aDescription, nsIFile * *aLocation, bool *_retval); \
  NS_IMETHOD SetLocation(nsIFile *aLocation); \
  NS_IMETHOD Import(PRUnichar * *aError, bool *_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIIMPORTFILTERS(_to) \
  NS_IMETHOD AutoLocate(PRUnichar * *aDescription, nsIFile * *aLocation, bool *_retval) { return _to AutoLocate(aDescription, aLocation, _retval); } \
  NS_IMETHOD SetLocation(nsIFile *aLocation) { return _to SetLocation(aLocation); } \
  NS_IMETHOD Import(PRUnichar * *aError, bool *_retval) { return _to Import(aError, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIIMPORTFILTERS(_to) \
  NS_IMETHOD AutoLocate(PRUnichar * *aDescription, nsIFile * *aLocation, bool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->AutoLocate(aDescription, aLocation, _retval); } \
  NS_IMETHOD SetLocation(nsIFile *aLocation) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetLocation(aLocation); } \
  NS_IMETHOD Import(PRUnichar * *aError, bool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->Import(aError, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsImportFilters : public nsIImportFilters
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIIMPORTFILTERS

  nsImportFilters();

private:
  ~nsImportFilters();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsImportFilters, nsIImportFilters)

nsImportFilters::nsImportFilters()
{
  /* member initializers and constructor code */
}

nsImportFilters::~nsImportFilters()
{
  /* destructor code */
}

/* boolean AutoLocate (out wstring aDescription, out nsIFile aLocation); */
NS_IMETHODIMP nsImportFilters::AutoLocate(PRUnichar * *aDescription, nsIFile * *aLocation, bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void SetLocation (in nsIFile aLocation); */
NS_IMETHODIMP nsImportFilters::SetLocation(nsIFile *aLocation)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean Import (out wstring aError); */
NS_IMETHODIMP nsImportFilters::Import(PRUnichar * *aError, bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif



#endif /* __gen_nsIImportFilters_h__ */
