/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/news/public/nsIMsgOfflineNewsState.idl
 */

#ifndef __gen_nsIMsgOfflineNewsState_h__
#define __gen_nsIMsgOfflineNewsState_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIMsgOfflineNewsState */
#define NS_IMSGOFFLINENEWSSTATE_IID_STR "921ac210-96b5-11d2-b7eb-00805f05ffa5"

#define NS_IMSGOFFLINENEWSSTATE_IID \
  {0x921ac210, 0x96b5, 0x11d2, \
    { 0xb7, 0xeb, 0x00, 0x80, 0x5f, 0x05, 0xff, 0xa5 }}

class NS_NO_VTABLE nsIMsgOfflineNewsState : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IMSGOFFLINENEWSSTATE_IID)

  /* long Process (out string outputBuffer, in long bufferSize); */
  NS_IMETHOD Process(char * *outputBuffer, int32_t bufferSize, int32_t *_retval) = 0;

  /* long Interrupt (); */
  NS_IMETHOD Interrupt(int32_t *_retval) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIMsgOfflineNewsState, NS_IMSGOFFLINENEWSSTATE_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGOFFLINENEWSSTATE \
  NS_IMETHOD Process(char * *outputBuffer, int32_t bufferSize, int32_t *_retval); \
  NS_IMETHOD Interrupt(int32_t *_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGOFFLINENEWSSTATE(_to) \
  NS_IMETHOD Process(char * *outputBuffer, int32_t bufferSize, int32_t *_retval) { return _to Process(outputBuffer, bufferSize, _retval); } \
  NS_IMETHOD Interrupt(int32_t *_retval) { return _to Interrupt(_retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGOFFLINENEWSSTATE(_to) \
  NS_IMETHOD Process(char * *outputBuffer, int32_t bufferSize, int32_t *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->Process(outputBuffer, bufferSize, _retval); } \
  NS_IMETHOD Interrupt(int32_t *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->Interrupt(_retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgOfflineNewsState : public nsIMsgOfflineNewsState
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGOFFLINENEWSSTATE

  nsMsgOfflineNewsState();

private:
  ~nsMsgOfflineNewsState();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgOfflineNewsState, nsIMsgOfflineNewsState)

nsMsgOfflineNewsState::nsMsgOfflineNewsState()
{
  /* member initializers and constructor code */
}

nsMsgOfflineNewsState::~nsMsgOfflineNewsState()
{
  /* destructor code */
}

/* long Process (out string outputBuffer, in long bufferSize); */
NS_IMETHODIMP nsMsgOfflineNewsState::Process(char * *outputBuffer, int32_t bufferSize, int32_t *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* long Interrupt (); */
NS_IMETHODIMP nsMsgOfflineNewsState::Interrupt(int32_t *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgOfflineNewsState_h__ */
