/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "domstubs.idl"

/**
 * The nsIDOMBarProp interface is the interface for controlling and
 * accessing the visibility of certain UI items (scrollbars, menubars,
 * toolbars, ...) through the DOM.
 */

[scriptable, uuid(9eb2c150-1d56-11d3-8221-0060083a0bcf)]
interface nsIDOMBarProp : nsISupports
{
           attribute boolean          visible;
};
