/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/base/public/nsIMsgCustomColumnHandler.idl
 */

#ifndef __gen_nsIMsgCustomColumnHandler_h__
#define __gen_nsIMsgCustomColumnHandler_h__


#ifndef __gen_nsITreeView_h__
#include "nsITreeView.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIMsgDBHdr; /* forward declaration */


/* starting interface:    nsIMsgCustomColumnHandler */
#define NS_IMSGCUSTOMCOLUMNHANDLER_IID_STR "00f75b13-3ac4-4a17-a8b9-c6e4dd1b3f32"

#define NS_IMSGCUSTOMCOLUMNHANDLER_IID \
  {0x00f75b13, 0x3ac4, 0x4a17, \
    { 0xa8, 0xb9, 0xc6, 0xe4, 0xdd, 0x1b, 0x3f, 0x32 }}

class NS_NO_VTABLE nsIMsgCustomColumnHandler : public nsITreeView {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IMSGCUSTOMCOLUMNHANDLER_IID)

  /* AString getSortStringForRow (in nsIMsgDBHdr aHdr); */
  NS_IMETHOD GetSortStringForRow(nsIMsgDBHdr *aHdr, nsAString & _retval) = 0;

  /* unsigned long getSortLongForRow (in nsIMsgDBHdr aHdr); */
  NS_IMETHOD GetSortLongForRow(nsIMsgDBHdr *aHdr, uint32_t *_retval) = 0;

  /* boolean isString (); */
  NS_IMETHOD IsString(bool *_retval) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIMsgCustomColumnHandler, NS_IMSGCUSTOMCOLUMNHANDLER_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGCUSTOMCOLUMNHANDLER \
  NS_IMETHOD GetSortStringForRow(nsIMsgDBHdr *aHdr, nsAString & _retval); \
  NS_IMETHOD GetSortLongForRow(nsIMsgDBHdr *aHdr, uint32_t *_retval); \
  NS_IMETHOD IsString(bool *_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGCUSTOMCOLUMNHANDLER(_to) \
  NS_IMETHOD GetSortStringForRow(nsIMsgDBHdr *aHdr, nsAString & _retval) { return _to GetSortStringForRow(aHdr, _retval); } \
  NS_IMETHOD GetSortLongForRow(nsIMsgDBHdr *aHdr, uint32_t *_retval) { return _to GetSortLongForRow(aHdr, _retval); } \
  NS_IMETHOD IsString(bool *_retval) { return _to IsString(_retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGCUSTOMCOLUMNHANDLER(_to) \
  NS_IMETHOD GetSortStringForRow(nsIMsgDBHdr *aHdr, nsAString & _retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSortStringForRow(aHdr, _retval); } \
  NS_IMETHOD GetSortLongForRow(nsIMsgDBHdr *aHdr, uint32_t *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSortLongForRow(aHdr, _retval); } \
  NS_IMETHOD IsString(bool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->IsString(_retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgCustomColumnHandler : public nsIMsgCustomColumnHandler
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGCUSTOMCOLUMNHANDLER

  nsMsgCustomColumnHandler();

private:
  ~nsMsgCustomColumnHandler();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgCustomColumnHandler, nsIMsgCustomColumnHandler)

nsMsgCustomColumnHandler::nsMsgCustomColumnHandler()
{
  /* member initializers and constructor code */
}

nsMsgCustomColumnHandler::~nsMsgCustomColumnHandler()
{
  /* destructor code */
}

/* AString getSortStringForRow (in nsIMsgDBHdr aHdr); */
NS_IMETHODIMP nsMsgCustomColumnHandler::GetSortStringForRow(nsIMsgDBHdr *aHdr, nsAString & _retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* unsigned long getSortLongForRow (in nsIMsgDBHdr aHdr); */
NS_IMETHODIMP nsMsgCustomColumnHandler::GetSortLongForRow(nsIMsgDBHdr *aHdr, uint32_t *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean isString (); */
NS_IMETHODIMP nsMsgCustomColumnHandler::IsString(bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgCustomColumnHandler_h__ */
