/* THIS FILE IS AUTOGENERATED - DO NOT EDIT */

#ifndef mozilla_dom_CSSStyleDeclarationBinding_h__
#define mozilla_dom_CSSStyleDeclarationBinding_h__

#include "mozilla/dom/BindingUtils.h"
#include "mozilla/dom/DOMJSClass.h"
#include "mozilla/dom/DOMJSProxyHandler.h"

class XPCWrappedNativeScope;
class nsICSSDeclaration;


namespace mozilla {
namespace dom {

template <>
struct PrototypeTraits<prototypes::id::CSSStyleDeclaration>
{
  enum
  {
    Depth = 0
  };
  typedef nsICSSDeclaration NativeType;
};
template <>
struct PrototypeIDMap<nsICSSDeclaration>
{
  enum
  {
    PrototypeID = prototypes::id::CSSStyleDeclaration
  };
};
} // namespace dom
} // namespace mozilla


namespace mozilla {
namespace dom {

namespace CSSStyleDeclarationBinding {

  JSObject*
  CreateInterfaceObjects(JSContext* aCx, JSObject* aGlobal, JSObject* aReceiver);

  inline JSObject* GetProtoObject(JSContext* aCx, JSObject* aGlobal, JSObject* aReceiver)
  {

    /* Get the interface prototype object for this class.  This will create the
       object as needed. */

    /* aGlobal and aReceiver are usually the same, but they can be different
       too. For example a sandbox often has an xray wrapper for a window as the
       prototype of the sandbox's global. In that case aReceiver is the xray
       wrapper and aGlobal is the sandbox's global.
     */

    /* Make sure our global is sane.  Hopefully we can remove this sometime */
    if (!(js::GetObjectClass(aGlobal)->flags & JSCLASS_DOM_GLOBAL)) {
      return NULL;
    }
    /* Check to see whether the interface objects are already installed */
    JSObject** protoOrIfaceArray = GetProtoOrIfaceArray(aGlobal);
    JSObject* cachedObject = protoOrIfaceArray[prototypes::id::CSSStyleDeclaration];
    if (!cachedObject) {
      protoOrIfaceArray[prototypes::id::CSSStyleDeclaration] = cachedObject = CreateInterfaceObjects(aCx, aGlobal, aReceiver);
    }

    /* cachedObject might _still_ be null, but that's OK */
    return cachedObject;
  }

  bool
  ResolveOwnProperty(JSContext* cx, JSObject* wrapper, jsid id, bool set, JSPropertyDescriptor* desc);

  bool
  EnumerateOwnProperties(JSContext* cx, JSObject* wrapper, JS::AutoIdVector& props);

  bool
  ResolveProperty(JSContext* cx, JSObject* wrapper, jsid id, bool set, JSPropertyDescriptor* desc);

  bool
  EnumerateProperties(JSContext* cx, JSObject* wrapper, JS::AutoIdVector& props);

  bool
  DefineDOMInterface(JSContext* aCx, JSObject* aReceiver, bool* aEnabled);

  extern const NativePropertyHooks NativeHooks;

  extern const DOMClass Class;

  class DOMProxyHandler : public mozilla::dom::DOMProxyHandler
  {
  public:
    static DOMProxyHandler instance;

    inline DOMProxyHandler();

    bool
    getOwnPropertyDescriptor(JSContext* cx, JSObject* proxy, jsid id, bool set, JSPropertyDescriptor* desc);

    bool
    getOwnPropertyNames(JSContext* cx, JSObject* proxy, JS::AutoIdVector& props);

    bool
    hasOwn(JSContext* cx, JSObject* proxy, jsid id, bool* bp);

    bool
    get(JSContext* cx, JSObject* proxy, JSObject* receiver, jsid id, JS::Value* vp);

    JSString*
    obj_toString(JSContext* cx, JSObject* proxy);

    void
    finalize(JSFreeOp* fop, JSObject* proxy);

    bool
    getElementIfPresent(JSContext* cx, JSObject* proxy, JSObject* receiver, uint32_t index, JS::Value* vp, bool* present);
  };

  bool
  Is(JSObject* obj);

  JSObject*
  Wrap(JSContext* aCx, JSObject* aScope, nsICSSDeclaration* aObject, nsWrapperCache* aCache, bool* aTriedToWrap);

  template <class T>
  inline JSObject* Wrap(JSContext* aCx, JSObject* aScope, T* aObject, bool* aTriedToWrap)
  {
    return Wrap(aCx, aScope, aObject, aObject, aTriedToWrap);
  }

} // namespace CSSStyleDeclarationBinding



} // namespace dom
} // namespace mozilla

#endif // mozilla_dom_CSSStyleDeclarationBinding_h__