/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/addrbook/public/nsIAddrDBListener.idl
 */

#ifndef __gen_nsIAddrDBListener_h__
#define __gen_nsIAddrDBListener_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsIAbCard_h__
#include "nsIAbCard.h"
#endif

#ifndef __gen_nsIAbDirectory_h__
#include "nsIAbDirectory.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIAddrDBAnnouncer; /* forward declaration */


/* starting interface:    nsIAddrDBListener */
#define NS_IADDRDBLISTENER_IID_STR "5d7e5a7a-1ac9-46dc-abfd-758c98be26e9"

#define NS_IADDRDBLISTENER_IID \
  {0x5d7e5a7a, 0x1ac9, 0x46dc, \
    { 0xab, 0xfd, 0x75, 0x8c, 0x98, 0xbe, 0x26, 0xe9 }}

class NS_NO_VTABLE nsIAddrDBListener : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IADDRDBLISTENER_IID)

  /* void onCardAttribChange (in unsigned long abCode); */
  NS_IMETHOD OnCardAttribChange(uint32_t abCode) = 0;

  /* void onCardEntryChange (in unsigned long aAbCode, in nsIAbCard aCard, in nsIAbDirectory aParent); */
  NS_IMETHOD OnCardEntryChange(uint32_t aAbCode, nsIAbCard *aCard, nsIAbDirectory *aParent) = 0;

  /* void onListEntryChange (in unsigned long abCode, in nsIAbDirectory list); */
  NS_IMETHOD OnListEntryChange(uint32_t abCode, nsIAbDirectory *list) = 0;

  /* void onAnnouncerGoingAway (); */
  NS_IMETHOD OnAnnouncerGoingAway(void) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIAddrDBListener, NS_IADDRDBLISTENER_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIADDRDBLISTENER \
  NS_IMETHOD OnCardAttribChange(uint32_t abCode); \
  NS_IMETHOD OnCardEntryChange(uint32_t aAbCode, nsIAbCard *aCard, nsIAbDirectory *aParent); \
  NS_IMETHOD OnListEntryChange(uint32_t abCode, nsIAbDirectory *list); \
  NS_IMETHOD OnAnnouncerGoingAway(void); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIADDRDBLISTENER(_to) \
  NS_IMETHOD OnCardAttribChange(uint32_t abCode) { return _to OnCardAttribChange(abCode); } \
  NS_IMETHOD OnCardEntryChange(uint32_t aAbCode, nsIAbCard *aCard, nsIAbDirectory *aParent) { return _to OnCardEntryChange(aAbCode, aCard, aParent); } \
  NS_IMETHOD OnListEntryChange(uint32_t abCode, nsIAbDirectory *list) { return _to OnListEntryChange(abCode, list); } \
  NS_IMETHOD OnAnnouncerGoingAway(void) { return _to OnAnnouncerGoingAway(); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIADDRDBLISTENER(_to) \
  NS_IMETHOD OnCardAttribChange(uint32_t abCode) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnCardAttribChange(abCode); } \
  NS_IMETHOD OnCardEntryChange(uint32_t aAbCode, nsIAbCard *aCard, nsIAbDirectory *aParent) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnCardEntryChange(aAbCode, aCard, aParent); } \
  NS_IMETHOD OnListEntryChange(uint32_t abCode, nsIAbDirectory *list) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnListEntryChange(abCode, list); } \
  NS_IMETHOD OnAnnouncerGoingAway(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnAnnouncerGoingAway(); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsAddrDBListener : public nsIAddrDBListener
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIADDRDBLISTENER

  nsAddrDBListener();

private:
  ~nsAddrDBListener();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsAddrDBListener, nsIAddrDBListener)

nsAddrDBListener::nsAddrDBListener()
{
  /* member initializers and constructor code */
}

nsAddrDBListener::~nsAddrDBListener()
{
  /* destructor code */
}

/* void onCardAttribChange (in unsigned long abCode); */
NS_IMETHODIMP nsAddrDBListener::OnCardAttribChange(uint32_t abCode)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void onCardEntryChange (in unsigned long aAbCode, in nsIAbCard aCard, in nsIAbDirectory aParent); */
NS_IMETHODIMP nsAddrDBListener::OnCardEntryChange(uint32_t aAbCode, nsIAbCard *aCard, nsIAbDirectory *aParent)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void onListEntryChange (in unsigned long abCode, in nsIAbDirectory list); */
NS_IMETHODIMP nsAddrDBListener::OnListEntryChange(uint32_t abCode, nsIAbDirectory *list)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void onAnnouncerGoingAway (); */
NS_IMETHODIMP nsAddrDBListener::OnAnnouncerGoingAway()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIAddrDBListener_h__ */
