/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/imap/public/nsIImapService.idl
 */

#ifndef __gen_nsIImapService_h__
#define __gen_nsIImapService_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsIImapUrl_h__
#include "nsIImapUrl.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIImapProtocol; /* forward declaration */

class nsIImapMessageSink; /* forward declaration */

class nsIUrlListener; /* forward declaration */

class nsIURI; /* forward declaration */

class nsIFile; /* forward declaration */

class nsIMsgFolder; /* forward declaration */

class nsIMsgWindow; /* forward declaration */

class nsIImapIncomingServer; /* forward declaration */

class nsICacheSession; /* forward declaration */


/* starting interface:    nsIImapService */
#define NS_IIMAPSERVICE_IID_STR "aba44b3d-7a0f-4987-8794-96d2de66d966"

#define NS_IIMAPSERVICE_IID \
  {0xaba44b3d, 0x7a0f, 0x4987, \
    { 0x87, 0x94, 0x96, 0xd2, 0xde, 0x66, 0xd9, 0x66 }}

class NS_NO_VTABLE nsIImapService : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IIMAPSERVICE_IID)

  /* void selectFolder (in nsIMsgFolder aImapMailFolder, in nsIUrlListener aUrlListener, in nsIMsgWindow aMsgWindow, out nsIURI aURL); */
  NS_IMETHOD SelectFolder(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *aURL) = 0;

  /* nsIURI liteSelectFolder (in nsIMsgFolder aImapMailFolder, in nsIUrlListener aUrlListener, in nsIMsgWindow aMsgWindow); */
  NS_IMETHOD LiteSelectFolder(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *_retval) = 0;

  /* void addImapFetchToUrl (in nsIURI aURL, in nsIMsgFolder aImapMailFolder, in ACString aMessageIdentifierList, in ACString aAdditionalHeader); */
  NS_IMETHOD AddImapFetchToUrl(nsIURI *aURL, nsIMsgFolder *aImapMailFolder, const nsACString & aMessageIdentifierList, const nsACString & aAdditionalHeader) = 0;

  /* void fetchMessage (in nsIImapUrl aUrl, in nsImapState aImapAction, in nsIMsgFolder aImapMailFolder, in nsIImapMessageSink aImapMessageSink, in nsIMsgWindow aMsgWindow, in nsISupports aConsumer, in ACString aMessageIdentifierList, in boolean convertDataToText, in ACString additionalHeader, out nsIURI aOutURL); */
  NS_IMETHOD FetchMessage(nsIImapUrl *aUrl, nsImapState aImapAction, nsIMsgFolder *aImapMailFolder, nsIImapMessageSink *aImapMessageSink, nsIMsgWindow *aMsgWindow, nsISupports *aConsumer, const nsACString & aMessageIdentifierList, bool convertDataToText, const nsACString & additionalHeader, nsIURI * *aOutURL) = 0;

  /* void noop (in nsIMsgFolder aImapMailFolder, in nsIUrlListener aUrlListener, out nsIURI aURL); */
  NS_IMETHOD Noop(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *aURL) = 0;

  /* void getHeaders (in nsIMsgFolder aImapMailFolder, in nsIUrlListener aUrlListener, out nsIURI aURL, in ACString aMessageIdentifierList, in boolean aMessageIdsAreUID); */
  NS_IMETHOD GetHeaders(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *aURL, const nsACString & aMessageIdentifierList, bool aMessageIdsAreUID) = 0;

  /* nsIURI getBodyStart (in nsIMsgFolder aImapMailFolder, in nsIUrlListener aUrlListener, in ACString aMessageIdentifierList, in long numBytes); */
  NS_IMETHOD GetBodyStart(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, const nsACString & aMessageIdentifierList, int32_t numBytes, nsIURI * *_retval) = 0;

  /* void expunge (in nsIMsgFolder aImapMailFolder, in nsIUrlListener aUrlListener, in nsIMsgWindow aMsgWindow, out nsIURI aURL); */
  NS_IMETHOD Expunge(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *aURL) = 0;

  /* nsIURI updateFolderStatus (in nsIMsgFolder aImapMailFolder, in nsIUrlListener aUrlListener); */
  NS_IMETHOD UpdateFolderStatus(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *_retval) = 0;

  /* nsIURI verifyLogon (in nsIMsgFolder aImapMailFolder, in nsIUrlListener aUrlListener, in nsIMsgWindow aMsgWindow); */
  NS_IMETHOD VerifyLogon(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *_retval) = 0;

  /* void biff (in nsIMsgFolder aImapMailFolder, in nsIUrlListener aUrlListener, out nsIURI aURL, in unsigned long aUidHighWater); */
  NS_IMETHOD Biff(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *aURL, uint32_t aUidHighWater) = 0;

  /* void deleteMessages (in nsIMsgFolder aImapMailFolder, in nsIUrlListener aUrlListener, out nsIURI aURL, in ACString aMessageIdentifierList, in boolean aMessageIdsAreUID); */
  NS_IMETHOD DeleteMessages(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *aURL, const nsACString & aMessageIdentifierList, bool aMessageIdsAreUID) = 0;

  /* void deleteAllMessages (in nsIMsgFolder aImapMailFolder, in nsIUrlListener aUrlListener, out nsIURI aURL); */
  NS_IMETHOD DeleteAllMessages(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *aURL) = 0;

  /* void addMessageFlags (in nsIMsgFolder aImapMailFolder, in nsIUrlListener aUrlListener, out nsIURI aURL, in ACString aMessageIdentifierList, in imapMessageFlagsType aFlags, in boolean aMessageIdsAreUID); */
  NS_IMETHOD AddMessageFlags(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *aURL, const nsACString & aMessageIdentifierList, imapMessageFlagsType aFlags, bool aMessageIdsAreUID) = 0;

  /* void subtractMessageFlags (in nsIMsgFolder aImapMailFolder, in nsIUrlListener aUrlListener, out nsIURI aURL, in ACString aMessageIdentifierList, in imapMessageFlagsType aFlags, in boolean aMessageIdsAreUID); */
  NS_IMETHOD SubtractMessageFlags(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *aURL, const nsACString & aMessageIdentifierList, imapMessageFlagsType aFlags, bool aMessageIdsAreUID) = 0;

  /* void setMessageFlags (in nsIMsgFolder aImapMailFolder, in nsIUrlListener aUrlListener, out nsIURI aURL, in ACString aMessageIdentifierList, in imapMessageFlagsType aFlags, in boolean aMessageIdsAreUID); */
  NS_IMETHOD SetMessageFlags(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *aURL, const nsACString & aMessageIdentifierList, imapMessageFlagsType aFlags, bool aMessageIdsAreUID) = 0;

  /* void discoverAllFolders (in nsIMsgFolder aImapMailFolder, in nsIUrlListener aUrlListener, in nsIMsgWindow aMsgWindow, out nsIURI aURL); */
  NS_IMETHOD DiscoverAllFolders(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *aURL) = 0;

  /* void discoverAllAndSubscribedFolders (in nsIMsgFolder aImapMailFolder, in nsIUrlListener aUrlListener, out nsIURI aURL); */
  NS_IMETHOD DiscoverAllAndSubscribedFolders(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *aURL) = 0;

  /* void discoverChildren (in nsIMsgFolder aImapMailFolder, in nsIUrlListener aUrlListener, in ACString folderPath, out nsIURI aURL); */
  NS_IMETHOD DiscoverChildren(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, const nsACString & folderPath, nsIURI * *aURL) = 0;

  /* void onlineMessageCopy (in nsIMsgFolder aSrcFolder, in ACString aMessageIds, in nsIMsgFolder aDstFolder, in boolean aIdsAreUids, in boolean aIsMove, in nsIUrlListener aUrlListener, out nsIURI aURL, in nsISupports aCopyState, in nsIMsgWindow aWindow); */
  NS_IMETHOD OnlineMessageCopy(nsIMsgFolder *aSrcFolder, const nsACString & aMessageIds, nsIMsgFolder *aDstFolder, bool aIdsAreUids, bool aIsMove, nsIUrlListener *aUrlListener, nsIURI * *aURL, nsISupports *aCopyState, nsIMsgWindow *aWindow) = 0;

  /* void appendMessageFromFile (in nsIFile aFile, in nsIMsgFolder aDstFolder, in ACString aMessageId, in boolean idsAreUids, in boolean aInSelectedState, in nsIUrlListener aUrlListener, out nsIURI aURL, in nsISupports aCopyState, in nsIMsgWindow aMsgWindow); */
  NS_IMETHOD AppendMessageFromFile(nsIFile *aFile, nsIMsgFolder *aDstFolder, const nsACString & aMessageId, bool idsAreUids, bool aInSelectedState, nsIUrlListener *aUrlListener, nsIURI * *aURL, nsISupports *aCopyState, nsIMsgWindow *aMsgWindow) = 0;

  /* void downloadMessagesForOffline (in ACString aMessageIds, in nsIMsgFolder aSrcFolder, in nsIUrlListener aListener, in nsIMsgWindow aMsgWindow); */
  NS_IMETHOD DownloadMessagesForOffline(const nsACString & aMessageIds, nsIMsgFolder *aSrcFolder, nsIUrlListener *aListener, nsIMsgWindow *aMsgWindow) = 0;

  /* nsIURI moveFolder (in nsIMsgFolder aSrcFolder, in nsIMsgFolder aDstFolder, in nsIUrlListener aUrlListener, in nsIMsgWindow msgWindow); */
  NS_IMETHOD MoveFolder(nsIMsgFolder *aSrcFolder, nsIMsgFolder *aDstFolder, nsIUrlListener *aUrlListener, nsIMsgWindow *msgWindow, nsIURI * *_retval) = 0;

  /* nsIURI renameLeaf (in nsIMsgFolder aSrcFolder, in AString aLeafName, in nsIUrlListener aUrlListener, in nsIMsgWindow msgWindow); */
  NS_IMETHOD RenameLeaf(nsIMsgFolder *aSrcFolder, const nsAString & aLeafName, nsIUrlListener *aUrlListener, nsIMsgWindow *msgWindow, nsIURI * *_retval) = 0;

  /* nsIURI deleteFolder (in nsIMsgFolder aFolder, in nsIUrlListener aUrlListener, in nsIMsgWindow aMsgWindow); */
  NS_IMETHOD DeleteFolder(nsIMsgFolder *aFolder, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *_retval) = 0;

  /* nsIURI createFolder (in nsIMsgFolder aParentFolder, in AString aLeafName, in nsIUrlListener aUrlListener); */
  NS_IMETHOD CreateFolder(nsIMsgFolder *aParentFolder, const nsAString & aLeafName, nsIUrlListener *aUrlListener, nsIURI * *_retval) = 0;

  /* nsIURI listFolder (in nsIMsgFolder aMailFolder, in nsIUrlListener aUrlListener); */
  NS_IMETHOD ListFolder(nsIMsgFolder *aMailFolder, nsIUrlListener *aUrlListener, nsIURI * *_retval) = 0;

  /* nsIURI subscribeFolder (in nsIMsgFolder aMailFolder, in AString mailboxName, in nsIUrlListener aUrlListener); */
  NS_IMETHOD SubscribeFolder(nsIMsgFolder *aMailFolder, const nsAString & mailboxName, nsIUrlListener *aUrlListener, nsIURI * *_retval) = 0;

  /* nsIURI unsubscribeFolder (in nsIMsgFolder aMailFolder, in AString mailboxName, in nsIUrlListener aUrlListener); */
  NS_IMETHOD UnsubscribeFolder(nsIMsgFolder *aMailFolder, const nsAString & mailboxName, nsIUrlListener *aUrlListener, nsIURI * *_retval) = 0;

  /* nsIURI ensureFolderExists (in nsIMsgFolder aParentFolder, in AString aLeafName, in nsIUrlListener aUrlListener); */
  NS_IMETHOD EnsureFolderExists(nsIMsgFolder *aParentFolder, const nsAString & aLeafName, nsIUrlListener *aUrlListener, nsIURI * *_retval) = 0;

  /* nsIURI getFolderAdminUrl (in nsIMsgFolder aMailFolder, in nsIMsgWindow aMsgWindow, in nsIUrlListener aUrlListener); */
  NS_IMETHOD GetFolderAdminUrl(nsIMsgFolder *aMailFolder, nsIMsgWindow *aMsgWindow, nsIUrlListener *aUrlListener, nsIURI * *_retval) = 0;

  /* nsIURI issueCommandOnMsgs (in nsIMsgFolder aMailFolder, in nsIMsgWindow aMsgWindow, in ACString aCommand, in ACString aMessageIdentifierList); */
  NS_IMETHOD IssueCommandOnMsgs(nsIMsgFolder *aMailFolder, nsIMsgWindow *aMsgWindow, const nsACString & aCommand, const nsACString & aMessageIdentifierList, nsIURI * *_retval) = 0;

  /* nsIURI fetchCustomMsgAttribute (in nsIMsgFolder aMailFolder, in nsIMsgWindow aMsgWindow, in ACString aAttribute, in ACString aMessageIdentifierList); */
  NS_IMETHOD FetchCustomMsgAttribute(nsIMsgFolder *aMailFolder, nsIMsgWindow *aMsgWindow, const nsACString & aAttribute, const nsACString & aMessageIdentifierList, nsIURI * *_retval) = 0;

  /* nsIURI storeCustomKeywords (in nsIMsgFolder aMailFolder, in nsIMsgWindow aMsgWindow, in ACString flagsToAdd, in ACString flagsToSubtract, in ACString aMessageIdentifierList); */
  NS_IMETHOD StoreCustomKeywords(nsIMsgFolder *aMailFolder, nsIMsgWindow *aMsgWindow, const nsACString & flagsToAdd, const nsACString & flagsToSubtract, const nsACString & aMessageIdentifierList, nsIURI * *_retval) = 0;

  /* void getListOfFoldersOnServer (in nsIImapIncomingServer aServer, in nsIMsgWindow aMsgWindow); */
  NS_IMETHOD GetListOfFoldersOnServer(nsIImapIncomingServer *aServer, nsIMsgWindow *aMsgWindow) = 0;

  /* void getListOfFoldersWithPath (in nsIImapIncomingServer aServer, in nsIMsgWindow aMsgWindow, in ACString folderPath); */
  NS_IMETHOD GetListOfFoldersWithPath(nsIImapIncomingServer *aServer, nsIMsgWindow *aMsgWindow, const nsACString & folderPath) = 0;

  /* nsISupports playbackAllOfflineOperations (in nsIMsgWindow aMsgWindow, in nsIUrlListener aListener); */
  NS_IMETHOD PlaybackAllOfflineOperations(nsIMsgWindow *aMsgWindow, nsIUrlListener *aListener, nsISupports * *_retval) = 0;

  /* void downloadAllOffineImapFolders (in nsIMsgWindow aMsgWindow, in nsIUrlListener aListener); */
  NS_IMETHOD DownloadAllOffineImapFolders(nsIMsgWindow *aMsgWindow, nsIUrlListener *aListener) = 0;

  /* readonly attribute nsICacheSession cacheSession; */
  NS_IMETHOD GetCacheSession(nsICacheSession * *aCacheSession) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIImapService, NS_IIMAPSERVICE_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIIMAPSERVICE \
  NS_IMETHOD SelectFolder(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *aURL); \
  NS_IMETHOD LiteSelectFolder(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *_retval); \
  NS_IMETHOD AddImapFetchToUrl(nsIURI *aURL, nsIMsgFolder *aImapMailFolder, const nsACString & aMessageIdentifierList, const nsACString & aAdditionalHeader); \
  NS_IMETHOD FetchMessage(nsIImapUrl *aUrl, nsImapState aImapAction, nsIMsgFolder *aImapMailFolder, nsIImapMessageSink *aImapMessageSink, nsIMsgWindow *aMsgWindow, nsISupports *aConsumer, const nsACString & aMessageIdentifierList, bool convertDataToText, const nsACString & additionalHeader, nsIURI * *aOutURL); \
  NS_IMETHOD Noop(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *aURL); \
  NS_IMETHOD GetHeaders(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *aURL, const nsACString & aMessageIdentifierList, bool aMessageIdsAreUID); \
  NS_IMETHOD GetBodyStart(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, const nsACString & aMessageIdentifierList, int32_t numBytes, nsIURI * *_retval); \
  NS_IMETHOD Expunge(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *aURL); \
  NS_IMETHOD UpdateFolderStatus(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *_retval); \
  NS_IMETHOD VerifyLogon(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *_retval); \
  NS_IMETHOD Biff(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *aURL, uint32_t aUidHighWater); \
  NS_IMETHOD DeleteMessages(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *aURL, const nsACString & aMessageIdentifierList, bool aMessageIdsAreUID); \
  NS_IMETHOD DeleteAllMessages(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *aURL); \
  NS_IMETHOD AddMessageFlags(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *aURL, const nsACString & aMessageIdentifierList, imapMessageFlagsType aFlags, bool aMessageIdsAreUID); \
  NS_IMETHOD SubtractMessageFlags(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *aURL, const nsACString & aMessageIdentifierList, imapMessageFlagsType aFlags, bool aMessageIdsAreUID); \
  NS_IMETHOD SetMessageFlags(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *aURL, const nsACString & aMessageIdentifierList, imapMessageFlagsType aFlags, bool aMessageIdsAreUID); \
  NS_IMETHOD DiscoverAllFolders(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *aURL); \
  NS_IMETHOD DiscoverAllAndSubscribedFolders(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *aURL); \
  NS_IMETHOD DiscoverChildren(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, const nsACString & folderPath, nsIURI * *aURL); \
  NS_IMETHOD OnlineMessageCopy(nsIMsgFolder *aSrcFolder, const nsACString & aMessageIds, nsIMsgFolder *aDstFolder, bool aIdsAreUids, bool aIsMove, nsIUrlListener *aUrlListener, nsIURI * *aURL, nsISupports *aCopyState, nsIMsgWindow *aWindow); \
  NS_IMETHOD AppendMessageFromFile(nsIFile *aFile, nsIMsgFolder *aDstFolder, const nsACString & aMessageId, bool idsAreUids, bool aInSelectedState, nsIUrlListener *aUrlListener, nsIURI * *aURL, nsISupports *aCopyState, nsIMsgWindow *aMsgWindow); \
  NS_IMETHOD DownloadMessagesForOffline(const nsACString & aMessageIds, nsIMsgFolder *aSrcFolder, nsIUrlListener *aListener, nsIMsgWindow *aMsgWindow); \
  NS_IMETHOD MoveFolder(nsIMsgFolder *aSrcFolder, nsIMsgFolder *aDstFolder, nsIUrlListener *aUrlListener, nsIMsgWindow *msgWindow, nsIURI * *_retval); \
  NS_IMETHOD RenameLeaf(nsIMsgFolder *aSrcFolder, const nsAString & aLeafName, nsIUrlListener *aUrlListener, nsIMsgWindow *msgWindow, nsIURI * *_retval); \
  NS_IMETHOD DeleteFolder(nsIMsgFolder *aFolder, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *_retval); \
  NS_IMETHOD CreateFolder(nsIMsgFolder *aParentFolder, const nsAString & aLeafName, nsIUrlListener *aUrlListener, nsIURI * *_retval); \
  NS_IMETHOD ListFolder(nsIMsgFolder *aMailFolder, nsIUrlListener *aUrlListener, nsIURI * *_retval); \
  NS_IMETHOD SubscribeFolder(nsIMsgFolder *aMailFolder, const nsAString & mailboxName, nsIUrlListener *aUrlListener, nsIURI * *_retval); \
  NS_IMETHOD UnsubscribeFolder(nsIMsgFolder *aMailFolder, const nsAString & mailboxName, nsIUrlListener *aUrlListener, nsIURI * *_retval); \
  NS_IMETHOD EnsureFolderExists(nsIMsgFolder *aParentFolder, const nsAString & aLeafName, nsIUrlListener *aUrlListener, nsIURI * *_retval); \
  NS_IMETHOD GetFolderAdminUrl(nsIMsgFolder *aMailFolder, nsIMsgWindow *aMsgWindow, nsIUrlListener *aUrlListener, nsIURI * *_retval); \
  NS_IMETHOD IssueCommandOnMsgs(nsIMsgFolder *aMailFolder, nsIMsgWindow *aMsgWindow, const nsACString & aCommand, const nsACString & aMessageIdentifierList, nsIURI * *_retval); \
  NS_IMETHOD FetchCustomMsgAttribute(nsIMsgFolder *aMailFolder, nsIMsgWindow *aMsgWindow, const nsACString & aAttribute, const nsACString & aMessageIdentifierList, nsIURI * *_retval); \
  NS_IMETHOD StoreCustomKeywords(nsIMsgFolder *aMailFolder, nsIMsgWindow *aMsgWindow, const nsACString & flagsToAdd, const nsACString & flagsToSubtract, const nsACString & aMessageIdentifierList, nsIURI * *_retval); \
  NS_IMETHOD GetListOfFoldersOnServer(nsIImapIncomingServer *aServer, nsIMsgWindow *aMsgWindow); \
  NS_IMETHOD GetListOfFoldersWithPath(nsIImapIncomingServer *aServer, nsIMsgWindow *aMsgWindow, const nsACString & folderPath); \
  NS_IMETHOD PlaybackAllOfflineOperations(nsIMsgWindow *aMsgWindow, nsIUrlListener *aListener, nsISupports * *_retval); \
  NS_IMETHOD DownloadAllOffineImapFolders(nsIMsgWindow *aMsgWindow, nsIUrlListener *aListener); \
  NS_IMETHOD GetCacheSession(nsICacheSession * *aCacheSession); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIIMAPSERVICE(_to) \
  NS_IMETHOD SelectFolder(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *aURL) { return _to SelectFolder(aImapMailFolder, aUrlListener, aMsgWindow, aURL); } \
  NS_IMETHOD LiteSelectFolder(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *_retval) { return _to LiteSelectFolder(aImapMailFolder, aUrlListener, aMsgWindow, _retval); } \
  NS_IMETHOD AddImapFetchToUrl(nsIURI *aURL, nsIMsgFolder *aImapMailFolder, const nsACString & aMessageIdentifierList, const nsACString & aAdditionalHeader) { return _to AddImapFetchToUrl(aURL, aImapMailFolder, aMessageIdentifierList, aAdditionalHeader); } \
  NS_IMETHOD FetchMessage(nsIImapUrl *aUrl, nsImapState aImapAction, nsIMsgFolder *aImapMailFolder, nsIImapMessageSink *aImapMessageSink, nsIMsgWindow *aMsgWindow, nsISupports *aConsumer, const nsACString & aMessageIdentifierList, bool convertDataToText, const nsACString & additionalHeader, nsIURI * *aOutURL) { return _to FetchMessage(aUrl, aImapAction, aImapMailFolder, aImapMessageSink, aMsgWindow, aConsumer, aMessageIdentifierList, convertDataToText, additionalHeader, aOutURL); } \
  NS_IMETHOD Noop(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *aURL) { return _to Noop(aImapMailFolder, aUrlListener, aURL); } \
  NS_IMETHOD GetHeaders(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *aURL, const nsACString & aMessageIdentifierList, bool aMessageIdsAreUID) { return _to GetHeaders(aImapMailFolder, aUrlListener, aURL, aMessageIdentifierList, aMessageIdsAreUID); } \
  NS_IMETHOD GetBodyStart(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, const nsACString & aMessageIdentifierList, int32_t numBytes, nsIURI * *_retval) { return _to GetBodyStart(aImapMailFolder, aUrlListener, aMessageIdentifierList, numBytes, _retval); } \
  NS_IMETHOD Expunge(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *aURL) { return _to Expunge(aImapMailFolder, aUrlListener, aMsgWindow, aURL); } \
  NS_IMETHOD UpdateFolderStatus(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *_retval) { return _to UpdateFolderStatus(aImapMailFolder, aUrlListener, _retval); } \
  NS_IMETHOD VerifyLogon(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *_retval) { return _to VerifyLogon(aImapMailFolder, aUrlListener, aMsgWindow, _retval); } \
  NS_IMETHOD Biff(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *aURL, uint32_t aUidHighWater) { return _to Biff(aImapMailFolder, aUrlListener, aURL, aUidHighWater); } \
  NS_IMETHOD DeleteMessages(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *aURL, const nsACString & aMessageIdentifierList, bool aMessageIdsAreUID) { return _to DeleteMessages(aImapMailFolder, aUrlListener, aURL, aMessageIdentifierList, aMessageIdsAreUID); } \
  NS_IMETHOD DeleteAllMessages(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *aURL) { return _to DeleteAllMessages(aImapMailFolder, aUrlListener, aURL); } \
  NS_IMETHOD AddMessageFlags(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *aURL, const nsACString & aMessageIdentifierList, imapMessageFlagsType aFlags, bool aMessageIdsAreUID) { return _to AddMessageFlags(aImapMailFolder, aUrlListener, aURL, aMessageIdentifierList, aFlags, aMessageIdsAreUID); } \
  NS_IMETHOD SubtractMessageFlags(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *aURL, const nsACString & aMessageIdentifierList, imapMessageFlagsType aFlags, bool aMessageIdsAreUID) { return _to SubtractMessageFlags(aImapMailFolder, aUrlListener, aURL, aMessageIdentifierList, aFlags, aMessageIdsAreUID); } \
  NS_IMETHOD SetMessageFlags(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *aURL, const nsACString & aMessageIdentifierList, imapMessageFlagsType aFlags, bool aMessageIdsAreUID) { return _to SetMessageFlags(aImapMailFolder, aUrlListener, aURL, aMessageIdentifierList, aFlags, aMessageIdsAreUID); } \
  NS_IMETHOD DiscoverAllFolders(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *aURL) { return _to DiscoverAllFolders(aImapMailFolder, aUrlListener, aMsgWindow, aURL); } \
  NS_IMETHOD DiscoverAllAndSubscribedFolders(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *aURL) { return _to DiscoverAllAndSubscribedFolders(aImapMailFolder, aUrlListener, aURL); } \
  NS_IMETHOD DiscoverChildren(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, const nsACString & folderPath, nsIURI * *aURL) { return _to DiscoverChildren(aImapMailFolder, aUrlListener, folderPath, aURL); } \
  NS_IMETHOD OnlineMessageCopy(nsIMsgFolder *aSrcFolder, const nsACString & aMessageIds, nsIMsgFolder *aDstFolder, bool aIdsAreUids, bool aIsMove, nsIUrlListener *aUrlListener, nsIURI * *aURL, nsISupports *aCopyState, nsIMsgWindow *aWindow) { return _to OnlineMessageCopy(aSrcFolder, aMessageIds, aDstFolder, aIdsAreUids, aIsMove, aUrlListener, aURL, aCopyState, aWindow); } \
  NS_IMETHOD AppendMessageFromFile(nsIFile *aFile, nsIMsgFolder *aDstFolder, const nsACString & aMessageId, bool idsAreUids, bool aInSelectedState, nsIUrlListener *aUrlListener, nsIURI * *aURL, nsISupports *aCopyState, nsIMsgWindow *aMsgWindow) { return _to AppendMessageFromFile(aFile, aDstFolder, aMessageId, idsAreUids, aInSelectedState, aUrlListener, aURL, aCopyState, aMsgWindow); } \
  NS_IMETHOD DownloadMessagesForOffline(const nsACString & aMessageIds, nsIMsgFolder *aSrcFolder, nsIUrlListener *aListener, nsIMsgWindow *aMsgWindow) { return _to DownloadMessagesForOffline(aMessageIds, aSrcFolder, aListener, aMsgWindow); } \
  NS_IMETHOD MoveFolder(nsIMsgFolder *aSrcFolder, nsIMsgFolder *aDstFolder, nsIUrlListener *aUrlListener, nsIMsgWindow *msgWindow, nsIURI * *_retval) { return _to MoveFolder(aSrcFolder, aDstFolder, aUrlListener, msgWindow, _retval); } \
  NS_IMETHOD RenameLeaf(nsIMsgFolder *aSrcFolder, const nsAString & aLeafName, nsIUrlListener *aUrlListener, nsIMsgWindow *msgWindow, nsIURI * *_retval) { return _to RenameLeaf(aSrcFolder, aLeafName, aUrlListener, msgWindow, _retval); } \
  NS_IMETHOD DeleteFolder(nsIMsgFolder *aFolder, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *_retval) { return _to DeleteFolder(aFolder, aUrlListener, aMsgWindow, _retval); } \
  NS_IMETHOD CreateFolder(nsIMsgFolder *aParentFolder, const nsAString & aLeafName, nsIUrlListener *aUrlListener, nsIURI * *_retval) { return _to CreateFolder(aParentFolder, aLeafName, aUrlListener, _retval); } \
  NS_IMETHOD ListFolder(nsIMsgFolder *aMailFolder, nsIUrlListener *aUrlListener, nsIURI * *_retval) { return _to ListFolder(aMailFolder, aUrlListener, _retval); } \
  NS_IMETHOD SubscribeFolder(nsIMsgFolder *aMailFolder, const nsAString & mailboxName, nsIUrlListener *aUrlListener, nsIURI * *_retval) { return _to SubscribeFolder(aMailFolder, mailboxName, aUrlListener, _retval); } \
  NS_IMETHOD UnsubscribeFolder(nsIMsgFolder *aMailFolder, const nsAString & mailboxName, nsIUrlListener *aUrlListener, nsIURI * *_retval) { return _to UnsubscribeFolder(aMailFolder, mailboxName, aUrlListener, _retval); } \
  NS_IMETHOD EnsureFolderExists(nsIMsgFolder *aParentFolder, const nsAString & aLeafName, nsIUrlListener *aUrlListener, nsIURI * *_retval) { return _to EnsureFolderExists(aParentFolder, aLeafName, aUrlListener, _retval); } \
  NS_IMETHOD GetFolderAdminUrl(nsIMsgFolder *aMailFolder, nsIMsgWindow *aMsgWindow, nsIUrlListener *aUrlListener, nsIURI * *_retval) { return _to GetFolderAdminUrl(aMailFolder, aMsgWindow, aUrlListener, _retval); } \
  NS_IMETHOD IssueCommandOnMsgs(nsIMsgFolder *aMailFolder, nsIMsgWindow *aMsgWindow, const nsACString & aCommand, const nsACString & aMessageIdentifierList, nsIURI * *_retval) { return _to IssueCommandOnMsgs(aMailFolder, aMsgWindow, aCommand, aMessageIdentifierList, _retval); } \
  NS_IMETHOD FetchCustomMsgAttribute(nsIMsgFolder *aMailFolder, nsIMsgWindow *aMsgWindow, const nsACString & aAttribute, const nsACString & aMessageIdentifierList, nsIURI * *_retval) { return _to FetchCustomMsgAttribute(aMailFolder, aMsgWindow, aAttribute, aMessageIdentifierList, _retval); } \
  NS_IMETHOD StoreCustomKeywords(nsIMsgFolder *aMailFolder, nsIMsgWindow *aMsgWindow, const nsACString & flagsToAdd, const nsACString & flagsToSubtract, const nsACString & aMessageIdentifierList, nsIURI * *_retval) { return _to StoreCustomKeywords(aMailFolder, aMsgWindow, flagsToAdd, flagsToSubtract, aMessageIdentifierList, _retval); } \
  NS_IMETHOD GetListOfFoldersOnServer(nsIImapIncomingServer *aServer, nsIMsgWindow *aMsgWindow) { return _to GetListOfFoldersOnServer(aServer, aMsgWindow); } \
  NS_IMETHOD GetListOfFoldersWithPath(nsIImapIncomingServer *aServer, nsIMsgWindow *aMsgWindow, const nsACString & folderPath) { return _to GetListOfFoldersWithPath(aServer, aMsgWindow, folderPath); } \
  NS_IMETHOD PlaybackAllOfflineOperations(nsIMsgWindow *aMsgWindow, nsIUrlListener *aListener, nsISupports * *_retval) { return _to PlaybackAllOfflineOperations(aMsgWindow, aListener, _retval); } \
  NS_IMETHOD DownloadAllOffineImapFolders(nsIMsgWindow *aMsgWindow, nsIUrlListener *aListener) { return _to DownloadAllOffineImapFolders(aMsgWindow, aListener); } \
  NS_IMETHOD GetCacheSession(nsICacheSession * *aCacheSession) { return _to GetCacheSession(aCacheSession); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIIMAPSERVICE(_to) \
  NS_IMETHOD SelectFolder(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *aURL) { return !_to ? NS_ERROR_NULL_POINTER : _to->SelectFolder(aImapMailFolder, aUrlListener, aMsgWindow, aURL); } \
  NS_IMETHOD LiteSelectFolder(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->LiteSelectFolder(aImapMailFolder, aUrlListener, aMsgWindow, _retval); } \
  NS_IMETHOD AddImapFetchToUrl(nsIURI *aURL, nsIMsgFolder *aImapMailFolder, const nsACString & aMessageIdentifierList, const nsACString & aAdditionalHeader) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddImapFetchToUrl(aURL, aImapMailFolder, aMessageIdentifierList, aAdditionalHeader); } \
  NS_IMETHOD FetchMessage(nsIImapUrl *aUrl, nsImapState aImapAction, nsIMsgFolder *aImapMailFolder, nsIImapMessageSink *aImapMessageSink, nsIMsgWindow *aMsgWindow, nsISupports *aConsumer, const nsACString & aMessageIdentifierList, bool convertDataToText, const nsACString & additionalHeader, nsIURI * *aOutURL) { return !_to ? NS_ERROR_NULL_POINTER : _to->FetchMessage(aUrl, aImapAction, aImapMailFolder, aImapMessageSink, aMsgWindow, aConsumer, aMessageIdentifierList, convertDataToText, additionalHeader, aOutURL); } \
  NS_IMETHOD Noop(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *aURL) { return !_to ? NS_ERROR_NULL_POINTER : _to->Noop(aImapMailFolder, aUrlListener, aURL); } \
  NS_IMETHOD GetHeaders(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *aURL, const nsACString & aMessageIdentifierList, bool aMessageIdsAreUID) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetHeaders(aImapMailFolder, aUrlListener, aURL, aMessageIdentifierList, aMessageIdsAreUID); } \
  NS_IMETHOD GetBodyStart(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, const nsACString & aMessageIdentifierList, int32_t numBytes, nsIURI * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetBodyStart(aImapMailFolder, aUrlListener, aMessageIdentifierList, numBytes, _retval); } \
  NS_IMETHOD Expunge(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *aURL) { return !_to ? NS_ERROR_NULL_POINTER : _to->Expunge(aImapMailFolder, aUrlListener, aMsgWindow, aURL); } \
  NS_IMETHOD UpdateFolderStatus(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->UpdateFolderStatus(aImapMailFolder, aUrlListener, _retval); } \
  NS_IMETHOD VerifyLogon(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->VerifyLogon(aImapMailFolder, aUrlListener, aMsgWindow, _retval); } \
  NS_IMETHOD Biff(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *aURL, uint32_t aUidHighWater) { return !_to ? NS_ERROR_NULL_POINTER : _to->Biff(aImapMailFolder, aUrlListener, aURL, aUidHighWater); } \
  NS_IMETHOD DeleteMessages(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *aURL, const nsACString & aMessageIdentifierList, bool aMessageIdsAreUID) { return !_to ? NS_ERROR_NULL_POINTER : _to->DeleteMessages(aImapMailFolder, aUrlListener, aURL, aMessageIdentifierList, aMessageIdsAreUID); } \
  NS_IMETHOD DeleteAllMessages(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *aURL) { return !_to ? NS_ERROR_NULL_POINTER : _to->DeleteAllMessages(aImapMailFolder, aUrlListener, aURL); } \
  NS_IMETHOD AddMessageFlags(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *aURL, const nsACString & aMessageIdentifierList, imapMessageFlagsType aFlags, bool aMessageIdsAreUID) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddMessageFlags(aImapMailFolder, aUrlListener, aURL, aMessageIdentifierList, aFlags, aMessageIdsAreUID); } \
  NS_IMETHOD SubtractMessageFlags(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *aURL, const nsACString & aMessageIdentifierList, imapMessageFlagsType aFlags, bool aMessageIdsAreUID) { return !_to ? NS_ERROR_NULL_POINTER : _to->SubtractMessageFlags(aImapMailFolder, aUrlListener, aURL, aMessageIdentifierList, aFlags, aMessageIdsAreUID); } \
  NS_IMETHOD SetMessageFlags(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *aURL, const nsACString & aMessageIdentifierList, imapMessageFlagsType aFlags, bool aMessageIdsAreUID) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMessageFlags(aImapMailFolder, aUrlListener, aURL, aMessageIdentifierList, aFlags, aMessageIdsAreUID); } \
  NS_IMETHOD DiscoverAllFolders(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *aURL) { return !_to ? NS_ERROR_NULL_POINTER : _to->DiscoverAllFolders(aImapMailFolder, aUrlListener, aMsgWindow, aURL); } \
  NS_IMETHOD DiscoverAllAndSubscribedFolders(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *aURL) { return !_to ? NS_ERROR_NULL_POINTER : _to->DiscoverAllAndSubscribedFolders(aImapMailFolder, aUrlListener, aURL); } \
  NS_IMETHOD DiscoverChildren(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, const nsACString & folderPath, nsIURI * *aURL) { return !_to ? NS_ERROR_NULL_POINTER : _to->DiscoverChildren(aImapMailFolder, aUrlListener, folderPath, aURL); } \
  NS_IMETHOD OnlineMessageCopy(nsIMsgFolder *aSrcFolder, const nsACString & aMessageIds, nsIMsgFolder *aDstFolder, bool aIdsAreUids, bool aIsMove, nsIUrlListener *aUrlListener, nsIURI * *aURL, nsISupports *aCopyState, nsIMsgWindow *aWindow) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnlineMessageCopy(aSrcFolder, aMessageIds, aDstFolder, aIdsAreUids, aIsMove, aUrlListener, aURL, aCopyState, aWindow); } \
  NS_IMETHOD AppendMessageFromFile(nsIFile *aFile, nsIMsgFolder *aDstFolder, const nsACString & aMessageId, bool idsAreUids, bool aInSelectedState, nsIUrlListener *aUrlListener, nsIURI * *aURL, nsISupports *aCopyState, nsIMsgWindow *aMsgWindow) { return !_to ? NS_ERROR_NULL_POINTER : _to->AppendMessageFromFile(aFile, aDstFolder, aMessageId, idsAreUids, aInSelectedState, aUrlListener, aURL, aCopyState, aMsgWindow); } \
  NS_IMETHOD DownloadMessagesForOffline(const nsACString & aMessageIds, nsIMsgFolder *aSrcFolder, nsIUrlListener *aListener, nsIMsgWindow *aMsgWindow) { return !_to ? NS_ERROR_NULL_POINTER : _to->DownloadMessagesForOffline(aMessageIds, aSrcFolder, aListener, aMsgWindow); } \
  NS_IMETHOD MoveFolder(nsIMsgFolder *aSrcFolder, nsIMsgFolder *aDstFolder, nsIUrlListener *aUrlListener, nsIMsgWindow *msgWindow, nsIURI * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->MoveFolder(aSrcFolder, aDstFolder, aUrlListener, msgWindow, _retval); } \
  NS_IMETHOD RenameLeaf(nsIMsgFolder *aSrcFolder, const nsAString & aLeafName, nsIUrlListener *aUrlListener, nsIMsgWindow *msgWindow, nsIURI * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->RenameLeaf(aSrcFolder, aLeafName, aUrlListener, msgWindow, _retval); } \
  NS_IMETHOD DeleteFolder(nsIMsgFolder *aFolder, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->DeleteFolder(aFolder, aUrlListener, aMsgWindow, _retval); } \
  NS_IMETHOD CreateFolder(nsIMsgFolder *aParentFolder, const nsAString & aLeafName, nsIUrlListener *aUrlListener, nsIURI * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->CreateFolder(aParentFolder, aLeafName, aUrlListener, _retval); } \
  NS_IMETHOD ListFolder(nsIMsgFolder *aMailFolder, nsIUrlListener *aUrlListener, nsIURI * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->ListFolder(aMailFolder, aUrlListener, _retval); } \
  NS_IMETHOD SubscribeFolder(nsIMsgFolder *aMailFolder, const nsAString & mailboxName, nsIUrlListener *aUrlListener, nsIURI * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->SubscribeFolder(aMailFolder, mailboxName, aUrlListener, _retval); } \
  NS_IMETHOD UnsubscribeFolder(nsIMsgFolder *aMailFolder, const nsAString & mailboxName, nsIUrlListener *aUrlListener, nsIURI * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->UnsubscribeFolder(aMailFolder, mailboxName, aUrlListener, _retval); } \
  NS_IMETHOD EnsureFolderExists(nsIMsgFolder *aParentFolder, const nsAString & aLeafName, nsIUrlListener *aUrlListener, nsIURI * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->EnsureFolderExists(aParentFolder, aLeafName, aUrlListener, _retval); } \
  NS_IMETHOD GetFolderAdminUrl(nsIMsgFolder *aMailFolder, nsIMsgWindow *aMsgWindow, nsIUrlListener *aUrlListener, nsIURI * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFolderAdminUrl(aMailFolder, aMsgWindow, aUrlListener, _retval); } \
  NS_IMETHOD IssueCommandOnMsgs(nsIMsgFolder *aMailFolder, nsIMsgWindow *aMsgWindow, const nsACString & aCommand, const nsACString & aMessageIdentifierList, nsIURI * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->IssueCommandOnMsgs(aMailFolder, aMsgWindow, aCommand, aMessageIdentifierList, _retval); } \
  NS_IMETHOD FetchCustomMsgAttribute(nsIMsgFolder *aMailFolder, nsIMsgWindow *aMsgWindow, const nsACString & aAttribute, const nsACString & aMessageIdentifierList, nsIURI * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->FetchCustomMsgAttribute(aMailFolder, aMsgWindow, aAttribute, aMessageIdentifierList, _retval); } \
  NS_IMETHOD StoreCustomKeywords(nsIMsgFolder *aMailFolder, nsIMsgWindow *aMsgWindow, const nsACString & flagsToAdd, const nsACString & flagsToSubtract, const nsACString & aMessageIdentifierList, nsIURI * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->StoreCustomKeywords(aMailFolder, aMsgWindow, flagsToAdd, flagsToSubtract, aMessageIdentifierList, _retval); } \
  NS_IMETHOD GetListOfFoldersOnServer(nsIImapIncomingServer *aServer, nsIMsgWindow *aMsgWindow) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetListOfFoldersOnServer(aServer, aMsgWindow); } \
  NS_IMETHOD GetListOfFoldersWithPath(nsIImapIncomingServer *aServer, nsIMsgWindow *aMsgWindow, const nsACString & folderPath) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetListOfFoldersWithPath(aServer, aMsgWindow, folderPath); } \
  NS_IMETHOD PlaybackAllOfflineOperations(nsIMsgWindow *aMsgWindow, nsIUrlListener *aListener, nsISupports * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->PlaybackAllOfflineOperations(aMsgWindow, aListener, _retval); } \
  NS_IMETHOD DownloadAllOffineImapFolders(nsIMsgWindow *aMsgWindow, nsIUrlListener *aListener) { return !_to ? NS_ERROR_NULL_POINTER : _to->DownloadAllOffineImapFolders(aMsgWindow, aListener); } \
  NS_IMETHOD GetCacheSession(nsICacheSession * *aCacheSession) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetCacheSession(aCacheSession); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsImapService : public nsIImapService
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIIMAPSERVICE

  nsImapService();

private:
  ~nsImapService();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsImapService, nsIImapService)

nsImapService::nsImapService()
{
  /* member initializers and constructor code */
}

nsImapService::~nsImapService()
{
  /* destructor code */
}

/* void selectFolder (in nsIMsgFolder aImapMailFolder, in nsIUrlListener aUrlListener, in nsIMsgWindow aMsgWindow, out nsIURI aURL); */
NS_IMETHODIMP nsImapService::SelectFolder(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *aURL)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIURI liteSelectFolder (in nsIMsgFolder aImapMailFolder, in nsIUrlListener aUrlListener, in nsIMsgWindow aMsgWindow); */
NS_IMETHODIMP nsImapService::LiteSelectFolder(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void addImapFetchToUrl (in nsIURI aURL, in nsIMsgFolder aImapMailFolder, in ACString aMessageIdentifierList, in ACString aAdditionalHeader); */
NS_IMETHODIMP nsImapService::AddImapFetchToUrl(nsIURI *aURL, nsIMsgFolder *aImapMailFolder, const nsACString & aMessageIdentifierList, const nsACString & aAdditionalHeader)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void fetchMessage (in nsIImapUrl aUrl, in nsImapState aImapAction, in nsIMsgFolder aImapMailFolder, in nsIImapMessageSink aImapMessageSink, in nsIMsgWindow aMsgWindow, in nsISupports aConsumer, in ACString aMessageIdentifierList, in boolean convertDataToText, in ACString additionalHeader, out nsIURI aOutURL); */
NS_IMETHODIMP nsImapService::FetchMessage(nsIImapUrl *aUrl, nsImapState aImapAction, nsIMsgFolder *aImapMailFolder, nsIImapMessageSink *aImapMessageSink, nsIMsgWindow *aMsgWindow, nsISupports *aConsumer, const nsACString & aMessageIdentifierList, bool convertDataToText, const nsACString & additionalHeader, nsIURI * *aOutURL)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void noop (in nsIMsgFolder aImapMailFolder, in nsIUrlListener aUrlListener, out nsIURI aURL); */
NS_IMETHODIMP nsImapService::Noop(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *aURL)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void getHeaders (in nsIMsgFolder aImapMailFolder, in nsIUrlListener aUrlListener, out nsIURI aURL, in ACString aMessageIdentifierList, in boolean aMessageIdsAreUID); */
NS_IMETHODIMP nsImapService::GetHeaders(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *aURL, const nsACString & aMessageIdentifierList, bool aMessageIdsAreUID)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIURI getBodyStart (in nsIMsgFolder aImapMailFolder, in nsIUrlListener aUrlListener, in ACString aMessageIdentifierList, in long numBytes); */
NS_IMETHODIMP nsImapService::GetBodyStart(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, const nsACString & aMessageIdentifierList, int32_t numBytes, nsIURI * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void expunge (in nsIMsgFolder aImapMailFolder, in nsIUrlListener aUrlListener, in nsIMsgWindow aMsgWindow, out nsIURI aURL); */
NS_IMETHODIMP nsImapService::Expunge(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *aURL)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIURI updateFolderStatus (in nsIMsgFolder aImapMailFolder, in nsIUrlListener aUrlListener); */
NS_IMETHODIMP nsImapService::UpdateFolderStatus(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIURI verifyLogon (in nsIMsgFolder aImapMailFolder, in nsIUrlListener aUrlListener, in nsIMsgWindow aMsgWindow); */
NS_IMETHODIMP nsImapService::VerifyLogon(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void biff (in nsIMsgFolder aImapMailFolder, in nsIUrlListener aUrlListener, out nsIURI aURL, in unsigned long aUidHighWater); */
NS_IMETHODIMP nsImapService::Biff(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *aURL, uint32_t aUidHighWater)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void deleteMessages (in nsIMsgFolder aImapMailFolder, in nsIUrlListener aUrlListener, out nsIURI aURL, in ACString aMessageIdentifierList, in boolean aMessageIdsAreUID); */
NS_IMETHODIMP nsImapService::DeleteMessages(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *aURL, const nsACString & aMessageIdentifierList, bool aMessageIdsAreUID)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void deleteAllMessages (in nsIMsgFolder aImapMailFolder, in nsIUrlListener aUrlListener, out nsIURI aURL); */
NS_IMETHODIMP nsImapService::DeleteAllMessages(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *aURL)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void addMessageFlags (in nsIMsgFolder aImapMailFolder, in nsIUrlListener aUrlListener, out nsIURI aURL, in ACString aMessageIdentifierList, in imapMessageFlagsType aFlags, in boolean aMessageIdsAreUID); */
NS_IMETHODIMP nsImapService::AddMessageFlags(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *aURL, const nsACString & aMessageIdentifierList, imapMessageFlagsType aFlags, bool aMessageIdsAreUID)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void subtractMessageFlags (in nsIMsgFolder aImapMailFolder, in nsIUrlListener aUrlListener, out nsIURI aURL, in ACString aMessageIdentifierList, in imapMessageFlagsType aFlags, in boolean aMessageIdsAreUID); */
NS_IMETHODIMP nsImapService::SubtractMessageFlags(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *aURL, const nsACString & aMessageIdentifierList, imapMessageFlagsType aFlags, bool aMessageIdsAreUID)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setMessageFlags (in nsIMsgFolder aImapMailFolder, in nsIUrlListener aUrlListener, out nsIURI aURL, in ACString aMessageIdentifierList, in imapMessageFlagsType aFlags, in boolean aMessageIdsAreUID); */
NS_IMETHODIMP nsImapService::SetMessageFlags(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *aURL, const nsACString & aMessageIdentifierList, imapMessageFlagsType aFlags, bool aMessageIdsAreUID)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void discoverAllFolders (in nsIMsgFolder aImapMailFolder, in nsIUrlListener aUrlListener, in nsIMsgWindow aMsgWindow, out nsIURI aURL); */
NS_IMETHODIMP nsImapService::DiscoverAllFolders(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *aURL)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void discoverAllAndSubscribedFolders (in nsIMsgFolder aImapMailFolder, in nsIUrlListener aUrlListener, out nsIURI aURL); */
NS_IMETHODIMP nsImapService::DiscoverAllAndSubscribedFolders(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, nsIURI * *aURL)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void discoverChildren (in nsIMsgFolder aImapMailFolder, in nsIUrlListener aUrlListener, in ACString folderPath, out nsIURI aURL); */
NS_IMETHODIMP nsImapService::DiscoverChildren(nsIMsgFolder *aImapMailFolder, nsIUrlListener *aUrlListener, const nsACString & folderPath, nsIURI * *aURL)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void onlineMessageCopy (in nsIMsgFolder aSrcFolder, in ACString aMessageIds, in nsIMsgFolder aDstFolder, in boolean aIdsAreUids, in boolean aIsMove, in nsIUrlListener aUrlListener, out nsIURI aURL, in nsISupports aCopyState, in nsIMsgWindow aWindow); */
NS_IMETHODIMP nsImapService::OnlineMessageCopy(nsIMsgFolder *aSrcFolder, const nsACString & aMessageIds, nsIMsgFolder *aDstFolder, bool aIdsAreUids, bool aIsMove, nsIUrlListener *aUrlListener, nsIURI * *aURL, nsISupports *aCopyState, nsIMsgWindow *aWindow)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void appendMessageFromFile (in nsIFile aFile, in nsIMsgFolder aDstFolder, in ACString aMessageId, in boolean idsAreUids, in boolean aInSelectedState, in nsIUrlListener aUrlListener, out nsIURI aURL, in nsISupports aCopyState, in nsIMsgWindow aMsgWindow); */
NS_IMETHODIMP nsImapService::AppendMessageFromFile(nsIFile *aFile, nsIMsgFolder *aDstFolder, const nsACString & aMessageId, bool idsAreUids, bool aInSelectedState, nsIUrlListener *aUrlListener, nsIURI * *aURL, nsISupports *aCopyState, nsIMsgWindow *aMsgWindow)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void downloadMessagesForOffline (in ACString aMessageIds, in nsIMsgFolder aSrcFolder, in nsIUrlListener aListener, in nsIMsgWindow aMsgWindow); */
NS_IMETHODIMP nsImapService::DownloadMessagesForOffline(const nsACString & aMessageIds, nsIMsgFolder *aSrcFolder, nsIUrlListener *aListener, nsIMsgWindow *aMsgWindow)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIURI moveFolder (in nsIMsgFolder aSrcFolder, in nsIMsgFolder aDstFolder, in nsIUrlListener aUrlListener, in nsIMsgWindow msgWindow); */
NS_IMETHODIMP nsImapService::MoveFolder(nsIMsgFolder *aSrcFolder, nsIMsgFolder *aDstFolder, nsIUrlListener *aUrlListener, nsIMsgWindow *msgWindow, nsIURI * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIURI renameLeaf (in nsIMsgFolder aSrcFolder, in AString aLeafName, in nsIUrlListener aUrlListener, in nsIMsgWindow msgWindow); */
NS_IMETHODIMP nsImapService::RenameLeaf(nsIMsgFolder *aSrcFolder, const nsAString & aLeafName, nsIUrlListener *aUrlListener, nsIMsgWindow *msgWindow, nsIURI * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIURI deleteFolder (in nsIMsgFolder aFolder, in nsIUrlListener aUrlListener, in nsIMsgWindow aMsgWindow); */
NS_IMETHODIMP nsImapService::DeleteFolder(nsIMsgFolder *aFolder, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow, nsIURI * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIURI createFolder (in nsIMsgFolder aParentFolder, in AString aLeafName, in nsIUrlListener aUrlListener); */
NS_IMETHODIMP nsImapService::CreateFolder(nsIMsgFolder *aParentFolder, const nsAString & aLeafName, nsIUrlListener *aUrlListener, nsIURI * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIURI listFolder (in nsIMsgFolder aMailFolder, in nsIUrlListener aUrlListener); */
NS_IMETHODIMP nsImapService::ListFolder(nsIMsgFolder *aMailFolder, nsIUrlListener *aUrlListener, nsIURI * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIURI subscribeFolder (in nsIMsgFolder aMailFolder, in AString mailboxName, in nsIUrlListener aUrlListener); */
NS_IMETHODIMP nsImapService::SubscribeFolder(nsIMsgFolder *aMailFolder, const nsAString & mailboxName, nsIUrlListener *aUrlListener, nsIURI * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIURI unsubscribeFolder (in nsIMsgFolder aMailFolder, in AString mailboxName, in nsIUrlListener aUrlListener); */
NS_IMETHODIMP nsImapService::UnsubscribeFolder(nsIMsgFolder *aMailFolder, const nsAString & mailboxName, nsIUrlListener *aUrlListener, nsIURI * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIURI ensureFolderExists (in nsIMsgFolder aParentFolder, in AString aLeafName, in nsIUrlListener aUrlListener); */
NS_IMETHODIMP nsImapService::EnsureFolderExists(nsIMsgFolder *aParentFolder, const nsAString & aLeafName, nsIUrlListener *aUrlListener, nsIURI * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIURI getFolderAdminUrl (in nsIMsgFolder aMailFolder, in nsIMsgWindow aMsgWindow, in nsIUrlListener aUrlListener); */
NS_IMETHODIMP nsImapService::GetFolderAdminUrl(nsIMsgFolder *aMailFolder, nsIMsgWindow *aMsgWindow, nsIUrlListener *aUrlListener, nsIURI * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIURI issueCommandOnMsgs (in nsIMsgFolder aMailFolder, in nsIMsgWindow aMsgWindow, in ACString aCommand, in ACString aMessageIdentifierList); */
NS_IMETHODIMP nsImapService::IssueCommandOnMsgs(nsIMsgFolder *aMailFolder, nsIMsgWindow *aMsgWindow, const nsACString & aCommand, const nsACString & aMessageIdentifierList, nsIURI * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIURI fetchCustomMsgAttribute (in nsIMsgFolder aMailFolder, in nsIMsgWindow aMsgWindow, in ACString aAttribute, in ACString aMessageIdentifierList); */
NS_IMETHODIMP nsImapService::FetchCustomMsgAttribute(nsIMsgFolder *aMailFolder, nsIMsgWindow *aMsgWindow, const nsACString & aAttribute, const nsACString & aMessageIdentifierList, nsIURI * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIURI storeCustomKeywords (in nsIMsgFolder aMailFolder, in nsIMsgWindow aMsgWindow, in ACString flagsToAdd, in ACString flagsToSubtract, in ACString aMessageIdentifierList); */
NS_IMETHODIMP nsImapService::StoreCustomKeywords(nsIMsgFolder *aMailFolder, nsIMsgWindow *aMsgWindow, const nsACString & flagsToAdd, const nsACString & flagsToSubtract, const nsACString & aMessageIdentifierList, nsIURI * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void getListOfFoldersOnServer (in nsIImapIncomingServer aServer, in nsIMsgWindow aMsgWindow); */
NS_IMETHODIMP nsImapService::GetListOfFoldersOnServer(nsIImapIncomingServer *aServer, nsIMsgWindow *aMsgWindow)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void getListOfFoldersWithPath (in nsIImapIncomingServer aServer, in nsIMsgWindow aMsgWindow, in ACString folderPath); */
NS_IMETHODIMP nsImapService::GetListOfFoldersWithPath(nsIImapIncomingServer *aServer, nsIMsgWindow *aMsgWindow, const nsACString & folderPath)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsISupports playbackAllOfflineOperations (in nsIMsgWindow aMsgWindow, in nsIUrlListener aListener); */
NS_IMETHODIMP nsImapService::PlaybackAllOfflineOperations(nsIMsgWindow *aMsgWindow, nsIUrlListener *aListener, nsISupports * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void downloadAllOffineImapFolders (in nsIMsgWindow aMsgWindow, in nsIUrlListener aListener); */
NS_IMETHODIMP nsImapService::DownloadAllOffineImapFolders(nsIMsgWindow *aMsgWindow, nsIUrlListener *aListener)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute nsICacheSession cacheSession; */
NS_IMETHODIMP nsImapService::GetCacheSession(nsICacheSession * *aCacheSession)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIImapService_h__ */
