/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "domstubs.idl"

interface nsIDOMSVGPathSegList;

[scriptable, uuid(6ef2b400-dbf4-4c12-8787-fe15caac5648)]
interface nsIDOMSVGAnimatedPathData : nsISupports
{   
  readonly attribute nsIDOMSVGPathSegList   pathSegList;
  readonly attribute nsIDOMSVGPathSegList   normalizedPathSegList;
  readonly attribute nsIDOMSVGPathSegList   animatedPathSegList;
  readonly attribute nsIDOMSVGPathSegList   animatedNormalizedPathSegList;
};

