/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsIDOMCSSValue.idl"

/**
 * The nsIDOMCSSValueList interface is a datatype for a list of CSS
 * values in the Document Object Model.
 *
 * For more information on this interface please see
 * http://www.w3.org/TR/DOM-Level-2-Style
 */

[scriptable, uuid(8f09fa84-39b9-4dca-9b2f-db0eeb186286)]
interface nsIDOMCSSValueList : nsIDOMCSSValue
{
  readonly attribute unsigned long    length;
  nsIDOMCSSValue     item(in unsigned long index);
};
