/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mozilla/xpcom/base/nsrootidl.idl
 */

#ifndef __gen_nsrootidl_h__
#define __gen_nsrootidl_h__

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

#include "nscore.h"
#include "prtime.h"
/*
 * Forward declarations for new string types
 */
class nsAString;
class nsACString;
/* 
 * Start commenting out the C++ versions of the below in the output header
 */
#if 0
typedef bool  bool;

typedef uint8_t  uint8_t;

typedef uint16_t  uint16_t;

typedef uint16_t  PRUnichar;

typedef uint32_t  uint32_t;

typedef uint64_t  uint64_t;

typedef int64_t  PRTime;

typedef int16_t  int16_t;

typedef int32_t  int32_t;

typedef int64_t  int64_t;

typedef uint32_t  nsrefcnt;

typedef uint32_t  nsresult;

typedef uint32_t  size_t;

/* 
 * End commenting out the C++ versions of the above in the output header
 */
#endif

#endif /* __gen_nsrootidl_h__ */
