/* THIS FILE IS AUTOGENERATED - DO NOT EDIT */

#ifndef mozilla_dom_XMLHttpRequestBinding_h__
#define mozilla_dom_XMLHttpRequestBinding_h__

#include "mozilla/dom/BindingUtils.h"
#include "mozilla/dom/DOMJSClass.h"
#include "mozilla/dom/DOMJSProxyHandler.h"

class XPCWrappedNativeScope;
class nsXMLHttpRequest;

namespace mozilla {
namespace dom {
namespace workers {

class XMLHttpRequest;

} // namespace workers
} // namespace dom
} // namespace mozilla


namespace mozilla {
namespace dom {

template <>
struct PrototypeTraits<prototypes::id::XMLHttpRequest>
{
  enum
  {
    Depth = 2
  };
  typedef nsXMLHttpRequest NativeType;
};
template <>
struct PrototypeTraits<prototypes::id::XMLHttpRequest_workers>
{
  enum
  {
    Depth = 2
  };
  typedef mozilla::dom::workers::XMLHttpRequest NativeType;
};
} // namespace dom
} // namespace mozilla


namespace mozilla {
namespace dom {

namespace XMLHttpRequestResponseTypeValues {

  enum valuelist {
    _empty,
    Arraybuffer,
    Blob,
    Document,
    Json,
    Text,
    Moz_chunked_text,
    Moz_chunked_arraybuffer,
    Moz_blob
  };

  extern const EnumEntry strings[10];
} // namespace XMLHttpRequestResponseTypeValues


typedef XMLHttpRequestResponseTypeValues::valuelist XMLHttpRequestResponseType;


struct MozXMLHttpRequestParametersWorkers {
  MozXMLHttpRequestParametersWorkers() {}
  bool Init(JSContext* cx, const JS::Value& val);

  bool mozAnon;
  bool mozSystem;
private:
  // Disallow copy-construction
  MozXMLHttpRequestParametersWorkers(const MozXMLHttpRequestParametersWorkers&) MOZ_DELETE;
  static bool InitIds(JSContext* cx);
  static bool initedIds;
  static jsid mozAnon_id;
  static jsid mozSystem_id;
};

struct MozXMLHttpRequestParameters {
  MozXMLHttpRequestParameters() {}
  bool Init(JSContext* cx, const JS::Value& val);

  bool mozAnon;
  bool mozSystem;
private:
  // Disallow copy-construction
  MozXMLHttpRequestParameters(const MozXMLHttpRequestParameters&) MOZ_DELETE;
  static bool InitIds(JSContext* cx);
  static bool initedIds;
  static jsid mozAnon_id;
  static jsid mozSystem_id;
};

namespace XMLHttpRequestBinding {

  JSObject*
  CreateInterfaceObjects(JSContext* aCx, JSObject* aGlobal, JSObject* aReceiver);

  inline JSObject* GetProtoObject(JSContext* aCx, JSObject* aGlobal, JSObject* aReceiver)
  {

    /* Get the interface prototype object for this class.  This will create the
       object as needed. */

    /* aGlobal and aReceiver are usually the same, but they can be different
       too. For example a sandbox often has an xray wrapper for a window as the
       prototype of the sandbox's global. In that case aReceiver is the xray
       wrapper and aGlobal is the sandbox's global.
     */

    /* Make sure our global is sane.  Hopefully we can remove this sometime */
    if (!(js::GetObjectClass(aGlobal)->flags & JSCLASS_DOM_GLOBAL)) {
      return NULL;
    }
    /* Check to see whether the interface objects are already installed */
    JSObject** protoOrIfaceArray = GetProtoOrIfaceArray(aGlobal);
    JSObject* cachedObject = protoOrIfaceArray[prototypes::id::XMLHttpRequest];
    if (!cachedObject) {
      protoOrIfaceArray[prototypes::id::XMLHttpRequest] = cachedObject = CreateInterfaceObjects(aCx, aGlobal, aReceiver);
    }

    /* cachedObject might _still_ be null, but that's OK */
    return cachedObject;
  }

  bool
  ResolveProperty(JSContext* cx, JSObject* wrapper, jsid id, bool set, JSPropertyDescriptor* desc);

  bool
  EnumerateProperties(JSContext* cx, JSObject* wrapper, JS::AutoIdVector& props);

  bool
  DefineDOMInterface(JSContext* aCx, JSObject* aReceiver, bool* aEnabled);

  extern const NativePropertyHooks NativeHooks;

  extern DOMJSClass Class;

  JSObject*
  Wrap(JSContext* aCx, JSObject* aScope, nsXMLHttpRequest* aObject, nsWrapperCache* aCache, bool* aTriedToWrap);

  template <class T>
  inline JSObject* Wrap(JSContext* aCx, JSObject* aScope, T* aObject, bool* aTriedToWrap)
  {
    return Wrap(aCx, aScope, aObject, aObject, aTriedToWrap);
  }

} // namespace XMLHttpRequestBinding



namespace XMLHttpRequestBinding_workers {

  JSObject*
  CreateInterfaceObjects(JSContext* aCx, JSObject* aGlobal, JSObject* aReceiver);

  inline JSObject* GetProtoObject(JSContext* aCx, JSObject* aGlobal, JSObject* aReceiver)
  {

    /* Get the interface prototype object for this class.  This will create the
       object as needed. */

    /* aGlobal and aReceiver are usually the same, but they can be different
       too. For example a sandbox often has an xray wrapper for a window as the
       prototype of the sandbox's global. In that case aReceiver is the xray
       wrapper and aGlobal is the sandbox's global.
     */

    /* Make sure our global is sane.  Hopefully we can remove this sometime */
    if (!(js::GetObjectClass(aGlobal)->flags & JSCLASS_DOM_GLOBAL)) {
      return NULL;
    }
    /* Check to see whether the interface objects are already installed */
    JSObject** protoOrIfaceArray = GetProtoOrIfaceArray(aGlobal);
    JSObject* cachedObject = protoOrIfaceArray[prototypes::id::XMLHttpRequest_workers];
    if (!cachedObject) {
      protoOrIfaceArray[prototypes::id::XMLHttpRequest_workers] = cachedObject = CreateInterfaceObjects(aCx, aGlobal, aReceiver);
    }

    /* cachedObject might _still_ be null, but that's OK */
    return cachedObject;
  }

  extern DOMJSClass Class;

  JSObject*
  Wrap(JSContext* aCx, JSObject* aScope, mozilla::dom::workers::XMLHttpRequest* aObject, nsWrapperCache* aCache, bool* aTriedToWrap);

  template <class T>
  inline JSObject* Wrap(JSContext* aCx, JSObject* aScope, T* aObject, bool* aTriedToWrap)
  {
    return Wrap(aCx, aScope, aObject, aObject, aTriedToWrap);
  }

} // namespace XMLHttpRequestBinding_workers



} // namespace dom
} // namespace mozilla

#endif // mozilla_dom_XMLHttpRequestBinding_h__