/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsIDOMSVGStringList.idl"

[scriptable, uuid(b6186ed0-0861-11e1-be50-0800200c9a66)]
interface nsIDOMSVGTests : nsISupports
{
  readonly attribute nsIDOMSVGStringList requiredFeatures;
  readonly attribute nsIDOMSVGStringList requiredExtensions;
  readonly attribute nsIDOMSVGStringList systemLanguage;

  boolean hasExtension(in DOMString extension);
};

