/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/base/public/nsIUrlListener.idl
 */

#ifndef __gen_nsIUrlListener_h__
#define __gen_nsIUrlListener_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIURI; /* forward declaration */

#include "nsIURL.h"

/* starting interface:    nsIUrlListener */
#define NS_IURLLISTENER_IID_STR "47618220-d008-11d2-8069-006008128c4e"

#define NS_IURLLISTENER_IID \
  {0x47618220, 0xd008, 0x11d2, \
    { 0x80, 0x69, 0x00, 0x60, 0x08, 0x12, 0x8c, 0x4e }}

class NS_NO_VTABLE nsIUrlListener : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IURLLISTENER_IID)

  /* void OnStartRunningUrl (in nsIURI url); */
  NS_IMETHOD OnStartRunningUrl(nsIURI *url) = 0;

  /* void OnStopRunningUrl (in nsIURI url, in nsresult aExitCode); */
  NS_IMETHOD OnStopRunningUrl(nsIURI *url, nsresult aExitCode) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIUrlListener, NS_IURLLISTENER_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIURLLISTENER \
  NS_IMETHOD OnStartRunningUrl(nsIURI *url); \
  NS_IMETHOD OnStopRunningUrl(nsIURI *url, nsresult aExitCode); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIURLLISTENER(_to) \
  NS_IMETHOD OnStartRunningUrl(nsIURI *url) { return _to OnStartRunningUrl(url); } \
  NS_IMETHOD OnStopRunningUrl(nsIURI *url, nsresult aExitCode) { return _to OnStopRunningUrl(url, aExitCode); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIURLLISTENER(_to) \
  NS_IMETHOD OnStartRunningUrl(nsIURI *url) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnStartRunningUrl(url); } \
  NS_IMETHOD OnStopRunningUrl(nsIURI *url, nsresult aExitCode) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnStopRunningUrl(url, aExitCode); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsUrlListener : public nsIUrlListener
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIURLLISTENER

  nsUrlListener();

private:
  ~nsUrlListener();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsUrlListener, nsIUrlListener)

nsUrlListener::nsUrlListener()
{
  /* member initializers and constructor code */
}

nsUrlListener::~nsUrlListener()
{
  /* destructor code */
}

/* void OnStartRunningUrl (in nsIURI url); */
NS_IMETHODIMP nsUrlListener::OnStartRunningUrl(nsIURI *url)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void OnStopRunningUrl (in nsIURI url, in nsresult aExitCode); */
NS_IMETHODIMP nsUrlListener::OnStopRunningUrl(nsIURI *url, nsresult aExitCode)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIUrlListener_h__ */
