/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/base/public/nsIMsgRDFDataSource.idl
 */

#ifndef __gen_nsIMsgRDFDataSource_h__
#define __gen_nsIMsgRDFDataSource_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsIMsgWindow_h__
#include "nsIMsgWindow.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIMsgRDFDataSource */
#define NS_IMSGRDFDATASOURCE_IID_STR "bb460dfe-8bf0-11d3-8afe-0060b0fc04d2"

#define NS_IMSGRDFDATASOURCE_IID \
  {0xbb460dfe, 0x8bf0, 0x11d3, \
    { 0x8a, 0xfe, 0x00, 0x60, 0xb0, 0xfc, 0x04, 0xd2 }}

class NS_NO_VTABLE nsIMsgRDFDataSource : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IMSGRDFDATASOURCE_IID)

  /* attribute nsIMsgWindow window; */
  NS_IMETHOD GetWindow(nsIMsgWindow * *aWindow) = 0;
  NS_IMETHOD SetWindow(nsIMsgWindow *aWindow) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIMsgRDFDataSource, NS_IMSGRDFDATASOURCE_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGRDFDATASOURCE \
  NS_IMETHOD GetWindow(nsIMsgWindow * *aWindow); \
  NS_IMETHOD SetWindow(nsIMsgWindow *aWindow); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGRDFDATASOURCE(_to) \
  NS_IMETHOD GetWindow(nsIMsgWindow * *aWindow) { return _to GetWindow(aWindow); } \
  NS_IMETHOD SetWindow(nsIMsgWindow *aWindow) { return _to SetWindow(aWindow); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGRDFDATASOURCE(_to) \
  NS_IMETHOD GetWindow(nsIMsgWindow * *aWindow) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetWindow(aWindow); } \
  NS_IMETHOD SetWindow(nsIMsgWindow *aWindow) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetWindow(aWindow); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgRDFDataSource : public nsIMsgRDFDataSource
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGRDFDATASOURCE

  nsMsgRDFDataSource();

private:
  ~nsMsgRDFDataSource();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgRDFDataSource, nsIMsgRDFDataSource)

nsMsgRDFDataSource::nsMsgRDFDataSource()
{
  /* member initializers and constructor code */
}

nsMsgRDFDataSource::~nsMsgRDFDataSource()
{
  /* destructor code */
}

/* attribute nsIMsgWindow window; */
NS_IMETHODIMP nsMsgRDFDataSource::GetWindow(nsIMsgWindow * *aWindow)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgRDFDataSource::SetWindow(nsIMsgWindow *aWindow)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgRDFDataSource_h__ */
