/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/local/public/nsINewsBlogFeedDownloader.idl
 */

#ifndef __gen_nsINewsBlogFeedDownloader_h__
#define __gen_nsINewsBlogFeedDownloader_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIMsgFolder; /* forward declaration */

class nsIUrlListener; /* forward declaration */

class nsIMsgWindow; /* forward declaration */


/* starting interface:    nsINewsBlogFeedDownloader */
#define NS_INEWSBLOGFEEDDOWNLOADER_IID_STR "c1c47796-c8b0-4d12-97aa-c93883ea1c97"

#define NS_INEWSBLOGFEEDDOWNLOADER_IID \
  {0xc1c47796, 0xc8b0, 0x4d12, \
    { 0x97, 0xaa, 0xc9, 0x38, 0x83, 0xea, 0x1c, 0x97 }}

class NS_NO_VTABLE nsINewsBlogFeedDownloader : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_INEWSBLOGFEEDDOWNLOADER_IID)

  /* void downloadFeed (in string aUrl, in nsIMsgFolder aFolder, in boolean aQuickMode, in wstring aTitle, in nsIUrlListener aUrlListener, in nsIMsgWindow aMsgWindow); */
  NS_IMETHOD DownloadFeed(const char * aUrl, nsIMsgFolder *aFolder, bool aQuickMode, const PRUnichar * aTitle, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow) = 0;

  /* void subscribeToFeed (in string aUrl, in nsIMsgFolder aFolder, in nsIMsgWindow aMsgWindow); */
  NS_IMETHOD SubscribeToFeed(const char * aUrl, nsIMsgFolder *aFolder, nsIMsgWindow *aMsgWindow) = 0;

  /* void updateSubscriptionsDS (in nsIMsgFolder aFolder, in boolean aUnsubscribe); */
  NS_IMETHOD UpdateSubscriptionsDS(nsIMsgFolder *aFolder, bool aUnsubscribe) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsINewsBlogFeedDownloader, NS_INEWSBLOGFEEDDOWNLOADER_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSINEWSBLOGFEEDDOWNLOADER \
  NS_IMETHOD DownloadFeed(const char * aUrl, nsIMsgFolder *aFolder, bool aQuickMode, const PRUnichar * aTitle, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow); \
  NS_IMETHOD SubscribeToFeed(const char * aUrl, nsIMsgFolder *aFolder, nsIMsgWindow *aMsgWindow); \
  NS_IMETHOD UpdateSubscriptionsDS(nsIMsgFolder *aFolder, bool aUnsubscribe); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSINEWSBLOGFEEDDOWNLOADER(_to) \
  NS_IMETHOD DownloadFeed(const char * aUrl, nsIMsgFolder *aFolder, bool aQuickMode, const PRUnichar * aTitle, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow) { return _to DownloadFeed(aUrl, aFolder, aQuickMode, aTitle, aUrlListener, aMsgWindow); } \
  NS_IMETHOD SubscribeToFeed(const char * aUrl, nsIMsgFolder *aFolder, nsIMsgWindow *aMsgWindow) { return _to SubscribeToFeed(aUrl, aFolder, aMsgWindow); } \
  NS_IMETHOD UpdateSubscriptionsDS(nsIMsgFolder *aFolder, bool aUnsubscribe) { return _to UpdateSubscriptionsDS(aFolder, aUnsubscribe); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSINEWSBLOGFEEDDOWNLOADER(_to) \
  NS_IMETHOD DownloadFeed(const char * aUrl, nsIMsgFolder *aFolder, bool aQuickMode, const PRUnichar * aTitle, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow) { return !_to ? NS_ERROR_NULL_POINTER : _to->DownloadFeed(aUrl, aFolder, aQuickMode, aTitle, aUrlListener, aMsgWindow); } \
  NS_IMETHOD SubscribeToFeed(const char * aUrl, nsIMsgFolder *aFolder, nsIMsgWindow *aMsgWindow) { return !_to ? NS_ERROR_NULL_POINTER : _to->SubscribeToFeed(aUrl, aFolder, aMsgWindow); } \
  NS_IMETHOD UpdateSubscriptionsDS(nsIMsgFolder *aFolder, bool aUnsubscribe) { return !_to ? NS_ERROR_NULL_POINTER : _to->UpdateSubscriptionsDS(aFolder, aUnsubscribe); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsNewsBlogFeedDownloader : public nsINewsBlogFeedDownloader
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSINEWSBLOGFEEDDOWNLOADER

  nsNewsBlogFeedDownloader();

private:
  ~nsNewsBlogFeedDownloader();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsNewsBlogFeedDownloader, nsINewsBlogFeedDownloader)

nsNewsBlogFeedDownloader::nsNewsBlogFeedDownloader()
{
  /* member initializers and constructor code */
}

nsNewsBlogFeedDownloader::~nsNewsBlogFeedDownloader()
{
  /* destructor code */
}

/* void downloadFeed (in string aUrl, in nsIMsgFolder aFolder, in boolean aQuickMode, in wstring aTitle, in nsIUrlListener aUrlListener, in nsIMsgWindow aMsgWindow); */
NS_IMETHODIMP nsNewsBlogFeedDownloader::DownloadFeed(const char * aUrl, nsIMsgFolder *aFolder, bool aQuickMode, const PRUnichar * aTitle, nsIUrlListener *aUrlListener, nsIMsgWindow *aMsgWindow)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void subscribeToFeed (in string aUrl, in nsIMsgFolder aFolder, in nsIMsgWindow aMsgWindow); */
NS_IMETHODIMP nsNewsBlogFeedDownloader::SubscribeToFeed(const char * aUrl, nsIMsgFolder *aFolder, nsIMsgWindow *aMsgWindow)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void updateSubscriptionsDS (in nsIMsgFolder aFolder, in boolean aUnsubscribe); */
NS_IMETHODIMP nsNewsBlogFeedDownloader::UpdateSubscriptionsDS(nsIMsgFolder *aFolder, bool aUnsubscribe)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsINewsBlogFeedDownloader_h__ */
