/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
#include "nsISupports.idl"

[scriptable, uuid(AACBFA34-8D29-4A08-9283-A8E5B3AB067F)]
interface nsIMsgStatusFeedback : nsISupports {
  void showStatusString(in AString aStatus);
  void startMeteors();
  void stopMeteors();
  void showProgress(in long aPercent);
  void setStatusString(in AString aStatus); // will be displayed until next user action

  /* aStatusFeedback: a wrapped JS status feedback object */
  void setWrappedStatusFeedback(in nsIMsgStatusFeedback aStatusFeedback);
};

