/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/base/search/public/nsIMsgFilterCustomAction.idl
 */

#ifndef __gen_nsIMsgFilterCustomAction_h__
#define __gen_nsIMsgFilterCustomAction_h__


#ifndef __gen_nsMsgFilterCore_h__
#include "nsMsgFilterCore.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIMsgFilterCustomAction */
#define NS_IMSGFILTERCUSTOMACTION_IID_STR "4699c41e-3671-436e-b6ae-4fd8106747e4"

#define NS_IMSGFILTERCUSTOMACTION_IID \
  {0x4699c41e, 0x3671, 0x436e, \
    { 0xb6, 0xae, 0x4f, 0xd8, 0x10, 0x67, 0x47, 0xe4 }}

class NS_NO_VTABLE nsIMsgFilterCustomAction : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IMSGFILTERCUSTOMACTION_IID)

  /* readonly attribute ACString id; */
  NS_IMETHOD GetId(nsACString & aId) = 0;

  /* readonly attribute AString name; */
  NS_IMETHOD GetName(nsAString & aName) = 0;

  /* boolean isValidForType (in nsMsgFilterTypeType type, in nsMsgSearchScopeValue scope); */
  NS_IMETHOD IsValidForType(nsMsgFilterTypeType type, nsMsgSearchScopeValue scope, bool *_retval) = 0;

  /* AUTF8String validateActionValue (in AUTF8String actionValue, in nsIMsgFolder actionFolder, in nsMsgFilterTypeType filterType); */
  NS_IMETHOD ValidateActionValue(const nsACString & actionValue, nsIMsgFolder *actionFolder, nsMsgFilterTypeType filterType, nsACString & _retval) = 0;

  /* attribute boolean allowDuplicates; */
  NS_IMETHOD GetAllowDuplicates(bool *aAllowDuplicates) = 0;
  NS_IMETHOD SetAllowDuplicates(bool aAllowDuplicates) = 0;

  /* void apply (in nsIArray msgHdrs, in AUTF8String actionValue, in nsIMsgCopyServiceListener copyListener, in nsMsgFilterTypeType filterType, in nsIMsgWindow msgWindow); */
  NS_IMETHOD Apply(nsIArray *msgHdrs, const nsACString & actionValue, nsIMsgCopyServiceListener *copyListener, nsMsgFilterTypeType filterType, nsIMsgWindow *msgWindow) = 0;

  /* readonly attribute boolean isAsync; */
  NS_IMETHOD GetIsAsync(bool *aIsAsync) = 0;

  /* readonly attribute boolean needsBody; */
  NS_IMETHOD GetNeedsBody(bool *aNeedsBody) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIMsgFilterCustomAction, NS_IMSGFILTERCUSTOMACTION_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGFILTERCUSTOMACTION \
  NS_IMETHOD GetId(nsACString & aId); \
  NS_IMETHOD GetName(nsAString & aName); \
  NS_IMETHOD IsValidForType(nsMsgFilterTypeType type, nsMsgSearchScopeValue scope, bool *_retval); \
  NS_IMETHOD ValidateActionValue(const nsACString & actionValue, nsIMsgFolder *actionFolder, nsMsgFilterTypeType filterType, nsACString & _retval); \
  NS_IMETHOD GetAllowDuplicates(bool *aAllowDuplicates); \
  NS_IMETHOD SetAllowDuplicates(bool aAllowDuplicates); \
  NS_IMETHOD Apply(nsIArray *msgHdrs, const nsACString & actionValue, nsIMsgCopyServiceListener *copyListener, nsMsgFilterTypeType filterType, nsIMsgWindow *msgWindow); \
  NS_IMETHOD GetIsAsync(bool *aIsAsync); \
  NS_IMETHOD GetNeedsBody(bool *aNeedsBody); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGFILTERCUSTOMACTION(_to) \
  NS_IMETHOD GetId(nsACString & aId) { return _to GetId(aId); } \
  NS_IMETHOD GetName(nsAString & aName) { return _to GetName(aName); } \
  NS_IMETHOD IsValidForType(nsMsgFilterTypeType type, nsMsgSearchScopeValue scope, bool *_retval) { return _to IsValidForType(type, scope, _retval); } \
  NS_IMETHOD ValidateActionValue(const nsACString & actionValue, nsIMsgFolder *actionFolder, nsMsgFilterTypeType filterType, nsACString & _retval) { return _to ValidateActionValue(actionValue, actionFolder, filterType, _retval); } \
  NS_IMETHOD GetAllowDuplicates(bool *aAllowDuplicates) { return _to GetAllowDuplicates(aAllowDuplicates); } \
  NS_IMETHOD SetAllowDuplicates(bool aAllowDuplicates) { return _to SetAllowDuplicates(aAllowDuplicates); } \
  NS_IMETHOD Apply(nsIArray *msgHdrs, const nsACString & actionValue, nsIMsgCopyServiceListener *copyListener, nsMsgFilterTypeType filterType, nsIMsgWindow *msgWindow) { return _to Apply(msgHdrs, actionValue, copyListener, filterType, msgWindow); } \
  NS_IMETHOD GetIsAsync(bool *aIsAsync) { return _to GetIsAsync(aIsAsync); } \
  NS_IMETHOD GetNeedsBody(bool *aNeedsBody) { return _to GetNeedsBody(aNeedsBody); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGFILTERCUSTOMACTION(_to) \
  NS_IMETHOD GetId(nsACString & aId) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetId(aId); } \
  NS_IMETHOD GetName(nsAString & aName) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetName(aName); } \
  NS_IMETHOD IsValidForType(nsMsgFilterTypeType type, nsMsgSearchScopeValue scope, bool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->IsValidForType(type, scope, _retval); } \
  NS_IMETHOD ValidateActionValue(const nsACString & actionValue, nsIMsgFolder *actionFolder, nsMsgFilterTypeType filterType, nsACString & _retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->ValidateActionValue(actionValue, actionFolder, filterType, _retval); } \
  NS_IMETHOD GetAllowDuplicates(bool *aAllowDuplicates) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetAllowDuplicates(aAllowDuplicates); } \
  NS_IMETHOD SetAllowDuplicates(bool aAllowDuplicates) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetAllowDuplicates(aAllowDuplicates); } \
  NS_IMETHOD Apply(nsIArray *msgHdrs, const nsACString & actionValue, nsIMsgCopyServiceListener *copyListener, nsMsgFilterTypeType filterType, nsIMsgWindow *msgWindow) { return !_to ? NS_ERROR_NULL_POINTER : _to->Apply(msgHdrs, actionValue, copyListener, filterType, msgWindow); } \
  NS_IMETHOD GetIsAsync(bool *aIsAsync) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetIsAsync(aIsAsync); } \
  NS_IMETHOD GetNeedsBody(bool *aNeedsBody) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNeedsBody(aNeedsBody); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgFilterCustomAction : public nsIMsgFilterCustomAction
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGFILTERCUSTOMACTION

  nsMsgFilterCustomAction();

private:
  ~nsMsgFilterCustomAction();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgFilterCustomAction, nsIMsgFilterCustomAction)

nsMsgFilterCustomAction::nsMsgFilterCustomAction()
{
  /* member initializers and constructor code */
}

nsMsgFilterCustomAction::~nsMsgFilterCustomAction()
{
  /* destructor code */
}

/* readonly attribute ACString id; */
NS_IMETHODIMP nsMsgFilterCustomAction::GetId(nsACString & aId)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute AString name; */
NS_IMETHODIMP nsMsgFilterCustomAction::GetName(nsAString & aName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean isValidForType (in nsMsgFilterTypeType type, in nsMsgSearchScopeValue scope); */
NS_IMETHODIMP nsMsgFilterCustomAction::IsValidForType(nsMsgFilterTypeType type, nsMsgSearchScopeValue scope, bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* AUTF8String validateActionValue (in AUTF8String actionValue, in nsIMsgFolder actionFolder, in nsMsgFilterTypeType filterType); */
NS_IMETHODIMP nsMsgFilterCustomAction::ValidateActionValue(const nsACString & actionValue, nsIMsgFolder *actionFolder, nsMsgFilterTypeType filterType, nsACString & _retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean allowDuplicates; */
NS_IMETHODIMP nsMsgFilterCustomAction::GetAllowDuplicates(bool *aAllowDuplicates)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgFilterCustomAction::SetAllowDuplicates(bool aAllowDuplicates)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void apply (in nsIArray msgHdrs, in AUTF8String actionValue, in nsIMsgCopyServiceListener copyListener, in nsMsgFilterTypeType filterType, in nsIMsgWindow msgWindow); */
NS_IMETHODIMP nsMsgFilterCustomAction::Apply(nsIArray *msgHdrs, const nsACString & actionValue, nsIMsgCopyServiceListener *copyListener, nsMsgFilterTypeType filterType, nsIMsgWindow *msgWindow)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean isAsync; */
NS_IMETHODIMP nsMsgFilterCustomAction::GetIsAsync(bool *aIsAsync)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean needsBody; */
NS_IMETHODIMP nsMsgFilterCustomAction::GetNeedsBody(bool *aNeedsBody)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgFilterCustomAction_h__ */
