/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "domstubs.idl"

interface nsIDOMSVGLengthList;

[scriptable, uuid(bfa6e42b-bc9d-404d-8688-729fdbfff801)]
interface nsIDOMSVGAnimatedLengthList : nsISupports
{ 
  readonly attribute nsIDOMSVGLengthList baseVal;
  readonly attribute nsIDOMSVGLengthList animVal;
};
