/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "domstubs.idl"

[scriptable, uuid(917da19d-62f5-441d-b47e-9e35f05639c9)]
interface nsIDOMClientRectList : nsISupports
{
  readonly attribute unsigned long length;
  [getter,forward(getItemAt)] nsIDOMClientRect        item(in unsigned long index);
  [noscript,notxpcom,nostdcall] nsIDOMClientRect getItemAt(in unsigned long index);
};
