/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/base/public/nsIMsgProtocolInfo.idl
 */

#ifndef __gen_nsIMsgProtocolInfo_h__
#define __gen_nsIMsgProtocolInfo_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIFile; /* forward declaration */

#define NS_MSGPROTOCOLINFO_CONTRACTID_PREFIX \
  "@mozilla.org/messenger/protocol/info;1?type="

/* starting interface:    nsIMsgProtocolInfo */
#define NS_IMSGPROTOCOLINFO_IID_STR "9428b5f5-8b12-493c-aae2-18296c2877b0"

#define NS_IMSGPROTOCOLINFO_IID \
  {0x9428b5f5, 0x8b12, 0x493c, \
    { 0xaa, 0xe2, 0x18, 0x29, 0x6c, 0x28, 0x77, 0xb0 }}

class NS_NO_VTABLE nsIMsgProtocolInfo : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IMSGPROTOCOLINFO_IID)

  /* attribute nsIFile defaultLocalPath; */
  NS_IMETHOD GetDefaultLocalPath(nsIFile * *aDefaultLocalPath) = 0;
  NS_IMETHOD SetDefaultLocalPath(nsIFile *aDefaultLocalPath) = 0;

  /* readonly attribute nsIIDPtr serverIID; */
  NS_IMETHOD GetServerIID(nsIID **aServerIID) = 0;

  /* readonly attribute boolean requiresUsername; */
  NS_IMETHOD GetRequiresUsername(bool *aRequiresUsername) = 0;

  /* readonly attribute boolean preflightPrettyNameWithEmailAddress; */
  NS_IMETHOD GetPreflightPrettyNameWithEmailAddress(bool *aPreflightPrettyNameWithEmailAddress) = 0;

  /* readonly attribute boolean canDelete; */
  NS_IMETHOD GetCanDelete(bool *aCanDelete) = 0;

  /* readonly attribute boolean canLoginAtStartUp; */
  NS_IMETHOD GetCanLoginAtStartUp(bool *aCanLoginAtStartUp) = 0;

  /* readonly attribute boolean canDuplicate; */
  NS_IMETHOD GetCanDuplicate(bool *aCanDuplicate) = 0;

  /* long getDefaultServerPort (in boolean isSecure); */
  NS_IMETHOD GetDefaultServerPort(bool isSecure, int32_t *_retval) = 0;

  /* readonly attribute boolean canGetMessages; */
  NS_IMETHOD GetCanGetMessages(bool *aCanGetMessages) = 0;

  /* readonly attribute boolean canGetIncomingMessages; */
  NS_IMETHOD GetCanGetIncomingMessages(bool *aCanGetIncomingMessages) = 0;

  /* readonly attribute boolean defaultDoBiff; */
  NS_IMETHOD GetDefaultDoBiff(bool *aDefaultDoBiff) = 0;

  /* readonly attribute boolean showComposeMsgLink; */
  NS_IMETHOD GetShowComposeMsgLink(bool *aShowComposeMsgLink) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIMsgProtocolInfo, NS_IMSGPROTOCOLINFO_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGPROTOCOLINFO \
  NS_IMETHOD GetDefaultLocalPath(nsIFile * *aDefaultLocalPath); \
  NS_IMETHOD SetDefaultLocalPath(nsIFile *aDefaultLocalPath); \
  NS_IMETHOD GetServerIID(nsIID **aServerIID); \
  NS_IMETHOD GetRequiresUsername(bool *aRequiresUsername); \
  NS_IMETHOD GetPreflightPrettyNameWithEmailAddress(bool *aPreflightPrettyNameWithEmailAddress); \
  NS_IMETHOD GetCanDelete(bool *aCanDelete); \
  NS_IMETHOD GetCanLoginAtStartUp(bool *aCanLoginAtStartUp); \
  NS_IMETHOD GetCanDuplicate(bool *aCanDuplicate); \
  NS_IMETHOD GetDefaultServerPort(bool isSecure, int32_t *_retval); \
  NS_IMETHOD GetCanGetMessages(bool *aCanGetMessages); \
  NS_IMETHOD GetCanGetIncomingMessages(bool *aCanGetIncomingMessages); \
  NS_IMETHOD GetDefaultDoBiff(bool *aDefaultDoBiff); \
  NS_IMETHOD GetShowComposeMsgLink(bool *aShowComposeMsgLink); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGPROTOCOLINFO(_to) \
  NS_IMETHOD GetDefaultLocalPath(nsIFile * *aDefaultLocalPath) { return _to GetDefaultLocalPath(aDefaultLocalPath); } \
  NS_IMETHOD SetDefaultLocalPath(nsIFile *aDefaultLocalPath) { return _to SetDefaultLocalPath(aDefaultLocalPath); } \
  NS_IMETHOD GetServerIID(nsIID **aServerIID) { return _to GetServerIID(aServerIID); } \
  NS_IMETHOD GetRequiresUsername(bool *aRequiresUsername) { return _to GetRequiresUsername(aRequiresUsername); } \
  NS_IMETHOD GetPreflightPrettyNameWithEmailAddress(bool *aPreflightPrettyNameWithEmailAddress) { return _to GetPreflightPrettyNameWithEmailAddress(aPreflightPrettyNameWithEmailAddress); } \
  NS_IMETHOD GetCanDelete(bool *aCanDelete) { return _to GetCanDelete(aCanDelete); } \
  NS_IMETHOD GetCanLoginAtStartUp(bool *aCanLoginAtStartUp) { return _to GetCanLoginAtStartUp(aCanLoginAtStartUp); } \
  NS_IMETHOD GetCanDuplicate(bool *aCanDuplicate) { return _to GetCanDuplicate(aCanDuplicate); } \
  NS_IMETHOD GetDefaultServerPort(bool isSecure, int32_t *_retval) { return _to GetDefaultServerPort(isSecure, _retval); } \
  NS_IMETHOD GetCanGetMessages(bool *aCanGetMessages) { return _to GetCanGetMessages(aCanGetMessages); } \
  NS_IMETHOD GetCanGetIncomingMessages(bool *aCanGetIncomingMessages) { return _to GetCanGetIncomingMessages(aCanGetIncomingMessages); } \
  NS_IMETHOD GetDefaultDoBiff(bool *aDefaultDoBiff) { return _to GetDefaultDoBiff(aDefaultDoBiff); } \
  NS_IMETHOD GetShowComposeMsgLink(bool *aShowComposeMsgLink) { return _to GetShowComposeMsgLink(aShowComposeMsgLink); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGPROTOCOLINFO(_to) \
  NS_IMETHOD GetDefaultLocalPath(nsIFile * *aDefaultLocalPath) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDefaultLocalPath(aDefaultLocalPath); } \
  NS_IMETHOD SetDefaultLocalPath(nsIFile *aDefaultLocalPath) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetDefaultLocalPath(aDefaultLocalPath); } \
  NS_IMETHOD GetServerIID(nsIID **aServerIID) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetServerIID(aServerIID); } \
  NS_IMETHOD GetRequiresUsername(bool *aRequiresUsername) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetRequiresUsername(aRequiresUsername); } \
  NS_IMETHOD GetPreflightPrettyNameWithEmailAddress(bool *aPreflightPrettyNameWithEmailAddress) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetPreflightPrettyNameWithEmailAddress(aPreflightPrettyNameWithEmailAddress); } \
  NS_IMETHOD GetCanDelete(bool *aCanDelete) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetCanDelete(aCanDelete); } \
  NS_IMETHOD GetCanLoginAtStartUp(bool *aCanLoginAtStartUp) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetCanLoginAtStartUp(aCanLoginAtStartUp); } \
  NS_IMETHOD GetCanDuplicate(bool *aCanDuplicate) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetCanDuplicate(aCanDuplicate); } \
  NS_IMETHOD GetDefaultServerPort(bool isSecure, int32_t *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDefaultServerPort(isSecure, _retval); } \
  NS_IMETHOD GetCanGetMessages(bool *aCanGetMessages) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetCanGetMessages(aCanGetMessages); } \
  NS_IMETHOD GetCanGetIncomingMessages(bool *aCanGetIncomingMessages) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetCanGetIncomingMessages(aCanGetIncomingMessages); } \
  NS_IMETHOD GetDefaultDoBiff(bool *aDefaultDoBiff) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDefaultDoBiff(aDefaultDoBiff); } \
  NS_IMETHOD GetShowComposeMsgLink(bool *aShowComposeMsgLink) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetShowComposeMsgLink(aShowComposeMsgLink); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgProtocolInfo : public nsIMsgProtocolInfo
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGPROTOCOLINFO

  nsMsgProtocolInfo();

private:
  ~nsMsgProtocolInfo();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgProtocolInfo, nsIMsgProtocolInfo)

nsMsgProtocolInfo::nsMsgProtocolInfo()
{
  /* member initializers and constructor code */
}

nsMsgProtocolInfo::~nsMsgProtocolInfo()
{
  /* destructor code */
}

/* attribute nsIFile defaultLocalPath; */
NS_IMETHODIMP nsMsgProtocolInfo::GetDefaultLocalPath(nsIFile * *aDefaultLocalPath)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgProtocolInfo::SetDefaultLocalPath(nsIFile *aDefaultLocalPath)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute nsIIDPtr serverIID; */
NS_IMETHODIMP nsMsgProtocolInfo::GetServerIID(nsIID **aServerIID)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean requiresUsername; */
NS_IMETHODIMP nsMsgProtocolInfo::GetRequiresUsername(bool *aRequiresUsername)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean preflightPrettyNameWithEmailAddress; */
NS_IMETHODIMP nsMsgProtocolInfo::GetPreflightPrettyNameWithEmailAddress(bool *aPreflightPrettyNameWithEmailAddress)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean canDelete; */
NS_IMETHODIMP nsMsgProtocolInfo::GetCanDelete(bool *aCanDelete)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean canLoginAtStartUp; */
NS_IMETHODIMP nsMsgProtocolInfo::GetCanLoginAtStartUp(bool *aCanLoginAtStartUp)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean canDuplicate; */
NS_IMETHODIMP nsMsgProtocolInfo::GetCanDuplicate(bool *aCanDuplicate)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* long getDefaultServerPort (in boolean isSecure); */
NS_IMETHODIMP nsMsgProtocolInfo::GetDefaultServerPort(bool isSecure, int32_t *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean canGetMessages; */
NS_IMETHODIMP nsMsgProtocolInfo::GetCanGetMessages(bool *aCanGetMessages)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean canGetIncomingMessages; */
NS_IMETHODIMP nsMsgProtocolInfo::GetCanGetIncomingMessages(bool *aCanGetIncomingMessages)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean defaultDoBiff; */
NS_IMETHODIMP nsMsgProtocolInfo::GetDefaultDoBiff(bool *aDefaultDoBiff)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean showComposeMsgLink; */
NS_IMETHODIMP nsMsgProtocolInfo::GetShowComposeMsgLink(bool *aShowComposeMsgLink)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgProtocolInfo_h__ */
