/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"
#include "nsIScreen.idl"

[scriptable, uuid(B92319E6-9A84-4ca7-A2CC-EEC22EA9854E)]
interface nsIScreenManager : nsISupports
{
    //
    // Returns the screen that contains the rectangle. If the rect overlaps
    // multiple screens, it picks the screen with the greatest area of intersection.
    //
    // The coordinates are in pixels (not twips) and in screen coordinates.
    //
  nsIScreen screenForRect ( in long left, in long top, in long width, in long height ) ;
  
    // The screen with the menubar/taskbar. This shouldn't be needed very
    // often.
  readonly attribute nsIScreen primaryScreen;
  
    // Holds the number of screens that are available
  readonly attribute unsigned long numberOfScreens;

    // Returns the nsIScreen instance for the given native widget pointer;
    // the pointer is specific to the particular widget implementation,
    // and is generally of the same type that NS_NATIVE_WINDOW is.
  [noscript] nsIScreen screenForNativeWidget ( in voidPtr nativeWidget );
};


%{ C++

%}
