/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "domstubs.idl"

interface nsIDOMSVGPreserveAspectRatio;

[scriptable, uuid(afcd7cd4-d74d-492f-b3b1-d71bfa36874f)]
interface nsIDOMSVGAnimatedPreserveAspectRatio : nsISupports
{
  readonly attribute nsIDOMSVGPreserveAspectRatio baseVal;
  readonly attribute nsIDOMSVGPreserveAspectRatio animVal;
};
