/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/extensions/smime/public/nsIMsgSMIMEHeaderSink.idl
 */

#ifndef __gen_nsIMsgSMIMEHeaderSink_h__
#define __gen_nsIMsgSMIMEHeaderSink_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIX509Cert; /* forward declaration */


/* starting interface:    nsIMsgSMIMEHeaderSink */
#define NS_IMSGSMIMEHEADERSINK_IID_STR "25380fa1-e70c-4e82-b0bc-f31c2f41c470"

#define NS_IMSGSMIMEHEADERSINK_IID \
  {0x25380fa1, 0xe70c, 0x4e82, \
    { 0xb0, 0xbc, 0xf3, 0x1c, 0x2f, 0x41, 0xc4, 0x70 }}

class NS_NO_VTABLE nsIMsgSMIMEHeaderSink : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IMSGSMIMEHEADERSINK_IID)

  /* void signedStatus (in long aNestingLevel, in long aSignatureStatus, in nsIX509Cert aSignerCert); */
  NS_IMETHOD SignedStatus(int32_t aNestingLevel, int32_t aSignatureStatus, nsIX509Cert *aSignerCert) = 0;

  /* void encryptionStatus (in long aNestingLevel, in long aEncryptionStatus, in nsIX509Cert aReceipientCert); */
  NS_IMETHOD EncryptionStatus(int32_t aNestingLevel, int32_t aEncryptionStatus, nsIX509Cert *aReceipientCert) = 0;

  /* long maxWantedNesting (); */
  NS_IMETHOD MaxWantedNesting(int32_t *_retval) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIMsgSMIMEHeaderSink, NS_IMSGSMIMEHEADERSINK_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGSMIMEHEADERSINK \
  NS_IMETHOD SignedStatus(int32_t aNestingLevel, int32_t aSignatureStatus, nsIX509Cert *aSignerCert); \
  NS_IMETHOD EncryptionStatus(int32_t aNestingLevel, int32_t aEncryptionStatus, nsIX509Cert *aReceipientCert); \
  NS_IMETHOD MaxWantedNesting(int32_t *_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGSMIMEHEADERSINK(_to) \
  NS_IMETHOD SignedStatus(int32_t aNestingLevel, int32_t aSignatureStatus, nsIX509Cert *aSignerCert) { return _to SignedStatus(aNestingLevel, aSignatureStatus, aSignerCert); } \
  NS_IMETHOD EncryptionStatus(int32_t aNestingLevel, int32_t aEncryptionStatus, nsIX509Cert *aReceipientCert) { return _to EncryptionStatus(aNestingLevel, aEncryptionStatus, aReceipientCert); } \
  NS_IMETHOD MaxWantedNesting(int32_t *_retval) { return _to MaxWantedNesting(_retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGSMIMEHEADERSINK(_to) \
  NS_IMETHOD SignedStatus(int32_t aNestingLevel, int32_t aSignatureStatus, nsIX509Cert *aSignerCert) { return !_to ? NS_ERROR_NULL_POINTER : _to->SignedStatus(aNestingLevel, aSignatureStatus, aSignerCert); } \
  NS_IMETHOD EncryptionStatus(int32_t aNestingLevel, int32_t aEncryptionStatus, nsIX509Cert *aReceipientCert) { return !_to ? NS_ERROR_NULL_POINTER : _to->EncryptionStatus(aNestingLevel, aEncryptionStatus, aReceipientCert); } \
  NS_IMETHOD MaxWantedNesting(int32_t *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->MaxWantedNesting(_retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgSMIMEHeaderSink : public nsIMsgSMIMEHeaderSink
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGSMIMEHEADERSINK

  nsMsgSMIMEHeaderSink();

private:
  ~nsMsgSMIMEHeaderSink();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgSMIMEHeaderSink, nsIMsgSMIMEHeaderSink)

nsMsgSMIMEHeaderSink::nsMsgSMIMEHeaderSink()
{
  /* member initializers and constructor code */
}

nsMsgSMIMEHeaderSink::~nsMsgSMIMEHeaderSink()
{
  /* destructor code */
}

/* void signedStatus (in long aNestingLevel, in long aSignatureStatus, in nsIX509Cert aSignerCert); */
NS_IMETHODIMP nsMsgSMIMEHeaderSink::SignedStatus(int32_t aNestingLevel, int32_t aSignatureStatus, nsIX509Cert *aSignerCert)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void encryptionStatus (in long aNestingLevel, in long aEncryptionStatus, in nsIX509Cert aReceipientCert); */
NS_IMETHODIMP nsMsgSMIMEHeaderSink::EncryptionStatus(int32_t aNestingLevel, int32_t aEncryptionStatus, nsIX509Cert *aReceipientCert)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* long maxWantedNesting (); */
NS_IMETHODIMP nsMsgSMIMEHeaderSink::MaxWantedNesting(int32_t *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgSMIMEHeaderSink_h__ */
