/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/extensions/fts3/public/nsIFts3Tokenizer.idl
 */

#ifndef __gen_nsIFts3Tokenizer_h__
#define __gen_nsIFts3Tokenizer_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class mozIStorageConnection; /* forward declaration */


/* starting interface:    nsIFts3Tokenizer */
#define NS_IFTS3TOKENIZER_IID_STR "136c88ea-7003-4fe8-8835-333fd18e598c"

#define NS_IFTS3TOKENIZER_IID \
  {0x136c88ea, 0x7003, 0x4fe8, \
    { 0x88, 0x35, 0x33, 0x3f, 0xd1, 0x8e, 0x59, 0x8c }}

class NS_NO_VTABLE nsIFts3Tokenizer : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IFTS3TOKENIZER_IID)

  /* void registerTokenizer (in mozIStorageConnection connection); */
  NS_IMETHOD RegisterTokenizer(mozIStorageConnection *connection) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIFts3Tokenizer, NS_IFTS3TOKENIZER_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIFTS3TOKENIZER \
  NS_IMETHOD RegisterTokenizer(mozIStorageConnection *connection); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIFTS3TOKENIZER(_to) \
  NS_IMETHOD RegisterTokenizer(mozIStorageConnection *connection) { return _to RegisterTokenizer(connection); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIFTS3TOKENIZER(_to) \
  NS_IMETHOD RegisterTokenizer(mozIStorageConnection *connection) { return !_to ? NS_ERROR_NULL_POINTER : _to->RegisterTokenizer(connection); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsFts3Tokenizer : public nsIFts3Tokenizer
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIFTS3TOKENIZER

  nsFts3Tokenizer();

private:
  ~nsFts3Tokenizer();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsFts3Tokenizer, nsIFts3Tokenizer)

nsFts3Tokenizer::nsFts3Tokenizer()
{
  /* member initializers and constructor code */
}

nsFts3Tokenizer::~nsFts3Tokenizer()
{
  /* destructor code */
}

/* void registerTokenizer (in mozIStorageConnection connection); */
NS_IMETHODIMP nsFts3Tokenizer::RegisterTokenizer(mozIStorageConnection *connection)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIFts3Tokenizer_h__ */
