/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/base/public/nsIMsgKeyArray.idl
 */

#ifndef __gen_nsIMsgKeyArray_h__
#define __gen_nsIMsgKeyArray_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_MailNewsTypes2_h__
#include "MailNewsTypes2.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIMsgKeyArray */
#define NS_IMSGKEYARRAY_IID_STR "4aa3ed2e-5bb1-40b3-ad03-2f1cfef386c4"

#define NS_IMSGKEYARRAY_IID \
  {0x4aa3ed2e, 0x5bb1, 0x40b3, \
    { 0xad, 0x03, 0x2f, 0x1c, 0xfe, 0xf3, 0x86, 0xc4 }}

class NS_NO_VTABLE nsIMsgKeyArray : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IMSGKEYARRAY_IID)

  /* nsMsgKey getKeyAt (in long aIndex); */
  NS_IMETHOD GetKeyAt(int32_t aIndex, nsMsgKey *_retval) = 0;

  /* readonly attribute unsigned long length; */
  NS_IMETHOD GetLength(uint32_t *aLength) = 0;

  /* void setCapacity (in unsigned long aCapacity); */
  NS_IMETHOD SetCapacity(uint32_t aCapacity) = 0;

  /* void appendElement (in nsMsgKey aMsgKey); */
  NS_IMETHOD AppendElement(nsMsgKey aMsgKey) = 0;

  /* void insertElementSorted (in nsMsgKey aMsgKey); */
  NS_IMETHOD InsertElementSorted(nsMsgKey aMsgKey) = 0;

  /* void sort (); */
  NS_IMETHOD Sort(void) = 0;

  /* void getArray (out unsigned long aCount, [array, size_is (aCount)] out nsMsgKey aKeys); */
  NS_IMETHOD GetArray(uint32_t *aCount, nsMsgKey **aKeys) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIMsgKeyArray, NS_IMSGKEYARRAY_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGKEYARRAY \
  NS_IMETHOD GetKeyAt(int32_t aIndex, nsMsgKey *_retval); \
  NS_IMETHOD GetLength(uint32_t *aLength); \
  NS_IMETHOD SetCapacity(uint32_t aCapacity); \
  NS_IMETHOD AppendElement(nsMsgKey aMsgKey); \
  NS_IMETHOD InsertElementSorted(nsMsgKey aMsgKey); \
  NS_IMETHOD Sort(void); \
  NS_IMETHOD GetArray(uint32_t *aCount, nsMsgKey **aKeys); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGKEYARRAY(_to) \
  NS_IMETHOD GetKeyAt(int32_t aIndex, nsMsgKey *_retval) { return _to GetKeyAt(aIndex, _retval); } \
  NS_IMETHOD GetLength(uint32_t *aLength) { return _to GetLength(aLength); } \
  NS_IMETHOD SetCapacity(uint32_t aCapacity) { return _to SetCapacity(aCapacity); } \
  NS_IMETHOD AppendElement(nsMsgKey aMsgKey) { return _to AppendElement(aMsgKey); } \
  NS_IMETHOD InsertElementSorted(nsMsgKey aMsgKey) { return _to InsertElementSorted(aMsgKey); } \
  NS_IMETHOD Sort(void) { return _to Sort(); } \
  NS_IMETHOD GetArray(uint32_t *aCount, nsMsgKey **aKeys) { return _to GetArray(aCount, aKeys); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGKEYARRAY(_to) \
  NS_IMETHOD GetKeyAt(int32_t aIndex, nsMsgKey *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetKeyAt(aIndex, _retval); } \
  NS_IMETHOD GetLength(uint32_t *aLength) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetLength(aLength); } \
  NS_IMETHOD SetCapacity(uint32_t aCapacity) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetCapacity(aCapacity); } \
  NS_IMETHOD AppendElement(nsMsgKey aMsgKey) { return !_to ? NS_ERROR_NULL_POINTER : _to->AppendElement(aMsgKey); } \
  NS_IMETHOD InsertElementSorted(nsMsgKey aMsgKey) { return !_to ? NS_ERROR_NULL_POINTER : _to->InsertElementSorted(aMsgKey); } \
  NS_IMETHOD Sort(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->Sort(); } \
  NS_IMETHOD GetArray(uint32_t *aCount, nsMsgKey **aKeys) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetArray(aCount, aKeys); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgKeyArray : public nsIMsgKeyArray
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGKEYARRAY

  nsMsgKeyArray();

private:
  ~nsMsgKeyArray();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgKeyArray, nsIMsgKeyArray)

nsMsgKeyArray::nsMsgKeyArray()
{
  /* member initializers and constructor code */
}

nsMsgKeyArray::~nsMsgKeyArray()
{
  /* destructor code */
}

/* nsMsgKey getKeyAt (in long aIndex); */
NS_IMETHODIMP nsMsgKeyArray::GetKeyAt(int32_t aIndex, nsMsgKey *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute unsigned long length; */
NS_IMETHODIMP nsMsgKeyArray::GetLength(uint32_t *aLength)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setCapacity (in unsigned long aCapacity); */
NS_IMETHODIMP nsMsgKeyArray::SetCapacity(uint32_t aCapacity)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void appendElement (in nsMsgKey aMsgKey); */
NS_IMETHODIMP nsMsgKeyArray::AppendElement(nsMsgKey aMsgKey)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void insertElementSorted (in nsMsgKey aMsgKey); */
NS_IMETHODIMP nsMsgKeyArray::InsertElementSorted(nsMsgKey aMsgKey)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void sort (); */
NS_IMETHODIMP nsMsgKeyArray::Sort()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void getArray (out unsigned long aCount, [array, size_is (aCount)] out nsMsgKey aKeys); */
NS_IMETHODIMP nsMsgKeyArray::GetArray(uint32_t *aCount, nsMsgKey **aKeys)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgKeyArray_h__ */
