/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*-
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"
interface nsILDAPURL;


[scriptable, uuid (0308fb36-1dd2-11b2-b16f-8510e8c5311a)]
interface nsILDAPSyncQuery : nsISupports {
  
  /**
   * getQueryResults
   *
   * Create a new LDAP connection do a synchronous LDAP search and return 
   * the results.
   * @param aServerURL - LDAP URL with parameters to a LDAP search 
   *                     ("ldap://host/base?attributes?one/sub?filter")
   * @param aProtocolVersion - LDAP protocol version to use for connection
   *                           (nsILDAPConnection.idl has symbolic constants)
   * @return results
   */
   wstring getQueryResults (in nsILDAPURL aServerURL,
                            in unsigned long aProtocolVersion);

};
