/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "domstubs.idl"

/**
 * The nsIDOMSVGAngle interface is the interface to an SVG angle.
 *
 * For more information on this interface please see
 * http://www.w3.org/TR/SVG11/types.html#InterfaceSVGAngle
 *
 */

[scriptable, uuid(58b6190e-37b3-412a-ba02-1d5ad6c6ea7c)]
interface nsIDOMSVGAngle : nsISupports
{
  // Angle Unit Types
  const unsigned short SVG_ANGLETYPE_UNKNOWN     = 0;
  const unsigned short SVG_ANGLETYPE_UNSPECIFIED = 1;
  const unsigned short SVG_ANGLETYPE_DEG         = 2;
  const unsigned short SVG_ANGLETYPE_RAD         = 3;
  const unsigned short SVG_ANGLETYPE_GRAD        = 4;

  readonly attribute unsigned short unitType;
  attribute float value;
  // raises DOMException on setting
  attribute float valueInSpecifiedUnits;
  // raises DOMException on setting
  attribute DOMString valueAsString;
  // raises DOMException on setting

  void newValueSpecifiedUnits(in unsigned short unitType, in float valueInSpecifiedUnits);
  void convertToSpecifiedUnits(in unsigned short unitType);
};
  
