/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/addrbook/public/nsIAbDirectoryQueryProxy.idl
 */

#ifndef __gen_nsIAbDirectoryQueryProxy_h__
#define __gen_nsIAbDirectoryQueryProxy_h__


#ifndef __gen_nsIAbDirectoryQuery_h__
#include "nsIAbDirectoryQuery.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIAbDirectoryQueryProxy */
#define NS_IABDIRECTORYQUERYPROXY_IID_STR "b8034849-1e98-4d39-819c-15ba61a7434f"

#define NS_IABDIRECTORYQUERYPROXY_IID \
  {0xb8034849, 0x1e98, 0x4d39, \
    { 0x81, 0x9c, 0x15, 0xba, 0x61, 0xa7, 0x43, 0x4f }}

class NS_NO_VTABLE nsIAbDirectoryQueryProxy : public nsIAbDirectoryQuery {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IABDIRECTORYQUERYPROXY_IID)

  /* void initiate (); */
  NS_IMETHOD Initiate(void) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIAbDirectoryQueryProxy, NS_IABDIRECTORYQUERYPROXY_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIABDIRECTORYQUERYPROXY \
  NS_IMETHOD Initiate(void); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIABDIRECTORYQUERYPROXY(_to) \
  NS_IMETHOD Initiate(void) { return _to Initiate(); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIABDIRECTORYQUERYPROXY(_to) \
  NS_IMETHOD Initiate(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->Initiate(); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsAbDirectoryQueryProxy : public nsIAbDirectoryQueryProxy
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIABDIRECTORYQUERYPROXY

  nsAbDirectoryQueryProxy();

private:
  ~nsAbDirectoryQueryProxy();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsAbDirectoryQueryProxy, nsIAbDirectoryQueryProxy)

nsAbDirectoryQueryProxy::nsAbDirectoryQueryProxy()
{
  /* member initializers and constructor code */
}

nsAbDirectoryQueryProxy::~nsAbDirectoryQueryProxy()
{
  /* destructor code */
}

/* void initiate (); */
NS_IMETHODIMP nsAbDirectoryQueryProxy::Initiate()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIAbDirectoryQueryProxy_h__ */
