/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */


#include "nsISupports.idl"

interface nsIAbDirFactory;

[scriptable, uuid(154a951b-a310-400c-b98f-d769cc5d575f)]
interface nsIAbDirFactoryService : nsISupports
{
  /**
   * Obtain a directory factory component given a uri representing an address
   * book. The scheme is extracted from the uri and contract id is generated
   * of the form:
   * @mozilla.org/addressbook/directory-factory;1?type=<scheme>
   * 
   * This id is used to instantiate a registered component which implemented
   * the nsIAbDirFactory interface.
   *
   * @param aURI  The uri which contains the scheme that defines what directory
   *              factory instance is returned
   */
  nsIAbDirFactory getDirFactory(in ACString aURI);
};

