/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/suite/profile/migration/public/nsISuiteProfileMigrator.idl
 */

#ifndef __gen_nsISuiteProfileMigrator_h__
#define __gen_nsISuiteProfileMigrator_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIArray; /* forward declaration */

class nsIProfileStartup; /* forward declaration */


/* starting interface:    nsISuiteProfileMigrator */
#define NS_ISUITEPROFILEMIGRATOR_IID_STR "b6adb2b8-5e3b-4fdd-b085-d58998b5c21a"

#define NS_ISUITEPROFILEMIGRATOR_IID \
  {0xb6adb2b8, 0x5e3b, 0x4fdd, \
    { 0xb0, 0x85, 0xd5, 0x89, 0x98, 0xb5, 0xc2, 0x1a }}

class NS_NO_VTABLE nsISuiteProfileMigrator : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_ISUITEPROFILEMIGRATOR_IID)

  enum {
    SETTINGS = 1U,
    COOKIES = 2U,
    HISTORY = 4U,
    HOMEPAGEDATA = 8U,
    PASSWORDS = 16U,
    BOOKMARKS = 32U,
    OTHERDATA = 64U,
    ACCOUNT_SETTINGS = 128U,
    ADDRESSBOOK_DATA = 256U,
    JUNKTRAINING = 512U,
    NEWSDATA = 1024U,
    MAILDATA = 2048U,
    ALL = 4095U
  };

  /* void migrate (in unsigned short aItems, in nsIProfileStartup aStartup, in wstring aProfile); */
  NS_IMETHOD Migrate(uint16_t aItems, nsIProfileStartup *aStartup, const PRUnichar * aProfile) = 0;

  /* unsigned short getMigrateData (in wstring aProfile, in boolean aDoingStartup); */
  NS_IMETHOD GetMigrateData(const PRUnichar * aProfile, bool aDoingStartup, uint16_t *_retval) = 0;

  /* readonly attribute unsigned short supportedItems; */
  NS_IMETHOD GetSupportedItems(uint16_t *aSupportedItems) = 0;

  /* readonly attribute boolean sourceExists; */
  NS_IMETHOD GetSourceExists(bool *aSourceExists) = 0;

  /* readonly attribute boolean sourceHasMultipleProfiles; */
  NS_IMETHOD GetSourceHasMultipleProfiles(bool *aSourceHasMultipleProfiles) = 0;

  /* readonly attribute nsIArray sourceProfiles; */
  NS_IMETHOD GetSourceProfiles(nsIArray * *aSourceProfiles) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsISuiteProfileMigrator, NS_ISUITEPROFILEMIGRATOR_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSISUITEPROFILEMIGRATOR \
  NS_IMETHOD Migrate(uint16_t aItems, nsIProfileStartup *aStartup, const PRUnichar * aProfile); \
  NS_IMETHOD GetMigrateData(const PRUnichar * aProfile, bool aDoingStartup, uint16_t *_retval); \
  NS_IMETHOD GetSupportedItems(uint16_t *aSupportedItems); \
  NS_IMETHOD GetSourceExists(bool *aSourceExists); \
  NS_IMETHOD GetSourceHasMultipleProfiles(bool *aSourceHasMultipleProfiles); \
  NS_IMETHOD GetSourceProfiles(nsIArray * *aSourceProfiles); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSISUITEPROFILEMIGRATOR(_to) \
  NS_IMETHOD Migrate(uint16_t aItems, nsIProfileStartup *aStartup, const PRUnichar * aProfile) { return _to Migrate(aItems, aStartup, aProfile); } \
  NS_IMETHOD GetMigrateData(const PRUnichar * aProfile, bool aDoingStartup, uint16_t *_retval) { return _to GetMigrateData(aProfile, aDoingStartup, _retval); } \
  NS_IMETHOD GetSupportedItems(uint16_t *aSupportedItems) { return _to GetSupportedItems(aSupportedItems); } \
  NS_IMETHOD GetSourceExists(bool *aSourceExists) { return _to GetSourceExists(aSourceExists); } \
  NS_IMETHOD GetSourceHasMultipleProfiles(bool *aSourceHasMultipleProfiles) { return _to GetSourceHasMultipleProfiles(aSourceHasMultipleProfiles); } \
  NS_IMETHOD GetSourceProfiles(nsIArray * *aSourceProfiles) { return _to GetSourceProfiles(aSourceProfiles); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSISUITEPROFILEMIGRATOR(_to) \
  NS_IMETHOD Migrate(uint16_t aItems, nsIProfileStartup *aStartup, const PRUnichar * aProfile) { return !_to ? NS_ERROR_NULL_POINTER : _to->Migrate(aItems, aStartup, aProfile); } \
  NS_IMETHOD GetMigrateData(const PRUnichar * aProfile, bool aDoingStartup, uint16_t *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMigrateData(aProfile, aDoingStartup, _retval); } \
  NS_IMETHOD GetSupportedItems(uint16_t *aSupportedItems) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSupportedItems(aSupportedItems); } \
  NS_IMETHOD GetSourceExists(bool *aSourceExists) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSourceExists(aSourceExists); } \
  NS_IMETHOD GetSourceHasMultipleProfiles(bool *aSourceHasMultipleProfiles) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSourceHasMultipleProfiles(aSourceHasMultipleProfiles); } \
  NS_IMETHOD GetSourceProfiles(nsIArray * *aSourceProfiles) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSourceProfiles(aSourceProfiles); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsSuiteProfileMigrator : public nsISuiteProfileMigrator
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSISUITEPROFILEMIGRATOR

  nsSuiteProfileMigrator();

private:
  ~nsSuiteProfileMigrator();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsSuiteProfileMigrator, nsISuiteProfileMigrator)

nsSuiteProfileMigrator::nsSuiteProfileMigrator()
{
  /* member initializers and constructor code */
}

nsSuiteProfileMigrator::~nsSuiteProfileMigrator()
{
  /* destructor code */
}

/* void migrate (in unsigned short aItems, in nsIProfileStartup aStartup, in wstring aProfile); */
NS_IMETHODIMP nsSuiteProfileMigrator::Migrate(uint16_t aItems, nsIProfileStartup *aStartup, const PRUnichar * aProfile)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* unsigned short getMigrateData (in wstring aProfile, in boolean aDoingStartup); */
NS_IMETHODIMP nsSuiteProfileMigrator::GetMigrateData(const PRUnichar * aProfile, bool aDoingStartup, uint16_t *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute unsigned short supportedItems; */
NS_IMETHODIMP nsSuiteProfileMigrator::GetSupportedItems(uint16_t *aSupportedItems)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean sourceExists; */
NS_IMETHODIMP nsSuiteProfileMigrator::GetSourceExists(bool *aSourceExists)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean sourceHasMultipleProfiles; */
NS_IMETHODIMP nsSuiteProfileMigrator::GetSourceHasMultipleProfiles(bool *aSourceHasMultipleProfiles)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute nsIArray sourceProfiles; */
NS_IMETHODIMP nsSuiteProfileMigrator::GetSourceProfiles(nsIArray * *aSourceProfiles)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsISuiteProfileMigrator_h__ */
