/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/import/public/nsIImportAddressBooks.idl
 */

#ifndef __gen_nsIImportAddressBooks_h__
#define __gen_nsIImportAddressBooks_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIFile; /* forward declaration */

class nsISupportsArray; /* forward declaration */

class nsIImportABDescriptor; /* forward declaration */

class nsIOutputStream; /* forward declaration */

class nsIAddrDatabase; /* forward declaration */

class nsIImportFieldMap; /* forward declaration */


/* starting interface:    nsIImportAddressBooks */
#define NS_IIMPORTADDRESSBOOKS_IID_STR "d64a87ba-f87b-6378-5ed1-4025a7474334"

#define NS_IIMPORTADDRESSBOOKS_IID \
  {0xd64a87ba, 0xf87b, 0x6378, \
    { 0x5e, 0xd1, 0x40, 0x25, 0xa7, 0x47, 0x43, 0x34 }}

class NS_NO_VTABLE nsIImportAddressBooks : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IIMPORTADDRESSBOOKS_IID)

  /* boolean GetSupportsMultiple (); */
  NS_IMETHOD GetSupportsMultiple(bool *_retval) = 0;

  /* boolean GetAutoFind (out wstring description); */
  NS_IMETHOD GetAutoFind(PRUnichar * *description, bool *_retval) = 0;

  /* boolean GetNeedsFieldMap (in nsIFile location); */
  NS_IMETHOD GetNeedsFieldMap(nsIFile *location, bool *_retval) = 0;

  /* void GetDefaultLocation (out nsIFile location, out boolean found, out boolean userVerify); */
  NS_IMETHOD GetDefaultLocation(nsIFile * *location, bool *found, bool *userVerify) = 0;

  /* nsISupportsArray FindAddressBooks (in nsIFile location); */
  NS_IMETHOD FindAddressBooks(nsIFile *location, nsISupportsArray * *_retval) = 0;

  /* void InitFieldMap (in nsIImportFieldMap fieldMap); */
  NS_IMETHOD InitFieldMap(nsIImportFieldMap *fieldMap) = 0;

  /* void ImportAddressBook (in nsIImportABDescriptor aSource, in nsIAddrDatabase aDestination, in nsIImportFieldMap aFieldMap, in nsISupports aSupportService, out wstring aErrorLog, out wstring aSuccessLog, out boolean aFatalError); */
  NS_IMETHOD ImportAddressBook(nsIImportABDescriptor *aSource, nsIAddrDatabase *aDestination, nsIImportFieldMap *aFieldMap, nsISupports *aSupportService, PRUnichar * *aErrorLog, PRUnichar * *aSuccessLog, bool *aFatalError) = 0;

  /* unsigned long GetImportProgress (); */
  NS_IMETHOD GetImportProgress(uint32_t *_retval) = 0;

  /* void SetSampleLocation (in nsIFile location); */
  NS_IMETHOD SetSampleLocation(nsIFile *location) = 0;

  /* wstring GetSampleData (in long recordNumber, out boolean recordExists); */
  NS_IMETHOD GetSampleData(int32_t recordNumber, bool *recordExists, PRUnichar * *_retval) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIImportAddressBooks, NS_IIMPORTADDRESSBOOKS_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIIMPORTADDRESSBOOKS \
  NS_IMETHOD GetSupportsMultiple(bool *_retval); \
  NS_IMETHOD GetAutoFind(PRUnichar * *description, bool *_retval); \
  NS_IMETHOD GetNeedsFieldMap(nsIFile *location, bool *_retval); \
  NS_IMETHOD GetDefaultLocation(nsIFile * *location, bool *found, bool *userVerify); \
  NS_IMETHOD FindAddressBooks(nsIFile *location, nsISupportsArray * *_retval); \
  NS_IMETHOD InitFieldMap(nsIImportFieldMap *fieldMap); \
  NS_IMETHOD ImportAddressBook(nsIImportABDescriptor *aSource, nsIAddrDatabase *aDestination, nsIImportFieldMap *aFieldMap, nsISupports *aSupportService, PRUnichar * *aErrorLog, PRUnichar * *aSuccessLog, bool *aFatalError); \
  NS_IMETHOD GetImportProgress(uint32_t *_retval); \
  NS_IMETHOD SetSampleLocation(nsIFile *location); \
  NS_IMETHOD GetSampleData(int32_t recordNumber, bool *recordExists, PRUnichar * *_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIIMPORTADDRESSBOOKS(_to) \
  NS_IMETHOD GetSupportsMultiple(bool *_retval) { return _to GetSupportsMultiple(_retval); } \
  NS_IMETHOD GetAutoFind(PRUnichar * *description, bool *_retval) { return _to GetAutoFind(description, _retval); } \
  NS_IMETHOD GetNeedsFieldMap(nsIFile *location, bool *_retval) { return _to GetNeedsFieldMap(location, _retval); } \
  NS_IMETHOD GetDefaultLocation(nsIFile * *location, bool *found, bool *userVerify) { return _to GetDefaultLocation(location, found, userVerify); } \
  NS_IMETHOD FindAddressBooks(nsIFile *location, nsISupportsArray * *_retval) { return _to FindAddressBooks(location, _retval); } \
  NS_IMETHOD InitFieldMap(nsIImportFieldMap *fieldMap) { return _to InitFieldMap(fieldMap); } \
  NS_IMETHOD ImportAddressBook(nsIImportABDescriptor *aSource, nsIAddrDatabase *aDestination, nsIImportFieldMap *aFieldMap, nsISupports *aSupportService, PRUnichar * *aErrorLog, PRUnichar * *aSuccessLog, bool *aFatalError) { return _to ImportAddressBook(aSource, aDestination, aFieldMap, aSupportService, aErrorLog, aSuccessLog, aFatalError); } \
  NS_IMETHOD GetImportProgress(uint32_t *_retval) { return _to GetImportProgress(_retval); } \
  NS_IMETHOD SetSampleLocation(nsIFile *location) { return _to SetSampleLocation(location); } \
  NS_IMETHOD GetSampleData(int32_t recordNumber, bool *recordExists, PRUnichar * *_retval) { return _to GetSampleData(recordNumber, recordExists, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIIMPORTADDRESSBOOKS(_to) \
  NS_IMETHOD GetSupportsMultiple(bool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSupportsMultiple(_retval); } \
  NS_IMETHOD GetAutoFind(PRUnichar * *description, bool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetAutoFind(description, _retval); } \
  NS_IMETHOD GetNeedsFieldMap(nsIFile *location, bool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNeedsFieldMap(location, _retval); } \
  NS_IMETHOD GetDefaultLocation(nsIFile * *location, bool *found, bool *userVerify) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDefaultLocation(location, found, userVerify); } \
  NS_IMETHOD FindAddressBooks(nsIFile *location, nsISupportsArray * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->FindAddressBooks(location, _retval); } \
  NS_IMETHOD InitFieldMap(nsIImportFieldMap *fieldMap) { return !_to ? NS_ERROR_NULL_POINTER : _to->InitFieldMap(fieldMap); } \
  NS_IMETHOD ImportAddressBook(nsIImportABDescriptor *aSource, nsIAddrDatabase *aDestination, nsIImportFieldMap *aFieldMap, nsISupports *aSupportService, PRUnichar * *aErrorLog, PRUnichar * *aSuccessLog, bool *aFatalError) { return !_to ? NS_ERROR_NULL_POINTER : _to->ImportAddressBook(aSource, aDestination, aFieldMap, aSupportService, aErrorLog, aSuccessLog, aFatalError); } \
  NS_IMETHOD GetImportProgress(uint32_t *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetImportProgress(_retval); } \
  NS_IMETHOD SetSampleLocation(nsIFile *location) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetSampleLocation(location); } \
  NS_IMETHOD GetSampleData(int32_t recordNumber, bool *recordExists, PRUnichar * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSampleData(recordNumber, recordExists, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsImportAddressBooks : public nsIImportAddressBooks
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIIMPORTADDRESSBOOKS

  nsImportAddressBooks();

private:
  ~nsImportAddressBooks();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsImportAddressBooks, nsIImportAddressBooks)

nsImportAddressBooks::nsImportAddressBooks()
{
  /* member initializers and constructor code */
}

nsImportAddressBooks::~nsImportAddressBooks()
{
  /* destructor code */
}

/* boolean GetSupportsMultiple (); */
NS_IMETHODIMP nsImportAddressBooks::GetSupportsMultiple(bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean GetAutoFind (out wstring description); */
NS_IMETHODIMP nsImportAddressBooks::GetAutoFind(PRUnichar * *description, bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean GetNeedsFieldMap (in nsIFile location); */
NS_IMETHODIMP nsImportAddressBooks::GetNeedsFieldMap(nsIFile *location, bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void GetDefaultLocation (out nsIFile location, out boolean found, out boolean userVerify); */
NS_IMETHODIMP nsImportAddressBooks::GetDefaultLocation(nsIFile * *location, bool *found, bool *userVerify)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsISupportsArray FindAddressBooks (in nsIFile location); */
NS_IMETHODIMP nsImportAddressBooks::FindAddressBooks(nsIFile *location, nsISupportsArray * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void InitFieldMap (in nsIImportFieldMap fieldMap); */
NS_IMETHODIMP nsImportAddressBooks::InitFieldMap(nsIImportFieldMap *fieldMap)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void ImportAddressBook (in nsIImportABDescriptor aSource, in nsIAddrDatabase aDestination, in nsIImportFieldMap aFieldMap, in nsISupports aSupportService, out wstring aErrorLog, out wstring aSuccessLog, out boolean aFatalError); */
NS_IMETHODIMP nsImportAddressBooks::ImportAddressBook(nsIImportABDescriptor *aSource, nsIAddrDatabase *aDestination, nsIImportFieldMap *aFieldMap, nsISupports *aSupportService, PRUnichar * *aErrorLog, PRUnichar * *aSuccessLog, bool *aFatalError)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* unsigned long GetImportProgress (); */
NS_IMETHODIMP nsImportAddressBooks::GetImportProgress(uint32_t *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void SetSampleLocation (in nsIFile location); */
NS_IMETHODIMP nsImportAddressBooks::SetSampleLocation(nsIFile *location)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* wstring GetSampleData (in long recordNumber, out boolean recordExists); */
NS_IMETHODIMP nsImportAddressBooks::GetSampleData(int32_t recordNumber, bool *recordExists, PRUnichar * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif



#endif /* __gen_nsIImportAddressBooks_h__ */
