/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"

interface nsIDOMSVGAnimatedString;

[scriptable, uuid(8092b5f3-dc8a-459c-94f1-92f8011f2438)]
interface nsIDOMSVGURIReference
  : nsISupports
{
  readonly attribute nsIDOMSVGAnimatedString href;
};
