/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"
#include "nsIPop3Sink.idl"

[scriptable, uuid(5fb87ae7-a3a0-440a-8b49-6bca42fb7ff2)]
interface nsIPop3URL : nsISupports {
  attribute nsIPop3Sink pop3Sink;
  attribute string messageUri;

  /// Constant for the default POP3 port number
  const int32_t DEFAULT_POP3_PORT = 110;

  /// Constant for the default POP3 over ssl port number
  const int32_t DEFAULT_POP3S_PORT = 995;
};
