/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/addrbook/public/nsIAbAddressCollector.idl
 */

#ifndef __gen_nsIAbAddressCollector_h__
#define __gen_nsIAbAddressCollector_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIAbCard; /* forward declaration */


/* starting interface:    nsIAbAddressCollector */
#define NS_IABADDRESSCOLLECTOR_IID_STR "069d3fba-37d4-4158-b401-a8efaeea0b66"

#define NS_IABADDRESSCOLLECTOR_IID \
  {0x069d3fba, 0x37d4, 0x4158, \
    { 0xb4, 0x01, 0xa8, 0xef, 0xae, 0xea, 0x0b, 0x66 }}

class NS_NO_VTABLE nsIAbAddressCollector : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IABADDRESSCOLLECTOR_IID)

  /* void collectAddress (in AUTF8String aAddresses, in boolean aCreateCard, in unsigned long aSendFormat); */
  NS_IMETHOD CollectAddress(const nsACString & aAddresses, bool aCreateCard, uint32_t aSendFormat) = 0;

  /* void collectSingleAddress (in AUTF8String aEmail, in AUTF8String aDisplayName, in boolean aCreateCard, in unsigned long aSendFormat, [optional] in boolean aSkipCheckExisting); */
  NS_IMETHOD CollectSingleAddress(const nsACString & aEmail, const nsACString & aDisplayName, bool aCreateCard, uint32_t aSendFormat, bool aSkipCheckExisting) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIAbAddressCollector, NS_IABADDRESSCOLLECTOR_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIABADDRESSCOLLECTOR \
  NS_IMETHOD CollectAddress(const nsACString & aAddresses, bool aCreateCard, uint32_t aSendFormat); \
  NS_IMETHOD CollectSingleAddress(const nsACString & aEmail, const nsACString & aDisplayName, bool aCreateCard, uint32_t aSendFormat, bool aSkipCheckExisting); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIABADDRESSCOLLECTOR(_to) \
  NS_IMETHOD CollectAddress(const nsACString & aAddresses, bool aCreateCard, uint32_t aSendFormat) { return _to CollectAddress(aAddresses, aCreateCard, aSendFormat); } \
  NS_IMETHOD CollectSingleAddress(const nsACString & aEmail, const nsACString & aDisplayName, bool aCreateCard, uint32_t aSendFormat, bool aSkipCheckExisting) { return _to CollectSingleAddress(aEmail, aDisplayName, aCreateCard, aSendFormat, aSkipCheckExisting); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIABADDRESSCOLLECTOR(_to) \
  NS_IMETHOD CollectAddress(const nsACString & aAddresses, bool aCreateCard, uint32_t aSendFormat) { return !_to ? NS_ERROR_NULL_POINTER : _to->CollectAddress(aAddresses, aCreateCard, aSendFormat); } \
  NS_IMETHOD CollectSingleAddress(const nsACString & aEmail, const nsACString & aDisplayName, bool aCreateCard, uint32_t aSendFormat, bool aSkipCheckExisting) { return !_to ? NS_ERROR_NULL_POINTER : _to->CollectSingleAddress(aEmail, aDisplayName, aCreateCard, aSendFormat, aSkipCheckExisting); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsAbAddressCollector : public nsIAbAddressCollector
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIABADDRESSCOLLECTOR

  nsAbAddressCollector();

private:
  ~nsAbAddressCollector();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsAbAddressCollector, nsIAbAddressCollector)

nsAbAddressCollector::nsAbAddressCollector()
{
  /* member initializers and constructor code */
}

nsAbAddressCollector::~nsAbAddressCollector()
{
  /* destructor code */
}

/* void collectAddress (in AUTF8String aAddresses, in boolean aCreateCard, in unsigned long aSendFormat); */
NS_IMETHODIMP nsAbAddressCollector::CollectAddress(const nsACString & aAddresses, bool aCreateCard, uint32_t aSendFormat)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void collectSingleAddress (in AUTF8String aEmail, in AUTF8String aDisplayName, in boolean aCreateCard, in unsigned long aSendFormat, [optional] in boolean aSkipCheckExisting); */
NS_IMETHODIMP nsAbAddressCollector::CollectSingleAddress(const nsACString & aEmail, const nsACString & aDisplayName, bool aCreateCard, uint32_t aSendFormat, bool aSkipCheckExisting)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIAbAddressCollector_h__ */
