/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"

interface nsIDOMMozConnection;
interface nsIDOMMozMobileConnection;

[scriptable, uuid(fb7c3429-aa2c-4ccc-948a-467c0de29fff)]
interface nsIDOMMozNavigatorNetwork : nsISupports
{
  readonly attribute nsIDOMMozConnection mozConnection;
  readonly attribute nsIDOMMozMobileConnection mozMobileConnection;
};
