/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/addrbook/public/nsIAbAutoCompleteResult.idl
 */

#ifndef __gen_nsIAbAutoCompleteResult_h__
#define __gen_nsIAbAutoCompleteResult_h__


#ifndef __gen_nsIAutoCompleteResult_h__
#include "nsIAutoCompleteResult.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIAbCard; /* forward declaration */


/* starting interface:    nsIAbAutoCompleteResult */
#define NS_IABAUTOCOMPLETERESULT_IID_STR "66fb7d23-a87c-4a0a-8dd7-b8b052d4cfac"

#define NS_IABAUTOCOMPLETERESULT_IID \
  {0x66fb7d23, 0xa87c, 0x4a0a, \
    { 0x8d, 0xd7, 0xb8, 0xb0, 0x52, 0xd4, 0xcf, 0xac }}

class NS_NO_VTABLE nsIAbAutoCompleteResult : public nsIAutoCompleteResult {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IABAUTOCOMPLETERESULT_IID)

  /* nsIAbCard getCardAt (in long index); */
  NS_IMETHOD GetCardAt(int32_t index, nsIAbCard * *_retval) = 0;

  /* AString getEmailToUse (in long index); */
  NS_IMETHOD GetEmailToUse(int32_t index, nsAString & _retval) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIAbAutoCompleteResult, NS_IABAUTOCOMPLETERESULT_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIABAUTOCOMPLETERESULT \
  NS_IMETHOD GetCardAt(int32_t index, nsIAbCard * *_retval); \
  NS_IMETHOD GetEmailToUse(int32_t index, nsAString & _retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIABAUTOCOMPLETERESULT(_to) \
  NS_IMETHOD GetCardAt(int32_t index, nsIAbCard * *_retval) { return _to GetCardAt(index, _retval); } \
  NS_IMETHOD GetEmailToUse(int32_t index, nsAString & _retval) { return _to GetEmailToUse(index, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIABAUTOCOMPLETERESULT(_to) \
  NS_IMETHOD GetCardAt(int32_t index, nsIAbCard * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetCardAt(index, _retval); } \
  NS_IMETHOD GetEmailToUse(int32_t index, nsAString & _retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetEmailToUse(index, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsAbAutoCompleteResult : public nsIAbAutoCompleteResult
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIABAUTOCOMPLETERESULT

  nsAbAutoCompleteResult();

private:
  ~nsAbAutoCompleteResult();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsAbAutoCompleteResult, nsIAbAutoCompleteResult)

nsAbAutoCompleteResult::nsAbAutoCompleteResult()
{
  /* member initializers and constructor code */
}

nsAbAutoCompleteResult::~nsAbAutoCompleteResult()
{
  /* destructor code */
}

/* nsIAbCard getCardAt (in long index); */
NS_IMETHODIMP nsAbAutoCompleteResult::GetCardAt(int32_t index, nsIAbCard * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* AString getEmailToUse (in long index); */
NS_IMETHODIMP nsAbAutoCompleteResult::GetEmailToUse(int32_t index, nsAString & _retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIAbAutoCompleteResult_h__ */
