/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsIDOMDOMTokenList.idl"

/**
 * The DOMSettableTokenList interface is the same as the DOMTokenList interface,
 * except that it allows the underlying string to be directly changed.
 *
 * For more information on this interface please see:
 * http://dev.w3.org/html5/spec/infrastructure.html#domsettabletokenlist
 */
[scriptable, uuid(cdac274e-6619-4b5f-ba1a-cd1dbfae44b8)]
interface nsIDOMDOMSettableTokenList : nsIDOMDOMTokenList
{
  attribute DOMString value;
};

