/* -*- Mode: IDL; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

/*
 * offline news message state. Interface for old MSG_OfflineNewsArtState
 */

#include "nsISupports.idl"

[scriptable, uuid(921AC210-96B5-11d2-B7EB-00805F05FFA5)]
interface nsIMsgOfflineNewsState : nsISupports {

    /* outputBuffer is actually
     * a buffer to dump data into, but we normally pass it NET_Socket_Buffer,
     * which is constant. The implementation should only allocate a new
     * buffer if *outputBuffer is NULL.
     */
  long Process(out string outputBuffer, in long bufferSize);
  long Interrupt();
};

