/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/local/public/nsIMovemailIncomingServer.idl
 */

#ifndef __gen_nsIMovemailIncomingServer_h__
#define __gen_nsIMovemailIncomingServer_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIMovemailIncomingServer */
#define NS_IMOVEMAILINCOMINGSERVER_IID_STR "0dbfa510-1dd2-11b2-9f0e-849c5a241ab6"

#define NS_IMOVEMAILINCOMINGSERVER_IID \
  {0x0dbfa510, 0x1dd2, 0x11b2, \
    { 0x9f, 0x0e, 0x84, 0x9c, 0x5a, 0x24, 0x1a, 0xb6 }}

class NS_NO_VTABLE nsIMovemailIncomingServer : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IMOVEMAILINCOMINGSERVER_IID)

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIMovemailIncomingServer, NS_IMOVEMAILINCOMINGSERVER_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMOVEMAILINCOMINGSERVER \
  /* no methods! */

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMOVEMAILINCOMINGSERVER(_to) \
  /* no methods! */

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMOVEMAILINCOMINGSERVER(_to) \
  /* no methods! */

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMovemailIncomingServer : public nsIMovemailIncomingServer
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMOVEMAILINCOMINGSERVER

  nsMovemailIncomingServer();

private:
  ~nsMovemailIncomingServer();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMovemailIncomingServer, nsIMovemailIncomingServer)

nsMovemailIncomingServer::nsMovemailIncomingServer()
{
  /* member initializers and constructor code */
}

nsMovemailIncomingServer::~nsMovemailIncomingServer()
{
  /* destructor code */
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMovemailIncomingServer_h__ */
