/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/suite/shell/public/nsIShellService.idl
 */

#ifndef __gen_nsIShellService_h__
#define __gen_nsIShellService_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIDOMElement; /* forward declaration */

class nsIFile; /* forward declaration */


/* starting interface:    nsIShellService */
#define NS_ISHELLSERVICE_IID_STR "4244d99e-0fbf-4cf3-903a-893634704e84"

#define NS_ISHELLSERVICE_IID \
  {0x4244d99e, 0x0fbf, 0x4cf3, \
    { 0x90, 0x3a, 0x89, 0x36, 0x34, 0x70, 0x4e, 0x84 }}

class NS_NO_VTABLE nsIShellService : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_ISHELLSERVICE_IID)

  enum {
    BROWSER = 1U,
    MAIL = 2U,
    NEWS = 4U,
    RSS = 8U
  };

  /* boolean isDefaultClient (in boolean aStartupCheck, in unsigned short aApps); */
  NS_IMETHOD IsDefaultClient(bool aStartupCheck, uint16_t aApps, bool *_retval) = 0;

  /* void setDefaultClient (in boolean aForAllUsers, in boolean aClaimAllTypes, in unsigned short aApps); */
  NS_IMETHOD SetDefaultClient(bool aForAllUsers, bool aClaimAllTypes, uint16_t aApps) = 0;

  /* attribute boolean shouldCheckDefaultClient; */
  NS_IMETHOD GetShouldCheckDefaultClient(bool *aShouldCheckDefaultClient) = 0;
  NS_IMETHOD SetShouldCheckDefaultClient(bool aShouldCheckDefaultClient) = 0;

  /* attribute unsigned short shouldBeDefaultClientFor; */
  NS_IMETHOD GetShouldBeDefaultClientFor(uint16_t *aShouldBeDefaultClientFor) = 0;
  NS_IMETHOD SetShouldBeDefaultClientFor(uint16_t aShouldBeDefaultClientFor) = 0;

  /* readonly attribute boolean canSetDesktopBackground; */
  NS_IMETHOD GetCanSetDesktopBackground(bool *aCanSetDesktopBackground) = 0;

  /* void setDesktopBackground (in nsIDOMElement aElement, in long aPosition); */
  NS_IMETHOD SetDesktopBackground(nsIDOMElement *aElement, int32_t aPosition) = 0;

  enum {
    BACKGROUND_TILE = 1,
    BACKGROUND_STRETCH = 2,
    BACKGROUND_CENTER = 3,
    BACKGROUND_FILL = 4,
    BACKGROUND_FIT = 5
  };

  /* attribute unsigned long desktopBackgroundColor; */
  NS_IMETHOD GetDesktopBackgroundColor(uint32_t *aDesktopBackgroundColor) = 0;
  NS_IMETHOD SetDesktopBackgroundColor(uint32_t aDesktopBackgroundColor) = 0;

  /* void openApplicationWithURI (in nsIFile aApplication, in ACString aURI); */
  NS_IMETHOD OpenApplicationWithURI(nsIFile *aApplication, const nsACString & aURI) = 0;

  /* readonly attribute nsIFile defaultFeedReader; */
  NS_IMETHOD GetDefaultFeedReader(nsIFile * *aDefaultFeedReader) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIShellService, NS_ISHELLSERVICE_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSISHELLSERVICE \
  NS_IMETHOD IsDefaultClient(bool aStartupCheck, uint16_t aApps, bool *_retval); \
  NS_IMETHOD SetDefaultClient(bool aForAllUsers, bool aClaimAllTypes, uint16_t aApps); \
  NS_IMETHOD GetShouldCheckDefaultClient(bool *aShouldCheckDefaultClient); \
  NS_IMETHOD SetShouldCheckDefaultClient(bool aShouldCheckDefaultClient); \
  NS_IMETHOD GetShouldBeDefaultClientFor(uint16_t *aShouldBeDefaultClientFor); \
  NS_IMETHOD SetShouldBeDefaultClientFor(uint16_t aShouldBeDefaultClientFor); \
  NS_IMETHOD GetCanSetDesktopBackground(bool *aCanSetDesktopBackground); \
  NS_IMETHOD SetDesktopBackground(nsIDOMElement *aElement, int32_t aPosition); \
  NS_IMETHOD GetDesktopBackgroundColor(uint32_t *aDesktopBackgroundColor); \
  NS_IMETHOD SetDesktopBackgroundColor(uint32_t aDesktopBackgroundColor); \
  NS_IMETHOD OpenApplicationWithURI(nsIFile *aApplication, const nsACString & aURI); \
  NS_IMETHOD GetDefaultFeedReader(nsIFile * *aDefaultFeedReader); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSISHELLSERVICE(_to) \
  NS_IMETHOD IsDefaultClient(bool aStartupCheck, uint16_t aApps, bool *_retval) { return _to IsDefaultClient(aStartupCheck, aApps, _retval); } \
  NS_IMETHOD SetDefaultClient(bool aForAllUsers, bool aClaimAllTypes, uint16_t aApps) { return _to SetDefaultClient(aForAllUsers, aClaimAllTypes, aApps); } \
  NS_IMETHOD GetShouldCheckDefaultClient(bool *aShouldCheckDefaultClient) { return _to GetShouldCheckDefaultClient(aShouldCheckDefaultClient); } \
  NS_IMETHOD SetShouldCheckDefaultClient(bool aShouldCheckDefaultClient) { return _to SetShouldCheckDefaultClient(aShouldCheckDefaultClient); } \
  NS_IMETHOD GetShouldBeDefaultClientFor(uint16_t *aShouldBeDefaultClientFor) { return _to GetShouldBeDefaultClientFor(aShouldBeDefaultClientFor); } \
  NS_IMETHOD SetShouldBeDefaultClientFor(uint16_t aShouldBeDefaultClientFor) { return _to SetShouldBeDefaultClientFor(aShouldBeDefaultClientFor); } \
  NS_IMETHOD GetCanSetDesktopBackground(bool *aCanSetDesktopBackground) { return _to GetCanSetDesktopBackground(aCanSetDesktopBackground); } \
  NS_IMETHOD SetDesktopBackground(nsIDOMElement *aElement, int32_t aPosition) { return _to SetDesktopBackground(aElement, aPosition); } \
  NS_IMETHOD GetDesktopBackgroundColor(uint32_t *aDesktopBackgroundColor) { return _to GetDesktopBackgroundColor(aDesktopBackgroundColor); } \
  NS_IMETHOD SetDesktopBackgroundColor(uint32_t aDesktopBackgroundColor) { return _to SetDesktopBackgroundColor(aDesktopBackgroundColor); } \
  NS_IMETHOD OpenApplicationWithURI(nsIFile *aApplication, const nsACString & aURI) { return _to OpenApplicationWithURI(aApplication, aURI); } \
  NS_IMETHOD GetDefaultFeedReader(nsIFile * *aDefaultFeedReader) { return _to GetDefaultFeedReader(aDefaultFeedReader); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSISHELLSERVICE(_to) \
  NS_IMETHOD IsDefaultClient(bool aStartupCheck, uint16_t aApps, bool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->IsDefaultClient(aStartupCheck, aApps, _retval); } \
  NS_IMETHOD SetDefaultClient(bool aForAllUsers, bool aClaimAllTypes, uint16_t aApps) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetDefaultClient(aForAllUsers, aClaimAllTypes, aApps); } \
  NS_IMETHOD GetShouldCheckDefaultClient(bool *aShouldCheckDefaultClient) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetShouldCheckDefaultClient(aShouldCheckDefaultClient); } \
  NS_IMETHOD SetShouldCheckDefaultClient(bool aShouldCheckDefaultClient) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetShouldCheckDefaultClient(aShouldCheckDefaultClient); } \
  NS_IMETHOD GetShouldBeDefaultClientFor(uint16_t *aShouldBeDefaultClientFor) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetShouldBeDefaultClientFor(aShouldBeDefaultClientFor); } \
  NS_IMETHOD SetShouldBeDefaultClientFor(uint16_t aShouldBeDefaultClientFor) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetShouldBeDefaultClientFor(aShouldBeDefaultClientFor); } \
  NS_IMETHOD GetCanSetDesktopBackground(bool *aCanSetDesktopBackground) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetCanSetDesktopBackground(aCanSetDesktopBackground); } \
  NS_IMETHOD SetDesktopBackground(nsIDOMElement *aElement, int32_t aPosition) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetDesktopBackground(aElement, aPosition); } \
  NS_IMETHOD GetDesktopBackgroundColor(uint32_t *aDesktopBackgroundColor) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDesktopBackgroundColor(aDesktopBackgroundColor); } \
  NS_IMETHOD SetDesktopBackgroundColor(uint32_t aDesktopBackgroundColor) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetDesktopBackgroundColor(aDesktopBackgroundColor); } \
  NS_IMETHOD OpenApplicationWithURI(nsIFile *aApplication, const nsACString & aURI) { return !_to ? NS_ERROR_NULL_POINTER : _to->OpenApplicationWithURI(aApplication, aURI); } \
  NS_IMETHOD GetDefaultFeedReader(nsIFile * *aDefaultFeedReader) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDefaultFeedReader(aDefaultFeedReader); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsShellService : public nsIShellService
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSISHELLSERVICE

  nsShellService();

private:
  ~nsShellService();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsShellService, nsIShellService)

nsShellService::nsShellService()
{
  /* member initializers and constructor code */
}

nsShellService::~nsShellService()
{
  /* destructor code */
}

/* boolean isDefaultClient (in boolean aStartupCheck, in unsigned short aApps); */
NS_IMETHODIMP nsShellService::IsDefaultClient(bool aStartupCheck, uint16_t aApps, bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setDefaultClient (in boolean aForAllUsers, in boolean aClaimAllTypes, in unsigned short aApps); */
NS_IMETHODIMP nsShellService::SetDefaultClient(bool aForAllUsers, bool aClaimAllTypes, uint16_t aApps)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean shouldCheckDefaultClient; */
NS_IMETHODIMP nsShellService::GetShouldCheckDefaultClient(bool *aShouldCheckDefaultClient)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsShellService::SetShouldCheckDefaultClient(bool aShouldCheckDefaultClient)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute unsigned short shouldBeDefaultClientFor; */
NS_IMETHODIMP nsShellService::GetShouldBeDefaultClientFor(uint16_t *aShouldBeDefaultClientFor)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsShellService::SetShouldBeDefaultClientFor(uint16_t aShouldBeDefaultClientFor)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean canSetDesktopBackground; */
NS_IMETHODIMP nsShellService::GetCanSetDesktopBackground(bool *aCanSetDesktopBackground)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setDesktopBackground (in nsIDOMElement aElement, in long aPosition); */
NS_IMETHODIMP nsShellService::SetDesktopBackground(nsIDOMElement *aElement, int32_t aPosition)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute unsigned long desktopBackgroundColor; */
NS_IMETHODIMP nsShellService::GetDesktopBackgroundColor(uint32_t *aDesktopBackgroundColor)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsShellService::SetDesktopBackgroundColor(uint32_t aDesktopBackgroundColor)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void openApplicationWithURI (in nsIFile aApplication, in ACString aURI); */
NS_IMETHODIMP nsShellService::OpenApplicationWithURI(nsIFile *aApplication, const nsACString & aURI)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute nsIFile defaultFeedReader; */
NS_IMETHODIMP nsShellService::GetDefaultFeedReader(nsIFile * *aDefaultFeedReader)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIShellService_h__ */
