/* -*- Mode: C++; tab-width: 20; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"
interface nsIURI;

[scriptable, uuid(FC6E8234-BBF3-44A1-9802-5F023A929173)]
interface nsISimpleMimeConverter : nsISupports
{
    // uri of message getting displayed
    attribute nsIURI uri;
    AUTF8String convertToHTML(in ACString contentType,
                              in AUTF8String data);
};

%{C++

#define NS_SIMPLEMIMECONVERTERS_CATEGORY "simple-mime-converters"

%}
