/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this file,
 * You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "domstubs.idl"
#include "nsIDOMEvent.idl"

[scriptable, uuid(49bdda6f-430a-4cf8-b535-b97b5b1ed575), builtinclass]
interface nsIDOMDeviceStorageChangeEvent : nsIDOMEvent
{

  [noscript] void initDeviceStorageChangeEvent(in DOMString eventTypeArg,
                                               in boolean canBubbleArg,
                                               in boolean cancelableArg,
                                               in DOMString path,
                                               in DOMString reason);
  
  readonly attribute DOMString path;
  readonly attribute DOMString reason;
};

dictionary DeviceStorageChangeEventInit : EventInit
{
  DOMString path;
  DOMString reason;
};
