/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/base/search/public/nsIMsgSearchCustomTerm.idl
 */

#ifndef __gen_nsIMsgSearchCustomTerm_h__
#define __gen_nsIMsgSearchCustomTerm_h__


#ifndef __gen_nsMsgSearchCore_h__
#include "nsMsgSearchCore.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIMsgSearchCustomTerm */
#define NS_IMSGSEARCHCUSTOMTERM_IID_STR "925db5aa-21af-494c-8652-984bc7bad13a"

#define NS_IMSGSEARCHCUSTOMTERM_IID \
  {0x925db5aa, 0x21af, 0x494c, \
    { 0x86, 0x52, 0x98, 0x4b, 0xc7, 0xba, 0xd1, 0x3a }}

class NS_NO_VTABLE nsIMsgSearchCustomTerm : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IMSGSEARCHCUSTOMTERM_IID)

  /* readonly attribute ACString id; */
  NS_IMETHOD GetId(nsACString & aId) = 0;

  /* readonly attribute AString name; */
  NS_IMETHOD GetName(nsAString & aName) = 0;

  /* readonly attribute boolean needsBody; */
  NS_IMETHOD GetNeedsBody(bool *aNeedsBody) = 0;

  /* boolean getEnabled (in nsMsgSearchScopeValue scope, in nsMsgSearchOpValue op); */
  NS_IMETHOD GetEnabled(nsMsgSearchScopeValue scope, nsMsgSearchOpValue op, bool *_retval) = 0;

  /* boolean getAvailable (in nsMsgSearchScopeValue scope, in nsMsgSearchOpValue op); */
  NS_IMETHOD GetAvailable(nsMsgSearchScopeValue scope, nsMsgSearchOpValue op, bool *_retval) = 0;

  /* void getAvailableOperators (in nsMsgSearchScopeValue scope, out unsigned long length, [array, size_is (length), retval] out nsMsgSearchOpValue operators); */
  NS_IMETHOD GetAvailableOperators(nsMsgSearchScopeValue scope, uint32_t *length, nsMsgSearchOpValue **operators) = 0;

  /* boolean match (in nsIMsgDBHdr msgHdr, in AUTF8String searchValue, in nsMsgSearchOpValue searchOp); */
  NS_IMETHOD Match(nsIMsgDBHdr *msgHdr, const nsACString & searchValue, nsMsgSearchOpValue searchOp, bool *_retval) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIMsgSearchCustomTerm, NS_IMSGSEARCHCUSTOMTERM_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGSEARCHCUSTOMTERM \
  NS_IMETHOD GetId(nsACString & aId); \
  NS_IMETHOD GetName(nsAString & aName); \
  NS_IMETHOD GetNeedsBody(bool *aNeedsBody); \
  NS_IMETHOD GetEnabled(nsMsgSearchScopeValue scope, nsMsgSearchOpValue op, bool *_retval); \
  NS_IMETHOD GetAvailable(nsMsgSearchScopeValue scope, nsMsgSearchOpValue op, bool *_retval); \
  NS_IMETHOD GetAvailableOperators(nsMsgSearchScopeValue scope, uint32_t *length, nsMsgSearchOpValue **operators); \
  NS_IMETHOD Match(nsIMsgDBHdr *msgHdr, const nsACString & searchValue, nsMsgSearchOpValue searchOp, bool *_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGSEARCHCUSTOMTERM(_to) \
  NS_IMETHOD GetId(nsACString & aId) { return _to GetId(aId); } \
  NS_IMETHOD GetName(nsAString & aName) { return _to GetName(aName); } \
  NS_IMETHOD GetNeedsBody(bool *aNeedsBody) { return _to GetNeedsBody(aNeedsBody); } \
  NS_IMETHOD GetEnabled(nsMsgSearchScopeValue scope, nsMsgSearchOpValue op, bool *_retval) { return _to GetEnabled(scope, op, _retval); } \
  NS_IMETHOD GetAvailable(nsMsgSearchScopeValue scope, nsMsgSearchOpValue op, bool *_retval) { return _to GetAvailable(scope, op, _retval); } \
  NS_IMETHOD GetAvailableOperators(nsMsgSearchScopeValue scope, uint32_t *length, nsMsgSearchOpValue **operators) { return _to GetAvailableOperators(scope, length, operators); } \
  NS_IMETHOD Match(nsIMsgDBHdr *msgHdr, const nsACString & searchValue, nsMsgSearchOpValue searchOp, bool *_retval) { return _to Match(msgHdr, searchValue, searchOp, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGSEARCHCUSTOMTERM(_to) \
  NS_IMETHOD GetId(nsACString & aId) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetId(aId); } \
  NS_IMETHOD GetName(nsAString & aName) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetName(aName); } \
  NS_IMETHOD GetNeedsBody(bool *aNeedsBody) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNeedsBody(aNeedsBody); } \
  NS_IMETHOD GetEnabled(nsMsgSearchScopeValue scope, nsMsgSearchOpValue op, bool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetEnabled(scope, op, _retval); } \
  NS_IMETHOD GetAvailable(nsMsgSearchScopeValue scope, nsMsgSearchOpValue op, bool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetAvailable(scope, op, _retval); } \
  NS_IMETHOD GetAvailableOperators(nsMsgSearchScopeValue scope, uint32_t *length, nsMsgSearchOpValue **operators) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetAvailableOperators(scope, length, operators); } \
  NS_IMETHOD Match(nsIMsgDBHdr *msgHdr, const nsACString & searchValue, nsMsgSearchOpValue searchOp, bool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->Match(msgHdr, searchValue, searchOp, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgSearchCustomTerm : public nsIMsgSearchCustomTerm
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGSEARCHCUSTOMTERM

  nsMsgSearchCustomTerm();

private:
  ~nsMsgSearchCustomTerm();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgSearchCustomTerm, nsIMsgSearchCustomTerm)

nsMsgSearchCustomTerm::nsMsgSearchCustomTerm()
{
  /* member initializers and constructor code */
}

nsMsgSearchCustomTerm::~nsMsgSearchCustomTerm()
{
  /* destructor code */
}

/* readonly attribute ACString id; */
NS_IMETHODIMP nsMsgSearchCustomTerm::GetId(nsACString & aId)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute AString name; */
NS_IMETHODIMP nsMsgSearchCustomTerm::GetName(nsAString & aName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean needsBody; */
NS_IMETHODIMP nsMsgSearchCustomTerm::GetNeedsBody(bool *aNeedsBody)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean getEnabled (in nsMsgSearchScopeValue scope, in nsMsgSearchOpValue op); */
NS_IMETHODIMP nsMsgSearchCustomTerm::GetEnabled(nsMsgSearchScopeValue scope, nsMsgSearchOpValue op, bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean getAvailable (in nsMsgSearchScopeValue scope, in nsMsgSearchOpValue op); */
NS_IMETHODIMP nsMsgSearchCustomTerm::GetAvailable(nsMsgSearchScopeValue scope, nsMsgSearchOpValue op, bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void getAvailableOperators (in nsMsgSearchScopeValue scope, out unsigned long length, [array, size_is (length), retval] out nsMsgSearchOpValue operators); */
NS_IMETHODIMP nsMsgSearchCustomTerm::GetAvailableOperators(nsMsgSearchScopeValue scope, uint32_t *length, nsMsgSearchOpValue **operators)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean match (in nsIMsgDBHdr msgHdr, in AUTF8String searchValue, in nsMsgSearchOpValue searchOp); */
NS_IMETHODIMP nsMsgSearchCustomTerm::Match(nsIMsgDBHdr *msgHdr, const nsACString & searchValue, nsMsgSearchOpValue searchOp, bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgSearchCustomTerm_h__ */
