/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"

interface nsIDOMMozSmsFilter;
interface nsIDOMMozSmsMessage;

[scriptable, function, uuid(77b41d7e-ccb1-4480-8322-2af7bc437a3c)]
interface nsIDOMMozSmsCursor : nsISupports
{
  // Can be null if there is no more results.
  readonly attribute nsIDOMMozSmsMessage message;
                                    void continue();
};
