/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#ifndef nsViewsCID_h__
#define nsViewsCID_h__

#include "nsISupports.h"
#include "nsIFactory.h"
#include "nsIComponentManager.h"

#define NS_VIEW_MANAGER_CID \
{ 0xc95f1831, 0xc376, 0x11d1, \
    {0xb7, 0x21, 0x0, 0x60, 0x8, 0x91, 0xd8, 0xc9}}

#endif // nsViewsCID_h__
