/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

/* This is a private interface used exclusively by SMIME. 
   It provides functionality to the JS UI code,
   that is only accessible from C++.
*/

#include "nsISupports.idl"

interface nsIMsgCompFields;
interface nsIX509Cert;

[scriptable, uuid(a54e3c8f-a000-4901-898f-fafb297b1546)]
interface nsISMimeJSHelper : nsISupports 
{
  /**
   * Obtains detailed information about the certificate availability
   * status of email recipients.
   *
   * @param compFields - Attributes of the composed message
   *
   * @param count - The number of entries in returned arrays
   *
   * @param emailAddresses - The list of all recipient email addresses
   *
   * @param certVerification - The verification/validity status of recipient certs
   *
   * @param certIssuedInfos - If a recipient cert was found, when has it been issued?
   *
   * @param certExpiredInfos - If a recipient cert was found, when will it expire?
   *
   * @param certs - The recipient certificates, which can contain null for not found
   *
   * @param canEncrypt - whether valid certificates have been found for all recipients
   *
   * @exception NS_ERROR_FAILURE - unexptected failure
   *
   * @exception NS_ERROR_OUT_OF_MEMORY - could not create the out list
   *
   * @exception NS_ERROR_INVALID_ARG
   */
  void getRecipientCertsInfo(in nsIMsgCompFields compFields,
                             out unsigned long count,
                             [array, size_is(count)] out wstring emailAddresses,
                             [array, size_is(count)] out long certVerification,
                             [array, size_is(count)] out wstring certIssuedInfos,
                             [array, size_is(count)] out wstring certExpiresInfos,
                             [array, size_is(count)] out nsIX509Cert certs,
                             out boolean canEncrypt);

  /**
   * Obtains a list of email addresses where valid email recipient certificates
   * are not yet available.
   *
   * @param compFields - Attributes of the composed message
   *
   * @param count - The number of returned email addresses
   *
   * @param emailAddresses - The list of email addresses without valid certs
   *
   * @exception NS_ERROR_FAILURE - unexptected failure
   *
   * @exception NS_ERROR_OUT_OF_MEMORY - could not create the out list
   *
   * @exception NS_ERROR_INVALID_ARG
   */
  void getNoCertAddresses(in nsIMsgCompFields compFields,
                          out unsigned long count,
                          [array, size_is(count)] out wstring emailAddresses);
};
