/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/base/public/nsIMsgFolderCompactor.idl
 */

#ifndef __gen_nsIMsgFolderCompactor_h__
#define __gen_nsIMsgFolderCompactor_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIMsgFolder; /* forward declaration */

class nsIMsgDatabase; /* forward declaration */

class nsIMsgWindow; /* forward declaration */

class nsIUrlListener; /* forward declaration */

class nsIArray; /* forward declaration */


/* starting interface:    nsIMsgFolderCompactor */
#define NS_IMSGFOLDERCOMPACTOR_IID_STR "38c7e876-3083-4aea-8dcd-0ea0ec1753a3"

#define NS_IMSGFOLDERCOMPACTOR_IID \
  {0x38c7e876, 0x3083, 0x4aea, \
    { 0x8d, 0xcd, 0x0e, 0xa0, 0xec, 0x17, 0x53, 0xa3 }}

class NS_NO_VTABLE nsIMsgFolderCompactor : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IMSGFOLDERCOMPACTOR_IID)

  /* void compact (in nsIMsgFolder aFolder, in boolean aOfflineStore, in nsIUrlListener aListener, in nsIMsgWindow aMsgWindow); */
  NS_IMETHOD Compact(nsIMsgFolder *aFolder, bool aOfflineStore, nsIUrlListener *aListener, nsIMsgWindow *aMsgWindow) = 0;

  /* void compactFolders (in nsIArray aArrayOfFoldersToCompact, in nsIArray aOfflineFolderArray, in nsIUrlListener aListener, in nsIMsgWindow aMsgWindow); */
  NS_IMETHOD CompactFolders(nsIArray *aArrayOfFoldersToCompact, nsIArray *aOfflineFolderArray, nsIUrlListener *aListener, nsIMsgWindow *aMsgWindow) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIMsgFolderCompactor, NS_IMSGFOLDERCOMPACTOR_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGFOLDERCOMPACTOR \
  NS_IMETHOD Compact(nsIMsgFolder *aFolder, bool aOfflineStore, nsIUrlListener *aListener, nsIMsgWindow *aMsgWindow); \
  NS_IMETHOD CompactFolders(nsIArray *aArrayOfFoldersToCompact, nsIArray *aOfflineFolderArray, nsIUrlListener *aListener, nsIMsgWindow *aMsgWindow); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGFOLDERCOMPACTOR(_to) \
  NS_IMETHOD Compact(nsIMsgFolder *aFolder, bool aOfflineStore, nsIUrlListener *aListener, nsIMsgWindow *aMsgWindow) { return _to Compact(aFolder, aOfflineStore, aListener, aMsgWindow); } \
  NS_IMETHOD CompactFolders(nsIArray *aArrayOfFoldersToCompact, nsIArray *aOfflineFolderArray, nsIUrlListener *aListener, nsIMsgWindow *aMsgWindow) { return _to CompactFolders(aArrayOfFoldersToCompact, aOfflineFolderArray, aListener, aMsgWindow); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGFOLDERCOMPACTOR(_to) \
  NS_IMETHOD Compact(nsIMsgFolder *aFolder, bool aOfflineStore, nsIUrlListener *aListener, nsIMsgWindow *aMsgWindow) { return !_to ? NS_ERROR_NULL_POINTER : _to->Compact(aFolder, aOfflineStore, aListener, aMsgWindow); } \
  NS_IMETHOD CompactFolders(nsIArray *aArrayOfFoldersToCompact, nsIArray *aOfflineFolderArray, nsIUrlListener *aListener, nsIMsgWindow *aMsgWindow) { return !_to ? NS_ERROR_NULL_POINTER : _to->CompactFolders(aArrayOfFoldersToCompact, aOfflineFolderArray, aListener, aMsgWindow); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgFolderCompactor : public nsIMsgFolderCompactor
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGFOLDERCOMPACTOR

  nsMsgFolderCompactor();

private:
  ~nsMsgFolderCompactor();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgFolderCompactor, nsIMsgFolderCompactor)

nsMsgFolderCompactor::nsMsgFolderCompactor()
{
  /* member initializers and constructor code */
}

nsMsgFolderCompactor::~nsMsgFolderCompactor()
{
  /* destructor code */
}

/* void compact (in nsIMsgFolder aFolder, in boolean aOfflineStore, in nsIUrlListener aListener, in nsIMsgWindow aMsgWindow); */
NS_IMETHODIMP nsMsgFolderCompactor::Compact(nsIMsgFolder *aFolder, bool aOfflineStore, nsIUrlListener *aListener, nsIMsgWindow *aMsgWindow)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void compactFolders (in nsIArray aArrayOfFoldersToCompact, in nsIArray aOfflineFolderArray, in nsIUrlListener aListener, in nsIMsgWindow aMsgWindow); */
NS_IMETHODIMP nsMsgFolderCompactor::CompactFolders(nsIArray *aArrayOfFoldersToCompact, nsIArray *aOfflineFolderArray, nsIUrlListener *aListener, nsIMsgWindow *aMsgWindow)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgFolderCompactor_h__ */
