/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/addrbook/public/nsILDAPAutoCompleteSession.idl
 */

#ifndef __gen_nsILDAPAutoCompleteSession_h__
#define __gen_nsILDAPAutoCompleteSession_h__


#ifndef __gen_nsIAutoCompleteSession_h__
#include "nsIAutoCompleteSession.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsILDAPURL; /* forward declaration */

class nsILDAPAutoCompFormatter; /* forward declaration */

class nsIMutableArray; /* forward declaration */


/* starting interface:    nsILDAPAutoCompleteSession */
#define NS_ILDAPAUTOCOMPLETESESSION_IID_STR "d6a64827-6206-4070-9bf9-24578df0afe2"

#define NS_ILDAPAUTOCOMPLETESESSION_IID \
  {0xd6a64827, 0x6206, 0x4070, \
    { 0x9b, 0xf9, 0x24, 0x57, 0x8d, 0xf0, 0xaf, 0xe2 }}

class NS_NO_VTABLE nsILDAPAutoCompleteSession : public nsIAutoCompleteSession {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_ILDAPAUTOCOMPLETESESSION_IID)

  /* attribute AUTF8String filterTemplate; */
  NS_IMETHOD GetFilterTemplate(nsACString & aFilterTemplate) = 0;
  NS_IMETHOD SetFilterTemplate(const nsACString & aFilterTemplate) = 0;

  /* attribute long maxHits; */
  NS_IMETHOD GetMaxHits(int32_t *aMaxHits) = 0;
  NS_IMETHOD SetMaxHits(int32_t aMaxHits) = 0;

  /* attribute unsigned long minStringLength; */
  NS_IMETHOD GetMinStringLength(uint32_t *aMinStringLength) = 0;
  NS_IMETHOD SetMinStringLength(uint32_t aMinStringLength) = 0;

  /* attribute unsigned long cjkMinStringLength; */
  NS_IMETHOD GetCjkMinStringLength(uint32_t *aCjkMinStringLength) = 0;
  NS_IMETHOD SetCjkMinStringLength(uint32_t aCjkMinStringLength) = 0;

  /* attribute nsILDAPURL serverURL; */
  NS_IMETHOD GetServerURL(nsILDAPURL * *aServerURL) = 0;
  NS_IMETHOD SetServerURL(nsILDAPURL *aServerURL) = 0;

  /* attribute nsILDAPAutoCompFormatter formatter; */
  NS_IMETHOD GetFormatter(nsILDAPAutoCompFormatter * *aFormatter) = 0;
  NS_IMETHOD SetFormatter(nsILDAPAutoCompFormatter *aFormatter) = 0;

  /* attribute AUTF8String login; */
  NS_IMETHOD GetLogin(nsACString & aLogin) = 0;
  NS_IMETHOD SetLogin(const nsACString & aLogin) = 0;

  /* attribute ACString saslMechanism; */
  NS_IMETHOD GetSaslMechanism(nsACString & aSaslMechanism) = 0;
  NS_IMETHOD SetSaslMechanism(const nsACString & aSaslMechanism) = 0;

  /* attribute unsigned long version; */
  NS_IMETHOD GetVersion(uint32_t *aVersion) = 0;
  NS_IMETHOD SetVersion(uint32_t aVersion) = 0;

  /* attribute nsIMutableArray searchServerControls; */
  NS_IMETHOD GetSearchServerControls(nsIMutableArray * *aSearchServerControls) = 0;
  NS_IMETHOD SetSearchServerControls(nsIMutableArray *aSearchServerControls) = 0;

  /* attribute nsIMutableArray searchClientControls; */
  NS_IMETHOD GetSearchClientControls(nsIMutableArray * *aSearchClientControls) = 0;
  NS_IMETHOD SetSearchClientControls(nsIMutableArray *aSearchClientControls) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsILDAPAutoCompleteSession, NS_ILDAPAUTOCOMPLETESESSION_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSILDAPAUTOCOMPLETESESSION \
  NS_IMETHOD GetFilterTemplate(nsACString & aFilterTemplate); \
  NS_IMETHOD SetFilterTemplate(const nsACString & aFilterTemplate); \
  NS_IMETHOD GetMaxHits(int32_t *aMaxHits); \
  NS_IMETHOD SetMaxHits(int32_t aMaxHits); \
  NS_IMETHOD GetMinStringLength(uint32_t *aMinStringLength); \
  NS_IMETHOD SetMinStringLength(uint32_t aMinStringLength); \
  NS_IMETHOD GetCjkMinStringLength(uint32_t *aCjkMinStringLength); \
  NS_IMETHOD SetCjkMinStringLength(uint32_t aCjkMinStringLength); \
  NS_IMETHOD GetServerURL(nsILDAPURL * *aServerURL); \
  NS_IMETHOD SetServerURL(nsILDAPURL *aServerURL); \
  NS_IMETHOD GetFormatter(nsILDAPAutoCompFormatter * *aFormatter); \
  NS_IMETHOD SetFormatter(nsILDAPAutoCompFormatter *aFormatter); \
  NS_IMETHOD GetLogin(nsACString & aLogin); \
  NS_IMETHOD SetLogin(const nsACString & aLogin); \
  NS_IMETHOD GetSaslMechanism(nsACString & aSaslMechanism); \
  NS_IMETHOD SetSaslMechanism(const nsACString & aSaslMechanism); \
  NS_IMETHOD GetVersion(uint32_t *aVersion); \
  NS_IMETHOD SetVersion(uint32_t aVersion); \
  NS_IMETHOD GetSearchServerControls(nsIMutableArray * *aSearchServerControls); \
  NS_IMETHOD SetSearchServerControls(nsIMutableArray *aSearchServerControls); \
  NS_IMETHOD GetSearchClientControls(nsIMutableArray * *aSearchClientControls); \
  NS_IMETHOD SetSearchClientControls(nsIMutableArray *aSearchClientControls); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSILDAPAUTOCOMPLETESESSION(_to) \
  NS_IMETHOD GetFilterTemplate(nsACString & aFilterTemplate) { return _to GetFilterTemplate(aFilterTemplate); } \
  NS_IMETHOD SetFilterTemplate(const nsACString & aFilterTemplate) { return _to SetFilterTemplate(aFilterTemplate); } \
  NS_IMETHOD GetMaxHits(int32_t *aMaxHits) { return _to GetMaxHits(aMaxHits); } \
  NS_IMETHOD SetMaxHits(int32_t aMaxHits) { return _to SetMaxHits(aMaxHits); } \
  NS_IMETHOD GetMinStringLength(uint32_t *aMinStringLength) { return _to GetMinStringLength(aMinStringLength); } \
  NS_IMETHOD SetMinStringLength(uint32_t aMinStringLength) { return _to SetMinStringLength(aMinStringLength); } \
  NS_IMETHOD GetCjkMinStringLength(uint32_t *aCjkMinStringLength) { return _to GetCjkMinStringLength(aCjkMinStringLength); } \
  NS_IMETHOD SetCjkMinStringLength(uint32_t aCjkMinStringLength) { return _to SetCjkMinStringLength(aCjkMinStringLength); } \
  NS_IMETHOD GetServerURL(nsILDAPURL * *aServerURL) { return _to GetServerURL(aServerURL); } \
  NS_IMETHOD SetServerURL(nsILDAPURL *aServerURL) { return _to SetServerURL(aServerURL); } \
  NS_IMETHOD GetFormatter(nsILDAPAutoCompFormatter * *aFormatter) { return _to GetFormatter(aFormatter); } \
  NS_IMETHOD SetFormatter(nsILDAPAutoCompFormatter *aFormatter) { return _to SetFormatter(aFormatter); } \
  NS_IMETHOD GetLogin(nsACString & aLogin) { return _to GetLogin(aLogin); } \
  NS_IMETHOD SetLogin(const nsACString & aLogin) { return _to SetLogin(aLogin); } \
  NS_IMETHOD GetSaslMechanism(nsACString & aSaslMechanism) { return _to GetSaslMechanism(aSaslMechanism); } \
  NS_IMETHOD SetSaslMechanism(const nsACString & aSaslMechanism) { return _to SetSaslMechanism(aSaslMechanism); } \
  NS_IMETHOD GetVersion(uint32_t *aVersion) { return _to GetVersion(aVersion); } \
  NS_IMETHOD SetVersion(uint32_t aVersion) { return _to SetVersion(aVersion); } \
  NS_IMETHOD GetSearchServerControls(nsIMutableArray * *aSearchServerControls) { return _to GetSearchServerControls(aSearchServerControls); } \
  NS_IMETHOD SetSearchServerControls(nsIMutableArray *aSearchServerControls) { return _to SetSearchServerControls(aSearchServerControls); } \
  NS_IMETHOD GetSearchClientControls(nsIMutableArray * *aSearchClientControls) { return _to GetSearchClientControls(aSearchClientControls); } \
  NS_IMETHOD SetSearchClientControls(nsIMutableArray *aSearchClientControls) { return _to SetSearchClientControls(aSearchClientControls); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSILDAPAUTOCOMPLETESESSION(_to) \
  NS_IMETHOD GetFilterTemplate(nsACString & aFilterTemplate) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFilterTemplate(aFilterTemplate); } \
  NS_IMETHOD SetFilterTemplate(const nsACString & aFilterTemplate) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetFilterTemplate(aFilterTemplate); } \
  NS_IMETHOD GetMaxHits(int32_t *aMaxHits) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMaxHits(aMaxHits); } \
  NS_IMETHOD SetMaxHits(int32_t aMaxHits) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMaxHits(aMaxHits); } \
  NS_IMETHOD GetMinStringLength(uint32_t *aMinStringLength) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMinStringLength(aMinStringLength); } \
  NS_IMETHOD SetMinStringLength(uint32_t aMinStringLength) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMinStringLength(aMinStringLength); } \
  NS_IMETHOD GetCjkMinStringLength(uint32_t *aCjkMinStringLength) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetCjkMinStringLength(aCjkMinStringLength); } \
  NS_IMETHOD SetCjkMinStringLength(uint32_t aCjkMinStringLength) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetCjkMinStringLength(aCjkMinStringLength); } \
  NS_IMETHOD GetServerURL(nsILDAPURL * *aServerURL) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetServerURL(aServerURL); } \
  NS_IMETHOD SetServerURL(nsILDAPURL *aServerURL) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetServerURL(aServerURL); } \
  NS_IMETHOD GetFormatter(nsILDAPAutoCompFormatter * *aFormatter) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFormatter(aFormatter); } \
  NS_IMETHOD SetFormatter(nsILDAPAutoCompFormatter *aFormatter) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetFormatter(aFormatter); } \
  NS_IMETHOD GetLogin(nsACString & aLogin) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetLogin(aLogin); } \
  NS_IMETHOD SetLogin(const nsACString & aLogin) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetLogin(aLogin); } \
  NS_IMETHOD GetSaslMechanism(nsACString & aSaslMechanism) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSaslMechanism(aSaslMechanism); } \
  NS_IMETHOD SetSaslMechanism(const nsACString & aSaslMechanism) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetSaslMechanism(aSaslMechanism); } \
  NS_IMETHOD GetVersion(uint32_t *aVersion) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetVersion(aVersion); } \
  NS_IMETHOD SetVersion(uint32_t aVersion) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetVersion(aVersion); } \
  NS_IMETHOD GetSearchServerControls(nsIMutableArray * *aSearchServerControls) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSearchServerControls(aSearchServerControls); } \
  NS_IMETHOD SetSearchServerControls(nsIMutableArray *aSearchServerControls) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetSearchServerControls(aSearchServerControls); } \
  NS_IMETHOD GetSearchClientControls(nsIMutableArray * *aSearchClientControls) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSearchClientControls(aSearchClientControls); } \
  NS_IMETHOD SetSearchClientControls(nsIMutableArray *aSearchClientControls) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetSearchClientControls(aSearchClientControls); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsLDAPAutoCompleteSession : public nsILDAPAutoCompleteSession
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSILDAPAUTOCOMPLETESESSION

  nsLDAPAutoCompleteSession();

private:
  ~nsLDAPAutoCompleteSession();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsLDAPAutoCompleteSession, nsILDAPAutoCompleteSession)

nsLDAPAutoCompleteSession::nsLDAPAutoCompleteSession()
{
  /* member initializers and constructor code */
}

nsLDAPAutoCompleteSession::~nsLDAPAutoCompleteSession()
{
  /* destructor code */
}

/* attribute AUTF8String filterTemplate; */
NS_IMETHODIMP nsLDAPAutoCompleteSession::GetFilterTemplate(nsACString & aFilterTemplate)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsLDAPAutoCompleteSession::SetFilterTemplate(const nsACString & aFilterTemplate)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute long maxHits; */
NS_IMETHODIMP nsLDAPAutoCompleteSession::GetMaxHits(int32_t *aMaxHits)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsLDAPAutoCompleteSession::SetMaxHits(int32_t aMaxHits)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute unsigned long minStringLength; */
NS_IMETHODIMP nsLDAPAutoCompleteSession::GetMinStringLength(uint32_t *aMinStringLength)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsLDAPAutoCompleteSession::SetMinStringLength(uint32_t aMinStringLength)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute unsigned long cjkMinStringLength; */
NS_IMETHODIMP nsLDAPAutoCompleteSession::GetCjkMinStringLength(uint32_t *aCjkMinStringLength)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsLDAPAutoCompleteSession::SetCjkMinStringLength(uint32_t aCjkMinStringLength)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsILDAPURL serverURL; */
NS_IMETHODIMP nsLDAPAutoCompleteSession::GetServerURL(nsILDAPURL * *aServerURL)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsLDAPAutoCompleteSession::SetServerURL(nsILDAPURL *aServerURL)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsILDAPAutoCompFormatter formatter; */
NS_IMETHODIMP nsLDAPAutoCompleteSession::GetFormatter(nsILDAPAutoCompFormatter * *aFormatter)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsLDAPAutoCompleteSession::SetFormatter(nsILDAPAutoCompFormatter *aFormatter)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute AUTF8String login; */
NS_IMETHODIMP nsLDAPAutoCompleteSession::GetLogin(nsACString & aLogin)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsLDAPAutoCompleteSession::SetLogin(const nsACString & aLogin)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute ACString saslMechanism; */
NS_IMETHODIMP nsLDAPAutoCompleteSession::GetSaslMechanism(nsACString & aSaslMechanism)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsLDAPAutoCompleteSession::SetSaslMechanism(const nsACString & aSaslMechanism)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute unsigned long version; */
NS_IMETHODIMP nsLDAPAutoCompleteSession::GetVersion(uint32_t *aVersion)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsLDAPAutoCompleteSession::SetVersion(uint32_t aVersion)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsIMutableArray searchServerControls; */
NS_IMETHODIMP nsLDAPAutoCompleteSession::GetSearchServerControls(nsIMutableArray * *aSearchServerControls)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsLDAPAutoCompleteSession::SetSearchServerControls(nsIMutableArray *aSearchServerControls)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsIMutableArray searchClientControls; */
NS_IMETHODIMP nsLDAPAutoCompleteSession::GetSearchClientControls(nsIMutableArray * *aSearchClientControls)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsLDAPAutoCompleteSession::SetSearchClientControls(nsIMutableArray *aSearchClientControls)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsILDAPAutoCompleteSession_h__ */
