/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/addrbook/public/nsIAbCollection.idl
 */

#ifndef __gen_nsIAbCollection_h__
#define __gen_nsIAbCollection_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsIAbItem_h__
#include "nsIAbItem.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIAbCard; /* forward declaration */

class nsISimpleEnumerator; /* forward declaration */


/* starting interface:    nsIAbCollection */
#define NS_IABCOLLECTION_IID_STR "70f6123f-e06b-4101-9750-4ce73b38134b"

#define NS_IABCOLLECTION_IID \
  {0x70f6123f, 0xe06b, 0x4101, \
    { 0x97, 0x50, 0x4c, 0xe7, 0x3b, 0x38, 0x13, 0x4b }}

class NS_NO_VTABLE nsIAbCollection : public nsIAbItem {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IABCOLLECTION_IID)

  /* readonly attribute boolean readOnly; */
  NS_IMETHOD GetReadOnly(bool *aReadOnly) = 0;

  /* readonly attribute boolean isRemote; */
  NS_IMETHOD GetIsRemote(bool *aIsRemote) = 0;

  /* readonly attribute boolean isSecure; */
  NS_IMETHOD GetIsSecure(bool *aIsSecure) = 0;

  /* nsIAbCard cardForEmailAddress (in AUTF8String emailAddress); */
  NS_IMETHOD CardForEmailAddress(const nsACString & emailAddress, nsIAbCard * *_retval) = 0;

  /* nsIAbCard getCardFromProperty (in string aProperty, in AUTF8String aValue, in boolean aCaseSensitive); */
  NS_IMETHOD GetCardFromProperty(const char * aProperty, const nsACString & aValue, bool aCaseSensitive, nsIAbCard * *_retval) = 0;

  /* nsISimpleEnumerator getCardsFromProperty (in string aProperty, in AUTF8String aValue, in boolean aCaseSensitive); */
  NS_IMETHOD GetCardsFromProperty(const char * aProperty, const nsACString & aValue, bool aCaseSensitive, nsISimpleEnumerator * *_retval) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIAbCollection, NS_IABCOLLECTION_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIABCOLLECTION \
  NS_IMETHOD GetReadOnly(bool *aReadOnly); \
  NS_IMETHOD GetIsRemote(bool *aIsRemote); \
  NS_IMETHOD GetIsSecure(bool *aIsSecure); \
  NS_IMETHOD CardForEmailAddress(const nsACString & emailAddress, nsIAbCard * *_retval); \
  NS_IMETHOD GetCardFromProperty(const char * aProperty, const nsACString & aValue, bool aCaseSensitive, nsIAbCard * *_retval); \
  NS_IMETHOD GetCardsFromProperty(const char * aProperty, const nsACString & aValue, bool aCaseSensitive, nsISimpleEnumerator * *_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIABCOLLECTION(_to) \
  NS_IMETHOD GetReadOnly(bool *aReadOnly) { return _to GetReadOnly(aReadOnly); } \
  NS_IMETHOD GetIsRemote(bool *aIsRemote) { return _to GetIsRemote(aIsRemote); } \
  NS_IMETHOD GetIsSecure(bool *aIsSecure) { return _to GetIsSecure(aIsSecure); } \
  NS_IMETHOD CardForEmailAddress(const nsACString & emailAddress, nsIAbCard * *_retval) { return _to CardForEmailAddress(emailAddress, _retval); } \
  NS_IMETHOD GetCardFromProperty(const char * aProperty, const nsACString & aValue, bool aCaseSensitive, nsIAbCard * *_retval) { return _to GetCardFromProperty(aProperty, aValue, aCaseSensitive, _retval); } \
  NS_IMETHOD GetCardsFromProperty(const char * aProperty, const nsACString & aValue, bool aCaseSensitive, nsISimpleEnumerator * *_retval) { return _to GetCardsFromProperty(aProperty, aValue, aCaseSensitive, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIABCOLLECTION(_to) \
  NS_IMETHOD GetReadOnly(bool *aReadOnly) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetReadOnly(aReadOnly); } \
  NS_IMETHOD GetIsRemote(bool *aIsRemote) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetIsRemote(aIsRemote); } \
  NS_IMETHOD GetIsSecure(bool *aIsSecure) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetIsSecure(aIsSecure); } \
  NS_IMETHOD CardForEmailAddress(const nsACString & emailAddress, nsIAbCard * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->CardForEmailAddress(emailAddress, _retval); } \
  NS_IMETHOD GetCardFromProperty(const char * aProperty, const nsACString & aValue, bool aCaseSensitive, nsIAbCard * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetCardFromProperty(aProperty, aValue, aCaseSensitive, _retval); } \
  NS_IMETHOD GetCardsFromProperty(const char * aProperty, const nsACString & aValue, bool aCaseSensitive, nsISimpleEnumerator * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetCardsFromProperty(aProperty, aValue, aCaseSensitive, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsAbCollection : public nsIAbCollection
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIABCOLLECTION

  nsAbCollection();

private:
  ~nsAbCollection();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsAbCollection, nsIAbCollection)

nsAbCollection::nsAbCollection()
{
  /* member initializers and constructor code */
}

nsAbCollection::~nsAbCollection()
{
  /* destructor code */
}

/* readonly attribute boolean readOnly; */
NS_IMETHODIMP nsAbCollection::GetReadOnly(bool *aReadOnly)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean isRemote; */
NS_IMETHODIMP nsAbCollection::GetIsRemote(bool *aIsRemote)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean isSecure; */
NS_IMETHODIMP nsAbCollection::GetIsSecure(bool *aIsSecure)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIAbCard cardForEmailAddress (in AUTF8String emailAddress); */
NS_IMETHODIMP nsAbCollection::CardForEmailAddress(const nsACString & emailAddress, nsIAbCard * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIAbCard getCardFromProperty (in string aProperty, in AUTF8String aValue, in boolean aCaseSensitive); */
NS_IMETHODIMP nsAbCollection::GetCardFromProperty(const char * aProperty, const nsACString & aValue, bool aCaseSensitive, nsIAbCard * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsISimpleEnumerator getCardsFromProperty (in string aProperty, in AUTF8String aValue, in boolean aCaseSensitive); */
NS_IMETHODIMP nsAbCollection::GetCardsFromProperty(const char * aProperty, const nsACString & aValue, bool aCaseSensitive, nsISimpleEnumerator * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIAbCollection_h__ */
