/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"

interface nsIFile;
interface nsIURI;

/**
 * The PlacesImportExport interface provides methods for exporting Places data.
 * The word "Import" is in the name for legacy reasons and was kept to avoid
 * disrupting potential extension code using the export part. The new importer
 * lives in BookmarkHTMLUtils.jsm.
 */

[scriptable, uuid(47a4a09e-c708-4e68-b2f2-664d982ce026)]
interface nsIPlacesImportExportService: nsISupports
{
  /**
   * Saves the current bookmarks hierarchy to a bookmarks.html file.
   */
  void exportHTMLToFile(in nsIFile aFile);

  /**
   * Backup the bookmarks.html file.
   */
  void backupBookmarksFile();
};
