/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/base/public/MailNewsTypes2.idl
 */

#ifndef __gen_MailNewsTypes2_h__
#define __gen_MailNewsTypes2_h__

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
typedef uint32_t  nsMsgKey;

typedef uint32_t  nsMsgViewIndex;

typedef int32_t  nsMsgSearchScopeValue;

typedef int32_t  nsMsgPriorityValue;

typedef int32_t  nsMsgSocketTypeValue;

typedef int32_t  nsMsgAuthMethodValue;

typedef uint32_t  nsMsgJunkStatus;

typedef uint32_t  nsMsgJunkScore;


/* starting interface:    nsMsgPriority */
#define NS_MSGPRIORITY_IID_STR "94c0d8d8-2045-11d3-8a8f-0060b0fc04d2"

#define NS_MSGPRIORITY_IID \
  {0x94c0d8d8, 0x2045, 0x11d3, \
    { 0x8a, 0x8f, 0x00, 0x60, 0xb0, 0xfc, 0x04, 0xd2 }}

class NS_NO_VTABLE nsMsgPriority {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_MSGPRIORITY_IID)

  enum {
    notSet = 0,
    none = 1,
    lowest = 2,
    low = 3,
    normal = 4,
    high = 5,
    highest = 6,
    Default = 4
  };

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsMsgPriority, NS_MSGPRIORITY_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSMSGPRIORITY \

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSMSGPRIORITY(_to) \

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSMSGPRIORITY(_to) \

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public nsMsgPriority
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSMSGPRIORITY

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, nsMsgPriority)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* End of implementation class template. */
#endif


/* starting interface:    nsMsgSocketType */
#define NS_MSGSOCKETTYPE_IID_STR "bc78bc74-1b34-48e8-ac2b-968e8dff1aeb"

#define NS_MSGSOCKETTYPE_IID \
  {0xbc78bc74, 0x1b34, 0x48e8, \
    { 0xac, 0x2b, 0x96, 0x8e, 0x8d, 0xff, 0x1a, 0xeb }}

class NS_NO_VTABLE nsMsgSocketType {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_MSGSOCKETTYPE_IID)

  enum {
    plain = 0,
    trySTARTTLS = 1,
    alwaysSTARTTLS = 2,
    SSL = 3
  };

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsMsgSocketType, NS_MSGSOCKETTYPE_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSMSGSOCKETTYPE \

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSMSGSOCKETTYPE(_to) \

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSMSGSOCKETTYPE(_to) \

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public nsMsgSocketType
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSMSGSOCKETTYPE

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, nsMsgSocketType)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* End of implementation class template. */
#endif


/* starting interface:    nsMsgAuthMethod */
#define NS_MSGAUTHMETHOD_IID_STR "4a10e647-d179-4a53-b7ef-df575ff5f405"

#define NS_MSGAUTHMETHOD_IID \
  {0x4a10e647, 0xd179, 0x4a53, \
    { 0xb7, 0xef, 0xdf, 0x57, 0x5f, 0xf5, 0xf4, 0x05 }}

class NS_NO_VTABLE nsMsgAuthMethod {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_MSGAUTHMETHOD_IID)

  enum {
    none = 1,
    old = 2,
    passwordCleartext = 3,
    passwordEncrypted = 4,
    GSSAPI = 5,
    NTLM = 6,
    External = 7,
    secure = 8,
    anything = 9
  };

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsMsgAuthMethod, NS_MSGAUTHMETHOD_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSMSGAUTHMETHOD \

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSMSGAUTHMETHOD(_to) \

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSMSGAUTHMETHOD(_to) \

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public nsMsgAuthMethod
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSMSGAUTHMETHOD

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, nsMsgAuthMethod)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* End of implementation class template. */
#endif

typedef uint32_t  nsMsgLabelValue;

typedef int32_t  nsMsgViewSortOrderValue;

typedef int32_t  nsMsgViewSortTypeValue;

typedef int32_t  nsMsgViewTypeValue;

typedef int32_t  nsMsgViewFlagsTypeValue;


#endif /* __gen_MailNewsTypes2_h__ */
