/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

/*
  Interface for importing filters.
*/

#include "nsISupports.idl"

interface nsIMsgAccount;
interface nsIFile;

[scriptable, uuid(f2680ccf-d110-4b5b-954d-e072d4a16129)]
interface nsIImportFilters : nsISupports
{
  boolean  AutoLocate( out wstring aDescription, out nsIFile aLocation);

  void     SetLocation( in nsIFile aLocation);

  /*
    Import filters and put any problems in the error out parameter.
  */
  boolean  Import( out wstring aError);
};



%{ C++

%}
