/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mozilla/dom/interfaces/css/nsIDOMCSSSupportsRule.idl
 */

#ifndef __gen_nsIDOMCSSSupportsRule_h__
#define __gen_nsIDOMCSSSupportsRule_h__


#ifndef __gen_nsIDOMCSSRule_h__
#include "nsIDOMCSSRule.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIDOMCSSSupportsRule */
#define NS_IDOMCSSSUPPORTSRULE_IID_STR "5f409a4d-92f9-4a62-8e8a-cc1c02c32918"

#define NS_IDOMCSSSUPPORTSRULE_IID \
  {0x5f409a4d, 0x92f9, 0x4a62, \
    { 0x8e, 0x8a, 0xcc, 0x1c, 0x02, 0xc3, 0x29, 0x18 }}

class NS_NO_VTABLE nsIDOMCSSSupportsRule : public nsIDOMCSSRule {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IDOMCSSSUPPORTSRULE_IID)

  /* readonly attribute nsIDOMCSSRuleList cssRules; */
  NS_IMETHOD GetCssRules(nsIDOMCSSRuleList * *aCssRules) = 0;

  /* unsigned long insertRule (in DOMString rule, in unsigned long index) raises (DOMException); */
  NS_IMETHOD InsertRule(const nsAString & rule, uint32_t index, uint32_t *_retval) = 0;

  /* void deleteRule (in unsigned long index) raises (DOMException); */
  NS_IMETHOD DeleteRule(uint32_t index) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIDOMCSSSupportsRule, NS_IDOMCSSSUPPORTSRULE_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIDOMCSSSUPPORTSRULE \
  NS_IMETHOD GetCssRules(nsIDOMCSSRuleList * *aCssRules); \
  NS_IMETHOD InsertRule(const nsAString & rule, uint32_t index, uint32_t *_retval); \
  NS_IMETHOD DeleteRule(uint32_t index); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIDOMCSSSUPPORTSRULE(_to) \
  NS_IMETHOD GetCssRules(nsIDOMCSSRuleList * *aCssRules) { return _to GetCssRules(aCssRules); } \
  NS_IMETHOD InsertRule(const nsAString & rule, uint32_t index, uint32_t *_retval) { return _to InsertRule(rule, index, _retval); } \
  NS_IMETHOD DeleteRule(uint32_t index) { return _to DeleteRule(index); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIDOMCSSSUPPORTSRULE(_to) \
  NS_IMETHOD GetCssRules(nsIDOMCSSRuleList * *aCssRules) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetCssRules(aCssRules); } \
  NS_IMETHOD InsertRule(const nsAString & rule, uint32_t index, uint32_t *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->InsertRule(rule, index, _retval); } \
  NS_IMETHOD DeleteRule(uint32_t index) { return !_to ? NS_ERROR_NULL_POINTER : _to->DeleteRule(index); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsDOMCSSSupportsRule : public nsIDOMCSSSupportsRule
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIDOMCSSSUPPORTSRULE

  nsDOMCSSSupportsRule();

private:
  ~nsDOMCSSSupportsRule();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsDOMCSSSupportsRule, nsIDOMCSSSupportsRule)

nsDOMCSSSupportsRule::nsDOMCSSSupportsRule()
{
  /* member initializers and constructor code */
}

nsDOMCSSSupportsRule::~nsDOMCSSSupportsRule()
{
  /* destructor code */
}

/* readonly attribute nsIDOMCSSRuleList cssRules; */
NS_IMETHODIMP nsDOMCSSSupportsRule::GetCssRules(nsIDOMCSSRuleList * *aCssRules)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* unsigned long insertRule (in DOMString rule, in unsigned long index) raises (DOMException); */
NS_IMETHODIMP nsDOMCSSSupportsRule::InsertRule(const nsAString & rule, uint32_t index, uint32_t *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void deleteRule (in unsigned long index) raises (DOMException); */
NS_IMETHODIMP nsDOMCSSSupportsRule::DeleteRule(uint32_t index)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIDOMCSSSupportsRule_h__ */
