/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/suite/common/public/nsISuiteDownloadManagerUI.idl
 */

#ifndef __gen_nsISuiteDownloadManagerUI_h__
#define __gen_nsISuiteDownloadManagerUI_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsIDownloadManagerUI_h__
#include "nsIDownloadManagerUI.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsISuiteDownloadManagerUI */
#define NS_ISUITEDOWNLOADMANAGERUI_IID_STR "b2180611-e56e-4831-9770-15a53aacb36a"

#define NS_ISUITEDOWNLOADMANAGERUI_IID \
  {0xb2180611, 0xe56e, 0x4831, \
    { 0x97, 0x70, 0x15, 0xa5, 0x3a, 0xac, 0xb3, 0x6a }}

class NS_NO_VTABLE nsISuiteDownloadManagerUI : public nsIDownloadManagerUI {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_ISUITEDOWNLOADMANAGERUI_IID)

  /* void showManager ([optional] in nsIInterfaceRequestor aWindowContext, [optional] in unsigned long aID, [optional] in short aReason); */
  NS_IMETHOD ShowManager(nsIInterfaceRequestor *aWindowContext, uint32_t aID, int16_t aReason) = 0;

  /* void showProgress ([optional] in nsIInterfaceRequestor aWindowContext, [optional] in unsigned long aID, [optional] in short aReason); */
  NS_IMETHOD ShowProgress(nsIInterfaceRequestor *aWindowContext, uint32_t aID, int16_t aReason) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsISuiteDownloadManagerUI, NS_ISUITEDOWNLOADMANAGERUI_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSISUITEDOWNLOADMANAGERUI \
  NS_IMETHOD ShowManager(nsIInterfaceRequestor *aWindowContext, uint32_t aID, int16_t aReason); \
  NS_IMETHOD ShowProgress(nsIInterfaceRequestor *aWindowContext, uint32_t aID, int16_t aReason); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSISUITEDOWNLOADMANAGERUI(_to) \
  NS_IMETHOD ShowManager(nsIInterfaceRequestor *aWindowContext, uint32_t aID, int16_t aReason) { return _to ShowManager(aWindowContext, aID, aReason); } \
  NS_IMETHOD ShowProgress(nsIInterfaceRequestor *aWindowContext, uint32_t aID, int16_t aReason) { return _to ShowProgress(aWindowContext, aID, aReason); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSISUITEDOWNLOADMANAGERUI(_to) \
  NS_IMETHOD ShowManager(nsIInterfaceRequestor *aWindowContext, uint32_t aID, int16_t aReason) { return !_to ? NS_ERROR_NULL_POINTER : _to->ShowManager(aWindowContext, aID, aReason); } \
  NS_IMETHOD ShowProgress(nsIInterfaceRequestor *aWindowContext, uint32_t aID, int16_t aReason) { return !_to ? NS_ERROR_NULL_POINTER : _to->ShowProgress(aWindowContext, aID, aReason); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsSuiteDownloadManagerUI : public nsISuiteDownloadManagerUI
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSISUITEDOWNLOADMANAGERUI

  nsSuiteDownloadManagerUI();

private:
  ~nsSuiteDownloadManagerUI();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsSuiteDownloadManagerUI, nsISuiteDownloadManagerUI)

nsSuiteDownloadManagerUI::nsSuiteDownloadManagerUI()
{
  /* member initializers and constructor code */
}

nsSuiteDownloadManagerUI::~nsSuiteDownloadManagerUI()
{
  /* destructor code */
}

/* void showManager ([optional] in nsIInterfaceRequestor aWindowContext, [optional] in unsigned long aID, [optional] in short aReason); */
NS_IMETHODIMP nsSuiteDownloadManagerUI::ShowManager(nsIInterfaceRequestor *aWindowContext, uint32_t aID, int16_t aReason)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void showProgress ([optional] in nsIInterfaceRequestor aWindowContext, [optional] in unsigned long aID, [optional] in short aReason); */
NS_IMETHODIMP nsSuiteDownloadManagerUI::ShowProgress(nsIInterfaceRequestor *aWindowContext, uint32_t aID, int16_t aReason)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsISuiteDownloadManagerUI_h__ */
