/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/suite/common/public/nsISessionStartup.idl
 */

#ifndef __gen_nsISessionStartup_h__
#define __gen_nsISessionStartup_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#include "jspubtd.h"

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsISessionStartup */
#define NS_ISESSIONSTARTUP_IID_STR "dd709821-820a-4d0d-b7e8-a566b32377ef"

#define NS_ISESSIONSTARTUP_IID \
  {0xdd709821, 0x820a, 0x4d0d, \
    { 0xb7, 0xe8, 0xa5, 0x66, 0xb3, 0x23, 0x77, 0xef }}

class NS_NO_VTABLE nsISessionStartup : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_ISESSIONSTARTUP_IID)

  /* readonly attribute jsval state; */
  NS_IMETHOD GetState(JS::Value *aState) = 0;

  /* boolean doRestore (); */
  NS_IMETHOD DoRestore(bool *_retval) = 0;

  enum {
    NO_SESSION = 0U,
    RECOVER_SESSION = 1U,
    RESUME_SESSION = 2U,
    DEFER_SESSION = 3U
  };

  /* readonly attribute unsigned long sessionType; */
  NS_IMETHOD GetSessionType(uint32_t *aSessionType) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsISessionStartup, NS_ISESSIONSTARTUP_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSISESSIONSTARTUP \
  NS_IMETHOD GetState(JS::Value *aState); \
  NS_IMETHOD DoRestore(bool *_retval); \
  NS_IMETHOD GetSessionType(uint32_t *aSessionType); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSISESSIONSTARTUP(_to) \
  NS_IMETHOD GetState(JS::Value *aState) { return _to GetState(aState); } \
  NS_IMETHOD DoRestore(bool *_retval) { return _to DoRestore(_retval); } \
  NS_IMETHOD GetSessionType(uint32_t *aSessionType) { return _to GetSessionType(aSessionType); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSISESSIONSTARTUP(_to) \
  NS_IMETHOD GetState(JS::Value *aState) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetState(aState); } \
  NS_IMETHOD DoRestore(bool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->DoRestore(_retval); } \
  NS_IMETHOD GetSessionType(uint32_t *aSessionType) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSessionType(aSessionType); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsSessionStartup : public nsISessionStartup
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSISESSIONSTARTUP

  nsSessionStartup();

private:
  ~nsSessionStartup();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsSessionStartup, nsISessionStartup)

nsSessionStartup::nsSessionStartup()
{
  /* member initializers and constructor code */
}

nsSessionStartup::~nsSessionStartup()
{
  /* destructor code */
}

/* readonly attribute jsval state; */
NS_IMETHODIMP nsSessionStartup::GetState(JS::Value *aState)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean doRestore (); */
NS_IMETHODIMP nsSessionStartup::DoRestore(bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute unsigned long sessionType; */
NS_IMETHODIMP nsSessionStartup::GetSessionType(uint32_t *aSessionType)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsISessionStartup_h__ */
