/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/news/public/nsINNTPArticleList.idl
 */

#ifndef __gen_nsINNTPArticleList_h__
#define __gen_nsINNTPArticleList_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIMsgNewsFolder; /* forward declaration */


/* starting interface:    nsINNTPArticleList */
#define NS_INNTPARTICLELIST_IID_STR "921ac214-96b5-11d2-b7eb-00805f05ffa5"

#define NS_INNTPARTICLELIST_IID \
  {0x921ac214, 0x96b5, 0x11d2, \
    { 0xb7, 0xeb, 0x00, 0x80, 0x5f, 0x05, 0xff, 0xa5 }}

class NS_NO_VTABLE nsINNTPArticleList : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_INNTPARTICLELIST_IID)

  /* void initialize (in nsIMsgNewsFolder newsFolder); */
  NS_IMETHOD Initialize(nsIMsgNewsFolder *newsFolder) = 0;

  /* void addArticleKey (in long key); */
  NS_IMETHOD AddArticleKey(int32_t key) = 0;

  /* void finishAddingArticleKeys (); */
  NS_IMETHOD FinishAddingArticleKeys(void) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsINNTPArticleList, NS_INNTPARTICLELIST_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSINNTPARTICLELIST \
  NS_IMETHOD Initialize(nsIMsgNewsFolder *newsFolder); \
  NS_IMETHOD AddArticleKey(int32_t key); \
  NS_IMETHOD FinishAddingArticleKeys(void); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSINNTPARTICLELIST(_to) \
  NS_IMETHOD Initialize(nsIMsgNewsFolder *newsFolder) { return _to Initialize(newsFolder); } \
  NS_IMETHOD AddArticleKey(int32_t key) { return _to AddArticleKey(key); } \
  NS_IMETHOD FinishAddingArticleKeys(void) { return _to FinishAddingArticleKeys(); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSINNTPARTICLELIST(_to) \
  NS_IMETHOD Initialize(nsIMsgNewsFolder *newsFolder) { return !_to ? NS_ERROR_NULL_POINTER : _to->Initialize(newsFolder); } \
  NS_IMETHOD AddArticleKey(int32_t key) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddArticleKey(key); } \
  NS_IMETHOD FinishAddingArticleKeys(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->FinishAddingArticleKeys(); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsNNTPArticleList : public nsINNTPArticleList
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSINNTPARTICLELIST

  nsNNTPArticleList();

private:
  ~nsNNTPArticleList();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsNNTPArticleList, nsINNTPArticleList)

nsNNTPArticleList::nsNNTPArticleList()
{
  /* member initializers and constructor code */
}

nsNNTPArticleList::~nsNNTPArticleList()
{
  /* destructor code */
}

/* void initialize (in nsIMsgNewsFolder newsFolder); */
NS_IMETHODIMP nsNNTPArticleList::Initialize(nsIMsgNewsFolder *newsFolder)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void addArticleKey (in long key); */
NS_IMETHODIMP nsNNTPArticleList::AddArticleKey(int32_t key)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void finishAddingArticleKeys (); */
NS_IMETHODIMP nsNNTPArticleList::FinishAddingArticleKeys()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsINNTPArticleList_h__ */
