/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/addrbook/public/nsIAbDirSearchListener.idl
 */

#ifndef __gen_nsIAbDirSearchListener_h__
#define __gen_nsIAbDirSearchListener_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIAbCard; /* forward declaration */


/* starting interface:    nsIAbDirSearchListener */
#define NS_IABDIRSEARCHLISTENER_IID_STR "eafe2488-4efb-4ac8-a6b4-7756eb1650a3"

#define NS_IABDIRSEARCHLISTENER_IID \
  {0xeafe2488, 0x4efb, 0x4ac8, \
    { 0xa6, 0xb4, 0x77, 0x56, 0xeb, 0x16, 0x50, 0xa3 }}

class NS_NO_VTABLE nsIAbDirSearchListener : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IABDIRSEARCHLISTENER_IID)

  /* void onSearchFinished (in long aResult, in AString aErrorMsg); */
  NS_IMETHOD OnSearchFinished(int32_t aResult, const nsAString & aErrorMsg) = 0;

  /* void onSearchFoundCard (in nsIAbCard aCard); */
  NS_IMETHOD OnSearchFoundCard(nsIAbCard *aCard) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIAbDirSearchListener, NS_IABDIRSEARCHLISTENER_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIABDIRSEARCHLISTENER \
  NS_IMETHOD OnSearchFinished(int32_t aResult, const nsAString & aErrorMsg); \
  NS_IMETHOD OnSearchFoundCard(nsIAbCard *aCard); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIABDIRSEARCHLISTENER(_to) \
  NS_IMETHOD OnSearchFinished(int32_t aResult, const nsAString & aErrorMsg) { return _to OnSearchFinished(aResult, aErrorMsg); } \
  NS_IMETHOD OnSearchFoundCard(nsIAbCard *aCard) { return _to OnSearchFoundCard(aCard); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIABDIRSEARCHLISTENER(_to) \
  NS_IMETHOD OnSearchFinished(int32_t aResult, const nsAString & aErrorMsg) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnSearchFinished(aResult, aErrorMsg); } \
  NS_IMETHOD OnSearchFoundCard(nsIAbCard *aCard) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnSearchFoundCard(aCard); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsAbDirSearchListener : public nsIAbDirSearchListener
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIABDIRSEARCHLISTENER

  nsAbDirSearchListener();

private:
  ~nsAbDirSearchListener();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsAbDirSearchListener, nsIAbDirSearchListener)

nsAbDirSearchListener::nsAbDirSearchListener()
{
  /* member initializers and constructor code */
}

nsAbDirSearchListener::~nsAbDirSearchListener()
{
  /* destructor code */
}

/* void onSearchFinished (in long aResult, in AString aErrorMsg); */
NS_IMETHODIMP nsAbDirSearchListener::OnSearchFinished(int32_t aResult, const nsAString & aErrorMsg)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void onSearchFoundCard (in nsIAbCard aCard); */
NS_IMETHODIMP nsAbDirSearchListener::OnSearchFoundCard(nsIAbCard *aCard)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIAbDirSearchListener_h__ */
