/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/base/public/nsIMessengerWindowService.idl
 */

#ifndef __gen_nsIMessengerWindowService_h__
#define __gen_nsIMessengerWindowService_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_MailNewsTypes2_h__
#include "MailNewsTypes2.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIMessengerWindowService */
#define NS_IMESSENGERWINDOWSERVICE_IID_STR "113a1a5a-1dd2-11b2-b1b7-a85ccc06c8ce"

#define NS_IMESSENGERWINDOWSERVICE_IID \
  {0x113a1a5a, 0x1dd2, 0x11b2, \
    { 0xb1, 0xb7, 0xa8, 0x5c, 0xcc, 0x06, 0xc8, 0xce }}

class NS_NO_VTABLE nsIMessengerWindowService : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IMESSENGERWINDOWSERVICE_IID)

  /* void openMessengerWindowWithUri (in string aWindowType, in string aFolderURI, in nsMsgKey aMsgKey); */
  NS_IMETHOD OpenMessengerWindowWithUri(const char * aWindowType, const char * aFolderURI, nsMsgKey aMsgKey) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIMessengerWindowService, NS_IMESSENGERWINDOWSERVICE_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMESSENGERWINDOWSERVICE \
  NS_IMETHOD OpenMessengerWindowWithUri(const char * aWindowType, const char * aFolderURI, nsMsgKey aMsgKey); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMESSENGERWINDOWSERVICE(_to) \
  NS_IMETHOD OpenMessengerWindowWithUri(const char * aWindowType, const char * aFolderURI, nsMsgKey aMsgKey) { return _to OpenMessengerWindowWithUri(aWindowType, aFolderURI, aMsgKey); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMESSENGERWINDOWSERVICE(_to) \
  NS_IMETHOD OpenMessengerWindowWithUri(const char * aWindowType, const char * aFolderURI, nsMsgKey aMsgKey) { return !_to ? NS_ERROR_NULL_POINTER : _to->OpenMessengerWindowWithUri(aWindowType, aFolderURI, aMsgKey); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMessengerWindowService : public nsIMessengerWindowService
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMESSENGERWINDOWSERVICE

  nsMessengerWindowService();

private:
  ~nsMessengerWindowService();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMessengerWindowService, nsIMessengerWindowService)

nsMessengerWindowService::nsMessengerWindowService()
{
  /* member initializers and constructor code */
}

nsMessengerWindowService::~nsMessengerWindowService()
{
  /* destructor code */
}

/* void openMessengerWindowWithUri (in string aWindowType, in string aFolderURI, in nsMsgKey aMsgKey); */
NS_IMETHODIMP nsMessengerWindowService::OpenMessengerWindowWithUri(const char * aWindowType, const char * aFolderURI, nsMsgKey aMsgKey)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMessengerWindowService_h__ */
