/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsIDOMHTMLElement.idl"

/**
 * The nsIDOMHTMLTableRowElement interface is the interface to a
 * [X]HTML tr element.
 *
 * This interface is trying to follow the DOM Level 2 HTML specification:
 * http://www.w3.org/TR/DOM-Level-2-HTML/
 *
 * with changes from the work-in-progress WHATWG HTML specification:
 * http://www.whatwg.org/specs/web-apps/current-work/
 */

[scriptable, uuid(0AC4A382-4F97-4143-A3B3-DE0A54978C67)]
interface nsIDOMHTMLTableRowElement : nsIDOMHTMLElement
{
  // Modified in DOM Level 2:
  readonly attribute long                 rowIndex;
  // Modified in DOM Level 2:
  readonly attribute long                 sectionRowIndex;
  // Modified in DOM Level 2:
  readonly attribute nsIDOMHTMLCollection cells;
           attribute DOMString            align;
           attribute DOMString            bgColor;
           attribute DOMString            ch;
           attribute DOMString            chOff;
           attribute DOMString            vAlign;
  // Modified in DOM Level 2:
  nsIDOMHTMLElement         insertCell(in long index)
                                               raises(DOMException);
  // Modified in DOM Level 2:
  void                      deleteCell(in long index)
                                               raises(DOMException);
};
