/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/addrbook/public/nsIAbMDBDirectory.idl
 */

#ifndef __gen_nsIAbMDBDirectory_h__
#define __gen_nsIAbMDBDirectory_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIFile; /* forward declaration */

class nsIAbDirectory; /* forward declaration */

class nsIAbCard; /* forward declaration */

class nsIAddrDatabase; /* forward declaration */

#define kMDBDirectoryRoot          "moz-abmdbdirectory://"
#define kMDBDirectoryRootLen       21

/* starting interface:    nsIAbMDBDirectory */
#define NS_IABMDBDIRECTORY_IID_STR "744072be-1ba0-46bc-af24-46e22567a2ea"

#define NS_IABMDBDIRECTORY_IID \
  {0x744072be, 0x1ba0, 0x46bc, \
    { 0xaf, 0x24, 0x46, 0xe2, 0x25, 0x67, 0xa2, 0xea }}

class NS_NO_VTABLE nsIAbMDBDirectory : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IABMDBDIRECTORY_IID)

  /* nsIAbDirectory addDirectory (in string uriName); */
  NS_IMETHOD AddDirectory(const char * uriName, nsIAbDirectory * *_retval) = 0;

  /* readonly attribute nsIFile databaseFile; */
  NS_IMETHOD GetDatabaseFile(nsIFile * *aDatabaseFile) = 0;

  /* readonly attribute nsIAddrDatabase database; */
  NS_IMETHOD GetDatabase(nsIAddrDatabase * *aDatabase) = 0;

  /* [noscript] void removeElementsFromAddressList (); */
  NS_IMETHOD RemoveElementsFromAddressList(void) = 0;

  /* void addMailListToDirectory (in nsIAbDirectory mailList); */
  NS_IMETHOD AddMailListToDirectory(nsIAbDirectory *mailList) = 0;

  /* void copyDBMailList (in nsIAbMDBDirectory srcListDB); */
  NS_IMETHOD CopyDBMailList(nsIAbMDBDirectory *srcListDB) = 0;

  /* void addAddressToList (in nsIAbCard card); */
  NS_IMETHOD AddAddressToList(nsIAbCard *card) = 0;

  /* void removeEmailAddressAt (in unsigned long aIndex); */
  NS_IMETHOD RemoveEmailAddressAt(uint32_t aIndex) = 0;

  /* attribute unsigned long dbRowID; */
  NS_IMETHOD GetDbRowID(uint32_t *aDbRowID) = 0;
  NS_IMETHOD SetDbRowID(uint32_t aDbRowID) = 0;

  /* [noscript] void notifyDirItemAdded (in nsISupports item); */
  NS_IMETHOD NotifyDirItemAdded(nsISupports *item) = 0;

  /* [noscript] void clearDatabase (); */
  NS_IMETHOD ClearDatabase(void) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIAbMDBDirectory, NS_IABMDBDIRECTORY_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIABMDBDIRECTORY \
  NS_IMETHOD AddDirectory(const char * uriName, nsIAbDirectory * *_retval); \
  NS_IMETHOD GetDatabaseFile(nsIFile * *aDatabaseFile); \
  NS_IMETHOD GetDatabase(nsIAddrDatabase * *aDatabase); \
  NS_IMETHOD RemoveElementsFromAddressList(void); \
  NS_IMETHOD AddMailListToDirectory(nsIAbDirectory *mailList); \
  NS_IMETHOD CopyDBMailList(nsIAbMDBDirectory *srcListDB); \
  NS_IMETHOD AddAddressToList(nsIAbCard *card); \
  NS_IMETHOD RemoveEmailAddressAt(uint32_t aIndex); \
  NS_IMETHOD GetDbRowID(uint32_t *aDbRowID); \
  NS_IMETHOD SetDbRowID(uint32_t aDbRowID); \
  NS_IMETHOD NotifyDirItemAdded(nsISupports *item); \
  NS_IMETHOD ClearDatabase(void); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIABMDBDIRECTORY(_to) \
  NS_IMETHOD AddDirectory(const char * uriName, nsIAbDirectory * *_retval) { return _to AddDirectory(uriName, _retval); } \
  NS_IMETHOD GetDatabaseFile(nsIFile * *aDatabaseFile) { return _to GetDatabaseFile(aDatabaseFile); } \
  NS_IMETHOD GetDatabase(nsIAddrDatabase * *aDatabase) { return _to GetDatabase(aDatabase); } \
  NS_IMETHOD RemoveElementsFromAddressList(void) { return _to RemoveElementsFromAddressList(); } \
  NS_IMETHOD AddMailListToDirectory(nsIAbDirectory *mailList) { return _to AddMailListToDirectory(mailList); } \
  NS_IMETHOD CopyDBMailList(nsIAbMDBDirectory *srcListDB) { return _to CopyDBMailList(srcListDB); } \
  NS_IMETHOD AddAddressToList(nsIAbCard *card) { return _to AddAddressToList(card); } \
  NS_IMETHOD RemoveEmailAddressAt(uint32_t aIndex) { return _to RemoveEmailAddressAt(aIndex); } \
  NS_IMETHOD GetDbRowID(uint32_t *aDbRowID) { return _to GetDbRowID(aDbRowID); } \
  NS_IMETHOD SetDbRowID(uint32_t aDbRowID) { return _to SetDbRowID(aDbRowID); } \
  NS_IMETHOD NotifyDirItemAdded(nsISupports *item) { return _to NotifyDirItemAdded(item); } \
  NS_IMETHOD ClearDatabase(void) { return _to ClearDatabase(); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIABMDBDIRECTORY(_to) \
  NS_IMETHOD AddDirectory(const char * uriName, nsIAbDirectory * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddDirectory(uriName, _retval); } \
  NS_IMETHOD GetDatabaseFile(nsIFile * *aDatabaseFile) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDatabaseFile(aDatabaseFile); } \
  NS_IMETHOD GetDatabase(nsIAddrDatabase * *aDatabase) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDatabase(aDatabase); } \
  NS_IMETHOD RemoveElementsFromAddressList(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->RemoveElementsFromAddressList(); } \
  NS_IMETHOD AddMailListToDirectory(nsIAbDirectory *mailList) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddMailListToDirectory(mailList); } \
  NS_IMETHOD CopyDBMailList(nsIAbMDBDirectory *srcListDB) { return !_to ? NS_ERROR_NULL_POINTER : _to->CopyDBMailList(srcListDB); } \
  NS_IMETHOD AddAddressToList(nsIAbCard *card) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddAddressToList(card); } \
  NS_IMETHOD RemoveEmailAddressAt(uint32_t aIndex) { return !_to ? NS_ERROR_NULL_POINTER : _to->RemoveEmailAddressAt(aIndex); } \
  NS_IMETHOD GetDbRowID(uint32_t *aDbRowID) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDbRowID(aDbRowID); } \
  NS_IMETHOD SetDbRowID(uint32_t aDbRowID) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetDbRowID(aDbRowID); } \
  NS_IMETHOD NotifyDirItemAdded(nsISupports *item) { return !_to ? NS_ERROR_NULL_POINTER : _to->NotifyDirItemAdded(item); } \
  NS_IMETHOD ClearDatabase(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->ClearDatabase(); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsAbMDBDirectory : public nsIAbMDBDirectory
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIABMDBDIRECTORY

  nsAbMDBDirectory();

private:
  ~nsAbMDBDirectory();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsAbMDBDirectory, nsIAbMDBDirectory)

nsAbMDBDirectory::nsAbMDBDirectory()
{
  /* member initializers and constructor code */
}

nsAbMDBDirectory::~nsAbMDBDirectory()
{
  /* destructor code */
}

/* nsIAbDirectory addDirectory (in string uriName); */
NS_IMETHODIMP nsAbMDBDirectory::AddDirectory(const char * uriName, nsIAbDirectory * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute nsIFile databaseFile; */
NS_IMETHODIMP nsAbMDBDirectory::GetDatabaseFile(nsIFile * *aDatabaseFile)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute nsIAddrDatabase database; */
NS_IMETHODIMP nsAbMDBDirectory::GetDatabase(nsIAddrDatabase * *aDatabase)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [noscript] void removeElementsFromAddressList (); */
NS_IMETHODIMP nsAbMDBDirectory::RemoveElementsFromAddressList()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void addMailListToDirectory (in nsIAbDirectory mailList); */
NS_IMETHODIMP nsAbMDBDirectory::AddMailListToDirectory(nsIAbDirectory *mailList)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void copyDBMailList (in nsIAbMDBDirectory srcListDB); */
NS_IMETHODIMP nsAbMDBDirectory::CopyDBMailList(nsIAbMDBDirectory *srcListDB)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void addAddressToList (in nsIAbCard card); */
NS_IMETHODIMP nsAbMDBDirectory::AddAddressToList(nsIAbCard *card)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void removeEmailAddressAt (in unsigned long aIndex); */
NS_IMETHODIMP nsAbMDBDirectory::RemoveEmailAddressAt(uint32_t aIndex)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute unsigned long dbRowID; */
NS_IMETHODIMP nsAbMDBDirectory::GetDbRowID(uint32_t *aDbRowID)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsAbMDBDirectory::SetDbRowID(uint32_t aDbRowID)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [noscript] void notifyDirItemAdded (in nsISupports item); */
NS_IMETHODIMP nsAbMDBDirectory::NotifyDirItemAdded(nsISupports *item)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [noscript] void clearDatabase (); */
NS_IMETHODIMP nsAbMDBDirectory::ClearDatabase()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIAbMDBDirectory_h__ */
