/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/addrbook/public/nsILDAPAutoCompFormatter.idl
 */

#ifndef __gen_nsILDAPAutoCompFormatter_h__
#define __gen_nsILDAPAutoCompFormatter_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIAutoCompleteItem; /* forward declaration */

class nsILDAPMessage; /* forward declaration */


/* starting interface:    nsILDAPAutoCompFormatter */
#define NS_ILDAPAUTOCOMPFORMATTER_IID_STR "450cb44e-1752-49d0-890a-f895f8163cc3"

#define NS_ILDAPAUTOCOMPFORMATTER_IID \
  {0x450cb44e, 0x1752, 0x49d0, \
    { 0x89, 0x0a, 0xf8, 0x95, 0xf8, 0x16, 0x3c, 0xc3 }}

class NS_NO_VTABLE nsILDAPAutoCompFormatter : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_ILDAPAUTOCOMPFORMATTER_IID)

  /* nsIAutoCompleteItem format (in nsILDAPMessage aMessage); */
  NS_IMETHOD Format(nsILDAPMessage *aMessage, nsIAutoCompleteItem * *_retval) = 0;

  /* readonly attribute ACString attributes; */
  NS_IMETHOD GetAttributes(nsACString & aAttributes) = 0;

  /* nsIAutoCompleteItem formatException (in long aState, in nsresult aErrorCode); */
  NS_IMETHOD FormatException(int32_t aState, nsresult aErrorCode, nsIAutoCompleteItem * *_retval) = 0;

  enum {
    STATE_UNBOUND = 0,
    STATE_INITIALIZING = 1,
    STATE_BINDING = 2,
    STATE_BOUND = 3,
    STATE_SEARCHING = 4
  };

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsILDAPAutoCompFormatter, NS_ILDAPAUTOCOMPFORMATTER_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSILDAPAUTOCOMPFORMATTER \
  NS_IMETHOD Format(nsILDAPMessage *aMessage, nsIAutoCompleteItem * *_retval); \
  NS_IMETHOD GetAttributes(nsACString & aAttributes); \
  NS_IMETHOD FormatException(int32_t aState, nsresult aErrorCode, nsIAutoCompleteItem * *_retval); \

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSILDAPAUTOCOMPFORMATTER(_to) \
  NS_IMETHOD Format(nsILDAPMessage *aMessage, nsIAutoCompleteItem * *_retval) { return _to Format(aMessage, _retval); } \
  NS_IMETHOD GetAttributes(nsACString & aAttributes) { return _to GetAttributes(aAttributes); } \
  NS_IMETHOD FormatException(int32_t aState, nsresult aErrorCode, nsIAutoCompleteItem * *_retval) { return _to FormatException(aState, aErrorCode, _retval); } \

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSILDAPAUTOCOMPFORMATTER(_to) \
  NS_IMETHOD Format(nsILDAPMessage *aMessage, nsIAutoCompleteItem * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->Format(aMessage, _retval); } \
  NS_IMETHOD GetAttributes(nsACString & aAttributes) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetAttributes(aAttributes); } \
  NS_IMETHOD FormatException(int32_t aState, nsresult aErrorCode, nsIAutoCompleteItem * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->FormatException(aState, aErrorCode, _retval); } \

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsLDAPAutoCompFormatter : public nsILDAPAutoCompFormatter
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSILDAPAUTOCOMPFORMATTER

  nsLDAPAutoCompFormatter();

private:
  ~nsLDAPAutoCompFormatter();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsLDAPAutoCompFormatter, nsILDAPAutoCompFormatter)

nsLDAPAutoCompFormatter::nsLDAPAutoCompFormatter()
{
  /* member initializers and constructor code */
}

nsLDAPAutoCompFormatter::~nsLDAPAutoCompFormatter()
{
  /* destructor code */
}

/* nsIAutoCompleteItem format (in nsILDAPMessage aMessage); */
NS_IMETHODIMP nsLDAPAutoCompFormatter::Format(nsILDAPMessage *aMessage, nsIAutoCompleteItem * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute ACString attributes; */
NS_IMETHODIMP nsLDAPAutoCompFormatter::GetAttributes(nsACString & aAttributes)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIAutoCompleteItem formatException (in long aState, in nsresult aErrorCode); */
NS_IMETHODIMP nsLDAPAutoCompFormatter::FormatException(int32_t aState, nsresult aErrorCode, nsIAutoCompleteItem * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsILDAPAutoCompFormatter_h__ */
