/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/compose/public/nsIMsgCompUtils.idl
 */

#ifndef __gen_nsIMsgCompUtils_h__
#define __gen_nsIMsgCompUtils_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsIMsgIdentity_h__
#include "nsIMsgIdentity.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIMsgCompUtils */
#define NS_IMSGCOMPUTILS_IID_STR "00b4569a-077e-4236-b993-980fd82bb948"

#define NS_IMSGCOMPUTILS_IID \
  {0x00b4569a, 0x077e, 0x4236, \
    { 0xb9, 0x93, 0x98, 0x0f, 0xd8, 0x2b, 0xb9, 0x48 }}

class NS_NO_VTABLE nsIMsgCompUtils : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IMSGCOMPUTILS_IID)

  /* string mimeMakeSeparator (in string prefix); */
  NS_IMETHOD MimeMakeSeparator(const char * prefix, char * *_retval) = 0;

  /* string msgGenerateMessageId (in nsIMsgIdentity identity); */
  NS_IMETHOD MsgGenerateMessageId(nsIMsgIdentity *identity, char * *_retval) = 0;

  /* readonly attribute boolean msgMimeConformToStandard; */
  NS_IMETHOD GetMsgMimeConformToStandard(bool *aMsgMimeConformToStandard) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIMsgCompUtils, NS_IMSGCOMPUTILS_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGCOMPUTILS \
  NS_IMETHOD MimeMakeSeparator(const char * prefix, char * *_retval); \
  NS_IMETHOD MsgGenerateMessageId(nsIMsgIdentity *identity, char * *_retval); \
  NS_IMETHOD GetMsgMimeConformToStandard(bool *aMsgMimeConformToStandard); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGCOMPUTILS(_to) \
  NS_IMETHOD MimeMakeSeparator(const char * prefix, char * *_retval) { return _to MimeMakeSeparator(prefix, _retval); } \
  NS_IMETHOD MsgGenerateMessageId(nsIMsgIdentity *identity, char * *_retval) { return _to MsgGenerateMessageId(identity, _retval); } \
  NS_IMETHOD GetMsgMimeConformToStandard(bool *aMsgMimeConformToStandard) { return _to GetMsgMimeConformToStandard(aMsgMimeConformToStandard); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGCOMPUTILS(_to) \
  NS_IMETHOD MimeMakeSeparator(const char * prefix, char * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->MimeMakeSeparator(prefix, _retval); } \
  NS_IMETHOD MsgGenerateMessageId(nsIMsgIdentity *identity, char * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->MsgGenerateMessageId(identity, _retval); } \
  NS_IMETHOD GetMsgMimeConformToStandard(bool *aMsgMimeConformToStandard) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMsgMimeConformToStandard(aMsgMimeConformToStandard); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgCompUtils : public nsIMsgCompUtils
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGCOMPUTILS

  nsMsgCompUtils();

private:
  ~nsMsgCompUtils();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgCompUtils, nsIMsgCompUtils)

nsMsgCompUtils::nsMsgCompUtils()
{
  /* member initializers and constructor code */
}

nsMsgCompUtils::~nsMsgCompUtils()
{
  /* destructor code */
}

/* string mimeMakeSeparator (in string prefix); */
NS_IMETHODIMP nsMsgCompUtils::MimeMakeSeparator(const char * prefix, char * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* string msgGenerateMessageId (in nsIMsgIdentity identity); */
NS_IMETHODIMP nsMsgCompUtils::MsgGenerateMessageId(nsIMsgIdentity *identity, char * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean msgMimeConformToStandard; */
NS_IMETHODIMP nsMsgCompUtils::GetMsgMimeConformToStandard(bool *aMsgMimeConformToStandard)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgCompUtils_h__ */
