/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/local/public/nsIMsgParseMailMsgState.idl
 */

#ifndef __gen_nsIMsgParseMailMsgState_h__
#define __gen_nsIMsgParseMailMsgState_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIMsgDatabase; /* forward declaration */

class nsIMsgDBHdr; /* forward declaration */

class nsIOutputStream; /* forward declaration */

#include "nsIMsgDatabase.h"
#include "nsIMsgHdr.h"
typedef int32_t  nsMailboxParseState;


/* starting interface:    nsIMsgParseMailMsgState */
#define NS_IMSGPARSEMAILMSGSTATE_IID_STR "abf6a8e2-955e-4952-a295-b71d45f770cf"

#define NS_IMSGPARSEMAILMSGSTATE_IID \
  {0xabf6a8e2, 0x955e, 0x4952, \
    { 0xa2, 0x95, 0xb7, 0x1d, 0x45, 0xf7, 0x70, 0xcf }}

class NS_NO_VTABLE nsIMsgParseMailMsgState : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IMSGPARSEMAILMSGSTATE_IID)

  /* attribute unsigned long envelopePos; */
  NS_IMETHOD GetEnvelopePos(uint32_t *aEnvelopePos) = 0;
  NS_IMETHOD SetEnvelopePos(uint32_t aEnvelopePos) = 0;

  /* void SetMailDB (in nsIMsgDatabase aDatabase); */
  NS_IMETHOD SetMailDB(nsIMsgDatabase *aDatabase) = 0;

  /* void SetBackupMailDB (in nsIMsgDatabase aDatabase); */
  NS_IMETHOD SetBackupMailDB(nsIMsgDatabase *aDatabase) = 0;

  /* void Clear (); */
  NS_IMETHOD Clear(void) = 0;

  /* void ParseAFolderLine (in string line, in unsigned long lineLength); */
  NS_IMETHOD ParseAFolderLine(const char * line, uint32_t lineLength) = 0;

  /* attribute nsIMsgDBHdr newMsgHdr; */
  NS_IMETHOD GetNewMsgHdr(nsIMsgDBHdr * *aNewMsgHdr) = 0;
  NS_IMETHOD SetNewMsgHdr(nsIMsgDBHdr *aNewMsgHdr) = 0;

  /* void FinishHeader (); */
  NS_IMETHOD FinishHeader(void) = 0;

  /* long GetAllHeaders (out string headers); */
  NS_IMETHOD GetAllHeaders(char * *headers, int32_t *_retval) = 0;

  /* readonly attribute string headers; */
  NS_IMETHOD GetHeaders(char * *aHeaders) = 0;

  /* attribute nsMailboxParseState state; */
  NS_IMETHOD GetState(nsMailboxParseState *aState) = 0;
  NS_IMETHOD SetState(nsMailboxParseState aState) = 0;

  enum {
    ParseEnvelopeState = 0,
    ParseHeadersState = 1,
    ParseBodyState = 2
  };

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIMsgParseMailMsgState, NS_IMSGPARSEMAILMSGSTATE_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGPARSEMAILMSGSTATE \
  NS_IMETHOD GetEnvelopePos(uint32_t *aEnvelopePos); \
  NS_IMETHOD SetEnvelopePos(uint32_t aEnvelopePos); \
  NS_IMETHOD SetMailDB(nsIMsgDatabase *aDatabase); \
  NS_IMETHOD SetBackupMailDB(nsIMsgDatabase *aDatabase); \
  NS_IMETHOD Clear(void); \
  NS_IMETHOD ParseAFolderLine(const char * line, uint32_t lineLength); \
  NS_IMETHOD GetNewMsgHdr(nsIMsgDBHdr * *aNewMsgHdr); \
  NS_IMETHOD SetNewMsgHdr(nsIMsgDBHdr *aNewMsgHdr); \
  NS_IMETHOD FinishHeader(void); \
  NS_IMETHOD GetAllHeaders(char * *headers, int32_t *_retval); \
  NS_IMETHOD GetHeaders(char * *aHeaders); \
  NS_IMETHOD GetState(nsMailboxParseState *aState); \
  NS_IMETHOD SetState(nsMailboxParseState aState); \

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGPARSEMAILMSGSTATE(_to) \
  NS_IMETHOD GetEnvelopePos(uint32_t *aEnvelopePos) { return _to GetEnvelopePos(aEnvelopePos); } \
  NS_IMETHOD SetEnvelopePos(uint32_t aEnvelopePos) { return _to SetEnvelopePos(aEnvelopePos); } \
  NS_IMETHOD SetMailDB(nsIMsgDatabase *aDatabase) { return _to SetMailDB(aDatabase); } \
  NS_IMETHOD SetBackupMailDB(nsIMsgDatabase *aDatabase) { return _to SetBackupMailDB(aDatabase); } \
  NS_IMETHOD Clear(void) { return _to Clear(); } \
  NS_IMETHOD ParseAFolderLine(const char * line, uint32_t lineLength) { return _to ParseAFolderLine(line, lineLength); } \
  NS_IMETHOD GetNewMsgHdr(nsIMsgDBHdr * *aNewMsgHdr) { return _to GetNewMsgHdr(aNewMsgHdr); } \
  NS_IMETHOD SetNewMsgHdr(nsIMsgDBHdr *aNewMsgHdr) { return _to SetNewMsgHdr(aNewMsgHdr); } \
  NS_IMETHOD FinishHeader(void) { return _to FinishHeader(); } \
  NS_IMETHOD GetAllHeaders(char * *headers, int32_t *_retval) { return _to GetAllHeaders(headers, _retval); } \
  NS_IMETHOD GetHeaders(char * *aHeaders) { return _to GetHeaders(aHeaders); } \
  NS_IMETHOD GetState(nsMailboxParseState *aState) { return _to GetState(aState); } \
  NS_IMETHOD SetState(nsMailboxParseState aState) { return _to SetState(aState); } \

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGPARSEMAILMSGSTATE(_to) \
  NS_IMETHOD GetEnvelopePos(uint32_t *aEnvelopePos) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetEnvelopePos(aEnvelopePos); } \
  NS_IMETHOD SetEnvelopePos(uint32_t aEnvelopePos) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetEnvelopePos(aEnvelopePos); } \
  NS_IMETHOD SetMailDB(nsIMsgDatabase *aDatabase) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMailDB(aDatabase); } \
  NS_IMETHOD SetBackupMailDB(nsIMsgDatabase *aDatabase) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetBackupMailDB(aDatabase); } \
  NS_IMETHOD Clear(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->Clear(); } \
  NS_IMETHOD ParseAFolderLine(const char * line, uint32_t lineLength) { return !_to ? NS_ERROR_NULL_POINTER : _to->ParseAFolderLine(line, lineLength); } \
  NS_IMETHOD GetNewMsgHdr(nsIMsgDBHdr * *aNewMsgHdr) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNewMsgHdr(aNewMsgHdr); } \
  NS_IMETHOD SetNewMsgHdr(nsIMsgDBHdr *aNewMsgHdr) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetNewMsgHdr(aNewMsgHdr); } \
  NS_IMETHOD FinishHeader(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->FinishHeader(); } \
  NS_IMETHOD GetAllHeaders(char * *headers, int32_t *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetAllHeaders(headers, _retval); } \
  NS_IMETHOD GetHeaders(char * *aHeaders) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetHeaders(aHeaders); } \
  NS_IMETHOD GetState(nsMailboxParseState *aState) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetState(aState); } \
  NS_IMETHOD SetState(nsMailboxParseState aState) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetState(aState); } \

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgParseMailMsgState : public nsIMsgParseMailMsgState
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGPARSEMAILMSGSTATE

  nsMsgParseMailMsgState();

private:
  ~nsMsgParseMailMsgState();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgParseMailMsgState, nsIMsgParseMailMsgState)

nsMsgParseMailMsgState::nsMsgParseMailMsgState()
{
  /* member initializers and constructor code */
}

nsMsgParseMailMsgState::~nsMsgParseMailMsgState()
{
  /* destructor code */
}

/* attribute unsigned long envelopePos; */
NS_IMETHODIMP nsMsgParseMailMsgState::GetEnvelopePos(uint32_t *aEnvelopePos)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgParseMailMsgState::SetEnvelopePos(uint32_t aEnvelopePos)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void SetMailDB (in nsIMsgDatabase aDatabase); */
NS_IMETHODIMP nsMsgParseMailMsgState::SetMailDB(nsIMsgDatabase *aDatabase)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void SetBackupMailDB (in nsIMsgDatabase aDatabase); */
NS_IMETHODIMP nsMsgParseMailMsgState::SetBackupMailDB(nsIMsgDatabase *aDatabase)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void Clear (); */
NS_IMETHODIMP nsMsgParseMailMsgState::Clear()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void ParseAFolderLine (in string line, in unsigned long lineLength); */
NS_IMETHODIMP nsMsgParseMailMsgState::ParseAFolderLine(const char * line, uint32_t lineLength)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsIMsgDBHdr newMsgHdr; */
NS_IMETHODIMP nsMsgParseMailMsgState::GetNewMsgHdr(nsIMsgDBHdr * *aNewMsgHdr)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgParseMailMsgState::SetNewMsgHdr(nsIMsgDBHdr *aNewMsgHdr)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void FinishHeader (); */
NS_IMETHODIMP nsMsgParseMailMsgState::FinishHeader()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* long GetAllHeaders (out string headers); */
NS_IMETHODIMP nsMsgParseMailMsgState::GetAllHeaders(char * *headers, int32_t *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute string headers; */
NS_IMETHODIMP nsMsgParseMailMsgState::GetHeaders(char * *aHeaders)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsMailboxParseState state; */
NS_IMETHODIMP nsMsgParseMailMsgState::GetState(nsMailboxParseState *aState)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgParseMailMsgState::SetState(nsMailboxParseState aState)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgParseMailMsgState_h__ */
