/* -*- Mode: C++; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* vim: set ts=2 et sw=2 tw=80: */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this file,
 * You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsIDOMDOMRequest.idl"

interface nsIDOMEventListener;
interface nsIDOMLockedFile;

[scriptable, builtinclass, uuid(fe06b66e-fede-4d44-ab3a-403f60d6b593)]
interface nsIDOMFileRequest : nsIDOMDOMRequest
{
  readonly attribute nsIDOMLockedFile lockedFile;

  attribute nsIDOMEventListener onprogress;
};
