/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "domstubs.idl"

interface nsIDOMSVGAnimatedString;
interface nsIDOMCSSStyleDeclaration;
interface nsIDOMCSSValue;

[scriptable, uuid(ea8a6cb1-9176-45db-989d-d0e89f563d7e)]
interface nsIDOMSVGStylable : nsISupports
{
  readonly attribute nsIDOMSVGAnimatedString   className;
  readonly attribute nsIDOMCSSStyleDeclaration style;

  nsIDOMCSSValue getPresentationAttribute(in DOMString name);
};
