/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/import/public/nsIImportMail.idl
 */

#ifndef __gen_nsIImportMail_h__
#define __gen_nsIImportMail_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIFile; /* forward declaration */

class nsISupportsArray; /* forward declaration */

class nsIImportMailboxDescriptor; /* forward declaration */

class nsIOutputStream; /* forward declaration */

class nsIMsgFolder; /* forward declaration */


/* starting interface:    nsIImportMail */
#define NS_IIMPORTMAIL_IID_STR "306561d3-ed2f-425d-87ee-eb129a84a6af"

#define NS_IIMPORTMAIL_IID \
  {0x306561d3, 0xed2f, 0x425d, \
    { 0x87, 0xee, 0xeb, 0x12, 0x9a, 0x84, 0xa6, 0xaf }}

class NS_NO_VTABLE nsIImportMail : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IIMPORTMAIL_IID)

  /* void GetDefaultLocation (out nsIFile location, out boolean found, out boolean userVerify); */
  NS_IMETHOD GetDefaultLocation(nsIFile * *location, bool *found, bool *userVerify) = 0;

  /* nsISupportsArray FindMailboxes (in nsIFile location); */
  NS_IMETHOD FindMailboxes(nsIFile *location, nsISupportsArray * *_retval) = 0;

  /* void ImportMailbox (in nsIImportMailboxDescriptor source, in nsIMsgFolder dstFolder, out wstring errorLog, out wstring successLog, out boolean fatalError); */
  NS_IMETHOD ImportMailbox(nsIImportMailboxDescriptor *source, nsIMsgFolder *dstFolder, PRUnichar * *errorLog, PRUnichar * *successLog, bool *fatalError) = 0;

  /* unsigned long GetImportProgress (); */
  NS_IMETHOD GetImportProgress(uint32_t *_retval) = 0;

  /* AString translateFolderName (in AString aFolderName); */
  NS_IMETHOD TranslateFolderName(const nsAString & aFolderName, nsAString & _retval) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIImportMail, NS_IIMPORTMAIL_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIIMPORTMAIL \
  NS_IMETHOD GetDefaultLocation(nsIFile * *location, bool *found, bool *userVerify); \
  NS_IMETHOD FindMailboxes(nsIFile *location, nsISupportsArray * *_retval); \
  NS_IMETHOD ImportMailbox(nsIImportMailboxDescriptor *source, nsIMsgFolder *dstFolder, PRUnichar * *errorLog, PRUnichar * *successLog, bool *fatalError); \
  NS_IMETHOD GetImportProgress(uint32_t *_retval); \
  NS_IMETHOD TranslateFolderName(const nsAString & aFolderName, nsAString & _retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIIMPORTMAIL(_to) \
  NS_IMETHOD GetDefaultLocation(nsIFile * *location, bool *found, bool *userVerify) { return _to GetDefaultLocation(location, found, userVerify); } \
  NS_IMETHOD FindMailboxes(nsIFile *location, nsISupportsArray * *_retval) { return _to FindMailboxes(location, _retval); } \
  NS_IMETHOD ImportMailbox(nsIImportMailboxDescriptor *source, nsIMsgFolder *dstFolder, PRUnichar * *errorLog, PRUnichar * *successLog, bool *fatalError) { return _to ImportMailbox(source, dstFolder, errorLog, successLog, fatalError); } \
  NS_IMETHOD GetImportProgress(uint32_t *_retval) { return _to GetImportProgress(_retval); } \
  NS_IMETHOD TranslateFolderName(const nsAString & aFolderName, nsAString & _retval) { return _to TranslateFolderName(aFolderName, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIIMPORTMAIL(_to) \
  NS_IMETHOD GetDefaultLocation(nsIFile * *location, bool *found, bool *userVerify) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDefaultLocation(location, found, userVerify); } \
  NS_IMETHOD FindMailboxes(nsIFile *location, nsISupportsArray * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->FindMailboxes(location, _retval); } \
  NS_IMETHOD ImportMailbox(nsIImportMailboxDescriptor *source, nsIMsgFolder *dstFolder, PRUnichar * *errorLog, PRUnichar * *successLog, bool *fatalError) { return !_to ? NS_ERROR_NULL_POINTER : _to->ImportMailbox(source, dstFolder, errorLog, successLog, fatalError); } \
  NS_IMETHOD GetImportProgress(uint32_t *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetImportProgress(_retval); } \
  NS_IMETHOD TranslateFolderName(const nsAString & aFolderName, nsAString & _retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->TranslateFolderName(aFolderName, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsImportMail : public nsIImportMail
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIIMPORTMAIL

  nsImportMail();

private:
  ~nsImportMail();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsImportMail, nsIImportMail)

nsImportMail::nsImportMail()
{
  /* member initializers and constructor code */
}

nsImportMail::~nsImportMail()
{
  /* destructor code */
}

/* void GetDefaultLocation (out nsIFile location, out boolean found, out boolean userVerify); */
NS_IMETHODIMP nsImportMail::GetDefaultLocation(nsIFile * *location, bool *found, bool *userVerify)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsISupportsArray FindMailboxes (in nsIFile location); */
NS_IMETHODIMP nsImportMail::FindMailboxes(nsIFile *location, nsISupportsArray * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void ImportMailbox (in nsIImportMailboxDescriptor source, in nsIMsgFolder dstFolder, out wstring errorLog, out wstring successLog, out boolean fatalError); */
NS_IMETHODIMP nsImportMail::ImportMailbox(nsIImportMailboxDescriptor *source, nsIMsgFolder *dstFolder, PRUnichar * *errorLog, PRUnichar * *successLog, bool *fatalError)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* unsigned long GetImportProgress (); */
NS_IMETHODIMP nsImportMail::GetImportProgress(uint32_t *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* AString translateFolderName (in AString aFolderName); */
NS_IMETHODIMP nsImportMail::TranslateFolderName(const nsAString & aFolderName, nsAString & _retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif

#define kDestTrashFolderName "Trash"
#define kDestUnsentMessagesFolderName "Unsent Messages"
#define kDestSentFolderName "Sent"
#define kDestInboxFolderName "Inbox"

#endif /* __gen_nsIImportMail_h__ */
