/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/db/msgdb/public/nsIDBChangeListener.idl
 */

#ifndef __gen_nsIDBChangeListener_h__
#define __gen_nsIDBChangeListener_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_MailNewsTypes2_h__
#include "MailNewsTypes2.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIDBChangeAnnouncer; /* forward declaration */

class nsIMsgDBHdr; /* forward declaration */

class nsIMsgDatabase; /* forward declaration */


/* starting interface:    nsIDBChangeListener */
#define NS_IDBCHANGELISTENER_IID_STR "21c56d34-71b9-42bb-9606-331a6a5f8210"

#define NS_IDBCHANGELISTENER_IID \
  {0x21c56d34, 0x71b9, 0x42bb, \
    { 0x96, 0x06, 0x33, 0x1a, 0x6a, 0x5f, 0x82, 0x10 }}

class NS_NO_VTABLE nsIDBChangeListener : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IDBCHANGELISTENER_IID)

  /* void onHdrFlagsChanged (in nsIMsgDBHdr aHdrChanged, in unsigned long aOldFlags, in unsigned long aNewFlags, in nsIDBChangeListener aInstigator); */
  NS_IMETHOD OnHdrFlagsChanged(nsIMsgDBHdr *aHdrChanged, uint32_t aOldFlags, uint32_t aNewFlags, nsIDBChangeListener *aInstigator) = 0;

  /* void onHdrDeleted (in nsIMsgDBHdr aHdrChanged, in nsMsgKey aParentKey, in long aFlags, in nsIDBChangeListener aInstigator); */
  NS_IMETHOD OnHdrDeleted(nsIMsgDBHdr *aHdrChanged, nsMsgKey aParentKey, int32_t aFlags, nsIDBChangeListener *aInstigator) = 0;

  /* void onHdrAdded (in nsIMsgDBHdr aHdrChanged, in nsMsgKey aParentKey, in long aFlags, in nsIDBChangeListener aInstigator); */
  NS_IMETHOD OnHdrAdded(nsIMsgDBHdr *aHdrChanged, nsMsgKey aParentKey, int32_t aFlags, nsIDBChangeListener *aInstigator) = 0;

  /* void onParentChanged (in nsMsgKey aKeyChanged, in nsMsgKey oldParent, in nsMsgKey newParent, in nsIDBChangeListener aInstigator); */
  NS_IMETHOD OnParentChanged(nsMsgKey aKeyChanged, nsMsgKey oldParent, nsMsgKey newParent, nsIDBChangeListener *aInstigator) = 0;

  /* void onAnnouncerGoingAway (in nsIDBChangeAnnouncer instigator); */
  NS_IMETHOD OnAnnouncerGoingAway(nsIDBChangeAnnouncer *instigator) = 0;

  /* void onReadChanged (in nsIDBChangeListener aInstigator); */
  NS_IMETHOD OnReadChanged(nsIDBChangeListener *aInstigator) = 0;

  /* void onJunkScoreChanged (in nsIDBChangeListener aInstigator); */
  NS_IMETHOD OnJunkScoreChanged(nsIDBChangeListener *aInstigator) = 0;

  /* void onHdrPropertyChanged (in nsIMsgDBHdr aHdrToChange, in boolean aPreChange, inout uint32_t aStatus, in nsIDBChangeListener aInstigator); */
  NS_IMETHOD OnHdrPropertyChanged(nsIMsgDBHdr *aHdrToChange, bool aPreChange, uint32_t *aStatus, nsIDBChangeListener *aInstigator) = 0;

  /* void onEvent (in nsIMsgDatabase aDB, in string aEvent); */
  NS_IMETHOD OnEvent(nsIMsgDatabase *aDB, const char * aEvent) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIDBChangeListener, NS_IDBCHANGELISTENER_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIDBCHANGELISTENER \
  NS_IMETHOD OnHdrFlagsChanged(nsIMsgDBHdr *aHdrChanged, uint32_t aOldFlags, uint32_t aNewFlags, nsIDBChangeListener *aInstigator); \
  NS_IMETHOD OnHdrDeleted(nsIMsgDBHdr *aHdrChanged, nsMsgKey aParentKey, int32_t aFlags, nsIDBChangeListener *aInstigator); \
  NS_IMETHOD OnHdrAdded(nsIMsgDBHdr *aHdrChanged, nsMsgKey aParentKey, int32_t aFlags, nsIDBChangeListener *aInstigator); \
  NS_IMETHOD OnParentChanged(nsMsgKey aKeyChanged, nsMsgKey oldParent, nsMsgKey newParent, nsIDBChangeListener *aInstigator); \
  NS_IMETHOD OnAnnouncerGoingAway(nsIDBChangeAnnouncer *instigator); \
  NS_IMETHOD OnReadChanged(nsIDBChangeListener *aInstigator); \
  NS_IMETHOD OnJunkScoreChanged(nsIDBChangeListener *aInstigator); \
  NS_IMETHOD OnHdrPropertyChanged(nsIMsgDBHdr *aHdrToChange, bool aPreChange, uint32_t *aStatus, nsIDBChangeListener *aInstigator); \
  NS_IMETHOD OnEvent(nsIMsgDatabase *aDB, const char * aEvent); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIDBCHANGELISTENER(_to) \
  NS_IMETHOD OnHdrFlagsChanged(nsIMsgDBHdr *aHdrChanged, uint32_t aOldFlags, uint32_t aNewFlags, nsIDBChangeListener *aInstigator) { return _to OnHdrFlagsChanged(aHdrChanged, aOldFlags, aNewFlags, aInstigator); } \
  NS_IMETHOD OnHdrDeleted(nsIMsgDBHdr *aHdrChanged, nsMsgKey aParentKey, int32_t aFlags, nsIDBChangeListener *aInstigator) { return _to OnHdrDeleted(aHdrChanged, aParentKey, aFlags, aInstigator); } \
  NS_IMETHOD OnHdrAdded(nsIMsgDBHdr *aHdrChanged, nsMsgKey aParentKey, int32_t aFlags, nsIDBChangeListener *aInstigator) { return _to OnHdrAdded(aHdrChanged, aParentKey, aFlags, aInstigator); } \
  NS_IMETHOD OnParentChanged(nsMsgKey aKeyChanged, nsMsgKey oldParent, nsMsgKey newParent, nsIDBChangeListener *aInstigator) { return _to OnParentChanged(aKeyChanged, oldParent, newParent, aInstigator); } \
  NS_IMETHOD OnAnnouncerGoingAway(nsIDBChangeAnnouncer *instigator) { return _to OnAnnouncerGoingAway(instigator); } \
  NS_IMETHOD OnReadChanged(nsIDBChangeListener *aInstigator) { return _to OnReadChanged(aInstigator); } \
  NS_IMETHOD OnJunkScoreChanged(nsIDBChangeListener *aInstigator) { return _to OnJunkScoreChanged(aInstigator); } \
  NS_IMETHOD OnHdrPropertyChanged(nsIMsgDBHdr *aHdrToChange, bool aPreChange, uint32_t *aStatus, nsIDBChangeListener *aInstigator) { return _to OnHdrPropertyChanged(aHdrToChange, aPreChange, aStatus, aInstigator); } \
  NS_IMETHOD OnEvent(nsIMsgDatabase *aDB, const char * aEvent) { return _to OnEvent(aDB, aEvent); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIDBCHANGELISTENER(_to) \
  NS_IMETHOD OnHdrFlagsChanged(nsIMsgDBHdr *aHdrChanged, uint32_t aOldFlags, uint32_t aNewFlags, nsIDBChangeListener *aInstigator) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnHdrFlagsChanged(aHdrChanged, aOldFlags, aNewFlags, aInstigator); } \
  NS_IMETHOD OnHdrDeleted(nsIMsgDBHdr *aHdrChanged, nsMsgKey aParentKey, int32_t aFlags, nsIDBChangeListener *aInstigator) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnHdrDeleted(aHdrChanged, aParentKey, aFlags, aInstigator); } \
  NS_IMETHOD OnHdrAdded(nsIMsgDBHdr *aHdrChanged, nsMsgKey aParentKey, int32_t aFlags, nsIDBChangeListener *aInstigator) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnHdrAdded(aHdrChanged, aParentKey, aFlags, aInstigator); } \
  NS_IMETHOD OnParentChanged(nsMsgKey aKeyChanged, nsMsgKey oldParent, nsMsgKey newParent, nsIDBChangeListener *aInstigator) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnParentChanged(aKeyChanged, oldParent, newParent, aInstigator); } \
  NS_IMETHOD OnAnnouncerGoingAway(nsIDBChangeAnnouncer *instigator) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnAnnouncerGoingAway(instigator); } \
  NS_IMETHOD OnReadChanged(nsIDBChangeListener *aInstigator) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnReadChanged(aInstigator); } \
  NS_IMETHOD OnJunkScoreChanged(nsIDBChangeListener *aInstigator) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnJunkScoreChanged(aInstigator); } \
  NS_IMETHOD OnHdrPropertyChanged(nsIMsgDBHdr *aHdrToChange, bool aPreChange, uint32_t *aStatus, nsIDBChangeListener *aInstigator) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnHdrPropertyChanged(aHdrToChange, aPreChange, aStatus, aInstigator); } \
  NS_IMETHOD OnEvent(nsIMsgDatabase *aDB, const char * aEvent) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnEvent(aDB, aEvent); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsDBChangeListener : public nsIDBChangeListener
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIDBCHANGELISTENER

  nsDBChangeListener();

private:
  ~nsDBChangeListener();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsDBChangeListener, nsIDBChangeListener)

nsDBChangeListener::nsDBChangeListener()
{
  /* member initializers and constructor code */
}

nsDBChangeListener::~nsDBChangeListener()
{
  /* destructor code */
}

/* void onHdrFlagsChanged (in nsIMsgDBHdr aHdrChanged, in unsigned long aOldFlags, in unsigned long aNewFlags, in nsIDBChangeListener aInstigator); */
NS_IMETHODIMP nsDBChangeListener::OnHdrFlagsChanged(nsIMsgDBHdr *aHdrChanged, uint32_t aOldFlags, uint32_t aNewFlags, nsIDBChangeListener *aInstigator)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void onHdrDeleted (in nsIMsgDBHdr aHdrChanged, in nsMsgKey aParentKey, in long aFlags, in nsIDBChangeListener aInstigator); */
NS_IMETHODIMP nsDBChangeListener::OnHdrDeleted(nsIMsgDBHdr *aHdrChanged, nsMsgKey aParentKey, int32_t aFlags, nsIDBChangeListener *aInstigator)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void onHdrAdded (in nsIMsgDBHdr aHdrChanged, in nsMsgKey aParentKey, in long aFlags, in nsIDBChangeListener aInstigator); */
NS_IMETHODIMP nsDBChangeListener::OnHdrAdded(nsIMsgDBHdr *aHdrChanged, nsMsgKey aParentKey, int32_t aFlags, nsIDBChangeListener *aInstigator)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void onParentChanged (in nsMsgKey aKeyChanged, in nsMsgKey oldParent, in nsMsgKey newParent, in nsIDBChangeListener aInstigator); */
NS_IMETHODIMP nsDBChangeListener::OnParentChanged(nsMsgKey aKeyChanged, nsMsgKey oldParent, nsMsgKey newParent, nsIDBChangeListener *aInstigator)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void onAnnouncerGoingAway (in nsIDBChangeAnnouncer instigator); */
NS_IMETHODIMP nsDBChangeListener::OnAnnouncerGoingAway(nsIDBChangeAnnouncer *instigator)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void onReadChanged (in nsIDBChangeListener aInstigator); */
NS_IMETHODIMP nsDBChangeListener::OnReadChanged(nsIDBChangeListener *aInstigator)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void onJunkScoreChanged (in nsIDBChangeListener aInstigator); */
NS_IMETHODIMP nsDBChangeListener::OnJunkScoreChanged(nsIDBChangeListener *aInstigator)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void onHdrPropertyChanged (in nsIMsgDBHdr aHdrToChange, in boolean aPreChange, inout uint32_t aStatus, in nsIDBChangeListener aInstigator); */
NS_IMETHODIMP nsDBChangeListener::OnHdrPropertyChanged(nsIMsgDBHdr *aHdrToChange, bool aPreChange, uint32_t *aStatus, nsIDBChangeListener *aInstigator)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void onEvent (in nsIMsgDatabase aDB, in string aEvent); */
NS_IMETHODIMP nsDBChangeListener::OnEvent(nsIMsgDatabase *aDB, const char * aEvent)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIDBChangeListener_h__ */
