/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/local/public/nsIRssIncomingServer.idl
 */

#ifndef __gen_nsIRssIncomingServer_h__
#define __gen_nsIRssIncomingServer_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIFile; /* forward declaration */


/* starting interface:    nsIRssIncomingServer */
#define NS_IRSSINCOMINGSERVER_IID_STR "6d744e7f-2218-45c6-8734-998a56cb3c6d"

#define NS_IRSSINCOMINGSERVER_IID \
  {0x6d744e7f, 0x2218, 0x45c6, \
    { 0x87, 0x34, 0x99, 0x8a, 0x56, 0xcb, 0x3c, 0x6d }}

class NS_NO_VTABLE nsIRssIncomingServer : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IRSSINCOMINGSERVER_IID)

  /* readonly attribute nsIFile subscriptionsDataSourcePath; */
  NS_IMETHOD GetSubscriptionsDataSourcePath(nsIFile * *aSubscriptionsDataSourcePath) = 0;

  /* readonly attribute nsIFile feedItemsDataSourcePath; */
  NS_IMETHOD GetFeedItemsDataSourcePath(nsIFile * *aFeedItemsDataSourcePath) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIRssIncomingServer, NS_IRSSINCOMINGSERVER_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIRSSINCOMINGSERVER \
  NS_IMETHOD GetSubscriptionsDataSourcePath(nsIFile * *aSubscriptionsDataSourcePath); \
  NS_IMETHOD GetFeedItemsDataSourcePath(nsIFile * *aFeedItemsDataSourcePath); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIRSSINCOMINGSERVER(_to) \
  NS_IMETHOD GetSubscriptionsDataSourcePath(nsIFile * *aSubscriptionsDataSourcePath) { return _to GetSubscriptionsDataSourcePath(aSubscriptionsDataSourcePath); } \
  NS_IMETHOD GetFeedItemsDataSourcePath(nsIFile * *aFeedItemsDataSourcePath) { return _to GetFeedItemsDataSourcePath(aFeedItemsDataSourcePath); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIRSSINCOMINGSERVER(_to) \
  NS_IMETHOD GetSubscriptionsDataSourcePath(nsIFile * *aSubscriptionsDataSourcePath) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSubscriptionsDataSourcePath(aSubscriptionsDataSourcePath); } \
  NS_IMETHOD GetFeedItemsDataSourcePath(nsIFile * *aFeedItemsDataSourcePath) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFeedItemsDataSourcePath(aFeedItemsDataSourcePath); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsRssIncomingServer : public nsIRssIncomingServer
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIRSSINCOMINGSERVER

  nsRssIncomingServer();

private:
  ~nsRssIncomingServer();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsRssIncomingServer, nsIRssIncomingServer)

nsRssIncomingServer::nsRssIncomingServer()
{
  /* member initializers and constructor code */
}

nsRssIncomingServer::~nsRssIncomingServer()
{
  /* destructor code */
}

/* readonly attribute nsIFile subscriptionsDataSourcePath; */
NS_IMETHODIMP nsRssIncomingServer::GetSubscriptionsDataSourcePath(nsIFile * *aSubscriptionsDataSourcePath)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute nsIFile feedItemsDataSourcePath; */
NS_IMETHODIMP nsRssIncomingServer::GetFeedItemsDataSourcePath(nsIFile * *aFeedItemsDataSourcePath)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIRssIncomingServer_h__ */
