/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"

[ptr] native PRNetAddrPtr(union PRNetAddr);

[scriptable, uuid(8f755c44-1dd2-11b2-a613-91117453fa95)]
interface nsISOCKSSocketInfo : nsISupports
{
    [noscript] attribute PRNetAddrPtr destinationAddr;
    [noscript] attribute PRNetAddrPtr externalProxyAddr;
    [noscript] attribute PRNetAddrPtr internalProxyAddr;
};
