/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/local/public/nsIPop3Protocol.idl
 */

#ifndef __gen_nsIPop3Protocol_h__
#define __gen_nsIPop3Protocol_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
#include "nsVoidArray.h"

/* starting interface:    nsIPop3Protocol */
#define NS_IPOP3PROTOCOL_IID_STR "aebda729-c423-4113-ae36-2229fdc3b699"

#define NS_IPOP3PROTOCOL_IID \
  {0xaebda729, 0xc423, 0x4113, \
    { 0xae, 0x36, 0x22, 0x29, 0xfd, 0xc3, 0xb6, 0x99 }}

class NS_NO_VTABLE nsIPop3Protocol : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IPOP3PROTOCOL_IID)

  /* [noscript] void markMessages (in nsVoidArray aUidl); */
  NS_IMETHOD MarkMessages(nsVoidArray *aUidl) = 0;

  /* boolean checkMessage (in string aUidl); */
  NS_IMETHOD CheckMessage(const char * aUidl, bool *_retval) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIPop3Protocol, NS_IPOP3PROTOCOL_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIPOP3PROTOCOL \
  NS_IMETHOD MarkMessages(nsVoidArray *aUidl); \
  NS_IMETHOD CheckMessage(const char * aUidl, bool *_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIPOP3PROTOCOL(_to) \
  NS_IMETHOD MarkMessages(nsVoidArray *aUidl) { return _to MarkMessages(aUidl); } \
  NS_IMETHOD CheckMessage(const char * aUidl, bool *_retval) { return _to CheckMessage(aUidl, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIPOP3PROTOCOL(_to) \
  NS_IMETHOD MarkMessages(nsVoidArray *aUidl) { return !_to ? NS_ERROR_NULL_POINTER : _to->MarkMessages(aUidl); } \
  NS_IMETHOD CheckMessage(const char * aUidl, bool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->CheckMessage(aUidl, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsPop3Protocol : public nsIPop3Protocol
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIPOP3PROTOCOL

  nsPop3Protocol();

private:
  ~nsPop3Protocol();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsPop3Protocol, nsIPop3Protocol)

nsPop3Protocol::nsPop3Protocol()
{
  /* member initializers and constructor code */
}

nsPop3Protocol::~nsPop3Protocol()
{
  /* destructor code */
}

/* [noscript] void markMessages (in nsVoidArray aUidl); */
NS_IMETHODIMP nsPop3Protocol::MarkMessages(nsVoidArray *aUidl)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean checkMessage (in string aUidl); */
NS_IMETHODIMP nsPop3Protocol::CheckMessage(const char * aUidl, bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIPop3Protocol_h__ */
