/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/base/public/nsIMsgProgress.idl
 */

#ifndef __gen_nsIMsgProgress_h__
#define __gen_nsIMsgProgress_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_domstubs_h__
#include "domstubs.h"
#endif

#ifndef __gen_nsIPrompt_h__
#include "nsIPrompt.h"
#endif

#ifndef __gen_nsIWebProgressListener_h__
#include "nsIWebProgressListener.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIDOMWindow; /* forward declaration */

class nsIMsgWindow; /* forward declaration */


/* starting interface:    nsIMsgProgress */
#define NS_IMSGPROGRESS_IID_STR "5aae7f1b-95f1-422e-86d5-2b1d599e2ccf"

#define NS_IMSGPROGRESS_IID \
  {0x5aae7f1b, 0x95f1, 0x422e, \
    { 0x86, 0xd5, 0x2b, 0x1d, 0x59, 0x9e, 0x2c, 0xcf }}

class NS_NO_VTABLE nsIMsgProgress : public nsIWebProgressListener {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IMSGPROGRESS_IID)

  /* void openProgressDialog (in nsIDOMWindow parent, in nsIMsgWindow aMsgWindow, in string dialogURL, in boolean inDisplayModal, in nsISupports parameters); */
  NS_IMETHOD OpenProgressDialog(nsIDOMWindow *parent, nsIMsgWindow *aMsgWindow, const char * dialogURL, bool inDisplayModal, nsISupports *parameters) = 0;

  /* void closeProgressDialog (in boolean forceClose); */
  NS_IMETHOD CloseProgressDialog(bool forceClose) = 0;

  /* void registerListener (in nsIWebProgressListener listener); */
  NS_IMETHOD RegisterListener(nsIWebProgressListener *listener) = 0;

  /* void unregisterListener (in nsIWebProgressListener listener); */
  NS_IMETHOD UnregisterListener(nsIWebProgressListener *listener) = 0;

  /* attribute boolean processCanceledByUser; */
  NS_IMETHOD GetProcessCanceledByUser(bool *aProcessCanceledByUser) = 0;
  NS_IMETHOD SetProcessCanceledByUser(bool aProcessCanceledByUser) = 0;

  /* attribute nsIMsgWindow msgWindow; */
  NS_IMETHOD GetMsgWindow(nsIMsgWindow * *aMsgWindow) = 0;
  NS_IMETHOD SetMsgWindow(nsIMsgWindow *aMsgWindow) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIMsgProgress, NS_IMSGPROGRESS_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGPROGRESS \
  NS_IMETHOD OpenProgressDialog(nsIDOMWindow *parent, nsIMsgWindow *aMsgWindow, const char * dialogURL, bool inDisplayModal, nsISupports *parameters); \
  NS_IMETHOD CloseProgressDialog(bool forceClose); \
  NS_IMETHOD RegisterListener(nsIWebProgressListener *listener); \
  NS_IMETHOD UnregisterListener(nsIWebProgressListener *listener); \
  NS_IMETHOD GetProcessCanceledByUser(bool *aProcessCanceledByUser); \
  NS_IMETHOD SetProcessCanceledByUser(bool aProcessCanceledByUser); \
  NS_IMETHOD GetMsgWindow(nsIMsgWindow * *aMsgWindow); \
  NS_IMETHOD SetMsgWindow(nsIMsgWindow *aMsgWindow); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGPROGRESS(_to) \
  NS_IMETHOD OpenProgressDialog(nsIDOMWindow *parent, nsIMsgWindow *aMsgWindow, const char * dialogURL, bool inDisplayModal, nsISupports *parameters) { return _to OpenProgressDialog(parent, aMsgWindow, dialogURL, inDisplayModal, parameters); } \
  NS_IMETHOD CloseProgressDialog(bool forceClose) { return _to CloseProgressDialog(forceClose); } \
  NS_IMETHOD RegisterListener(nsIWebProgressListener *listener) { return _to RegisterListener(listener); } \
  NS_IMETHOD UnregisterListener(nsIWebProgressListener *listener) { return _to UnregisterListener(listener); } \
  NS_IMETHOD GetProcessCanceledByUser(bool *aProcessCanceledByUser) { return _to GetProcessCanceledByUser(aProcessCanceledByUser); } \
  NS_IMETHOD SetProcessCanceledByUser(bool aProcessCanceledByUser) { return _to SetProcessCanceledByUser(aProcessCanceledByUser); } \
  NS_IMETHOD GetMsgWindow(nsIMsgWindow * *aMsgWindow) { return _to GetMsgWindow(aMsgWindow); } \
  NS_IMETHOD SetMsgWindow(nsIMsgWindow *aMsgWindow) { return _to SetMsgWindow(aMsgWindow); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGPROGRESS(_to) \
  NS_IMETHOD OpenProgressDialog(nsIDOMWindow *parent, nsIMsgWindow *aMsgWindow, const char * dialogURL, bool inDisplayModal, nsISupports *parameters) { return !_to ? NS_ERROR_NULL_POINTER : _to->OpenProgressDialog(parent, aMsgWindow, dialogURL, inDisplayModal, parameters); } \
  NS_IMETHOD CloseProgressDialog(bool forceClose) { return !_to ? NS_ERROR_NULL_POINTER : _to->CloseProgressDialog(forceClose); } \
  NS_IMETHOD RegisterListener(nsIWebProgressListener *listener) { return !_to ? NS_ERROR_NULL_POINTER : _to->RegisterListener(listener); } \
  NS_IMETHOD UnregisterListener(nsIWebProgressListener *listener) { return !_to ? NS_ERROR_NULL_POINTER : _to->UnregisterListener(listener); } \
  NS_IMETHOD GetProcessCanceledByUser(bool *aProcessCanceledByUser) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetProcessCanceledByUser(aProcessCanceledByUser); } \
  NS_IMETHOD SetProcessCanceledByUser(bool aProcessCanceledByUser) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetProcessCanceledByUser(aProcessCanceledByUser); } \
  NS_IMETHOD GetMsgWindow(nsIMsgWindow * *aMsgWindow) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMsgWindow(aMsgWindow); } \
  NS_IMETHOD SetMsgWindow(nsIMsgWindow *aMsgWindow) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMsgWindow(aMsgWindow); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgProgress : public nsIMsgProgress
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGPROGRESS

  nsMsgProgress();

private:
  ~nsMsgProgress();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgProgress, nsIMsgProgress)

nsMsgProgress::nsMsgProgress()
{
  /* member initializers and constructor code */
}

nsMsgProgress::~nsMsgProgress()
{
  /* destructor code */
}

/* void openProgressDialog (in nsIDOMWindow parent, in nsIMsgWindow aMsgWindow, in string dialogURL, in boolean inDisplayModal, in nsISupports parameters); */
NS_IMETHODIMP nsMsgProgress::OpenProgressDialog(nsIDOMWindow *parent, nsIMsgWindow *aMsgWindow, const char * dialogURL, bool inDisplayModal, nsISupports *parameters)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void closeProgressDialog (in boolean forceClose); */
NS_IMETHODIMP nsMsgProgress::CloseProgressDialog(bool forceClose)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void registerListener (in nsIWebProgressListener listener); */
NS_IMETHODIMP nsMsgProgress::RegisterListener(nsIWebProgressListener *listener)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void unregisterListener (in nsIWebProgressListener listener); */
NS_IMETHODIMP nsMsgProgress::UnregisterListener(nsIWebProgressListener *listener)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean processCanceledByUser; */
NS_IMETHODIMP nsMsgProgress::GetProcessCanceledByUser(bool *aProcessCanceledByUser)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgProgress::SetProcessCanceledByUser(bool aProcessCanceledByUser)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsIMsgWindow msgWindow; */
NS_IMETHODIMP nsMsgProgress::GetMsgWindow(nsIMsgWindow * *aMsgWindow)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgProgress::SetMsgWindow(nsIMsgWindow *aMsgWindow)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgProgress_h__ */
