/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/addrbook/public/nsIAbDirFactoryService.idl
 */

#ifndef __gen_nsIAbDirFactoryService_h__
#define __gen_nsIAbDirFactoryService_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIAbDirFactory; /* forward declaration */


/* starting interface:    nsIAbDirFactoryService */
#define NS_IABDIRFACTORYSERVICE_IID_STR "154a951b-a310-400c-b98f-d769cc5d575f"

#define NS_IABDIRFACTORYSERVICE_IID \
  {0x154a951b, 0xa310, 0x400c, \
    { 0xb9, 0x8f, 0xd7, 0x69, 0xcc, 0x5d, 0x57, 0x5f }}

class NS_NO_VTABLE nsIAbDirFactoryService : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IABDIRFACTORYSERVICE_IID)

  /* nsIAbDirFactory getDirFactory (in ACString aURI); */
  NS_IMETHOD GetDirFactory(const nsACString & aURI, nsIAbDirFactory * *_retval) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIAbDirFactoryService, NS_IABDIRFACTORYSERVICE_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIABDIRFACTORYSERVICE \
  NS_IMETHOD GetDirFactory(const nsACString & aURI, nsIAbDirFactory * *_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIABDIRFACTORYSERVICE(_to) \
  NS_IMETHOD GetDirFactory(const nsACString & aURI, nsIAbDirFactory * *_retval) { return _to GetDirFactory(aURI, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIABDIRFACTORYSERVICE(_to) \
  NS_IMETHOD GetDirFactory(const nsACString & aURI, nsIAbDirFactory * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDirFactory(aURI, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsAbDirFactoryService : public nsIAbDirFactoryService
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIABDIRFACTORYSERVICE

  nsAbDirFactoryService();

private:
  ~nsAbDirFactoryService();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsAbDirFactoryService, nsIAbDirFactoryService)

nsAbDirFactoryService::nsAbDirFactoryService()
{
  /* member initializers and constructor code */
}

nsAbDirFactoryService::~nsAbDirFactoryService()
{
  /* destructor code */
}

/* nsIAbDirFactory getDirFactory (in ACString aURI); */
NS_IMETHODIMP nsAbDirFactoryService::GetDirFactory(const nsACString & aURI, nsIAbDirFactory * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIAbDirFactoryService_h__ */
