/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"

interface nsIDOMBatteryManager;

[scriptable, uuid(4a78a8d5-5bbb-4a92-ad97-f19e853a7008)]
interface nsINavigatorBattery : nsISupports
{
  readonly attribute nsIDOMBatteryManager battery;
};
