/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/imap/public/nsIAutoSyncFolderStrategy.idl
 */

#ifndef __gen_nsIAutoSyncFolderStrategy_h__
#define __gen_nsIAutoSyncFolderStrategy_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsIAutoSyncMsgStrategy_h__
#include "nsIAutoSyncMsgStrategy.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIMsgAccount; /* forward declaration */


/* starting interface:    nsIAutoSyncFolderStrategy */
#define NS_IAUTOSYNCFOLDERSTRATEGY_IID_STR "d3bf91cc-37bb-4752-9994-1a8473e46a90"

#define NS_IAUTOSYNCFOLDERSTRATEGY_IID \
  {0xd3bf91cc, 0x37bb, 0x4752, \
    { 0x99, 0x94, 0x1a, 0x84, 0x73, 0xe4, 0x6a, 0x90 }}

class NS_NO_VTABLE nsIAutoSyncFolderStrategy : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IAUTOSYNCFOLDERSTRATEGY_IID)

  /* nsAutoSyncStrategyDecisionType sort (in nsIMsgFolder aFolder1, in nsIMsgFolder aFolder2); */
  NS_IMETHOD Sort(nsIMsgFolder *aFolder1, nsIMsgFolder *aFolder2, nsAutoSyncStrategyDecisionType *_retval) = 0;

  /* boolean isExcluded (in nsIMsgFolder aFolder); */
  NS_IMETHOD IsExcluded(nsIMsgFolder *aFolder, bool *_retval) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIAutoSyncFolderStrategy, NS_IAUTOSYNCFOLDERSTRATEGY_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIAUTOSYNCFOLDERSTRATEGY \
  NS_IMETHOD Sort(nsIMsgFolder *aFolder1, nsIMsgFolder *aFolder2, nsAutoSyncStrategyDecisionType *_retval); \
  NS_IMETHOD IsExcluded(nsIMsgFolder *aFolder, bool *_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIAUTOSYNCFOLDERSTRATEGY(_to) \
  NS_IMETHOD Sort(nsIMsgFolder *aFolder1, nsIMsgFolder *aFolder2, nsAutoSyncStrategyDecisionType *_retval) { return _to Sort(aFolder1, aFolder2, _retval); } \
  NS_IMETHOD IsExcluded(nsIMsgFolder *aFolder, bool *_retval) { return _to IsExcluded(aFolder, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIAUTOSYNCFOLDERSTRATEGY(_to) \
  NS_IMETHOD Sort(nsIMsgFolder *aFolder1, nsIMsgFolder *aFolder2, nsAutoSyncStrategyDecisionType *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->Sort(aFolder1, aFolder2, _retval); } \
  NS_IMETHOD IsExcluded(nsIMsgFolder *aFolder, bool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->IsExcluded(aFolder, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsAutoSyncFolderStrategy : public nsIAutoSyncFolderStrategy
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIAUTOSYNCFOLDERSTRATEGY

  nsAutoSyncFolderStrategy();

private:
  ~nsAutoSyncFolderStrategy();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsAutoSyncFolderStrategy, nsIAutoSyncFolderStrategy)

nsAutoSyncFolderStrategy::nsAutoSyncFolderStrategy()
{
  /* member initializers and constructor code */
}

nsAutoSyncFolderStrategy::~nsAutoSyncFolderStrategy()
{
  /* destructor code */
}

/* nsAutoSyncStrategyDecisionType sort (in nsIMsgFolder aFolder1, in nsIMsgFolder aFolder2); */
NS_IMETHODIMP nsAutoSyncFolderStrategy::Sort(nsIMsgFolder *aFolder1, nsIMsgFolder *aFolder2, nsAutoSyncStrategyDecisionType *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean isExcluded (in nsIMsgFolder aFolder); */
NS_IMETHODIMP nsAutoSyncFolderStrategy::IsExcluded(nsIMsgFolder *aFolder, bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIAutoSyncFolderStrategy_h__ */
