/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "domstubs.idl"

interface nsIDOMSVGTransformList;

[scriptable, uuid(fd54c8c4-2eb4-4849-8df6-79985c2491da)]
interface nsIDOMSVGAnimatedTransformList : nsISupports
{ 
  readonly attribute nsIDOMSVGTransformList baseVal;
  readonly attribute nsIDOMSVGTransformList animVal;
};
