/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "domstubs.idl"

interface nsIDOMSVGRect;
interface nsIDOMSVGMatrix;
interface nsIDOMSVGElement;

[scriptable, uuid(9cf4fc9c-90b2-4d66-88f5-35049b558aee)]
interface nsIDOMSVGLocatable : nsISupports
{ 
  readonly attribute nsIDOMSVGElement  nearestViewportElement;
  readonly attribute nsIDOMSVGElement  farthestViewportElement;
  
  nsIDOMSVGRect   getBBox();
  nsIDOMSVGMatrix getCTM();
  nsIDOMSVGMatrix getScreenCTM();
  nsIDOMSVGMatrix getTransformToElement(in nsIDOMSVGElement element);
      // raises( SVGException );
};
