/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsIStreamListener.idl"

interface nsIMimeHeaders;

[scriptable, uuid(1fe345e6-2428-4a43-a0c6-d2acea0d4da4)]
interface nsIMsgQuotingOutputStreamListener : nsIStreamListener {

    // The headers are used to fill in the reply's compose fields
    void setMimeHeaders(in nsIMimeHeaders headers);

};
