/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */


#include "domstubs.idl"

interface nsIDOMSVGPointList;

[scriptable, uuid(ebf334b3-86ef-4bf3-8a92-d775c72defa4)]
interface nsIDOMSVGAnimatedPoints : nsISupports
{
  readonly attribute nsIDOMSVGPointList   points;
  readonly attribute nsIDOMSVGPointList   animatedPoints;
};
