/* -*- Mode: C++; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* vim: set ts=2 et sw=2 tw=80: */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this file,
 * You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"

%{C++
namespace mozilla {
namespace dom {
namespace indexedDB {
class FileInfo;
}
}
}
%}

[ptr] native FileInfo(mozilla::dom::indexedDB::FileInfo);

interface nsIDOMDOMRequest;
interface nsIDOMEventListener;
interface nsIDOMLockedFile;

[scriptable, builtinclass, uuid(882ad3d0-6fb1-4841-8e17-0ba17b11edc8)]
interface nsIDOMFileHandle : nsISupports
{
  readonly attribute DOMString name;

  readonly attribute DOMString type;

  // mode can be either "readonly" or "readwrite"
  [optional_argc]
  nsIDOMLockedFile
  open([optional /* "readonly" */] in DOMString mode);

  nsIDOMDOMRequest
  getFile();

  [notxpcom]
  long long
  getFileId();

  [notxpcom]
  FileInfo
  getFileInfo();

  attribute nsIDOMEventListener onabort;

  attribute nsIDOMEventListener onerror;
};
