/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/imap/public/nsIImapProtocolSink.idl
 */

#ifndef __gen_nsIImapProtocolSink_h__
#define __gen_nsIImapProtocolSink_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIMsgWindow; /* forward declaration */

class nsIMsgMailNewsUrl; /* forward declaration */


/* starting interface:    nsIImapProtocolSink */
#define NS_IIMAPPROTOCOLSINK_IID_STR "1217cd9d-7678-4026-b323-0d4b45816af0"

#define NS_IIMAPPROTOCOLSINK_IID \
  {0x1217cd9d, 0x7678, 0x4026, \
    { 0xb3, 0x23, 0x0d, 0x4b, 0x45, 0x81, 0x6a, 0xf0 }}

class NS_NO_VTABLE nsIImapProtocolSink : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IIMAPPROTOCOLSINK_IID)

  /* void closeStreams (); */
  NS_IMETHOD CloseStreams(void) = 0;

  /* nsIMsgWindow getUrlWindow (in nsIMsgMailNewsUrl aUrl); */
  NS_IMETHOD GetUrlWindow(nsIMsgMailNewsUrl *aUrl, nsIMsgWindow * *_retval) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIImapProtocolSink, NS_IIMAPPROTOCOLSINK_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIIMAPPROTOCOLSINK \
  NS_IMETHOD CloseStreams(void); \
  NS_IMETHOD GetUrlWindow(nsIMsgMailNewsUrl *aUrl, nsIMsgWindow * *_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIIMAPPROTOCOLSINK(_to) \
  NS_IMETHOD CloseStreams(void) { return _to CloseStreams(); } \
  NS_IMETHOD GetUrlWindow(nsIMsgMailNewsUrl *aUrl, nsIMsgWindow * *_retval) { return _to GetUrlWindow(aUrl, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIIMAPPROTOCOLSINK(_to) \
  NS_IMETHOD CloseStreams(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->CloseStreams(); } \
  NS_IMETHOD GetUrlWindow(nsIMsgMailNewsUrl *aUrl, nsIMsgWindow * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetUrlWindow(aUrl, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsImapProtocolSink : public nsIImapProtocolSink
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIIMAPPROTOCOLSINK

  nsImapProtocolSink();

private:
  ~nsImapProtocolSink();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsImapProtocolSink, nsIImapProtocolSink)

nsImapProtocolSink::nsImapProtocolSink()
{
  /* member initializers and constructor code */
}

nsImapProtocolSink::~nsImapProtocolSink()
{
  /* destructor code */
}

/* void closeStreams (); */
NS_IMETHODIMP nsImapProtocolSink::CloseStreams()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIMsgWindow getUrlWindow (in nsIMsgMailNewsUrl aUrl); */
NS_IMETHODIMP nsImapProtocolSink::GetUrlWindow(nsIMsgMailNewsUrl *aUrl, nsIMsgWindow * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIImapProtocolSink_h__ */
