/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsIDOMElement.idl"

interface nsIDOMSVGSVGElement;

[scriptable, uuid(9B16734D-DBFD-4465-8EAF-354694934A1D)]
interface nsIDOMSVGElement : nsIDOMElement 
{ 
  attribute DOMString id;
            // raises DOMException on setting
  readonly attribute nsIDOMSVGSVGElement ownerSVGElement;
  readonly attribute nsIDOMSVGElement    viewportElement;
};
