/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/extensions/mailviews/public/nsIMsgMailViewList.idl
 */

#ifndef __gen_nsIMsgMailViewList_h__
#define __gen_nsIMsgMailViewList_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsIMsgMailView_h__
#include "nsIMsgMailView.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
typedef int32_t  nsMsgMailViewListFileAttribValue;


/* starting interface:    nsIMsgMailViewList */
#define NS_IMSGMAILVIEWLIST_IID_STR "6dd798d7-9528-49e6-9447-3aaf14d2d36f"

#define NS_IMSGMAILVIEWLIST_IID \
  {0x6dd798d7, 0x9528, 0x49e6, \
    { 0x94, 0x47, 0x3a, 0xaf, 0x14, 0xd2, 0xd3, 0x6f }}

class NS_NO_VTABLE nsIMsgMailViewList : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IMSGMAILVIEWLIST_IID)

  /* readonly attribute unsigned long mailViewCount; */
  NS_IMETHOD GetMailViewCount(uint32_t *aMailViewCount) = 0;

  /* nsIMsgMailView getMailViewAt (in unsigned long mailViewIndex); */
  NS_IMETHOD GetMailViewAt(uint32_t mailViewIndex, nsIMsgMailView * *_retval) = 0;

  /* void addMailView (in nsIMsgMailView mailView); */
  NS_IMETHOD AddMailView(nsIMsgMailView *mailView) = 0;

  /* void removeMailView (in nsIMsgMailView mailView); */
  NS_IMETHOD RemoveMailView(nsIMsgMailView *mailView) = 0;

  /* nsIMsgMailView createMailView (); */
  NS_IMETHOD CreateMailView(nsIMsgMailView * *_retval) = 0;

  /* void save (); */
  NS_IMETHOD Save(void) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIMsgMailViewList, NS_IMSGMAILVIEWLIST_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGMAILVIEWLIST \
  NS_IMETHOD GetMailViewCount(uint32_t *aMailViewCount); \
  NS_IMETHOD GetMailViewAt(uint32_t mailViewIndex, nsIMsgMailView * *_retval); \
  NS_IMETHOD AddMailView(nsIMsgMailView *mailView); \
  NS_IMETHOD RemoveMailView(nsIMsgMailView *mailView); \
  NS_IMETHOD CreateMailView(nsIMsgMailView * *_retval); \
  NS_IMETHOD Save(void); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGMAILVIEWLIST(_to) \
  NS_IMETHOD GetMailViewCount(uint32_t *aMailViewCount) { return _to GetMailViewCount(aMailViewCount); } \
  NS_IMETHOD GetMailViewAt(uint32_t mailViewIndex, nsIMsgMailView * *_retval) { return _to GetMailViewAt(mailViewIndex, _retval); } \
  NS_IMETHOD AddMailView(nsIMsgMailView *mailView) { return _to AddMailView(mailView); } \
  NS_IMETHOD RemoveMailView(nsIMsgMailView *mailView) { return _to RemoveMailView(mailView); } \
  NS_IMETHOD CreateMailView(nsIMsgMailView * *_retval) { return _to CreateMailView(_retval); } \
  NS_IMETHOD Save(void) { return _to Save(); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGMAILVIEWLIST(_to) \
  NS_IMETHOD GetMailViewCount(uint32_t *aMailViewCount) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMailViewCount(aMailViewCount); } \
  NS_IMETHOD GetMailViewAt(uint32_t mailViewIndex, nsIMsgMailView * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMailViewAt(mailViewIndex, _retval); } \
  NS_IMETHOD AddMailView(nsIMsgMailView *mailView) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddMailView(mailView); } \
  NS_IMETHOD RemoveMailView(nsIMsgMailView *mailView) { return !_to ? NS_ERROR_NULL_POINTER : _to->RemoveMailView(mailView); } \
  NS_IMETHOD CreateMailView(nsIMsgMailView * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->CreateMailView(_retval); } \
  NS_IMETHOD Save(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->Save(); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgMailViewList : public nsIMsgMailViewList
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGMAILVIEWLIST

  nsMsgMailViewList();

private:
  ~nsMsgMailViewList();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgMailViewList, nsIMsgMailViewList)

nsMsgMailViewList::nsMsgMailViewList()
{
  /* member initializers and constructor code */
}

nsMsgMailViewList::~nsMsgMailViewList()
{
  /* destructor code */
}

/* readonly attribute unsigned long mailViewCount; */
NS_IMETHODIMP nsMsgMailViewList::GetMailViewCount(uint32_t *aMailViewCount)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIMsgMailView getMailViewAt (in unsigned long mailViewIndex); */
NS_IMETHODIMP nsMsgMailViewList::GetMailViewAt(uint32_t mailViewIndex, nsIMsgMailView * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void addMailView (in nsIMsgMailView mailView); */
NS_IMETHODIMP nsMsgMailViewList::AddMailView(nsIMsgMailView *mailView)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void removeMailView (in nsIMsgMailView mailView); */
NS_IMETHODIMP nsMsgMailViewList::RemoveMailView(nsIMsgMailView *mailView)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIMsgMailView createMailView (); */
NS_IMETHODIMP nsMsgMailViewList::CreateMailView(nsIMsgMailView * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void save (); */
NS_IMETHODIMP nsMsgMailViewList::Save()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgMailViewList_h__ */
