/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"

interface nsIWebProgressListener;
interface nsILDAPURL;
interface nsILDAPConnection;
interface nsILDAPOperation;
interface nsIAbLDAPDirectory;

/**
 * this interface provides methods to perform LDAP Replication Queries
 */
[scriptable, uuid(460a739c-a8c1-4f24-b705-c89d136ab9f5)]
interface nsIAbLDAPReplicationQuery : nsISupports
{
  /**
   * initialize for the query
   */
  void init(in nsIAbLDAPDirectory aDirectory,
            in nsIWebProgressListener aProgressListener);
     
  /**
   * Starts an LDAP query to do replication as needed
   */
  void doReplicationQuery();

  /**
   * Cancels the currently executing query
   */
  void cancelQuery();

  /**
   * this method is the callback when query is done, failed or successful
   */
  void done(in boolean aSuccess);
};

// XXX This interface currently isn't implemented as it didn't work.
// Bug 311632 should fix it
[scriptable, uuid(126202D1-4460-11d6-B7C2-00B0D06E5F27)]
interface nsIAbLDAPChangeLogQuery : nsISupports
{
  /**
   * Starts an LDAP query to find auth DN
   */
  void queryAuthDN(in AUTF8String aValueUsedToFindDn);

  /**
   * Starts an LDAP query to search server's Root DSE
   */
  void queryRootDSE();

  /**
   * Starts an LDAP ChangeLog query to find changelog entries
   */
  void queryChangeLog(in AUTF8String aChangeLogDN, in int32_t aLastChangeNo);
      
  /**
   * Starts an LDAP query to find changed entries
   */
  void queryChangedEntries(in AUTF8String aChangedEntryDN);
};

