/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"
#include "nsIMsgIdentity.idl"

[scriptable, uuid(00b4569a-077e-4236-b993-980fd82bb948)]
interface nsIMsgCompUtils : nsISupports {
  string mimeMakeSeparator(in string prefix);
  string msgGenerateMessageId(in nsIMsgIdentity identity);
  readonly attribute boolean msgMimeConformToStandard;
};
