/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/ldap/xpcom/public/nsILDAPBERValue.idl
 */

#ifndef __gen_nsILDAPBERValue_h__
#define __gen_nsILDAPBERValue_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsILDAPBERValue */
#define NS_ILDAPBERVALUE_IID_STR "c817c5fe-1dd1-11b2-a10b-ae9885762ea9"

#define NS_ILDAPBERVALUE_IID \
  {0xc817c5fe, 0x1dd1, 0x11b2, \
    { 0xa1, 0x0b, 0xae, 0x98, 0x85, 0x76, 0x2e, 0xa9 }}

class NS_NO_VTABLE nsILDAPBERValue : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_ILDAPBERVALUE_IID)

  /* void set (in unsigned long aCount, [array, size_is (aCount)] in octet aValue); */
  NS_IMETHOD Set(uint32_t aCount, uint8_t *aValue) = 0;

  /* void setFromUTF8 (in AUTF8String aValue); */
  NS_IMETHOD SetFromUTF8(const nsACString & aValue) = 0;

  /* void get (out unsigned long aCount, [array, size_is (aCount), retval] out octet aRetVal); */
  NS_IMETHOD Get(uint32_t *aCount, uint8_t **aRetVal) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsILDAPBERValue, NS_ILDAPBERVALUE_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSILDAPBERVALUE \
  NS_IMETHOD Set(uint32_t aCount, uint8_t *aValue); \
  NS_IMETHOD SetFromUTF8(const nsACString & aValue); \
  NS_IMETHOD Get(uint32_t *aCount, uint8_t **aRetVal); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSILDAPBERVALUE(_to) \
  NS_IMETHOD Set(uint32_t aCount, uint8_t *aValue) { return _to Set(aCount, aValue); } \
  NS_IMETHOD SetFromUTF8(const nsACString & aValue) { return _to SetFromUTF8(aValue); } \
  NS_IMETHOD Get(uint32_t *aCount, uint8_t **aRetVal) { return _to Get(aCount, aRetVal); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSILDAPBERVALUE(_to) \
  NS_IMETHOD Set(uint32_t aCount, uint8_t *aValue) { return !_to ? NS_ERROR_NULL_POINTER : _to->Set(aCount, aValue); } \
  NS_IMETHOD SetFromUTF8(const nsACString & aValue) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetFromUTF8(aValue); } \
  NS_IMETHOD Get(uint32_t *aCount, uint8_t **aRetVal) { return !_to ? NS_ERROR_NULL_POINTER : _to->Get(aCount, aRetVal); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsLDAPBERValue : public nsILDAPBERValue
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSILDAPBERVALUE

  nsLDAPBERValue();

private:
  ~nsLDAPBERValue();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsLDAPBERValue, nsILDAPBERValue)

nsLDAPBERValue::nsLDAPBERValue()
{
  /* member initializers and constructor code */
}

nsLDAPBERValue::~nsLDAPBERValue()
{
  /* destructor code */
}

/* void set (in unsigned long aCount, [array, size_is (aCount)] in octet aValue); */
NS_IMETHODIMP nsLDAPBERValue::Set(uint32_t aCount, uint8_t *aValue)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setFromUTF8 (in AUTF8String aValue); */
NS_IMETHODIMP nsLDAPBERValue::SetFromUTF8(const nsACString & aValue)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void get (out unsigned long aCount, [array, size_is (aCount), retval] out octet aRetVal); */
NS_IMETHODIMP nsLDAPBERValue::Get(uint32_t *aCount, uint8_t **aRetVal)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsILDAPBERValue_h__ */
