/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this file,
 * You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsIDOMEvent.idl"

[scriptable, builtinclass, uuid(9cc7684c-a239-428c-b4f1-34c510c98a1c)]
interface nsIDOMDeviceLightEvent : nsIDOMEvent
{
  [noscript] void initDeviceLightEvent(in DOMString eventTypeArg,
                                       in boolean canBubbleArg,
                                       in boolean cancelableArg,
                                       in double value);

  readonly attribute double value;
};

dictionary DeviceLightEventInit : EventInit
{
   double value;
};
