/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "domstubs.idl"

/**
 * The nsIDOMSVGAnimatedBoolean interface is the interface to an SVG
 * animated boolean.
 *
 * For more information on this interface please see
 * http://www.w3.org/TR/SVG11/types.html
 *
 */

[scriptable, uuid(7e325385-cc82-4763-bd14-e2c92edd5462)]
interface nsIDOMSVGAnimatedBoolean : nsISupports
{
  attribute boolean baseVal;
      // raises DOMException on setting
  readonly attribute boolean animVal;
};


