/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/db/msgdb/public/nsINewsDatabase.idl
 */

#ifndef __gen_nsINewsDatabase_h__
#define __gen_nsINewsDatabase_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
#include "nsMsgKeySet.h"

/* starting interface:    nsINewsDatabase */
#define NS_INEWSDATABASE_IID_STR "f700208a-1dd1-11b2-b947-e4e1e4fdf278"

#define NS_INEWSDATABASE_IID \
  {0xf700208a, 0x1dd1, 0x11b2, \
    { 0xb9, 0x47, 0xe4, 0xe1, 0xe4, 0xfd, 0xf2, 0x78 }}

class NS_NO_VTABLE nsINewsDatabase : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_INEWSDATABASE_IID)

  /* [noscript] attribute nsMsgKeySetPtr readSet; */
  NS_IMETHOD GetReadSet(nsMsgKeySet **aReadSet) = 0;
  NS_IMETHOD SetReadSet(nsMsgKeySet *aReadSet) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsINewsDatabase, NS_INEWSDATABASE_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSINEWSDATABASE \
  NS_IMETHOD GetReadSet(nsMsgKeySet **aReadSet); \
  NS_IMETHOD SetReadSet(nsMsgKeySet *aReadSet); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSINEWSDATABASE(_to) \
  NS_IMETHOD GetReadSet(nsMsgKeySet **aReadSet) { return _to GetReadSet(aReadSet); } \
  NS_IMETHOD SetReadSet(nsMsgKeySet *aReadSet) { return _to SetReadSet(aReadSet); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSINEWSDATABASE(_to) \
  NS_IMETHOD GetReadSet(nsMsgKeySet **aReadSet) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetReadSet(aReadSet); } \
  NS_IMETHOD SetReadSet(nsMsgKeySet *aReadSet) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetReadSet(aReadSet); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsNewsDatabase : public nsINewsDatabase
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSINEWSDATABASE

  nsNewsDatabase();

private:
  ~nsNewsDatabase();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsNewsDatabase, nsINewsDatabase)

nsNewsDatabase::nsNewsDatabase()
{
  /* member initializers and constructor code */
}

nsNewsDatabase::~nsNewsDatabase()
{
  /* destructor code */
}

/* [noscript] attribute nsMsgKeySetPtr readSet; */
NS_IMETHODIMP nsNewsDatabase::GetReadSet(nsMsgKeySet **aReadSet)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsNewsDatabase::SetReadSet(nsMsgKeySet *aReadSet)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsINewsDatabase_h__ */
