/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsIDOMSVGLocatable.idl"

interface nsIDOMSVGAnimatedTransformList;

[scriptable, uuid(b81f6e37-1842-4534-a546-1ab86e59a3c6)]
interface nsIDOMSVGTransformable : nsIDOMSVGLocatable
{ 
  readonly attribute nsIDOMSVGAnimatedTransformList transform;
};
