/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"

%{C++
#include "nsMsgKeySet.h"
%}

[ptr] native nsMsgKeySetPtr(nsMsgKeySet);

[scriptable, uuid(f700208a-1dd1-11b2-b947-e4e1e4fdf278)]

interface nsINewsDatabase : nsISupports {
  [noscript] attribute nsMsgKeySetPtr readSet;
};
