/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsIURI.idl"

[scriptable, uuid(6EB9D874-01AA-11d4-8FBE-000064657374)]
interface nsIAddbookUrlOperation 
{ 
    const long InvalidUrl = 0;  
    const long PrintAddressBook = 1;
	const long AddVCard = 2;
};

[uuid(5f965083-e866-4bfb-ba40-13c344395798)]
interface nsIAddbookUrl : nsIURI {
  readonly attribute long addbookOperation;
};
