/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/ldap/xpcom/public/nsILDAPBERElement.idl
 */

#ifndef __gen_nsILDAPBERElement_h__
#define __gen_nsILDAPBERElement_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsILDAPBERValue; /* forward declaration */


/* starting interface:    nsILDAPBERElement */
#define NS_ILDAPBERELEMENT_IID_STR "409f5b31-c062-4d11-a35b-0a09e7967bf2"

#define NS_ILDAPBERELEMENT_IID \
  {0x409f5b31, 0xc062, 0x4d11, \
    { 0xa3, 0x5b, 0x0a, 0x09, 0xe7, 0x96, 0x7b, 0xf2 }}

class NS_NO_VTABLE nsILDAPBERElement : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_ILDAPBERELEMENT_IID)

  /* void init (in nsILDAPBERValue aValue); */
  NS_IMETHOD Init(nsILDAPBERValue *aValue) = 0;

  enum {
    TAG_LBER_ERROR = 4294967295U,
    TAG_LBER_DEFAULT = 4294967295U,
    TAG_LBER_END_OF_SEQORSET = 4294967294U,
    TAG_LBER_PRIMITIVE = 0U,
    TAG_LBER_CONSTRUCTED = 32U,
    TAG_LBER_ENCODING_MASK = 32U,
    TAG_LBER_BIG_TAG_MASK = 31U,
    TAG_LBER_MORE_TAG_MASK = 128U,
    TAG_LBER_BOOLEAN = 1U,
    TAG_LBER_INTEGER = 2U,
    TAG_LBER_BITSTRING = 3U,
    TAG_LBER_OCTETSTRING = 4U,
    TAG_LBER_NULL = 5U,
    TAG_LBER_ENUMERATED = 10U,
    TAG_LBER_SEQUENCE = 48U,
    TAG_LBER_SET = 49U
  };

  /* unsigned long putString (in AUTF8String aString, in unsigned long aTag); */
  NS_IMETHOD PutString(const nsACString & aString, uint32_t aTag, uint32_t *_retval) = 0;

  /* void startSet (in unsigned long aTag); */
  NS_IMETHOD StartSet(uint32_t aTag) = 0;

  /* unsigned long putSet (); */
  NS_IMETHOD PutSet(uint32_t *_retval) = 0;

  /* readonly attribute nsILDAPBERValue asValue; */
  NS_IMETHOD GetAsValue(nsILDAPBERValue * *aAsValue) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsILDAPBERElement, NS_ILDAPBERELEMENT_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSILDAPBERELEMENT \
  NS_IMETHOD Init(nsILDAPBERValue *aValue); \
  NS_IMETHOD PutString(const nsACString & aString, uint32_t aTag, uint32_t *_retval); \
  NS_IMETHOD StartSet(uint32_t aTag); \
  NS_IMETHOD PutSet(uint32_t *_retval); \
  NS_IMETHOD GetAsValue(nsILDAPBERValue * *aAsValue); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSILDAPBERELEMENT(_to) \
  NS_IMETHOD Init(nsILDAPBERValue *aValue) { return _to Init(aValue); } \
  NS_IMETHOD PutString(const nsACString & aString, uint32_t aTag, uint32_t *_retval) { return _to PutString(aString, aTag, _retval); } \
  NS_IMETHOD StartSet(uint32_t aTag) { return _to StartSet(aTag); } \
  NS_IMETHOD PutSet(uint32_t *_retval) { return _to PutSet(_retval); } \
  NS_IMETHOD GetAsValue(nsILDAPBERValue * *aAsValue) { return _to GetAsValue(aAsValue); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSILDAPBERELEMENT(_to) \
  NS_IMETHOD Init(nsILDAPBERValue *aValue) { return !_to ? NS_ERROR_NULL_POINTER : _to->Init(aValue); } \
  NS_IMETHOD PutString(const nsACString & aString, uint32_t aTag, uint32_t *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->PutString(aString, aTag, _retval); } \
  NS_IMETHOD StartSet(uint32_t aTag) { return !_to ? NS_ERROR_NULL_POINTER : _to->StartSet(aTag); } \
  NS_IMETHOD PutSet(uint32_t *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->PutSet(_retval); } \
  NS_IMETHOD GetAsValue(nsILDAPBERValue * *aAsValue) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetAsValue(aAsValue); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsLDAPBERElement : public nsILDAPBERElement
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSILDAPBERELEMENT

  nsLDAPBERElement();

private:
  ~nsLDAPBERElement();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsLDAPBERElement, nsILDAPBERElement)

nsLDAPBERElement::nsLDAPBERElement()
{
  /* member initializers and constructor code */
}

nsLDAPBERElement::~nsLDAPBERElement()
{
  /* destructor code */
}

/* void init (in nsILDAPBERValue aValue); */
NS_IMETHODIMP nsLDAPBERElement::Init(nsILDAPBERValue *aValue)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* unsigned long putString (in AUTF8String aString, in unsigned long aTag); */
NS_IMETHODIMP nsLDAPBERElement::PutString(const nsACString & aString, uint32_t aTag, uint32_t *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void startSet (in unsigned long aTag); */
NS_IMETHODIMP nsLDAPBERElement::StartSet(uint32_t aTag)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* unsigned long putSet (); */
NS_IMETHODIMP nsLDAPBERElement::PutSet(uint32_t *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute nsILDAPBERValue asValue; */
NS_IMETHODIMP nsLDAPBERElement::GetAsValue(nsILDAPBERValue * *aAsValue)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsILDAPBERElement_h__ */
