/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/local/public/nsINoIncomingServer.idl
 */

#ifndef __gen_nsINoIncomingServer_h__
#define __gen_nsINoIncomingServer_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIFile; /* forward declaration */


/* starting interface:    nsINoIncomingServer */
#define NS_INOINCOMINGSERVER_IID_STR "ba3071e9-39a5-4a10-b770-1809317ef2c1"

#define NS_INOINCOMINGSERVER_IID \
  {0xba3071e9, 0x39a5, 0x4a10, \
    { 0xb7, 0x70, 0x18, 0x09, 0x31, 0x7e, 0xf2, 0xc1 }}

class NS_NO_VTABLE nsINoIncomingServer : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_INOINCOMINGSERVER_IID)

  /* void copyDefaultMessages (in string folderNameOnDisk, in nsIFile parentDir); */
  NS_IMETHOD CopyDefaultMessages(const char * folderNameOnDisk, nsIFile *parentDir) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsINoIncomingServer, NS_INOINCOMINGSERVER_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSINOINCOMINGSERVER \
  NS_IMETHOD CopyDefaultMessages(const char * folderNameOnDisk, nsIFile *parentDir); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSINOINCOMINGSERVER(_to) \
  NS_IMETHOD CopyDefaultMessages(const char * folderNameOnDisk, nsIFile *parentDir) { return _to CopyDefaultMessages(folderNameOnDisk, parentDir); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSINOINCOMINGSERVER(_to) \
  NS_IMETHOD CopyDefaultMessages(const char * folderNameOnDisk, nsIFile *parentDir) { return !_to ? NS_ERROR_NULL_POINTER : _to->CopyDefaultMessages(folderNameOnDisk, parentDir); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsNoIncomingServer : public nsINoIncomingServer
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSINOINCOMINGSERVER

  nsNoIncomingServer();

private:
  ~nsNoIncomingServer();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsNoIncomingServer, nsINoIncomingServer)

nsNoIncomingServer::nsNoIncomingServer()
{
  /* member initializers and constructor code */
}

nsNoIncomingServer::~nsNoIncomingServer()
{
  /* destructor code */
}

/* void copyDefaultMessages (in string folderNameOnDisk, in nsIFile parentDir); */
NS_IMETHODIMP nsNoIncomingServer::CopyDefaultMessages(const char * folderNameOnDisk, nsIFile *parentDir)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsINoIncomingServer_h__ */
