/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/base/public/nsIFolderListener.idl
 */

#ifndef __gen_nsIFolderListener_h__
#define __gen_nsIFolderListener_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsIAtom_h__
#include "nsIAtom.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIMsgFolder; /* forward declaration */

class nsIMsgDBHdr; /* forward declaration */

typedef uint32_t  folderListenerNotifyFlagValue;


/* starting interface:    nsIFolderListener */
#define NS_IFOLDERLISTENER_IID_STR "f60ee1a2-6d81-422c-958f-d408b1b2daa6"

#define NS_IFOLDERLISTENER_IID \
  {0xf60ee1a2, 0x6d81, 0x422c, \
    { 0x95, 0x8f, 0xd4, 0x08, 0xb1, 0xb2, 0xda, 0xa6 }}

class NS_NO_VTABLE nsIFolderListener : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IFOLDERLISTENER_IID)

  enum {
    added = 1U
  };

  /* void OnItemAdded (in nsIMsgFolder aParentItem, in nsISupports aItem); */
  NS_IMETHOD OnItemAdded(nsIMsgFolder *aParentItem, nsISupports *aItem) = 0;

  enum {
    removed = 2U
  };

  /* void OnItemRemoved (in nsIMsgFolder aParentItem, in nsISupports aItem); */
  NS_IMETHOD OnItemRemoved(nsIMsgFolder *aParentItem, nsISupports *aItem) = 0;

  enum {
    propertyChanged = 4U
  };

  /* void OnItemPropertyChanged (in nsIMsgFolder aItem, in nsIAtom aProperty, in string aOldValue, in string aNewValue); */
  NS_IMETHOD OnItemPropertyChanged(nsIMsgFolder *aItem, nsIAtom *aProperty, const char * aOldValue, const char * aNewValue) = 0;

  enum {
    intPropertyChanged = 8U
  };

  /* void OnItemIntPropertyChanged (in nsIMsgFolder aItem, in nsIAtom aProperty, in long aOldValue, in long aNewValue); */
  NS_IMETHOD OnItemIntPropertyChanged(nsIMsgFolder *aItem, nsIAtom *aProperty, int32_t aOldValue, int32_t aNewValue) = 0;

  enum {
    boolPropertyChanged = 16U
  };

  /* void OnItemBoolPropertyChanged (in nsIMsgFolder aItem, in nsIAtom aProperty, in boolean aOldValue, in boolean aNewValue); */
  NS_IMETHOD OnItemBoolPropertyChanged(nsIMsgFolder *aItem, nsIAtom *aProperty, bool aOldValue, bool aNewValue) = 0;

  enum {
    unicharPropertyChanged = 32U
  };

  /* void OnItemUnicharPropertyChanged (in nsIMsgFolder aItem, in nsIAtom aProperty, in wstring aOldValue, in wstring aNewValue); */
  NS_IMETHOD OnItemUnicharPropertyChanged(nsIMsgFolder *aItem, nsIAtom *aProperty, const PRUnichar * aOldValue, const PRUnichar * aNewValue) = 0;

  enum {
    propertyFlagChanged = 64U
  };

  /* void OnItemPropertyFlagChanged (in nsIMsgDBHdr aItem, in nsIAtom aProperty, in unsigned long aOldFlag, in unsigned long aNewFlag); */
  NS_IMETHOD OnItemPropertyFlagChanged(nsIMsgDBHdr *aItem, nsIAtom *aProperty, uint32_t aOldFlag, uint32_t aNewFlag) = 0;

  enum {
    event = 128U
  };

  /* void OnItemEvent (in nsIMsgFolder aItem, in nsIAtom aEvent); */
  NS_IMETHOD OnItemEvent(nsIMsgFolder *aItem, nsIAtom *aEvent) = 0;

  enum {
    all = 4294967295U
  };

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIFolderListener, NS_IFOLDERLISTENER_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIFOLDERLISTENER \
  NS_IMETHOD OnItemAdded(nsIMsgFolder *aParentItem, nsISupports *aItem); \
  NS_IMETHOD OnItemRemoved(nsIMsgFolder *aParentItem, nsISupports *aItem); \
  NS_IMETHOD OnItemPropertyChanged(nsIMsgFolder *aItem, nsIAtom *aProperty, const char * aOldValue, const char * aNewValue); \
  NS_IMETHOD OnItemIntPropertyChanged(nsIMsgFolder *aItem, nsIAtom *aProperty, int32_t aOldValue, int32_t aNewValue); \
  NS_IMETHOD OnItemBoolPropertyChanged(nsIMsgFolder *aItem, nsIAtom *aProperty, bool aOldValue, bool aNewValue); \
  NS_IMETHOD OnItemUnicharPropertyChanged(nsIMsgFolder *aItem, nsIAtom *aProperty, const PRUnichar * aOldValue, const PRUnichar * aNewValue); \
  NS_IMETHOD OnItemPropertyFlagChanged(nsIMsgDBHdr *aItem, nsIAtom *aProperty, uint32_t aOldFlag, uint32_t aNewFlag); \
  NS_IMETHOD OnItemEvent(nsIMsgFolder *aItem, nsIAtom *aEvent); \

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIFOLDERLISTENER(_to) \
  NS_IMETHOD OnItemAdded(nsIMsgFolder *aParentItem, nsISupports *aItem) { return _to OnItemAdded(aParentItem, aItem); } \
  NS_IMETHOD OnItemRemoved(nsIMsgFolder *aParentItem, nsISupports *aItem) { return _to OnItemRemoved(aParentItem, aItem); } \
  NS_IMETHOD OnItemPropertyChanged(nsIMsgFolder *aItem, nsIAtom *aProperty, const char * aOldValue, const char * aNewValue) { return _to OnItemPropertyChanged(aItem, aProperty, aOldValue, aNewValue); } \
  NS_IMETHOD OnItemIntPropertyChanged(nsIMsgFolder *aItem, nsIAtom *aProperty, int32_t aOldValue, int32_t aNewValue) { return _to OnItemIntPropertyChanged(aItem, aProperty, aOldValue, aNewValue); } \
  NS_IMETHOD OnItemBoolPropertyChanged(nsIMsgFolder *aItem, nsIAtom *aProperty, bool aOldValue, bool aNewValue) { return _to OnItemBoolPropertyChanged(aItem, aProperty, aOldValue, aNewValue); } \
  NS_IMETHOD OnItemUnicharPropertyChanged(nsIMsgFolder *aItem, nsIAtom *aProperty, const PRUnichar * aOldValue, const PRUnichar * aNewValue) { return _to OnItemUnicharPropertyChanged(aItem, aProperty, aOldValue, aNewValue); } \
  NS_IMETHOD OnItemPropertyFlagChanged(nsIMsgDBHdr *aItem, nsIAtom *aProperty, uint32_t aOldFlag, uint32_t aNewFlag) { return _to OnItemPropertyFlagChanged(aItem, aProperty, aOldFlag, aNewFlag); } \
  NS_IMETHOD OnItemEvent(nsIMsgFolder *aItem, nsIAtom *aEvent) { return _to OnItemEvent(aItem, aEvent); } \

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIFOLDERLISTENER(_to) \
  NS_IMETHOD OnItemAdded(nsIMsgFolder *aParentItem, nsISupports *aItem) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnItemAdded(aParentItem, aItem); } \
  NS_IMETHOD OnItemRemoved(nsIMsgFolder *aParentItem, nsISupports *aItem) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnItemRemoved(aParentItem, aItem); } \
  NS_IMETHOD OnItemPropertyChanged(nsIMsgFolder *aItem, nsIAtom *aProperty, const char * aOldValue, const char * aNewValue) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnItemPropertyChanged(aItem, aProperty, aOldValue, aNewValue); } \
  NS_IMETHOD OnItemIntPropertyChanged(nsIMsgFolder *aItem, nsIAtom *aProperty, int32_t aOldValue, int32_t aNewValue) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnItemIntPropertyChanged(aItem, aProperty, aOldValue, aNewValue); } \
  NS_IMETHOD OnItemBoolPropertyChanged(nsIMsgFolder *aItem, nsIAtom *aProperty, bool aOldValue, bool aNewValue) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnItemBoolPropertyChanged(aItem, aProperty, aOldValue, aNewValue); } \
  NS_IMETHOD OnItemUnicharPropertyChanged(nsIMsgFolder *aItem, nsIAtom *aProperty, const PRUnichar * aOldValue, const PRUnichar * aNewValue) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnItemUnicharPropertyChanged(aItem, aProperty, aOldValue, aNewValue); } \
  NS_IMETHOD OnItemPropertyFlagChanged(nsIMsgDBHdr *aItem, nsIAtom *aProperty, uint32_t aOldFlag, uint32_t aNewFlag) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnItemPropertyFlagChanged(aItem, aProperty, aOldFlag, aNewFlag); } \
  NS_IMETHOD OnItemEvent(nsIMsgFolder *aItem, nsIAtom *aEvent) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnItemEvent(aItem, aEvent); } \

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsFolderListener : public nsIFolderListener
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIFOLDERLISTENER

  nsFolderListener();

private:
  ~nsFolderListener();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsFolderListener, nsIFolderListener)

nsFolderListener::nsFolderListener()
{
  /* member initializers and constructor code */
}

nsFolderListener::~nsFolderListener()
{
  /* destructor code */
}

/* void OnItemAdded (in nsIMsgFolder aParentItem, in nsISupports aItem); */
NS_IMETHODIMP nsFolderListener::OnItemAdded(nsIMsgFolder *aParentItem, nsISupports *aItem)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void OnItemRemoved (in nsIMsgFolder aParentItem, in nsISupports aItem); */
NS_IMETHODIMP nsFolderListener::OnItemRemoved(nsIMsgFolder *aParentItem, nsISupports *aItem)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void OnItemPropertyChanged (in nsIMsgFolder aItem, in nsIAtom aProperty, in string aOldValue, in string aNewValue); */
NS_IMETHODIMP nsFolderListener::OnItemPropertyChanged(nsIMsgFolder *aItem, nsIAtom *aProperty, const char * aOldValue, const char * aNewValue)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void OnItemIntPropertyChanged (in nsIMsgFolder aItem, in nsIAtom aProperty, in long aOldValue, in long aNewValue); */
NS_IMETHODIMP nsFolderListener::OnItemIntPropertyChanged(nsIMsgFolder *aItem, nsIAtom *aProperty, int32_t aOldValue, int32_t aNewValue)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void OnItemBoolPropertyChanged (in nsIMsgFolder aItem, in nsIAtom aProperty, in boolean aOldValue, in boolean aNewValue); */
NS_IMETHODIMP nsFolderListener::OnItemBoolPropertyChanged(nsIMsgFolder *aItem, nsIAtom *aProperty, bool aOldValue, bool aNewValue)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void OnItemUnicharPropertyChanged (in nsIMsgFolder aItem, in nsIAtom aProperty, in wstring aOldValue, in wstring aNewValue); */
NS_IMETHODIMP nsFolderListener::OnItemUnicharPropertyChanged(nsIMsgFolder *aItem, nsIAtom *aProperty, const PRUnichar * aOldValue, const PRUnichar * aNewValue)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void OnItemPropertyFlagChanged (in nsIMsgDBHdr aItem, in nsIAtom aProperty, in unsigned long aOldFlag, in unsigned long aNewFlag); */
NS_IMETHODIMP nsFolderListener::OnItemPropertyFlagChanged(nsIMsgDBHdr *aItem, nsIAtom *aProperty, uint32_t aOldFlag, uint32_t aNewFlag)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void OnItemEvent (in nsIMsgFolder aItem, in nsIAtom aEvent); */
NS_IMETHODIMP nsFolderListener::OnItemEvent(nsIMsgFolder *aItem, nsIAtom *aEvent)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIFolderListener_h__ */
