/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"
#include "nsIDOMEventTarget.idl"
#include "nsIDOMEvent.idl"

interface nsIVariant;

dictionary MozWifiStatusChangeEventInit : EventInit
{
  nsIVariant network;
  DOMString status;
};

dictionary MozWifiConnectionInfoEventInit : EventInit
{
  nsIVariant network;
  short signalStrength;
  short relSignalStrength;
  long linkSpeed;
};
