/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/addrbook/public/nsIAbItem.idl
 */

#ifndef __gen_nsIAbItem_h__
#define __gen_nsIAbItem_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIMsgHeaderParser; /* forward declaration */

class nsIStringBundle; /* forward declaration */


/* starting interface:    nsIAbItem */
#define NS_IABITEM_IID_STR "bb691a55-cbfe-4cf8-974a-e18cfa845a73"

#define NS_IABITEM_IID \
  {0xbb691a55, 0xcbfe, 0x4cf8, \
    { 0x97, 0x4a, 0xe1, 0x8c, 0xfa, 0x84, 0x5a, 0x73 }}

class NS_NO_VTABLE nsIAbItem : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IABITEM_IID)

  /* readonly attribute AUTF8String uuid; */
  NS_IMETHOD GetUuid(nsACString & aUuid) = 0;

  enum {
    GENERATE_DISPLAY_NAME = 0U,
    GENERATE_LAST_FIRST_ORDER = 1U,
    GENERATE_FIRST_LAST_ORDER = 2U
  };

  /* AString generateName (in long aGenerateFormat, [optional] in nsIStringBundle aBundle); */
  NS_IMETHOD GenerateName(int32_t aGenerateFormat, nsIStringBundle *aBundle, nsAString & _retval) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIAbItem, NS_IABITEM_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIABITEM \
  NS_IMETHOD GetUuid(nsACString & aUuid); \
  NS_IMETHOD GenerateName(int32_t aGenerateFormat, nsIStringBundle *aBundle, nsAString & _retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIABITEM(_to) \
  NS_IMETHOD GetUuid(nsACString & aUuid) { return _to GetUuid(aUuid); } \
  NS_IMETHOD GenerateName(int32_t aGenerateFormat, nsIStringBundle *aBundle, nsAString & _retval) { return _to GenerateName(aGenerateFormat, aBundle, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIABITEM(_to) \
  NS_IMETHOD GetUuid(nsACString & aUuid) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetUuid(aUuid); } \
  NS_IMETHOD GenerateName(int32_t aGenerateFormat, nsIStringBundle *aBundle, nsAString & _retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GenerateName(aGenerateFormat, aBundle, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsAbItem : public nsIAbItem
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIABITEM

  nsAbItem();

private:
  ~nsAbItem();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsAbItem, nsIAbItem)

nsAbItem::nsAbItem()
{
  /* member initializers and constructor code */
}

nsAbItem::~nsAbItem()
{
  /* destructor code */
}

/* readonly attribute AUTF8String uuid; */
NS_IMETHODIMP nsAbItem::GetUuid(nsACString & aUuid)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* AString generateName (in long aGenerateFormat, [optional] in nsIStringBundle aBundle); */
NS_IMETHODIMP nsAbItem::GenerateName(int32_t aGenerateFormat, nsIStringBundle *aBundle, nsAString & _retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIAbItem_h__ */
