/* -*- Mode: IDL; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"

[scriptable, uuid(d9e45fee-1dd1-11b2-938c-9147855ed837)]
interface nsIMessengerOSIntegration : nsISupports {
  // for now, nothing.  it's up to the implementation to 
  // do all the work of registering itself as listeners
  // all we guarantee is your service will be created
  // when accounts are loaded by the account manager
};
