/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"
#include "nsIMsgAttachment.idl"
#include "nsISimpleEnumerator.idl"

[scriptable, uuid(a58cd120-ba9b-11de-8a39-0800200c9a66)]
interface nsIMsgCompFields : nsISupports {

  attribute AString from;
  attribute AString replyTo;
  attribute AString to;
  attribute AString cc;
  attribute AString bcc;
  
  attribute AString fcc;
  attribute AString fcc2;
  
  attribute AString newsgroups;
  attribute string  newshost;
  attribute string  newspostUrl;
  attribute AString followupTo;

  attribute AString subject;
  
  attribute AString organization;
  attribute string  references;
  attribute string  priority;
  attribute string  messageId;
  attribute string  characterSet;
  readonly attribute string defaultCharacterSet;

  attribute AString templateName;
  attribute string  draftId;

  attribute boolean returnReceipt;
  attribute long receiptHeaderType;
  attribute boolean DSN;
  attribute boolean attachVCard;
  attribute boolean forcePlainText;
  attribute boolean useMultipartAlternative;
  attribute boolean bodyIsAsciiOnly;
  attribute boolean forceMsgEncoding;

  attribute AString otherRandomHeaders;

  /**
   * Addresses for the other forms of reply.
   */
  attribute AString senderReply;
  attribute AString allReply;
  attribute AString listReply;

  /**
   * Beware that when setting this property, your body must be properly wrapped,
   * and the line endings must match MSG_LINEBREAK, namely "\r\n" on Windows
   * and "\n" on Linux and OSX.
   */
  attribute AString body;

  /**
   * temporaryFiles
   *
   * @OBSOLETE, DO NOT USE ANYMORE
   */
  attribute string  temporaryFiles;
  
  readonly attribute nsISimpleEnumerator attachments;
  void addAttachment(in nsIMsgAttachment attachment);
  void removeAttachment(in nsIMsgAttachment attachment);
  void removeAttachments();

  /**
   * This function will split the recipients into an array.
   *
   * @param aRecipients       The recipients list to split.
   * @param aEmailAddressOnly Set to true to drop display names from the results
   *                          array.
   * @param aLength           The length of the aResult array.
   * @param aResult           An array of the recipients.
   */
  void splitRecipients(in AString aRecipients, in boolean aEmailAddressOnly,
                       out unsigned long aLength,
                       [array, size_is(aLength), retval] out wstring aResult);

  void ConvertBodyToPlainText();

  // Check if the composing mail headers can be converted to a mail charset.
  boolean checkCharsetConversion(out string fallbackCharset);

  /** 
   * Indicates whether we need to check if the current |DocumentCharset|
   * can represent all the characters in the message body. It should be
   * initialized to true and set to false when 'Send Anyway' is selected
   * by a user. (bug 249530)
   */
  attribute boolean needToCheckCharset; 

  attribute nsISupports securityInfo;
};

