/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/addrbook/public/nsIAbDirFactory.idl
 */

#ifndef __gen_nsIAbDirFactory_h__
#define __gen_nsIAbDirFactory_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsISimpleEnumerator_h__
#include "nsISimpleEnumerator.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIAbDirectory; /* forward declaration */


/* starting interface:    nsIAbDirFactory */
#define NS_IABDIRFACTORY_IID_STR "ad61b4fc-d8d8-40b2-b924-4c10f28a8a17"

#define NS_IABDIRFACTORY_IID \
  {0xad61b4fc, 0xd8d8, 0x40b2, \
    { 0xb9, 0x24, 0x4c, 0x10, 0xf2, 0x8a, 0x8a, 0x17 }}

class NS_NO_VTABLE nsIAbDirFactory : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IABDIRFACTORY_IID)

  /* nsISimpleEnumerator getDirectories (in AString aDirName, in ACString aURI, in ACString aPrefName); */
  NS_IMETHOD GetDirectories(const nsAString & aDirName, const nsACString & aURI, const nsACString & aPrefName, nsISimpleEnumerator * *_retval) = 0;

  /* void deleteDirectory (in nsIAbDirectory directory); */
  NS_IMETHOD DeleteDirectory(nsIAbDirectory *directory) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIAbDirFactory, NS_IABDIRFACTORY_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIABDIRFACTORY \
  NS_IMETHOD GetDirectories(const nsAString & aDirName, const nsACString & aURI, const nsACString & aPrefName, nsISimpleEnumerator * *_retval); \
  NS_IMETHOD DeleteDirectory(nsIAbDirectory *directory); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIABDIRFACTORY(_to) \
  NS_IMETHOD GetDirectories(const nsAString & aDirName, const nsACString & aURI, const nsACString & aPrefName, nsISimpleEnumerator * *_retval) { return _to GetDirectories(aDirName, aURI, aPrefName, _retval); } \
  NS_IMETHOD DeleteDirectory(nsIAbDirectory *directory) { return _to DeleteDirectory(directory); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIABDIRFACTORY(_to) \
  NS_IMETHOD GetDirectories(const nsAString & aDirName, const nsACString & aURI, const nsACString & aPrefName, nsISimpleEnumerator * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDirectories(aDirName, aURI, aPrefName, _retval); } \
  NS_IMETHOD DeleteDirectory(nsIAbDirectory *directory) { return !_to ? NS_ERROR_NULL_POINTER : _to->DeleteDirectory(directory); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsAbDirFactory : public nsIAbDirFactory
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIABDIRFACTORY

  nsAbDirFactory();

private:
  ~nsAbDirFactory();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsAbDirFactory, nsIAbDirFactory)

nsAbDirFactory::nsAbDirFactory()
{
  /* member initializers and constructor code */
}

nsAbDirFactory::~nsAbDirFactory()
{
  /* destructor code */
}

/* nsISimpleEnumerator getDirectories (in AString aDirName, in ACString aURI, in ACString aPrefName); */
NS_IMETHODIMP nsAbDirFactory::GetDirectories(const nsAString & aDirName, const nsACString & aURI, const nsACString & aPrefName, nsISimpleEnumerator * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void deleteDirectory (in nsIAbDirectory directory); */
NS_IMETHODIMP nsAbDirFactory::DeleteDirectory(nsIAbDirectory *directory)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIAbDirFactory_h__ */
