/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this file,
 * You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "domstubs.idl"

[scriptable, uuid(0e22289a-469d-42c0-98dd-ae9831bd6a6d)]
interface nsIDOMDeviceStorageStat : nsISupports
{
  readonly attribute uint64_t totalBytes;
  readonly attribute uint64_t freeBytes;

  // "shared", "available", "unavailable"
  readonly attribute DOMString state;
};
