/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/local/public/nsIPop3Sink.idl
 */

#ifndef __gen_nsIPop3Sink_h__
#define __gen_nsIPop3Sink_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsIPop3IncomingServer_h__
#include "nsIPop3IncomingServer.h"
#endif

#ifndef __gen_nsIMsgFolder_h__
#include "nsIMsgFolder.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIURI; /* forward declaration */


/* starting interface:    nsIPop3Sink */
#define NS_IPOP3SINK_IID_STR "ceabfc6b-f139-4c25-890f-efb7c3069d3f"

#define NS_IPOP3SINK_IID \
  {0xceabfc6b, 0xf139, 0x4c25, \
    { 0x89, 0x0f, 0xef, 0xb7, 0xc3, 0x06, 0x9d, 0x3f }}

class NS_NO_VTABLE nsIPop3Sink : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IPOP3SINK_IID)

  /* attribute boolean userAuthenticated; */
  NS_IMETHOD GetUserAuthenticated(bool *aUserAuthenticated) = 0;
  NS_IMETHOD SetUserAuthenticated(bool aUserAuthenticated) = 0;

  /* attribute string mailAccountURL; */
  NS_IMETHOD GetMailAccountURL(char * *aMailAccountURL) = 0;
  NS_IMETHOD SetMailAccountURL(const char * aMailAccountURL) = 0;

  /* attribute boolean buildMessageUri; */
  NS_IMETHOD GetBuildMessageUri(bool *aBuildMessageUri) = 0;
  NS_IMETHOD SetBuildMessageUri(bool aBuildMessageUri) = 0;

  /* attribute string messageUri; */
  NS_IMETHOD GetMessageUri(char * *aMessageUri) = 0;
  NS_IMETHOD SetMessageUri(const char * aMessageUri) = 0;

  /* attribute string baseMessageUri; */
  NS_IMETHOD GetBaseMessageUri(char * *aBaseMessageUri) = 0;
  NS_IMETHOD SetBaseMessageUri(const char * aBaseMessageUri) = 0;

  /* attribute ACString origMessageUri; */
  NS_IMETHOD GetOrigMessageUri(nsACString & aOrigMessageUri) = 0;
  NS_IMETHOD SetOrigMessageUri(const nsACString & aOrigMessageUri) = 0;

  /* boolean BeginMailDelivery (in boolean uidlDownload, in nsIMsgWindow msgWindow); */
  NS_IMETHOD BeginMailDelivery(bool uidlDownload, nsIMsgWindow *msgWindow, bool *_retval) = 0;

  /* void endMailDelivery (in nsIPop3Protocol protocol); */
  NS_IMETHOD EndMailDelivery(nsIPop3Protocol *protocol) = 0;

  /* void AbortMailDelivery (in nsIPop3Protocol protocol); */
  NS_IMETHOD AbortMailDelivery(nsIPop3Protocol *protocol) = 0;

  /* [noscript] voidPtr IncorporateBegin (in string uidlString, in nsIURI aURL, in unsigned long flags); */
  NS_IMETHOD IncorporateBegin(const char * uidlString, nsIURI *aURL, uint32_t flags, void **_retval) = 0;

  /* [noscript] void IncorporateWrite (in string block, in long length); */
  NS_IMETHOD IncorporateWrite(const char * block, int32_t length) = 0;

  /* [noscript] void IncorporateComplete (in nsIMsgWindow aMsgWindow, in int32_t aSize); */
  NS_IMETHOD IncorporateComplete(nsIMsgWindow *aMsgWindow, int32_t aSize) = 0;

  /* [noscript] void IncorporateAbort (in boolean uidlDownload); */
  NS_IMETHOD IncorporateAbort(bool uidlDownload) = 0;

  /* void BiffGetNewMail (); */
  NS_IMETHOD BiffGetNewMail(void) = 0;

  /* void setMsgsToDownload (in unsigned long aNumMessages); */
  NS_IMETHOD SetMsgsToDownload(uint32_t aNumMessages) = 0;

  /* void SetBiffStateAndUpdateFE (in unsigned long biffState, in long numNewMessages, in boolean notify); */
  NS_IMETHOD SetBiffStateAndUpdateFE(uint32_t biffState, int32_t numNewMessages, bool notify) = 0;

  /* [noscript] void SetSenderAuthedFlag (in voidPtr closure, in boolean authed); */
  NS_IMETHOD SetSenderAuthedFlag(void *closure, bool authed) = 0;

  /* attribute nsIPop3IncomingServer popServer; */
  NS_IMETHOD GetPopServer(nsIPop3IncomingServer * *aPopServer) = 0;
  NS_IMETHOD SetPopServer(nsIPop3IncomingServer *aPopServer) = 0;

  /* attribute nsIMsgFolder folder; */
  NS_IMETHOD GetFolder(nsIMsgFolder * *aFolder) = 0;
  NS_IMETHOD SetFolder(nsIMsgFolder *aFolder) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIPop3Sink, NS_IPOP3SINK_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIPOP3SINK \
  NS_IMETHOD GetUserAuthenticated(bool *aUserAuthenticated); \
  NS_IMETHOD SetUserAuthenticated(bool aUserAuthenticated); \
  NS_IMETHOD GetMailAccountURL(char * *aMailAccountURL); \
  NS_IMETHOD SetMailAccountURL(const char * aMailAccountURL); \
  NS_IMETHOD GetBuildMessageUri(bool *aBuildMessageUri); \
  NS_IMETHOD SetBuildMessageUri(bool aBuildMessageUri); \
  NS_IMETHOD GetMessageUri(char * *aMessageUri); \
  NS_IMETHOD SetMessageUri(const char * aMessageUri); \
  NS_IMETHOD GetBaseMessageUri(char * *aBaseMessageUri); \
  NS_IMETHOD SetBaseMessageUri(const char * aBaseMessageUri); \
  NS_IMETHOD GetOrigMessageUri(nsACString & aOrigMessageUri); \
  NS_IMETHOD SetOrigMessageUri(const nsACString & aOrigMessageUri); \
  NS_IMETHOD BeginMailDelivery(bool uidlDownload, nsIMsgWindow *msgWindow, bool *_retval); \
  NS_IMETHOD EndMailDelivery(nsIPop3Protocol *protocol); \
  NS_IMETHOD AbortMailDelivery(nsIPop3Protocol *protocol); \
  NS_IMETHOD IncorporateBegin(const char * uidlString, nsIURI *aURL, uint32_t flags, void **_retval); \
  NS_IMETHOD IncorporateWrite(const char * block, int32_t length); \
  NS_IMETHOD IncorporateComplete(nsIMsgWindow *aMsgWindow, int32_t aSize); \
  NS_IMETHOD IncorporateAbort(bool uidlDownload); \
  NS_IMETHOD BiffGetNewMail(void); \
  NS_IMETHOD SetMsgsToDownload(uint32_t aNumMessages); \
  NS_IMETHOD SetBiffStateAndUpdateFE(uint32_t biffState, int32_t numNewMessages, bool notify); \
  NS_IMETHOD SetSenderAuthedFlag(void *closure, bool authed); \
  NS_IMETHOD GetPopServer(nsIPop3IncomingServer * *aPopServer); \
  NS_IMETHOD SetPopServer(nsIPop3IncomingServer *aPopServer); \
  NS_IMETHOD GetFolder(nsIMsgFolder * *aFolder); \
  NS_IMETHOD SetFolder(nsIMsgFolder *aFolder); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIPOP3SINK(_to) \
  NS_IMETHOD GetUserAuthenticated(bool *aUserAuthenticated) { return _to GetUserAuthenticated(aUserAuthenticated); } \
  NS_IMETHOD SetUserAuthenticated(bool aUserAuthenticated) { return _to SetUserAuthenticated(aUserAuthenticated); } \
  NS_IMETHOD GetMailAccountURL(char * *aMailAccountURL) { return _to GetMailAccountURL(aMailAccountURL); } \
  NS_IMETHOD SetMailAccountURL(const char * aMailAccountURL) { return _to SetMailAccountURL(aMailAccountURL); } \
  NS_IMETHOD GetBuildMessageUri(bool *aBuildMessageUri) { return _to GetBuildMessageUri(aBuildMessageUri); } \
  NS_IMETHOD SetBuildMessageUri(bool aBuildMessageUri) { return _to SetBuildMessageUri(aBuildMessageUri); } \
  NS_IMETHOD GetMessageUri(char * *aMessageUri) { return _to GetMessageUri(aMessageUri); } \
  NS_IMETHOD SetMessageUri(const char * aMessageUri) { return _to SetMessageUri(aMessageUri); } \
  NS_IMETHOD GetBaseMessageUri(char * *aBaseMessageUri) { return _to GetBaseMessageUri(aBaseMessageUri); } \
  NS_IMETHOD SetBaseMessageUri(const char * aBaseMessageUri) { return _to SetBaseMessageUri(aBaseMessageUri); } \
  NS_IMETHOD GetOrigMessageUri(nsACString & aOrigMessageUri) { return _to GetOrigMessageUri(aOrigMessageUri); } \
  NS_IMETHOD SetOrigMessageUri(const nsACString & aOrigMessageUri) { return _to SetOrigMessageUri(aOrigMessageUri); } \
  NS_IMETHOD BeginMailDelivery(bool uidlDownload, nsIMsgWindow *msgWindow, bool *_retval) { return _to BeginMailDelivery(uidlDownload, msgWindow, _retval); } \
  NS_IMETHOD EndMailDelivery(nsIPop3Protocol *protocol) { return _to EndMailDelivery(protocol); } \
  NS_IMETHOD AbortMailDelivery(nsIPop3Protocol *protocol) { return _to AbortMailDelivery(protocol); } \
  NS_IMETHOD IncorporateBegin(const char * uidlString, nsIURI *aURL, uint32_t flags, void **_retval) { return _to IncorporateBegin(uidlString, aURL, flags, _retval); } \
  NS_IMETHOD IncorporateWrite(const char * block, int32_t length) { return _to IncorporateWrite(block, length); } \
  NS_IMETHOD IncorporateComplete(nsIMsgWindow *aMsgWindow, int32_t aSize) { return _to IncorporateComplete(aMsgWindow, aSize); } \
  NS_IMETHOD IncorporateAbort(bool uidlDownload) { return _to IncorporateAbort(uidlDownload); } \
  NS_IMETHOD BiffGetNewMail(void) { return _to BiffGetNewMail(); } \
  NS_IMETHOD SetMsgsToDownload(uint32_t aNumMessages) { return _to SetMsgsToDownload(aNumMessages); } \
  NS_IMETHOD SetBiffStateAndUpdateFE(uint32_t biffState, int32_t numNewMessages, bool notify) { return _to SetBiffStateAndUpdateFE(biffState, numNewMessages, notify); } \
  NS_IMETHOD SetSenderAuthedFlag(void *closure, bool authed) { return _to SetSenderAuthedFlag(closure, authed); } \
  NS_IMETHOD GetPopServer(nsIPop3IncomingServer * *aPopServer) { return _to GetPopServer(aPopServer); } \
  NS_IMETHOD SetPopServer(nsIPop3IncomingServer *aPopServer) { return _to SetPopServer(aPopServer); } \
  NS_IMETHOD GetFolder(nsIMsgFolder * *aFolder) { return _to GetFolder(aFolder); } \
  NS_IMETHOD SetFolder(nsIMsgFolder *aFolder) { return _to SetFolder(aFolder); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIPOP3SINK(_to) \
  NS_IMETHOD GetUserAuthenticated(bool *aUserAuthenticated) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetUserAuthenticated(aUserAuthenticated); } \
  NS_IMETHOD SetUserAuthenticated(bool aUserAuthenticated) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetUserAuthenticated(aUserAuthenticated); } \
  NS_IMETHOD GetMailAccountURL(char * *aMailAccountURL) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMailAccountURL(aMailAccountURL); } \
  NS_IMETHOD SetMailAccountURL(const char * aMailAccountURL) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMailAccountURL(aMailAccountURL); } \
  NS_IMETHOD GetBuildMessageUri(bool *aBuildMessageUri) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetBuildMessageUri(aBuildMessageUri); } \
  NS_IMETHOD SetBuildMessageUri(bool aBuildMessageUri) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetBuildMessageUri(aBuildMessageUri); } \
  NS_IMETHOD GetMessageUri(char * *aMessageUri) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMessageUri(aMessageUri); } \
  NS_IMETHOD SetMessageUri(const char * aMessageUri) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMessageUri(aMessageUri); } \
  NS_IMETHOD GetBaseMessageUri(char * *aBaseMessageUri) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetBaseMessageUri(aBaseMessageUri); } \
  NS_IMETHOD SetBaseMessageUri(const char * aBaseMessageUri) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetBaseMessageUri(aBaseMessageUri); } \
  NS_IMETHOD GetOrigMessageUri(nsACString & aOrigMessageUri) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetOrigMessageUri(aOrigMessageUri); } \
  NS_IMETHOD SetOrigMessageUri(const nsACString & aOrigMessageUri) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetOrigMessageUri(aOrigMessageUri); } \
  NS_IMETHOD BeginMailDelivery(bool uidlDownload, nsIMsgWindow *msgWindow, bool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->BeginMailDelivery(uidlDownload, msgWindow, _retval); } \
  NS_IMETHOD EndMailDelivery(nsIPop3Protocol *protocol) { return !_to ? NS_ERROR_NULL_POINTER : _to->EndMailDelivery(protocol); } \
  NS_IMETHOD AbortMailDelivery(nsIPop3Protocol *protocol) { return !_to ? NS_ERROR_NULL_POINTER : _to->AbortMailDelivery(protocol); } \
  NS_IMETHOD IncorporateBegin(const char * uidlString, nsIURI *aURL, uint32_t flags, void **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->IncorporateBegin(uidlString, aURL, flags, _retval); } \
  NS_IMETHOD IncorporateWrite(const char * block, int32_t length) { return !_to ? NS_ERROR_NULL_POINTER : _to->IncorporateWrite(block, length); } \
  NS_IMETHOD IncorporateComplete(nsIMsgWindow *aMsgWindow, int32_t aSize) { return !_to ? NS_ERROR_NULL_POINTER : _to->IncorporateComplete(aMsgWindow, aSize); } \
  NS_IMETHOD IncorporateAbort(bool uidlDownload) { return !_to ? NS_ERROR_NULL_POINTER : _to->IncorporateAbort(uidlDownload); } \
  NS_IMETHOD BiffGetNewMail(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->BiffGetNewMail(); } \
  NS_IMETHOD SetMsgsToDownload(uint32_t aNumMessages) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMsgsToDownload(aNumMessages); } \
  NS_IMETHOD SetBiffStateAndUpdateFE(uint32_t biffState, int32_t numNewMessages, bool notify) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetBiffStateAndUpdateFE(biffState, numNewMessages, notify); } \
  NS_IMETHOD SetSenderAuthedFlag(void *closure, bool authed) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetSenderAuthedFlag(closure, authed); } \
  NS_IMETHOD GetPopServer(nsIPop3IncomingServer * *aPopServer) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetPopServer(aPopServer); } \
  NS_IMETHOD SetPopServer(nsIPop3IncomingServer *aPopServer) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetPopServer(aPopServer); } \
  NS_IMETHOD GetFolder(nsIMsgFolder * *aFolder) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFolder(aFolder); } \
  NS_IMETHOD SetFolder(nsIMsgFolder *aFolder) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetFolder(aFolder); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsPop3Sink : public nsIPop3Sink
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIPOP3SINK

  nsPop3Sink();

private:
  ~nsPop3Sink();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsPop3Sink, nsIPop3Sink)

nsPop3Sink::nsPop3Sink()
{
  /* member initializers and constructor code */
}

nsPop3Sink::~nsPop3Sink()
{
  /* destructor code */
}

/* attribute boolean userAuthenticated; */
NS_IMETHODIMP nsPop3Sink::GetUserAuthenticated(bool *aUserAuthenticated)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsPop3Sink::SetUserAuthenticated(bool aUserAuthenticated)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute string mailAccountURL; */
NS_IMETHODIMP nsPop3Sink::GetMailAccountURL(char * *aMailAccountURL)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsPop3Sink::SetMailAccountURL(const char * aMailAccountURL)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean buildMessageUri; */
NS_IMETHODIMP nsPop3Sink::GetBuildMessageUri(bool *aBuildMessageUri)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsPop3Sink::SetBuildMessageUri(bool aBuildMessageUri)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute string messageUri; */
NS_IMETHODIMP nsPop3Sink::GetMessageUri(char * *aMessageUri)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsPop3Sink::SetMessageUri(const char * aMessageUri)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute string baseMessageUri; */
NS_IMETHODIMP nsPop3Sink::GetBaseMessageUri(char * *aBaseMessageUri)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsPop3Sink::SetBaseMessageUri(const char * aBaseMessageUri)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute ACString origMessageUri; */
NS_IMETHODIMP nsPop3Sink::GetOrigMessageUri(nsACString & aOrigMessageUri)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsPop3Sink::SetOrigMessageUri(const nsACString & aOrigMessageUri)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean BeginMailDelivery (in boolean uidlDownload, in nsIMsgWindow msgWindow); */
NS_IMETHODIMP nsPop3Sink::BeginMailDelivery(bool uidlDownload, nsIMsgWindow *msgWindow, bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void endMailDelivery (in nsIPop3Protocol protocol); */
NS_IMETHODIMP nsPop3Sink::EndMailDelivery(nsIPop3Protocol *protocol)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void AbortMailDelivery (in nsIPop3Protocol protocol); */
NS_IMETHODIMP nsPop3Sink::AbortMailDelivery(nsIPop3Protocol *protocol)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [noscript] voidPtr IncorporateBegin (in string uidlString, in nsIURI aURL, in unsigned long flags); */
NS_IMETHODIMP nsPop3Sink::IncorporateBegin(const char * uidlString, nsIURI *aURL, uint32_t flags, void **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [noscript] void IncorporateWrite (in string block, in long length); */
NS_IMETHODIMP nsPop3Sink::IncorporateWrite(const char * block, int32_t length)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [noscript] void IncorporateComplete (in nsIMsgWindow aMsgWindow, in int32_t aSize); */
NS_IMETHODIMP nsPop3Sink::IncorporateComplete(nsIMsgWindow *aMsgWindow, int32_t aSize)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [noscript] void IncorporateAbort (in boolean uidlDownload); */
NS_IMETHODIMP nsPop3Sink::IncorporateAbort(bool uidlDownload)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void BiffGetNewMail (); */
NS_IMETHODIMP nsPop3Sink::BiffGetNewMail()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setMsgsToDownload (in unsigned long aNumMessages); */
NS_IMETHODIMP nsPop3Sink::SetMsgsToDownload(uint32_t aNumMessages)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void SetBiffStateAndUpdateFE (in unsigned long biffState, in long numNewMessages, in boolean notify); */
NS_IMETHODIMP nsPop3Sink::SetBiffStateAndUpdateFE(uint32_t biffState, int32_t numNewMessages, bool notify)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [noscript] void SetSenderAuthedFlag (in voidPtr closure, in boolean authed); */
NS_IMETHODIMP nsPop3Sink::SetSenderAuthedFlag(void *closure, bool authed)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsIPop3IncomingServer popServer; */
NS_IMETHODIMP nsPop3Sink::GetPopServer(nsIPop3IncomingServer * *aPopServer)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsPop3Sink::SetPopServer(nsIPop3IncomingServer *aPopServer)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsIMsgFolder folder; */
NS_IMETHODIMP nsPop3Sink::GetFolder(nsIMsgFolder * *aFolder)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsPop3Sink::SetFolder(nsIMsgFolder *aFolder)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIPop3Sink_h__ */
