/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/base/public/nsIMsgOfflineManager.idl
 */

#ifndef __gen_nsIMsgOfflineManager_h__
#define __gen_nsIMsgOfflineManager_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIMsgWindow; /* forward declaration */


/* starting interface:    nsIMsgOfflineManager */
#define NS_IMSGOFFLINEMANAGER_IID_STR "5e885fec-09b0-11d5-a5bf-0060b0fc04b7"

#define NS_IMSGOFFLINEMANAGER_IID \
  {0x5e885fec, 0x09b0, 0x11d5, \
    { 0xa5, 0xbf, 0x00, 0x60, 0xb0, 0xfc, 0x04, 0xb7 }}

class NS_NO_VTABLE nsIMsgOfflineManager : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IMSGOFFLINEMANAGER_IID)

  /* attribute nsIMsgWindow window; */
  NS_IMETHOD GetWindow(nsIMsgWindow * *aWindow) = 0;
  NS_IMETHOD SetWindow(nsIMsgWindow *aWindow) = 0;

  /* attribute boolean inProgress; */
  NS_IMETHOD GetInProgress(bool *aInProgress) = 0;
  NS_IMETHOD SetInProgress(bool aInProgress) = 0;

  /* void goOnline (in boolean sendUnsentMessages, in boolean playbackOfflineImapOperations, in nsIMsgWindow aMsgWindow); */
  NS_IMETHOD GoOnline(bool sendUnsentMessages, bool playbackOfflineImapOperations, nsIMsgWindow *aMsgWindow) = 0;

  /* void synchronizeForOffline (in boolean downloadNews, in boolean downloadMail, in boolean sendUnsentMessages, in boolean goOfflineWhenDone, in nsIMsgWindow aMsgWindow); */
  NS_IMETHOD SynchronizeForOffline(bool downloadNews, bool downloadMail, bool sendUnsentMessages, bool goOfflineWhenDone, nsIMsgWindow *aMsgWindow) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIMsgOfflineManager, NS_IMSGOFFLINEMANAGER_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGOFFLINEMANAGER \
  NS_IMETHOD GetWindow(nsIMsgWindow * *aWindow); \
  NS_IMETHOD SetWindow(nsIMsgWindow *aWindow); \
  NS_IMETHOD GetInProgress(bool *aInProgress); \
  NS_IMETHOD SetInProgress(bool aInProgress); \
  NS_IMETHOD GoOnline(bool sendUnsentMessages, bool playbackOfflineImapOperations, nsIMsgWindow *aMsgWindow); \
  NS_IMETHOD SynchronizeForOffline(bool downloadNews, bool downloadMail, bool sendUnsentMessages, bool goOfflineWhenDone, nsIMsgWindow *aMsgWindow); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGOFFLINEMANAGER(_to) \
  NS_IMETHOD GetWindow(nsIMsgWindow * *aWindow) { return _to GetWindow(aWindow); } \
  NS_IMETHOD SetWindow(nsIMsgWindow *aWindow) { return _to SetWindow(aWindow); } \
  NS_IMETHOD GetInProgress(bool *aInProgress) { return _to GetInProgress(aInProgress); } \
  NS_IMETHOD SetInProgress(bool aInProgress) { return _to SetInProgress(aInProgress); } \
  NS_IMETHOD GoOnline(bool sendUnsentMessages, bool playbackOfflineImapOperations, nsIMsgWindow *aMsgWindow) { return _to GoOnline(sendUnsentMessages, playbackOfflineImapOperations, aMsgWindow); } \
  NS_IMETHOD SynchronizeForOffline(bool downloadNews, bool downloadMail, bool sendUnsentMessages, bool goOfflineWhenDone, nsIMsgWindow *aMsgWindow) { return _to SynchronizeForOffline(downloadNews, downloadMail, sendUnsentMessages, goOfflineWhenDone, aMsgWindow); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGOFFLINEMANAGER(_to) \
  NS_IMETHOD GetWindow(nsIMsgWindow * *aWindow) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetWindow(aWindow); } \
  NS_IMETHOD SetWindow(nsIMsgWindow *aWindow) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetWindow(aWindow); } \
  NS_IMETHOD GetInProgress(bool *aInProgress) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetInProgress(aInProgress); } \
  NS_IMETHOD SetInProgress(bool aInProgress) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetInProgress(aInProgress); } \
  NS_IMETHOD GoOnline(bool sendUnsentMessages, bool playbackOfflineImapOperations, nsIMsgWindow *aMsgWindow) { return !_to ? NS_ERROR_NULL_POINTER : _to->GoOnline(sendUnsentMessages, playbackOfflineImapOperations, aMsgWindow); } \
  NS_IMETHOD SynchronizeForOffline(bool downloadNews, bool downloadMail, bool sendUnsentMessages, bool goOfflineWhenDone, nsIMsgWindow *aMsgWindow) { return !_to ? NS_ERROR_NULL_POINTER : _to->SynchronizeForOffline(downloadNews, downloadMail, sendUnsentMessages, goOfflineWhenDone, aMsgWindow); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgOfflineManager : public nsIMsgOfflineManager
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGOFFLINEMANAGER

  nsMsgOfflineManager();

private:
  ~nsMsgOfflineManager();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgOfflineManager, nsIMsgOfflineManager)

nsMsgOfflineManager::nsMsgOfflineManager()
{
  /* member initializers and constructor code */
}

nsMsgOfflineManager::~nsMsgOfflineManager()
{
  /* destructor code */
}

/* attribute nsIMsgWindow window; */
NS_IMETHODIMP nsMsgOfflineManager::GetWindow(nsIMsgWindow * *aWindow)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgOfflineManager::SetWindow(nsIMsgWindow *aWindow)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean inProgress; */
NS_IMETHODIMP nsMsgOfflineManager::GetInProgress(bool *aInProgress)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgOfflineManager::SetInProgress(bool aInProgress)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void goOnline (in boolean sendUnsentMessages, in boolean playbackOfflineImapOperations, in nsIMsgWindow aMsgWindow); */
NS_IMETHODIMP nsMsgOfflineManager::GoOnline(bool sendUnsentMessages, bool playbackOfflineImapOperations, nsIMsgWindow *aMsgWindow)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void synchronizeForOffline (in boolean downloadNews, in boolean downloadMail, in boolean sendUnsentMessages, in boolean goOfflineWhenDone, in nsIMsgWindow aMsgWindow); */
NS_IMETHODIMP nsMsgOfflineManager::SynchronizeForOffline(bool downloadNews, bool downloadMail, bool sendUnsentMessages, bool goOfflineWhenDone, nsIMsgWindow *aMsgWindow)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgOfflineManager_h__ */
