/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/mime/public/nsIPgpMimeProxy.idl
 */

#ifndef __gen_nsIPgpMimeProxy_h__
#define __gen_nsIPgpMimeProxy_h__


#ifndef __gen_nsIStreamListener_h__
#include "nsIStreamListener.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
typedef int (*MimeDecodeCallbackFun)(const char *buf, int32_t buf_size, void *output_closure);
#define NS_PGPMIMEPROXY_CLASSNAME "PGP/Mime Decryption"
#define NS_PGPMIMEPROXY_CONTRACTID "@mozilla.org/mime/pgp-mime-decrypt;1"
#define NS_PGPMIMEPROXY_CID                     \
{ /* c200d239-6dad-434f-a614-1b58a58c61ec */      \
   0xc200d239, 0x6dad, 0x434f,                    \
{0xa6, 0x14, 0x1b, 0x58, 0xa5, 0x8c, 0x61, 0xec } }

/* starting interface:    nsIPgpMimeProxy */
#define NS_IPGPMIMEPROXY_IID_STR "c200d239-6dad-434f-a614-1b58a58c61ec"

#define NS_IPGPMIMEPROXY_IID \
  {0xc200d239, 0x6dad, 0x434f, \
    { 0xa6, 0x14, 0x1b, 0x58, 0xa5, 0x8c, 0x61, 0xec }}

class NS_NO_VTABLE nsIPgpMimeProxy : public nsIStreamListener {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IPGPMIMEPROXY_IID)

  /* [noscript] void setMimeCallback (in MimeDecodeCallbackFun outputFun, in voidPtr outputClosure); */
  NS_IMETHOD SetMimeCallback(MimeDecodeCallbackFun outputFun, void *outputClosure) = 0;

  /* void init (); */
  NS_IMETHOD Init(void) = 0;

  /* void write (in string buf, in unsigned long count); */
  NS_IMETHOD Write(const char * buf, uint32_t count) = 0;

  /* void finish (); */
  NS_IMETHOD Finish(void) = 0;

  /* attribute nsIStreamListener decryptor; */
  NS_IMETHOD GetDecryptor(nsIStreamListener * *aDecryptor) = 0;
  NS_IMETHOD SetDecryptor(nsIStreamListener *aDecryptor) = 0;

  /* attribute ACString contentType; */
  NS_IMETHOD GetContentType(nsACString & aContentType) = 0;
  NS_IMETHOD SetContentType(const nsACString & aContentType) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIPgpMimeProxy, NS_IPGPMIMEPROXY_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIPGPMIMEPROXY \
  NS_IMETHOD SetMimeCallback(MimeDecodeCallbackFun outputFun, void *outputClosure); \
  NS_IMETHOD Init(void); \
  NS_IMETHOD Write(const char * buf, uint32_t count); \
  NS_IMETHOD Finish(void); \
  NS_IMETHOD GetDecryptor(nsIStreamListener * *aDecryptor); \
  NS_IMETHOD SetDecryptor(nsIStreamListener *aDecryptor); \
  NS_IMETHOD GetContentType(nsACString & aContentType); \
  NS_IMETHOD SetContentType(const nsACString & aContentType); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIPGPMIMEPROXY(_to) \
  NS_IMETHOD SetMimeCallback(MimeDecodeCallbackFun outputFun, void *outputClosure) { return _to SetMimeCallback(outputFun, outputClosure); } \
  NS_IMETHOD Init(void) { return _to Init(); } \
  NS_IMETHOD Write(const char * buf, uint32_t count) { return _to Write(buf, count); } \
  NS_IMETHOD Finish(void) { return _to Finish(); } \
  NS_IMETHOD GetDecryptor(nsIStreamListener * *aDecryptor) { return _to GetDecryptor(aDecryptor); } \
  NS_IMETHOD SetDecryptor(nsIStreamListener *aDecryptor) { return _to SetDecryptor(aDecryptor); } \
  NS_IMETHOD GetContentType(nsACString & aContentType) { return _to GetContentType(aContentType); } \
  NS_IMETHOD SetContentType(const nsACString & aContentType) { return _to SetContentType(aContentType); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIPGPMIMEPROXY(_to) \
  NS_IMETHOD SetMimeCallback(MimeDecodeCallbackFun outputFun, void *outputClosure) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMimeCallback(outputFun, outputClosure); } \
  NS_IMETHOD Init(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->Init(); } \
  NS_IMETHOD Write(const char * buf, uint32_t count) { return !_to ? NS_ERROR_NULL_POINTER : _to->Write(buf, count); } \
  NS_IMETHOD Finish(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->Finish(); } \
  NS_IMETHOD GetDecryptor(nsIStreamListener * *aDecryptor) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDecryptor(aDecryptor); } \
  NS_IMETHOD SetDecryptor(nsIStreamListener *aDecryptor) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetDecryptor(aDecryptor); } \
  NS_IMETHOD GetContentType(nsACString & aContentType) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetContentType(aContentType); } \
  NS_IMETHOD SetContentType(const nsACString & aContentType) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetContentType(aContentType); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsPgpMimeProxy : public nsIPgpMimeProxy
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIPGPMIMEPROXY

  nsPgpMimeProxy();

private:
  ~nsPgpMimeProxy();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsPgpMimeProxy, nsIPgpMimeProxy)

nsPgpMimeProxy::nsPgpMimeProxy()
{
  /* member initializers and constructor code */
}

nsPgpMimeProxy::~nsPgpMimeProxy()
{
  /* destructor code */
}

/* [noscript] void setMimeCallback (in MimeDecodeCallbackFun outputFun, in voidPtr outputClosure); */
NS_IMETHODIMP nsPgpMimeProxy::SetMimeCallback(MimeDecodeCallbackFun outputFun, void *outputClosure)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void init (); */
NS_IMETHODIMP nsPgpMimeProxy::Init()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void write (in string buf, in unsigned long count); */
NS_IMETHODIMP nsPgpMimeProxy::Write(const char * buf, uint32_t count)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void finish (); */
NS_IMETHODIMP nsPgpMimeProxy::Finish()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsIStreamListener decryptor; */
NS_IMETHODIMP nsPgpMimeProxy::GetDecryptor(nsIStreamListener * *aDecryptor)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsPgpMimeProxy::SetDecryptor(nsIStreamListener *aDecryptor)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute ACString contentType; */
NS_IMETHODIMP nsPgpMimeProxy::GetContentType(nsACString & aContentType)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsPgpMimeProxy::SetContentType(const nsACString & aContentType)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIPgpMimeProxy_h__ */
