/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/base/public/nsIMsgPurgeService.idl
 */

#ifndef __gen_nsIMsgPurgeService_h__
#define __gen_nsIMsgPurgeService_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIMsgPurgeService */
#define NS_IMSGPURGESERVICE_IID_STR "c73294b2-b619-4915-b0e8-314d4215e08d"

#define NS_IMSGPURGESERVICE_IID \
  {0xc73294b2, 0xb619, 0x4915, \
    { 0xb0, 0xe8, 0x31, 0x4d, 0x42, 0x15, 0xe0, 0x8d }}

class NS_NO_VTABLE nsIMsgPurgeService : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IMSGPURGESERVICE_IID)

  /* void init (); */
  NS_IMETHOD Init(void) = 0;

  /* void shutdown (); */
  NS_IMETHOD Shutdown(void) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIMsgPurgeService, NS_IMSGPURGESERVICE_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGPURGESERVICE \
  NS_IMETHOD Init(void); \
  NS_IMETHOD Shutdown(void); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGPURGESERVICE(_to) \
  NS_IMETHOD Init(void) { return _to Init(); } \
  NS_IMETHOD Shutdown(void) { return _to Shutdown(); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGPURGESERVICE(_to) \
  NS_IMETHOD Init(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->Init(); } \
  NS_IMETHOD Shutdown(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->Shutdown(); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgPurgeService : public nsIMsgPurgeService
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGPURGESERVICE

  nsMsgPurgeService();

private:
  ~nsMsgPurgeService();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgPurgeService, nsIMsgPurgeService)

nsMsgPurgeService::nsMsgPurgeService()
{
  /* member initializers and constructor code */
}

nsMsgPurgeService::~nsMsgPurgeService()
{
  /* destructor code */
}

/* void init (); */
NS_IMETHODIMP nsMsgPurgeService::Init()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void shutdown (); */
NS_IMETHODIMP nsMsgPurgeService::Shutdown()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgPurgeService_h__ */
