/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/ldap/xpcom/public/nsILDAPControl.idl
 */

#ifndef __gen_nsILDAPControl_h__
#define __gen_nsILDAPControl_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsILDAPBERValue; /* forward declaration */


/* starting interface:    nsILDAPControl */
#define NS_ILDAPCONTROL_IID_STR "3a7ceb8e-482a-4a4f-9aa4-26b9a69a3595"

#define NS_ILDAPCONTROL_IID \
  {0x3a7ceb8e, 0x482a, 0x4a4f, \
    { 0x9a, 0xa4, 0x26, 0xb9, 0xa6, 0x9a, 0x35, 0x95 }}

class NS_NO_VTABLE nsILDAPControl : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_ILDAPCONTROL_IID)

  /* attribute ACString oid; */
  NS_IMETHOD GetOid(nsACString & aOid) = 0;
  NS_IMETHOD SetOid(const nsACString & aOid) = 0;

  /* attribute nsILDAPBERValue value; */
  NS_IMETHOD GetValue(nsILDAPBERValue * *aValue) = 0;
  NS_IMETHOD SetValue(nsILDAPBERValue *aValue) = 0;

  /* attribute boolean isCritical; */
  NS_IMETHOD GetIsCritical(bool *aIsCritical) = 0;
  NS_IMETHOD SetIsCritical(bool aIsCritical) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsILDAPControl, NS_ILDAPCONTROL_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSILDAPCONTROL \
  NS_IMETHOD GetOid(nsACString & aOid); \
  NS_IMETHOD SetOid(const nsACString & aOid); \
  NS_IMETHOD GetValue(nsILDAPBERValue * *aValue); \
  NS_IMETHOD SetValue(nsILDAPBERValue *aValue); \
  NS_IMETHOD GetIsCritical(bool *aIsCritical); \
  NS_IMETHOD SetIsCritical(bool aIsCritical); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSILDAPCONTROL(_to) \
  NS_IMETHOD GetOid(nsACString & aOid) { return _to GetOid(aOid); } \
  NS_IMETHOD SetOid(const nsACString & aOid) { return _to SetOid(aOid); } \
  NS_IMETHOD GetValue(nsILDAPBERValue * *aValue) { return _to GetValue(aValue); } \
  NS_IMETHOD SetValue(nsILDAPBERValue *aValue) { return _to SetValue(aValue); } \
  NS_IMETHOD GetIsCritical(bool *aIsCritical) { return _to GetIsCritical(aIsCritical); } \
  NS_IMETHOD SetIsCritical(bool aIsCritical) { return _to SetIsCritical(aIsCritical); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSILDAPCONTROL(_to) \
  NS_IMETHOD GetOid(nsACString & aOid) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetOid(aOid); } \
  NS_IMETHOD SetOid(const nsACString & aOid) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetOid(aOid); } \
  NS_IMETHOD GetValue(nsILDAPBERValue * *aValue) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetValue(aValue); } \
  NS_IMETHOD SetValue(nsILDAPBERValue *aValue) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetValue(aValue); } \
  NS_IMETHOD GetIsCritical(bool *aIsCritical) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetIsCritical(aIsCritical); } \
  NS_IMETHOD SetIsCritical(bool aIsCritical) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetIsCritical(aIsCritical); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsLDAPControl : public nsILDAPControl
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSILDAPCONTROL

  nsLDAPControl();

private:
  ~nsLDAPControl();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsLDAPControl, nsILDAPControl)

nsLDAPControl::nsLDAPControl()
{
  /* member initializers and constructor code */
}

nsLDAPControl::~nsLDAPControl()
{
  /* destructor code */
}

/* attribute ACString oid; */
NS_IMETHODIMP nsLDAPControl::GetOid(nsACString & aOid)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsLDAPControl::SetOid(const nsACString & aOid)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsILDAPBERValue value; */
NS_IMETHODIMP nsLDAPControl::GetValue(nsILDAPBERValue * *aValue)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsLDAPControl::SetValue(nsILDAPBERValue *aValue)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean isCritical; */
NS_IMETHODIMP nsLDAPControl::GetIsCritical(bool *aIsCritical)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsLDAPControl::SetIsCritical(bool aIsCritical)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsILDAPControl_h__ */
