/* -*- Mode: C++; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* vim: set ts=2 et sw=2 tw=80: */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"

interface nsIIDBObjectStore;
interface nsIIDBRequest;
interface nsIIDBTransaction;
interface nsIDOMDOMStringList;
interface nsIDOMEventListener;

dictionary IDBObjectStoreParameters
{
  jsval keyPath;
  boolean autoIncrement;
};

/**
 * IDBDatabase interface.  See
 * http://dvcs.w3.org/hg/IndexedDB/raw-file/tip/Overview.html#idl-def-IDBDatabase
 * for more information.
 */
[scriptable, builtinclass, uuid(601a43a0-dce2-402f-8ba5-238fe5d5f8d2)]
interface nsIIDBDatabase : nsISupports
{
  readonly attribute DOMString name;

  readonly attribute unsigned long long version;

  readonly attribute nsIDOMDOMStringList objectStoreNames;

  [implicit_jscontext]
  nsIIDBObjectStore
  createObjectStore([Null(Stringify)] in DOMString name,
                    /* IDBObjectStoreParameters */
                    [optional /* none */] in jsval options);

  void
  deleteObjectStore([Null(Stringify)] in DOMString name);

  // mode can be either "readonly" or "readwrite"
  [optional_argc, implicit_jscontext]
  nsIIDBTransaction
  transaction(in jsval storeNames, // js array of strings
              [optional /* "readonly" */] in DOMString mode);

  [implicit_jscontext]
  nsIIDBRequest
  mozCreateFileHandle(in DOMString name,
                      [optional] in DOMString type);

  void
  close();

  attribute nsIDOMEventListener onabort;

  attribute nsIDOMEventListener onerror;

  attribute nsIDOMEventListener onversionchange;
};
