/* -*- Mode: IDL; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"

interface nsIURI;
interface nsIMsgWindow;
interface nsIUrlListener;
interface nsIMsgFolder;
interface nsIFile;

[scriptable, uuid(e710d72c-9328-4bcb-8b8f-dd7ac18e2156)]
interface nsILocalMailIncomingServer : nsISupports 
{
  void createDefaultMailboxes(in nsIFile aPath);
  void setFlagsOnDefaultMailboxes();
  nsIURI getNewMail(in nsIMsgWindow aMsgWindow, in nsIUrlListener aUrlListener, in nsIMsgFolder aInbox);
};

