/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "domstubs.idl"

[scriptable, uuid(18967370-921a-4245-8158-a279b190abca)]
interface nsIDOMSVGZoomAndPan : nsISupports
{ 
    // Zoom and Pan Types
    const unsigned short SVG_ZOOMANDPAN_UNKNOWN = 0;
    const unsigned short SVG_ZOOMANDPAN_DISABLE = 1;
    const unsigned short SVG_ZOOMANDPAN_MAGNIFY = 2;

    attribute unsigned short zoomAndPan;
       // raises DOMException on setting
};
