/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

/*

  Interface for importing mail - ui provided by the import module.  If
  you wish to provide your own UI then implement the nsIImportGeneric
  interface.

 */

#include "nsISupports.idl"

interface nsIFile;

[scriptable, uuid(69eba744-9c4f-4f79-a964-2134746b3656)]
interface nsIImportMailboxDescriptor : nsISupports
{
  attribute unsigned long identifier;
  attribute unsigned long  depth;
  attribute unsigned long  size;

  wstring  GetDisplayName();
  void  SetDisplayName( [const] in wstring name);

  attribute boolean import;
  readonly attribute nsIFile file;
};



%{ C++

/*
  The default implementation can be obtained from
  nsIImportService::CreateNewMailboxDescriptor();

  You should only be interested in using this class if you implement
  the nsIImportMail interface in which case, just using the service to
  create new ones should work fine for you.  If not, implement your
  own.
*/

%}
