/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this file,
 * You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"

[scriptable, uuid(217ddd76-75db-4210-955d-8806cd8d87f9)]
interface nsIMmsService : nsISupports
{
  boolean        hasSupport();
};
