/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/imap/public/nsIMailboxSpec.idl
 */

#ifndef __gen_nsIMailboxSpec_h__
#define __gen_nsIMailboxSpec_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsIImapFlagAndUidState_h__
#include "nsIImapFlagAndUidState.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIMAPNamespace; /* forward declaration */


/* starting interface:    nsIMailboxSpec */
#define NS_IMAILBOXSPEC_IID_STR "a9fbbc80-5291-4ed8-a7f7-c2fcad231269"

#define NS_IMAILBOXSPEC_IID \
  {0xa9fbbc80, 0x5291, 0x4ed8, \
    { 0xa7, 0xf7, 0xc2, 0xfc, 0xad, 0x23, 0x12, 0x69 }}

class NS_NO_VTABLE nsIMailboxSpec : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IMAILBOXSPEC_IID)

  /* attribute long folder_UIDVALIDITY; */
  NS_IMETHOD GetFolder_UIDVALIDITY(int32_t *aFolder_UIDVALIDITY) = 0;
  NS_IMETHOD SetFolder_UIDVALIDITY(int32_t aFolder_UIDVALIDITY) = 0;

  /* attribute unsigned long long highestModSeq; */
  NS_IMETHOD GetHighestModSeq(uint64_t *aHighestModSeq) = 0;
  NS_IMETHOD SetHighestModSeq(uint64_t aHighestModSeq) = 0;

  /* attribute long numMessages; */
  NS_IMETHOD GetNumMessages(int32_t *aNumMessages) = 0;
  NS_IMETHOD SetNumMessages(int32_t aNumMessages) = 0;

  /* attribute long numUnseenMessages; */
  NS_IMETHOD GetNumUnseenMessages(int32_t *aNumUnseenMessages) = 0;
  NS_IMETHOD SetNumUnseenMessages(int32_t aNumUnseenMessages) = 0;

  /* attribute long numRecentMessages; */
  NS_IMETHOD GetNumRecentMessages(int32_t *aNumRecentMessages) = 0;
  NS_IMETHOD SetNumRecentMessages(int32_t aNumRecentMessages) = 0;

  /* attribute long nextUID; */
  NS_IMETHOD GetNextUID(int32_t *aNextUID) = 0;
  NS_IMETHOD SetNextUID(int32_t aNextUID) = 0;

  /* attribute unsigned long box_flags; */
  NS_IMETHOD GetBox_flags(uint32_t *aBox_flags) = 0;
  NS_IMETHOD SetBox_flags(uint32_t aBox_flags) = 0;

  /* attribute unsigned long supportedUserFlags; */
  NS_IMETHOD GetSupportedUserFlags(uint32_t *aSupportedUserFlags) = 0;
  NS_IMETHOD SetSupportedUserFlags(uint32_t aSupportedUserFlags) = 0;

  /* attribute ACString allocatedPathName; */
  NS_IMETHOD GetAllocatedPathName(nsACString & aAllocatedPathName) = 0;
  NS_IMETHOD SetAllocatedPathName(const nsACString & aAllocatedPathName) = 0;

  /* attribute AString unicharPathName; */
  NS_IMETHOD GetUnicharPathName(nsAString & aUnicharPathName) = 0;
  NS_IMETHOD SetUnicharPathName(const nsAString & aUnicharPathName) = 0;

  /* attribute char hierarchyDelimiter; */
  NS_IMETHOD GetHierarchyDelimiter(char *aHierarchyDelimiter) = 0;
  NS_IMETHOD SetHierarchyDelimiter(char aHierarchyDelimiter) = 0;

  /* attribute ACString hostName; */
  NS_IMETHOD GetHostName(nsACString & aHostName) = 0;
  NS_IMETHOD SetHostName(const nsACString & aHostName) = 0;

  /* attribute nsIImapFlagAndUidState flagState; */
  NS_IMETHOD GetFlagState(nsIImapFlagAndUidState * *aFlagState) = 0;
  NS_IMETHOD SetFlagState(nsIImapFlagAndUidState *aFlagState) = 0;

  /* attribute boolean folderSelected; */
  NS_IMETHOD GetFolderSelected(bool *aFolderSelected) = 0;
  NS_IMETHOD SetFolderSelected(bool aFolderSelected) = 0;

  /* attribute boolean discoveredFromLsub; */
  NS_IMETHOD GetDiscoveredFromLsub(bool *aDiscoveredFromLsub) = 0;
  NS_IMETHOD SetDiscoveredFromLsub(bool aDiscoveredFromLsub) = 0;

  /* attribute boolean onlineVerified; */
  NS_IMETHOD GetOnlineVerified(bool *aOnlineVerified) = 0;
  NS_IMETHOD SetOnlineVerified(bool aOnlineVerified) = 0;

  /* [noscript] attribute nsIMAPNamespace namespaceForFolder; */
  NS_IMETHOD GetNamespaceForFolder(nsIMAPNamespace * *aNamespaceForFolder) = 0;
  NS_IMETHOD SetNamespaceForFolder(nsIMAPNamespace *aNamespaceForFolder) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIMailboxSpec, NS_IMAILBOXSPEC_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMAILBOXSPEC \
  NS_IMETHOD GetFolder_UIDVALIDITY(int32_t *aFolder_UIDVALIDITY); \
  NS_IMETHOD SetFolder_UIDVALIDITY(int32_t aFolder_UIDVALIDITY); \
  NS_IMETHOD GetHighestModSeq(uint64_t *aHighestModSeq); \
  NS_IMETHOD SetHighestModSeq(uint64_t aHighestModSeq); \
  NS_IMETHOD GetNumMessages(int32_t *aNumMessages); \
  NS_IMETHOD SetNumMessages(int32_t aNumMessages); \
  NS_IMETHOD GetNumUnseenMessages(int32_t *aNumUnseenMessages); \
  NS_IMETHOD SetNumUnseenMessages(int32_t aNumUnseenMessages); \
  NS_IMETHOD GetNumRecentMessages(int32_t *aNumRecentMessages); \
  NS_IMETHOD SetNumRecentMessages(int32_t aNumRecentMessages); \
  NS_IMETHOD GetNextUID(int32_t *aNextUID); \
  NS_IMETHOD SetNextUID(int32_t aNextUID); \
  NS_IMETHOD GetBox_flags(uint32_t *aBox_flags); \
  NS_IMETHOD SetBox_flags(uint32_t aBox_flags); \
  NS_IMETHOD GetSupportedUserFlags(uint32_t *aSupportedUserFlags); \
  NS_IMETHOD SetSupportedUserFlags(uint32_t aSupportedUserFlags); \
  NS_IMETHOD GetAllocatedPathName(nsACString & aAllocatedPathName); \
  NS_IMETHOD SetAllocatedPathName(const nsACString & aAllocatedPathName); \
  NS_IMETHOD GetUnicharPathName(nsAString & aUnicharPathName); \
  NS_IMETHOD SetUnicharPathName(const nsAString & aUnicharPathName); \
  NS_IMETHOD GetHierarchyDelimiter(char *aHierarchyDelimiter); \
  NS_IMETHOD SetHierarchyDelimiter(char aHierarchyDelimiter); \
  NS_IMETHOD GetHostName(nsACString & aHostName); \
  NS_IMETHOD SetHostName(const nsACString & aHostName); \
  NS_IMETHOD GetFlagState(nsIImapFlagAndUidState * *aFlagState); \
  NS_IMETHOD SetFlagState(nsIImapFlagAndUidState *aFlagState); \
  NS_IMETHOD GetFolderSelected(bool *aFolderSelected); \
  NS_IMETHOD SetFolderSelected(bool aFolderSelected); \
  NS_IMETHOD GetDiscoveredFromLsub(bool *aDiscoveredFromLsub); \
  NS_IMETHOD SetDiscoveredFromLsub(bool aDiscoveredFromLsub); \
  NS_IMETHOD GetOnlineVerified(bool *aOnlineVerified); \
  NS_IMETHOD SetOnlineVerified(bool aOnlineVerified); \
  NS_IMETHOD GetNamespaceForFolder(nsIMAPNamespace * *aNamespaceForFolder); \
  NS_IMETHOD SetNamespaceForFolder(nsIMAPNamespace *aNamespaceForFolder); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMAILBOXSPEC(_to) \
  NS_IMETHOD GetFolder_UIDVALIDITY(int32_t *aFolder_UIDVALIDITY) { return _to GetFolder_UIDVALIDITY(aFolder_UIDVALIDITY); } \
  NS_IMETHOD SetFolder_UIDVALIDITY(int32_t aFolder_UIDVALIDITY) { return _to SetFolder_UIDVALIDITY(aFolder_UIDVALIDITY); } \
  NS_IMETHOD GetHighestModSeq(uint64_t *aHighestModSeq) { return _to GetHighestModSeq(aHighestModSeq); } \
  NS_IMETHOD SetHighestModSeq(uint64_t aHighestModSeq) { return _to SetHighestModSeq(aHighestModSeq); } \
  NS_IMETHOD GetNumMessages(int32_t *aNumMessages) { return _to GetNumMessages(aNumMessages); } \
  NS_IMETHOD SetNumMessages(int32_t aNumMessages) { return _to SetNumMessages(aNumMessages); } \
  NS_IMETHOD GetNumUnseenMessages(int32_t *aNumUnseenMessages) { return _to GetNumUnseenMessages(aNumUnseenMessages); } \
  NS_IMETHOD SetNumUnseenMessages(int32_t aNumUnseenMessages) { return _to SetNumUnseenMessages(aNumUnseenMessages); } \
  NS_IMETHOD GetNumRecentMessages(int32_t *aNumRecentMessages) { return _to GetNumRecentMessages(aNumRecentMessages); } \
  NS_IMETHOD SetNumRecentMessages(int32_t aNumRecentMessages) { return _to SetNumRecentMessages(aNumRecentMessages); } \
  NS_IMETHOD GetNextUID(int32_t *aNextUID) { return _to GetNextUID(aNextUID); } \
  NS_IMETHOD SetNextUID(int32_t aNextUID) { return _to SetNextUID(aNextUID); } \
  NS_IMETHOD GetBox_flags(uint32_t *aBox_flags) { return _to GetBox_flags(aBox_flags); } \
  NS_IMETHOD SetBox_flags(uint32_t aBox_flags) { return _to SetBox_flags(aBox_flags); } \
  NS_IMETHOD GetSupportedUserFlags(uint32_t *aSupportedUserFlags) { return _to GetSupportedUserFlags(aSupportedUserFlags); } \
  NS_IMETHOD SetSupportedUserFlags(uint32_t aSupportedUserFlags) { return _to SetSupportedUserFlags(aSupportedUserFlags); } \
  NS_IMETHOD GetAllocatedPathName(nsACString & aAllocatedPathName) { return _to GetAllocatedPathName(aAllocatedPathName); } \
  NS_IMETHOD SetAllocatedPathName(const nsACString & aAllocatedPathName) { return _to SetAllocatedPathName(aAllocatedPathName); } \
  NS_IMETHOD GetUnicharPathName(nsAString & aUnicharPathName) { return _to GetUnicharPathName(aUnicharPathName); } \
  NS_IMETHOD SetUnicharPathName(const nsAString & aUnicharPathName) { return _to SetUnicharPathName(aUnicharPathName); } \
  NS_IMETHOD GetHierarchyDelimiter(char *aHierarchyDelimiter) { return _to GetHierarchyDelimiter(aHierarchyDelimiter); } \
  NS_IMETHOD SetHierarchyDelimiter(char aHierarchyDelimiter) { return _to SetHierarchyDelimiter(aHierarchyDelimiter); } \
  NS_IMETHOD GetHostName(nsACString & aHostName) { return _to GetHostName(aHostName); } \
  NS_IMETHOD SetHostName(const nsACString & aHostName) { return _to SetHostName(aHostName); } \
  NS_IMETHOD GetFlagState(nsIImapFlagAndUidState * *aFlagState) { return _to GetFlagState(aFlagState); } \
  NS_IMETHOD SetFlagState(nsIImapFlagAndUidState *aFlagState) { return _to SetFlagState(aFlagState); } \
  NS_IMETHOD GetFolderSelected(bool *aFolderSelected) { return _to GetFolderSelected(aFolderSelected); } \
  NS_IMETHOD SetFolderSelected(bool aFolderSelected) { return _to SetFolderSelected(aFolderSelected); } \
  NS_IMETHOD GetDiscoveredFromLsub(bool *aDiscoveredFromLsub) { return _to GetDiscoveredFromLsub(aDiscoveredFromLsub); } \
  NS_IMETHOD SetDiscoveredFromLsub(bool aDiscoveredFromLsub) { return _to SetDiscoveredFromLsub(aDiscoveredFromLsub); } \
  NS_IMETHOD GetOnlineVerified(bool *aOnlineVerified) { return _to GetOnlineVerified(aOnlineVerified); } \
  NS_IMETHOD SetOnlineVerified(bool aOnlineVerified) { return _to SetOnlineVerified(aOnlineVerified); } \
  NS_IMETHOD GetNamespaceForFolder(nsIMAPNamespace * *aNamespaceForFolder) { return _to GetNamespaceForFolder(aNamespaceForFolder); } \
  NS_IMETHOD SetNamespaceForFolder(nsIMAPNamespace *aNamespaceForFolder) { return _to SetNamespaceForFolder(aNamespaceForFolder); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMAILBOXSPEC(_to) \
  NS_IMETHOD GetFolder_UIDVALIDITY(int32_t *aFolder_UIDVALIDITY) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFolder_UIDVALIDITY(aFolder_UIDVALIDITY); } \
  NS_IMETHOD SetFolder_UIDVALIDITY(int32_t aFolder_UIDVALIDITY) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetFolder_UIDVALIDITY(aFolder_UIDVALIDITY); } \
  NS_IMETHOD GetHighestModSeq(uint64_t *aHighestModSeq) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetHighestModSeq(aHighestModSeq); } \
  NS_IMETHOD SetHighestModSeq(uint64_t aHighestModSeq) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetHighestModSeq(aHighestModSeq); } \
  NS_IMETHOD GetNumMessages(int32_t *aNumMessages) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNumMessages(aNumMessages); } \
  NS_IMETHOD SetNumMessages(int32_t aNumMessages) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetNumMessages(aNumMessages); } \
  NS_IMETHOD GetNumUnseenMessages(int32_t *aNumUnseenMessages) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNumUnseenMessages(aNumUnseenMessages); } \
  NS_IMETHOD SetNumUnseenMessages(int32_t aNumUnseenMessages) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetNumUnseenMessages(aNumUnseenMessages); } \
  NS_IMETHOD GetNumRecentMessages(int32_t *aNumRecentMessages) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNumRecentMessages(aNumRecentMessages); } \
  NS_IMETHOD SetNumRecentMessages(int32_t aNumRecentMessages) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetNumRecentMessages(aNumRecentMessages); } \
  NS_IMETHOD GetNextUID(int32_t *aNextUID) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNextUID(aNextUID); } \
  NS_IMETHOD SetNextUID(int32_t aNextUID) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetNextUID(aNextUID); } \
  NS_IMETHOD GetBox_flags(uint32_t *aBox_flags) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetBox_flags(aBox_flags); } \
  NS_IMETHOD SetBox_flags(uint32_t aBox_flags) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetBox_flags(aBox_flags); } \
  NS_IMETHOD GetSupportedUserFlags(uint32_t *aSupportedUserFlags) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSupportedUserFlags(aSupportedUserFlags); } \
  NS_IMETHOD SetSupportedUserFlags(uint32_t aSupportedUserFlags) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetSupportedUserFlags(aSupportedUserFlags); } \
  NS_IMETHOD GetAllocatedPathName(nsACString & aAllocatedPathName) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetAllocatedPathName(aAllocatedPathName); } \
  NS_IMETHOD SetAllocatedPathName(const nsACString & aAllocatedPathName) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetAllocatedPathName(aAllocatedPathName); } \
  NS_IMETHOD GetUnicharPathName(nsAString & aUnicharPathName) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetUnicharPathName(aUnicharPathName); } \
  NS_IMETHOD SetUnicharPathName(const nsAString & aUnicharPathName) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetUnicharPathName(aUnicharPathName); } \
  NS_IMETHOD GetHierarchyDelimiter(char *aHierarchyDelimiter) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetHierarchyDelimiter(aHierarchyDelimiter); } \
  NS_IMETHOD SetHierarchyDelimiter(char aHierarchyDelimiter) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetHierarchyDelimiter(aHierarchyDelimiter); } \
  NS_IMETHOD GetHostName(nsACString & aHostName) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetHostName(aHostName); } \
  NS_IMETHOD SetHostName(const nsACString & aHostName) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetHostName(aHostName); } \
  NS_IMETHOD GetFlagState(nsIImapFlagAndUidState * *aFlagState) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFlagState(aFlagState); } \
  NS_IMETHOD SetFlagState(nsIImapFlagAndUidState *aFlagState) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetFlagState(aFlagState); } \
  NS_IMETHOD GetFolderSelected(bool *aFolderSelected) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFolderSelected(aFolderSelected); } \
  NS_IMETHOD SetFolderSelected(bool aFolderSelected) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetFolderSelected(aFolderSelected); } \
  NS_IMETHOD GetDiscoveredFromLsub(bool *aDiscoveredFromLsub) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDiscoveredFromLsub(aDiscoveredFromLsub); } \
  NS_IMETHOD SetDiscoveredFromLsub(bool aDiscoveredFromLsub) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetDiscoveredFromLsub(aDiscoveredFromLsub); } \
  NS_IMETHOD GetOnlineVerified(bool *aOnlineVerified) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetOnlineVerified(aOnlineVerified); } \
  NS_IMETHOD SetOnlineVerified(bool aOnlineVerified) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetOnlineVerified(aOnlineVerified); } \
  NS_IMETHOD GetNamespaceForFolder(nsIMAPNamespace * *aNamespaceForFolder) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNamespaceForFolder(aNamespaceForFolder); } \
  NS_IMETHOD SetNamespaceForFolder(nsIMAPNamespace *aNamespaceForFolder) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetNamespaceForFolder(aNamespaceForFolder); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMailboxSpec : public nsIMailboxSpec
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMAILBOXSPEC

  nsMailboxSpec();

private:
  ~nsMailboxSpec();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMailboxSpec, nsIMailboxSpec)

nsMailboxSpec::nsMailboxSpec()
{
  /* member initializers and constructor code */
}

nsMailboxSpec::~nsMailboxSpec()
{
  /* destructor code */
}

/* attribute long folder_UIDVALIDITY; */
NS_IMETHODIMP nsMailboxSpec::GetFolder_UIDVALIDITY(int32_t *aFolder_UIDVALIDITY)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMailboxSpec::SetFolder_UIDVALIDITY(int32_t aFolder_UIDVALIDITY)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute unsigned long long highestModSeq; */
NS_IMETHODIMP nsMailboxSpec::GetHighestModSeq(uint64_t *aHighestModSeq)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMailboxSpec::SetHighestModSeq(uint64_t aHighestModSeq)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute long numMessages; */
NS_IMETHODIMP nsMailboxSpec::GetNumMessages(int32_t *aNumMessages)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMailboxSpec::SetNumMessages(int32_t aNumMessages)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute long numUnseenMessages; */
NS_IMETHODIMP nsMailboxSpec::GetNumUnseenMessages(int32_t *aNumUnseenMessages)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMailboxSpec::SetNumUnseenMessages(int32_t aNumUnseenMessages)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute long numRecentMessages; */
NS_IMETHODIMP nsMailboxSpec::GetNumRecentMessages(int32_t *aNumRecentMessages)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMailboxSpec::SetNumRecentMessages(int32_t aNumRecentMessages)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute long nextUID; */
NS_IMETHODIMP nsMailboxSpec::GetNextUID(int32_t *aNextUID)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMailboxSpec::SetNextUID(int32_t aNextUID)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute unsigned long box_flags; */
NS_IMETHODIMP nsMailboxSpec::GetBox_flags(uint32_t *aBox_flags)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMailboxSpec::SetBox_flags(uint32_t aBox_flags)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute unsigned long supportedUserFlags; */
NS_IMETHODIMP nsMailboxSpec::GetSupportedUserFlags(uint32_t *aSupportedUserFlags)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMailboxSpec::SetSupportedUserFlags(uint32_t aSupportedUserFlags)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute ACString allocatedPathName; */
NS_IMETHODIMP nsMailboxSpec::GetAllocatedPathName(nsACString & aAllocatedPathName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMailboxSpec::SetAllocatedPathName(const nsACString & aAllocatedPathName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute AString unicharPathName; */
NS_IMETHODIMP nsMailboxSpec::GetUnicharPathName(nsAString & aUnicharPathName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMailboxSpec::SetUnicharPathName(const nsAString & aUnicharPathName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute char hierarchyDelimiter; */
NS_IMETHODIMP nsMailboxSpec::GetHierarchyDelimiter(char *aHierarchyDelimiter)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMailboxSpec::SetHierarchyDelimiter(char aHierarchyDelimiter)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute ACString hostName; */
NS_IMETHODIMP nsMailboxSpec::GetHostName(nsACString & aHostName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMailboxSpec::SetHostName(const nsACString & aHostName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsIImapFlagAndUidState flagState; */
NS_IMETHODIMP nsMailboxSpec::GetFlagState(nsIImapFlagAndUidState * *aFlagState)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMailboxSpec::SetFlagState(nsIImapFlagAndUidState *aFlagState)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean folderSelected; */
NS_IMETHODIMP nsMailboxSpec::GetFolderSelected(bool *aFolderSelected)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMailboxSpec::SetFolderSelected(bool aFolderSelected)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean discoveredFromLsub; */
NS_IMETHODIMP nsMailboxSpec::GetDiscoveredFromLsub(bool *aDiscoveredFromLsub)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMailboxSpec::SetDiscoveredFromLsub(bool aDiscoveredFromLsub)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean onlineVerified; */
NS_IMETHODIMP nsMailboxSpec::GetOnlineVerified(bool *aOnlineVerified)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMailboxSpec::SetOnlineVerified(bool aOnlineVerified)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [noscript] attribute nsIMAPNamespace namespaceForFolder; */
NS_IMETHODIMP nsMailboxSpec::GetNamespaceForFolder(nsIMAPNamespace * *aNamespaceForFolder)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMailboxSpec::SetNamespaceForFolder(nsIMAPNamespace *aNamespaceForFolder)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMailboxSpec_h__ */
