/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/addrbook/public/nsIAbLDAPReplicationService.idl
 */

#ifndef __gen_nsIAbLDAPReplicationService_h__
#define __gen_nsIAbLDAPReplicationService_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIWebProgressListener; /* forward declaration */

class nsIAbLDAPDirectory; /* forward declaration */


/* starting interface:    nsIAbLDAPReplicationService */
#define NS_IABLDAPREPLICATIONSERVICE_IID_STR "3f499c70-5ceb-4b91-8b7f-62c366859383"

#define NS_IABLDAPREPLICATIONSERVICE_IID \
  {0x3f499c70, 0x5ceb, 0x4b91, \
    { 0x8b, 0x7f, 0x62, 0xc3, 0x66, 0x85, 0x93, 0x83 }}

class NS_NO_VTABLE nsIAbLDAPReplicationService : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IABLDAPREPLICATIONSERVICE_IID)

  /* void startReplication (in nsIAbLDAPDirectory aDirectory, in nsIWebProgressListener progressListener); */
  NS_IMETHOD StartReplication(nsIAbLDAPDirectory *aDirectory, nsIWebProgressListener *progressListener) = 0;

  /* void cancelReplication (in nsIAbLDAPDirectory aDirectory); */
  NS_IMETHOD CancelReplication(nsIAbLDAPDirectory *aDirectory) = 0;

  /* void done (in boolean aSuccess); */
  NS_IMETHOD Done(bool aSuccess) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIAbLDAPReplicationService, NS_IABLDAPREPLICATIONSERVICE_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIABLDAPREPLICATIONSERVICE \
  NS_IMETHOD StartReplication(nsIAbLDAPDirectory *aDirectory, nsIWebProgressListener *progressListener); \
  NS_IMETHOD CancelReplication(nsIAbLDAPDirectory *aDirectory); \
  NS_IMETHOD Done(bool aSuccess); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIABLDAPREPLICATIONSERVICE(_to) \
  NS_IMETHOD StartReplication(nsIAbLDAPDirectory *aDirectory, nsIWebProgressListener *progressListener) { return _to StartReplication(aDirectory, progressListener); } \
  NS_IMETHOD CancelReplication(nsIAbLDAPDirectory *aDirectory) { return _to CancelReplication(aDirectory); } \
  NS_IMETHOD Done(bool aSuccess) { return _to Done(aSuccess); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIABLDAPREPLICATIONSERVICE(_to) \
  NS_IMETHOD StartReplication(nsIAbLDAPDirectory *aDirectory, nsIWebProgressListener *progressListener) { return !_to ? NS_ERROR_NULL_POINTER : _to->StartReplication(aDirectory, progressListener); } \
  NS_IMETHOD CancelReplication(nsIAbLDAPDirectory *aDirectory) { return !_to ? NS_ERROR_NULL_POINTER : _to->CancelReplication(aDirectory); } \
  NS_IMETHOD Done(bool aSuccess) { return !_to ? NS_ERROR_NULL_POINTER : _to->Done(aSuccess); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsAbLDAPReplicationService : public nsIAbLDAPReplicationService
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIABLDAPREPLICATIONSERVICE

  nsAbLDAPReplicationService();

private:
  ~nsAbLDAPReplicationService();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsAbLDAPReplicationService, nsIAbLDAPReplicationService)

nsAbLDAPReplicationService::nsAbLDAPReplicationService()
{
  /* member initializers and constructor code */
}

nsAbLDAPReplicationService::~nsAbLDAPReplicationService()
{
  /* destructor code */
}

/* void startReplication (in nsIAbLDAPDirectory aDirectory, in nsIWebProgressListener progressListener); */
NS_IMETHODIMP nsAbLDAPReplicationService::StartReplication(nsIAbLDAPDirectory *aDirectory, nsIWebProgressListener *progressListener)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void cancelReplication (in nsIAbLDAPDirectory aDirectory); */
NS_IMETHODIMP nsAbLDAPReplicationService::CancelReplication(nsIAbLDAPDirectory *aDirectory)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void done (in boolean aSuccess); */
NS_IMETHODIMP nsAbLDAPReplicationService::Done(bool aSuccess)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIAbLDAPReplicationService_h__ */
