/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/db/msgdb/public/nsIDBFolderInfo.idl
 */

#ifndef __gen_nsIDBFolderInfo_h__
#define __gen_nsIDBFolderInfo_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_MailNewsTypes2_h__
#include "MailNewsTypes2.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIDBFolderInfo */
#define NS_IDBFOLDERINFO_IID_STR "538577e4-80e9-4567-8de1-3578efaef62d"

#define NS_IDBFOLDERINFO_IID \
  {0x538577e4, 0x80e9, 0x4567, \
    { 0x8d, 0xe1, 0x35, 0x78, 0xef, 0xae, 0xf6, 0x2d }}

class NS_NO_VTABLE nsIDBFolderInfo : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IDBFOLDERINFO_IID)

  /* attribute long flags; */
  NS_IMETHOD GetFlags(int32_t *aFlags) = 0;
  NS_IMETHOD SetFlags(int32_t aFlags) = 0;

  /* long orFlags (in long aFlags); */
  NS_IMETHOD OrFlags(int32_t aFlags, int32_t *_retval) = 0;

  /* long andFlags (in long aFlags); */
  NS_IMETHOD AndFlags(int32_t aFlags, int32_t *_retval) = 0;

  /* void onKeyAdded (in nsMsgKey aNewKey); */
  NS_IMETHOD OnKeyAdded(nsMsgKey aNewKey) = 0;

  /* attribute nsMsgKey highWater; */
  NS_IMETHOD GetHighWater(nsMsgKey *aHighWater) = 0;
  NS_IMETHOD SetHighWater(nsMsgKey aHighWater) = 0;

  /* attribute nsMsgKey expiredMark; */
  NS_IMETHOD GetExpiredMark(nsMsgKey *aExpiredMark) = 0;
  NS_IMETHOD SetExpiredMark(nsMsgKey aExpiredMark) = 0;

  /* attribute unsigned long long folderSize; */
  NS_IMETHOD GetFolderSize(uint64_t *aFolderSize) = 0;
  NS_IMETHOD SetFolderSize(uint64_t aFolderSize) = 0;

  /* attribute unsigned long folderDate; */
  NS_IMETHOD GetFolderDate(uint32_t *aFolderDate) = 0;
  NS_IMETHOD SetFolderDate(uint32_t aFolderDate) = 0;

  /* void changeNumUnreadMessages (in long aDelta); */
  NS_IMETHOD ChangeNumUnreadMessages(int32_t aDelta) = 0;

  /* void changeNumMessages (in long aDelta); */
  NS_IMETHOD ChangeNumMessages(int32_t aDelta) = 0;

  /* attribute long numUnreadMessages; */
  NS_IMETHOD GetNumUnreadMessages(int32_t *aNumUnreadMessages) = 0;
  NS_IMETHOD SetNumUnreadMessages(int32_t aNumUnreadMessages) = 0;

  /* attribute long numMessages; */
  NS_IMETHOD GetNumMessages(int32_t *aNumMessages) = 0;
  NS_IMETHOD SetNumMessages(int32_t aNumMessages) = 0;

  /* attribute long expungedBytes; */
  NS_IMETHOD GetExpungedBytes(int32_t *aExpungedBytes) = 0;
  NS_IMETHOD SetExpungedBytes(int32_t aExpungedBytes) = 0;

  /* attribute long imapUidValidity; */
  NS_IMETHOD GetImapUidValidity(int32_t *aImapUidValidity) = 0;
  NS_IMETHOD SetImapUidValidity(int32_t aImapUidValidity) = 0;

  /* attribute unsigned long version; */
  NS_IMETHOD GetVersion(uint32_t *aVersion) = 0;
  NS_IMETHOD SetVersion(uint32_t aVersion) = 0;

  /* attribute long imapTotalPendingMessages; */
  NS_IMETHOD GetImapTotalPendingMessages(int32_t *aImapTotalPendingMessages) = 0;
  NS_IMETHOD SetImapTotalPendingMessages(int32_t aImapTotalPendingMessages) = 0;

  /* attribute long imapUnreadPendingMessages; */
  NS_IMETHOD GetImapUnreadPendingMessages(int32_t *aImapUnreadPendingMessages) = 0;
  NS_IMETHOD SetImapUnreadPendingMessages(int32_t aImapUnreadPendingMessages) = 0;

  /* attribute nsMsgViewTypeValue viewType; */
  NS_IMETHOD GetViewType(nsMsgViewTypeValue *aViewType) = 0;
  NS_IMETHOD SetViewType(nsMsgViewTypeValue aViewType) = 0;

  /* attribute nsMsgViewFlagsTypeValue viewFlags; */
  NS_IMETHOD GetViewFlags(nsMsgViewFlagsTypeValue *aViewFlags) = 0;
  NS_IMETHOD SetViewFlags(nsMsgViewFlagsTypeValue aViewFlags) = 0;

  /* attribute nsMsgViewSortTypeValue sortType; */
  NS_IMETHOD GetSortType(nsMsgViewSortTypeValue *aSortType) = 0;
  NS_IMETHOD SetSortType(nsMsgViewSortTypeValue aSortType) = 0;

  /* attribute nsMsgViewSortOrderValue sortOrder; */
  NS_IMETHOD GetSortOrder(nsMsgViewSortOrderValue *aSortOrder) = 0;
  NS_IMETHOD SetSortOrder(nsMsgViewSortOrderValue aSortOrder) = 0;

  /* void changeExpungedBytes (in long aDelta); */
  NS_IMETHOD ChangeExpungedBytes(int32_t aDelta) = 0;

  /* ACString getCharProperty (in string propertyName); */
  NS_IMETHOD GetCharProperty(const char * propertyName, nsACString & _retval) = 0;

  /* void setCharProperty (in string aPropertyName, in ACString aPropertyValue); */
  NS_IMETHOD SetCharProperty(const char * aPropertyName, const nsACString & aPropertyValue) = 0;

  /* void setUint32Property (in string propertyName, in unsigned long propertyValue); */
  NS_IMETHOD SetUint32Property(const char * propertyName, uint32_t propertyValue) = 0;

  /* unsigned long getUint32Property (in string propertyName, in unsigned long defaultValue); */
  NS_IMETHOD GetUint32Property(const char * propertyName, uint32_t defaultValue, uint32_t *_retval) = 0;

  /* boolean getBooleanProperty (in string propertyName, in boolean defaultValue); */
  NS_IMETHOD GetBooleanProperty(const char * propertyName, bool defaultValue, bool *_retval) = 0;

  /* void setBooleanProperty (in string propertyName, in boolean aPropertyValue); */
  NS_IMETHOD SetBooleanProperty(const char * propertyName, bool aPropertyValue) = 0;

  /* nsIDBFolderInfo GetTransferInfo (); */
  NS_IMETHOD GetTransferInfo(nsIDBFolderInfo * *_retval) = 0;

  /* void initFromTransferInfo (in nsIDBFolderInfo transferInfo); */
  NS_IMETHOD InitFromTransferInfo(nsIDBFolderInfo *transferInfo) = 0;

  /* attribute ACString characterSet; */
  NS_IMETHOD GetCharacterSet(nsACString & aCharacterSet) = 0;
  NS_IMETHOD SetCharacterSet(const nsACString & aCharacterSet) = 0;

  /* readonly attribute ACString effectiveCharacterSet; */
  NS_IMETHOD GetEffectiveCharacterSet(nsACString & aEffectiveCharacterSet) = 0;

  /* attribute boolean characterSetOverride; */
  NS_IMETHOD GetCharacterSetOverride(bool *aCharacterSetOverride) = 0;
  NS_IMETHOD SetCharacterSetOverride(bool aCharacterSetOverride) = 0;

  /* attribute AString locale; */
  NS_IMETHOD GetLocale(nsAString & aLocale) = 0;
  NS_IMETHOD SetLocale(const nsAString & aLocale) = 0;

  /* attribute AString mailboxName; */
  NS_IMETHOD GetMailboxName(nsAString & aMailboxName) = 0;
  NS_IMETHOD SetMailboxName(const nsAString & aMailboxName) = 0;

  /* AString getProperty (in string propertyName); */
  NS_IMETHOD GetProperty(const char * propertyName, nsAString & _retval) = 0;

  /* void setProperty (in string propertyName, in AString propertyStr); */
  NS_IMETHOD SetProperty(const char * propertyName, const nsAString & propertyStr) = 0;

  /* attribute string knownArtsSet; */
  NS_IMETHOD GetKnownArtsSet(char * *aKnownArtsSet) = 0;
  NS_IMETHOD SetKnownArtsSet(const char * aKnownArtsSet) = 0;

  /* attribute ACString folderName; */
  NS_IMETHOD GetFolderName(nsACString & aFolderName) = 0;
  NS_IMETHOD SetFolderName(const nsACString & aFolderName) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIDBFolderInfo, NS_IDBFOLDERINFO_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIDBFOLDERINFO \
  NS_IMETHOD GetFlags(int32_t *aFlags); \
  NS_IMETHOD SetFlags(int32_t aFlags); \
  NS_IMETHOD OrFlags(int32_t aFlags, int32_t *_retval); \
  NS_IMETHOD AndFlags(int32_t aFlags, int32_t *_retval); \
  NS_IMETHOD OnKeyAdded(nsMsgKey aNewKey); \
  NS_IMETHOD GetHighWater(nsMsgKey *aHighWater); \
  NS_IMETHOD SetHighWater(nsMsgKey aHighWater); \
  NS_IMETHOD GetExpiredMark(nsMsgKey *aExpiredMark); \
  NS_IMETHOD SetExpiredMark(nsMsgKey aExpiredMark); \
  NS_IMETHOD GetFolderSize(uint64_t *aFolderSize); \
  NS_IMETHOD SetFolderSize(uint64_t aFolderSize); \
  NS_IMETHOD GetFolderDate(uint32_t *aFolderDate); \
  NS_IMETHOD SetFolderDate(uint32_t aFolderDate); \
  NS_IMETHOD ChangeNumUnreadMessages(int32_t aDelta); \
  NS_IMETHOD ChangeNumMessages(int32_t aDelta); \
  NS_IMETHOD GetNumUnreadMessages(int32_t *aNumUnreadMessages); \
  NS_IMETHOD SetNumUnreadMessages(int32_t aNumUnreadMessages); \
  NS_IMETHOD GetNumMessages(int32_t *aNumMessages); \
  NS_IMETHOD SetNumMessages(int32_t aNumMessages); \
  NS_IMETHOD GetExpungedBytes(int32_t *aExpungedBytes); \
  NS_IMETHOD SetExpungedBytes(int32_t aExpungedBytes); \
  NS_IMETHOD GetImapUidValidity(int32_t *aImapUidValidity); \
  NS_IMETHOD SetImapUidValidity(int32_t aImapUidValidity); \
  NS_IMETHOD GetVersion(uint32_t *aVersion); \
  NS_IMETHOD SetVersion(uint32_t aVersion); \
  NS_IMETHOD GetImapTotalPendingMessages(int32_t *aImapTotalPendingMessages); \
  NS_IMETHOD SetImapTotalPendingMessages(int32_t aImapTotalPendingMessages); \
  NS_IMETHOD GetImapUnreadPendingMessages(int32_t *aImapUnreadPendingMessages); \
  NS_IMETHOD SetImapUnreadPendingMessages(int32_t aImapUnreadPendingMessages); \
  NS_IMETHOD GetViewType(nsMsgViewTypeValue *aViewType); \
  NS_IMETHOD SetViewType(nsMsgViewTypeValue aViewType); \
  NS_IMETHOD GetViewFlags(nsMsgViewFlagsTypeValue *aViewFlags); \
  NS_IMETHOD SetViewFlags(nsMsgViewFlagsTypeValue aViewFlags); \
  NS_IMETHOD GetSortType(nsMsgViewSortTypeValue *aSortType); \
  NS_IMETHOD SetSortType(nsMsgViewSortTypeValue aSortType); \
  NS_IMETHOD GetSortOrder(nsMsgViewSortOrderValue *aSortOrder); \
  NS_IMETHOD SetSortOrder(nsMsgViewSortOrderValue aSortOrder); \
  NS_IMETHOD ChangeExpungedBytes(int32_t aDelta); \
  NS_IMETHOD GetCharProperty(const char * propertyName, nsACString & _retval); \
  NS_IMETHOD SetCharProperty(const char * aPropertyName, const nsACString & aPropertyValue); \
  NS_IMETHOD SetUint32Property(const char * propertyName, uint32_t propertyValue); \
  NS_IMETHOD GetUint32Property(const char * propertyName, uint32_t defaultValue, uint32_t *_retval); \
  NS_IMETHOD GetBooleanProperty(const char * propertyName, bool defaultValue, bool *_retval); \
  NS_IMETHOD SetBooleanProperty(const char * propertyName, bool aPropertyValue); \
  NS_IMETHOD GetTransferInfo(nsIDBFolderInfo * *_retval); \
  NS_IMETHOD InitFromTransferInfo(nsIDBFolderInfo *transferInfo); \
  NS_IMETHOD GetCharacterSet(nsACString & aCharacterSet); \
  NS_IMETHOD SetCharacterSet(const nsACString & aCharacterSet); \
  NS_IMETHOD GetEffectiveCharacterSet(nsACString & aEffectiveCharacterSet); \
  NS_IMETHOD GetCharacterSetOverride(bool *aCharacterSetOverride); \
  NS_IMETHOD SetCharacterSetOverride(bool aCharacterSetOverride); \
  NS_IMETHOD GetLocale(nsAString & aLocale); \
  NS_IMETHOD SetLocale(const nsAString & aLocale); \
  NS_IMETHOD GetMailboxName(nsAString & aMailboxName); \
  NS_IMETHOD SetMailboxName(const nsAString & aMailboxName); \
  NS_IMETHOD GetProperty(const char * propertyName, nsAString & _retval); \
  NS_IMETHOD SetProperty(const char * propertyName, const nsAString & propertyStr); \
  NS_IMETHOD GetKnownArtsSet(char * *aKnownArtsSet); \
  NS_IMETHOD SetKnownArtsSet(const char * aKnownArtsSet); \
  NS_IMETHOD GetFolderName(nsACString & aFolderName); \
  NS_IMETHOD SetFolderName(const nsACString & aFolderName); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIDBFOLDERINFO(_to) \
  NS_IMETHOD GetFlags(int32_t *aFlags) { return _to GetFlags(aFlags); } \
  NS_IMETHOD SetFlags(int32_t aFlags) { return _to SetFlags(aFlags); } \
  NS_IMETHOD OrFlags(int32_t aFlags, int32_t *_retval) { return _to OrFlags(aFlags, _retval); } \
  NS_IMETHOD AndFlags(int32_t aFlags, int32_t *_retval) { return _to AndFlags(aFlags, _retval); } \
  NS_IMETHOD OnKeyAdded(nsMsgKey aNewKey) { return _to OnKeyAdded(aNewKey); } \
  NS_IMETHOD GetHighWater(nsMsgKey *aHighWater) { return _to GetHighWater(aHighWater); } \
  NS_IMETHOD SetHighWater(nsMsgKey aHighWater) { return _to SetHighWater(aHighWater); } \
  NS_IMETHOD GetExpiredMark(nsMsgKey *aExpiredMark) { return _to GetExpiredMark(aExpiredMark); } \
  NS_IMETHOD SetExpiredMark(nsMsgKey aExpiredMark) { return _to SetExpiredMark(aExpiredMark); } \
  NS_IMETHOD GetFolderSize(uint64_t *aFolderSize) { return _to GetFolderSize(aFolderSize); } \
  NS_IMETHOD SetFolderSize(uint64_t aFolderSize) { return _to SetFolderSize(aFolderSize); } \
  NS_IMETHOD GetFolderDate(uint32_t *aFolderDate) { return _to GetFolderDate(aFolderDate); } \
  NS_IMETHOD SetFolderDate(uint32_t aFolderDate) { return _to SetFolderDate(aFolderDate); } \
  NS_IMETHOD ChangeNumUnreadMessages(int32_t aDelta) { return _to ChangeNumUnreadMessages(aDelta); } \
  NS_IMETHOD ChangeNumMessages(int32_t aDelta) { return _to ChangeNumMessages(aDelta); } \
  NS_IMETHOD GetNumUnreadMessages(int32_t *aNumUnreadMessages) { return _to GetNumUnreadMessages(aNumUnreadMessages); } \
  NS_IMETHOD SetNumUnreadMessages(int32_t aNumUnreadMessages) { return _to SetNumUnreadMessages(aNumUnreadMessages); } \
  NS_IMETHOD GetNumMessages(int32_t *aNumMessages) { return _to GetNumMessages(aNumMessages); } \
  NS_IMETHOD SetNumMessages(int32_t aNumMessages) { return _to SetNumMessages(aNumMessages); } \
  NS_IMETHOD GetExpungedBytes(int32_t *aExpungedBytes) { return _to GetExpungedBytes(aExpungedBytes); } \
  NS_IMETHOD SetExpungedBytes(int32_t aExpungedBytes) { return _to SetExpungedBytes(aExpungedBytes); } \
  NS_IMETHOD GetImapUidValidity(int32_t *aImapUidValidity) { return _to GetImapUidValidity(aImapUidValidity); } \
  NS_IMETHOD SetImapUidValidity(int32_t aImapUidValidity) { return _to SetImapUidValidity(aImapUidValidity); } \
  NS_IMETHOD GetVersion(uint32_t *aVersion) { return _to GetVersion(aVersion); } \
  NS_IMETHOD SetVersion(uint32_t aVersion) { return _to SetVersion(aVersion); } \
  NS_IMETHOD GetImapTotalPendingMessages(int32_t *aImapTotalPendingMessages) { return _to GetImapTotalPendingMessages(aImapTotalPendingMessages); } \
  NS_IMETHOD SetImapTotalPendingMessages(int32_t aImapTotalPendingMessages) { return _to SetImapTotalPendingMessages(aImapTotalPendingMessages); } \
  NS_IMETHOD GetImapUnreadPendingMessages(int32_t *aImapUnreadPendingMessages) { return _to GetImapUnreadPendingMessages(aImapUnreadPendingMessages); } \
  NS_IMETHOD SetImapUnreadPendingMessages(int32_t aImapUnreadPendingMessages) { return _to SetImapUnreadPendingMessages(aImapUnreadPendingMessages); } \
  NS_IMETHOD GetViewType(nsMsgViewTypeValue *aViewType) { return _to GetViewType(aViewType); } \
  NS_IMETHOD SetViewType(nsMsgViewTypeValue aViewType) { return _to SetViewType(aViewType); } \
  NS_IMETHOD GetViewFlags(nsMsgViewFlagsTypeValue *aViewFlags) { return _to GetViewFlags(aViewFlags); } \
  NS_IMETHOD SetViewFlags(nsMsgViewFlagsTypeValue aViewFlags) { return _to SetViewFlags(aViewFlags); } \
  NS_IMETHOD GetSortType(nsMsgViewSortTypeValue *aSortType) { return _to GetSortType(aSortType); } \
  NS_IMETHOD SetSortType(nsMsgViewSortTypeValue aSortType) { return _to SetSortType(aSortType); } \
  NS_IMETHOD GetSortOrder(nsMsgViewSortOrderValue *aSortOrder) { return _to GetSortOrder(aSortOrder); } \
  NS_IMETHOD SetSortOrder(nsMsgViewSortOrderValue aSortOrder) { return _to SetSortOrder(aSortOrder); } \
  NS_IMETHOD ChangeExpungedBytes(int32_t aDelta) { return _to ChangeExpungedBytes(aDelta); } \
  NS_IMETHOD GetCharProperty(const char * propertyName, nsACString & _retval) { return _to GetCharProperty(propertyName, _retval); } \
  NS_IMETHOD SetCharProperty(const char * aPropertyName, const nsACString & aPropertyValue) { return _to SetCharProperty(aPropertyName, aPropertyValue); } \
  NS_IMETHOD SetUint32Property(const char * propertyName, uint32_t propertyValue) { return _to SetUint32Property(propertyName, propertyValue); } \
  NS_IMETHOD GetUint32Property(const char * propertyName, uint32_t defaultValue, uint32_t *_retval) { return _to GetUint32Property(propertyName, defaultValue, _retval); } \
  NS_IMETHOD GetBooleanProperty(const char * propertyName, bool defaultValue, bool *_retval) { return _to GetBooleanProperty(propertyName, defaultValue, _retval); } \
  NS_IMETHOD SetBooleanProperty(const char * propertyName, bool aPropertyValue) { return _to SetBooleanProperty(propertyName, aPropertyValue); } \
  NS_IMETHOD GetTransferInfo(nsIDBFolderInfo * *_retval) { return _to GetTransferInfo(_retval); } \
  NS_IMETHOD InitFromTransferInfo(nsIDBFolderInfo *transferInfo) { return _to InitFromTransferInfo(transferInfo); } \
  NS_IMETHOD GetCharacterSet(nsACString & aCharacterSet) { return _to GetCharacterSet(aCharacterSet); } \
  NS_IMETHOD SetCharacterSet(const nsACString & aCharacterSet) { return _to SetCharacterSet(aCharacterSet); } \
  NS_IMETHOD GetEffectiveCharacterSet(nsACString & aEffectiveCharacterSet) { return _to GetEffectiveCharacterSet(aEffectiveCharacterSet); } \
  NS_IMETHOD GetCharacterSetOverride(bool *aCharacterSetOverride) { return _to GetCharacterSetOverride(aCharacterSetOverride); } \
  NS_IMETHOD SetCharacterSetOverride(bool aCharacterSetOverride) { return _to SetCharacterSetOverride(aCharacterSetOverride); } \
  NS_IMETHOD GetLocale(nsAString & aLocale) { return _to GetLocale(aLocale); } \
  NS_IMETHOD SetLocale(const nsAString & aLocale) { return _to SetLocale(aLocale); } \
  NS_IMETHOD GetMailboxName(nsAString & aMailboxName) { return _to GetMailboxName(aMailboxName); } \
  NS_IMETHOD SetMailboxName(const nsAString & aMailboxName) { return _to SetMailboxName(aMailboxName); } \
  NS_IMETHOD GetProperty(const char * propertyName, nsAString & _retval) { return _to GetProperty(propertyName, _retval); } \
  NS_IMETHOD SetProperty(const char * propertyName, const nsAString & propertyStr) { return _to SetProperty(propertyName, propertyStr); } \
  NS_IMETHOD GetKnownArtsSet(char * *aKnownArtsSet) { return _to GetKnownArtsSet(aKnownArtsSet); } \
  NS_IMETHOD SetKnownArtsSet(const char * aKnownArtsSet) { return _to SetKnownArtsSet(aKnownArtsSet); } \
  NS_IMETHOD GetFolderName(nsACString & aFolderName) { return _to GetFolderName(aFolderName); } \
  NS_IMETHOD SetFolderName(const nsACString & aFolderName) { return _to SetFolderName(aFolderName); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIDBFOLDERINFO(_to) \
  NS_IMETHOD GetFlags(int32_t *aFlags) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFlags(aFlags); } \
  NS_IMETHOD SetFlags(int32_t aFlags) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetFlags(aFlags); } \
  NS_IMETHOD OrFlags(int32_t aFlags, int32_t *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->OrFlags(aFlags, _retval); } \
  NS_IMETHOD AndFlags(int32_t aFlags, int32_t *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->AndFlags(aFlags, _retval); } \
  NS_IMETHOD OnKeyAdded(nsMsgKey aNewKey) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnKeyAdded(aNewKey); } \
  NS_IMETHOD GetHighWater(nsMsgKey *aHighWater) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetHighWater(aHighWater); } \
  NS_IMETHOD SetHighWater(nsMsgKey aHighWater) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetHighWater(aHighWater); } \
  NS_IMETHOD GetExpiredMark(nsMsgKey *aExpiredMark) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetExpiredMark(aExpiredMark); } \
  NS_IMETHOD SetExpiredMark(nsMsgKey aExpiredMark) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetExpiredMark(aExpiredMark); } \
  NS_IMETHOD GetFolderSize(uint64_t *aFolderSize) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFolderSize(aFolderSize); } \
  NS_IMETHOD SetFolderSize(uint64_t aFolderSize) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetFolderSize(aFolderSize); } \
  NS_IMETHOD GetFolderDate(uint32_t *aFolderDate) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFolderDate(aFolderDate); } \
  NS_IMETHOD SetFolderDate(uint32_t aFolderDate) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetFolderDate(aFolderDate); } \
  NS_IMETHOD ChangeNumUnreadMessages(int32_t aDelta) { return !_to ? NS_ERROR_NULL_POINTER : _to->ChangeNumUnreadMessages(aDelta); } \
  NS_IMETHOD ChangeNumMessages(int32_t aDelta) { return !_to ? NS_ERROR_NULL_POINTER : _to->ChangeNumMessages(aDelta); } \
  NS_IMETHOD GetNumUnreadMessages(int32_t *aNumUnreadMessages) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNumUnreadMessages(aNumUnreadMessages); } \
  NS_IMETHOD SetNumUnreadMessages(int32_t aNumUnreadMessages) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetNumUnreadMessages(aNumUnreadMessages); } \
  NS_IMETHOD GetNumMessages(int32_t *aNumMessages) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNumMessages(aNumMessages); } \
  NS_IMETHOD SetNumMessages(int32_t aNumMessages) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetNumMessages(aNumMessages); } \
  NS_IMETHOD GetExpungedBytes(int32_t *aExpungedBytes) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetExpungedBytes(aExpungedBytes); } \
  NS_IMETHOD SetExpungedBytes(int32_t aExpungedBytes) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetExpungedBytes(aExpungedBytes); } \
  NS_IMETHOD GetImapUidValidity(int32_t *aImapUidValidity) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetImapUidValidity(aImapUidValidity); } \
  NS_IMETHOD SetImapUidValidity(int32_t aImapUidValidity) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetImapUidValidity(aImapUidValidity); } \
  NS_IMETHOD GetVersion(uint32_t *aVersion) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetVersion(aVersion); } \
  NS_IMETHOD SetVersion(uint32_t aVersion) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetVersion(aVersion); } \
  NS_IMETHOD GetImapTotalPendingMessages(int32_t *aImapTotalPendingMessages) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetImapTotalPendingMessages(aImapTotalPendingMessages); } \
  NS_IMETHOD SetImapTotalPendingMessages(int32_t aImapTotalPendingMessages) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetImapTotalPendingMessages(aImapTotalPendingMessages); } \
  NS_IMETHOD GetImapUnreadPendingMessages(int32_t *aImapUnreadPendingMessages) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetImapUnreadPendingMessages(aImapUnreadPendingMessages); } \
  NS_IMETHOD SetImapUnreadPendingMessages(int32_t aImapUnreadPendingMessages) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetImapUnreadPendingMessages(aImapUnreadPendingMessages); } \
  NS_IMETHOD GetViewType(nsMsgViewTypeValue *aViewType) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetViewType(aViewType); } \
  NS_IMETHOD SetViewType(nsMsgViewTypeValue aViewType) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetViewType(aViewType); } \
  NS_IMETHOD GetViewFlags(nsMsgViewFlagsTypeValue *aViewFlags) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetViewFlags(aViewFlags); } \
  NS_IMETHOD SetViewFlags(nsMsgViewFlagsTypeValue aViewFlags) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetViewFlags(aViewFlags); } \
  NS_IMETHOD GetSortType(nsMsgViewSortTypeValue *aSortType) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSortType(aSortType); } \
  NS_IMETHOD SetSortType(nsMsgViewSortTypeValue aSortType) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetSortType(aSortType); } \
  NS_IMETHOD GetSortOrder(nsMsgViewSortOrderValue *aSortOrder) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSortOrder(aSortOrder); } \
  NS_IMETHOD SetSortOrder(nsMsgViewSortOrderValue aSortOrder) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetSortOrder(aSortOrder); } \
  NS_IMETHOD ChangeExpungedBytes(int32_t aDelta) { return !_to ? NS_ERROR_NULL_POINTER : _to->ChangeExpungedBytes(aDelta); } \
  NS_IMETHOD GetCharProperty(const char * propertyName, nsACString & _retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetCharProperty(propertyName, _retval); } \
  NS_IMETHOD SetCharProperty(const char * aPropertyName, const nsACString & aPropertyValue) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetCharProperty(aPropertyName, aPropertyValue); } \
  NS_IMETHOD SetUint32Property(const char * propertyName, uint32_t propertyValue) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetUint32Property(propertyName, propertyValue); } \
  NS_IMETHOD GetUint32Property(const char * propertyName, uint32_t defaultValue, uint32_t *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetUint32Property(propertyName, defaultValue, _retval); } \
  NS_IMETHOD GetBooleanProperty(const char * propertyName, bool defaultValue, bool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetBooleanProperty(propertyName, defaultValue, _retval); } \
  NS_IMETHOD SetBooleanProperty(const char * propertyName, bool aPropertyValue) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetBooleanProperty(propertyName, aPropertyValue); } \
  NS_IMETHOD GetTransferInfo(nsIDBFolderInfo * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetTransferInfo(_retval); } \
  NS_IMETHOD InitFromTransferInfo(nsIDBFolderInfo *transferInfo) { return !_to ? NS_ERROR_NULL_POINTER : _to->InitFromTransferInfo(transferInfo); } \
  NS_IMETHOD GetCharacterSet(nsACString & aCharacterSet) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetCharacterSet(aCharacterSet); } \
  NS_IMETHOD SetCharacterSet(const nsACString & aCharacterSet) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetCharacterSet(aCharacterSet); } \
  NS_IMETHOD GetEffectiveCharacterSet(nsACString & aEffectiveCharacterSet) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetEffectiveCharacterSet(aEffectiveCharacterSet); } \
  NS_IMETHOD GetCharacterSetOverride(bool *aCharacterSetOverride) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetCharacterSetOverride(aCharacterSetOverride); } \
  NS_IMETHOD SetCharacterSetOverride(bool aCharacterSetOverride) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetCharacterSetOverride(aCharacterSetOverride); } \
  NS_IMETHOD GetLocale(nsAString & aLocale) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetLocale(aLocale); } \
  NS_IMETHOD SetLocale(const nsAString & aLocale) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetLocale(aLocale); } \
  NS_IMETHOD GetMailboxName(nsAString & aMailboxName) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMailboxName(aMailboxName); } \
  NS_IMETHOD SetMailboxName(const nsAString & aMailboxName) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMailboxName(aMailboxName); } \
  NS_IMETHOD GetProperty(const char * propertyName, nsAString & _retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetProperty(propertyName, _retval); } \
  NS_IMETHOD SetProperty(const char * propertyName, const nsAString & propertyStr) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetProperty(propertyName, propertyStr); } \
  NS_IMETHOD GetKnownArtsSet(char * *aKnownArtsSet) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetKnownArtsSet(aKnownArtsSet); } \
  NS_IMETHOD SetKnownArtsSet(const char * aKnownArtsSet) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetKnownArtsSet(aKnownArtsSet); } \
  NS_IMETHOD GetFolderName(nsACString & aFolderName) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFolderName(aFolderName); } \
  NS_IMETHOD SetFolderName(const nsACString & aFolderName) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetFolderName(aFolderName); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsDBFolderInfo : public nsIDBFolderInfo
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIDBFOLDERINFO

  nsDBFolderInfo();

private:
  ~nsDBFolderInfo();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsDBFolderInfo, nsIDBFolderInfo)

nsDBFolderInfo::nsDBFolderInfo()
{
  /* member initializers and constructor code */
}

nsDBFolderInfo::~nsDBFolderInfo()
{
  /* destructor code */
}

/* attribute long flags; */
NS_IMETHODIMP nsDBFolderInfo::GetFlags(int32_t *aFlags)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDBFolderInfo::SetFlags(int32_t aFlags)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* long orFlags (in long aFlags); */
NS_IMETHODIMP nsDBFolderInfo::OrFlags(int32_t aFlags, int32_t *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* long andFlags (in long aFlags); */
NS_IMETHODIMP nsDBFolderInfo::AndFlags(int32_t aFlags, int32_t *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void onKeyAdded (in nsMsgKey aNewKey); */
NS_IMETHODIMP nsDBFolderInfo::OnKeyAdded(nsMsgKey aNewKey)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsMsgKey highWater; */
NS_IMETHODIMP nsDBFolderInfo::GetHighWater(nsMsgKey *aHighWater)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDBFolderInfo::SetHighWater(nsMsgKey aHighWater)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsMsgKey expiredMark; */
NS_IMETHODIMP nsDBFolderInfo::GetExpiredMark(nsMsgKey *aExpiredMark)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDBFolderInfo::SetExpiredMark(nsMsgKey aExpiredMark)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute unsigned long long folderSize; */
NS_IMETHODIMP nsDBFolderInfo::GetFolderSize(uint64_t *aFolderSize)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDBFolderInfo::SetFolderSize(uint64_t aFolderSize)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute unsigned long folderDate; */
NS_IMETHODIMP nsDBFolderInfo::GetFolderDate(uint32_t *aFolderDate)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDBFolderInfo::SetFolderDate(uint32_t aFolderDate)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void changeNumUnreadMessages (in long aDelta); */
NS_IMETHODIMP nsDBFolderInfo::ChangeNumUnreadMessages(int32_t aDelta)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void changeNumMessages (in long aDelta); */
NS_IMETHODIMP nsDBFolderInfo::ChangeNumMessages(int32_t aDelta)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute long numUnreadMessages; */
NS_IMETHODIMP nsDBFolderInfo::GetNumUnreadMessages(int32_t *aNumUnreadMessages)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDBFolderInfo::SetNumUnreadMessages(int32_t aNumUnreadMessages)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute long numMessages; */
NS_IMETHODIMP nsDBFolderInfo::GetNumMessages(int32_t *aNumMessages)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDBFolderInfo::SetNumMessages(int32_t aNumMessages)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute long expungedBytes; */
NS_IMETHODIMP nsDBFolderInfo::GetExpungedBytes(int32_t *aExpungedBytes)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDBFolderInfo::SetExpungedBytes(int32_t aExpungedBytes)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute long imapUidValidity; */
NS_IMETHODIMP nsDBFolderInfo::GetImapUidValidity(int32_t *aImapUidValidity)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDBFolderInfo::SetImapUidValidity(int32_t aImapUidValidity)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute unsigned long version; */
NS_IMETHODIMP nsDBFolderInfo::GetVersion(uint32_t *aVersion)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDBFolderInfo::SetVersion(uint32_t aVersion)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute long imapTotalPendingMessages; */
NS_IMETHODIMP nsDBFolderInfo::GetImapTotalPendingMessages(int32_t *aImapTotalPendingMessages)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDBFolderInfo::SetImapTotalPendingMessages(int32_t aImapTotalPendingMessages)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute long imapUnreadPendingMessages; */
NS_IMETHODIMP nsDBFolderInfo::GetImapUnreadPendingMessages(int32_t *aImapUnreadPendingMessages)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDBFolderInfo::SetImapUnreadPendingMessages(int32_t aImapUnreadPendingMessages)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsMsgViewTypeValue viewType; */
NS_IMETHODIMP nsDBFolderInfo::GetViewType(nsMsgViewTypeValue *aViewType)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDBFolderInfo::SetViewType(nsMsgViewTypeValue aViewType)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsMsgViewFlagsTypeValue viewFlags; */
NS_IMETHODIMP nsDBFolderInfo::GetViewFlags(nsMsgViewFlagsTypeValue *aViewFlags)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDBFolderInfo::SetViewFlags(nsMsgViewFlagsTypeValue aViewFlags)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsMsgViewSortTypeValue sortType; */
NS_IMETHODIMP nsDBFolderInfo::GetSortType(nsMsgViewSortTypeValue *aSortType)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDBFolderInfo::SetSortType(nsMsgViewSortTypeValue aSortType)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsMsgViewSortOrderValue sortOrder; */
NS_IMETHODIMP nsDBFolderInfo::GetSortOrder(nsMsgViewSortOrderValue *aSortOrder)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDBFolderInfo::SetSortOrder(nsMsgViewSortOrderValue aSortOrder)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void changeExpungedBytes (in long aDelta); */
NS_IMETHODIMP nsDBFolderInfo::ChangeExpungedBytes(int32_t aDelta)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* ACString getCharProperty (in string propertyName); */
NS_IMETHODIMP nsDBFolderInfo::GetCharProperty(const char * propertyName, nsACString & _retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setCharProperty (in string aPropertyName, in ACString aPropertyValue); */
NS_IMETHODIMP nsDBFolderInfo::SetCharProperty(const char * aPropertyName, const nsACString & aPropertyValue)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setUint32Property (in string propertyName, in unsigned long propertyValue); */
NS_IMETHODIMP nsDBFolderInfo::SetUint32Property(const char * propertyName, uint32_t propertyValue)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* unsigned long getUint32Property (in string propertyName, in unsigned long defaultValue); */
NS_IMETHODIMP nsDBFolderInfo::GetUint32Property(const char * propertyName, uint32_t defaultValue, uint32_t *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean getBooleanProperty (in string propertyName, in boolean defaultValue); */
NS_IMETHODIMP nsDBFolderInfo::GetBooleanProperty(const char * propertyName, bool defaultValue, bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setBooleanProperty (in string propertyName, in boolean aPropertyValue); */
NS_IMETHODIMP nsDBFolderInfo::SetBooleanProperty(const char * propertyName, bool aPropertyValue)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIDBFolderInfo GetTransferInfo (); */
NS_IMETHODIMP nsDBFolderInfo::GetTransferInfo(nsIDBFolderInfo * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void initFromTransferInfo (in nsIDBFolderInfo transferInfo); */
NS_IMETHODIMP nsDBFolderInfo::InitFromTransferInfo(nsIDBFolderInfo *transferInfo)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute ACString characterSet; */
NS_IMETHODIMP nsDBFolderInfo::GetCharacterSet(nsACString & aCharacterSet)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDBFolderInfo::SetCharacterSet(const nsACString & aCharacterSet)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute ACString effectiveCharacterSet; */
NS_IMETHODIMP nsDBFolderInfo::GetEffectiveCharacterSet(nsACString & aEffectiveCharacterSet)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean characterSetOverride; */
NS_IMETHODIMP nsDBFolderInfo::GetCharacterSetOverride(bool *aCharacterSetOverride)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDBFolderInfo::SetCharacterSetOverride(bool aCharacterSetOverride)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute AString locale; */
NS_IMETHODIMP nsDBFolderInfo::GetLocale(nsAString & aLocale)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDBFolderInfo::SetLocale(const nsAString & aLocale)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute AString mailboxName; */
NS_IMETHODIMP nsDBFolderInfo::GetMailboxName(nsAString & aMailboxName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDBFolderInfo::SetMailboxName(const nsAString & aMailboxName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* AString getProperty (in string propertyName); */
NS_IMETHODIMP nsDBFolderInfo::GetProperty(const char * propertyName, nsAString & _retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setProperty (in string propertyName, in AString propertyStr); */
NS_IMETHODIMP nsDBFolderInfo::SetProperty(const char * propertyName, const nsAString & propertyStr)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute string knownArtsSet; */
NS_IMETHODIMP nsDBFolderInfo::GetKnownArtsSet(char * *aKnownArtsSet)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDBFolderInfo::SetKnownArtsSet(const char * aKnownArtsSet)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute ACString folderName; */
NS_IMETHODIMP nsDBFolderInfo::GetFolderName(nsACString & aFolderName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDBFolderInfo::SetFolderName(const nsACString & aFolderName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIDBFolderInfo_h__ */
