/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/news/public/nsINewsDownloadDialogArgs.idl
 */

#ifndef __gen_nsINewsDownloadDialogArgs_h__
#define __gen_nsINewsDownloadDialogArgs_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsINewsDownloadDialogArgs */
#define NS_INEWSDOWNLOADDIALOGARGS_IID_STR "3634327c-392b-4686-adf5-576e6cef9196"

#define NS_INEWSDOWNLOADDIALOGARGS_IID \
  {0x3634327c, 0x392b, 0x4686, \
    { 0xad, 0xf5, 0x57, 0x6e, 0x6c, 0xef, 0x91, 0x96 }}

class NS_NO_VTABLE nsINewsDownloadDialogArgs : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_INEWSDOWNLOADDIALOGARGS_IID)

  /* attribute AString groupName; */
  NS_IMETHOD GetGroupName(nsAString & aGroupName) = 0;
  NS_IMETHOD SetGroupName(const nsAString & aGroupName) = 0;

  /* attribute long articleCount; */
  NS_IMETHOD GetArticleCount(int32_t *aArticleCount) = 0;
  NS_IMETHOD SetArticleCount(int32_t aArticleCount) = 0;

  /* attribute string serverKey; */
  NS_IMETHOD GetServerKey(char * *aServerKey) = 0;
  NS_IMETHOD SetServerKey(const char * aServerKey) = 0;

  /* attribute boolean hitOK; */
  NS_IMETHOD GetHitOK(bool *aHitOK) = 0;
  NS_IMETHOD SetHitOK(bool aHitOK) = 0;

  /* attribute boolean downloadAll; */
  NS_IMETHOD GetDownloadAll(bool *aDownloadAll) = 0;
  NS_IMETHOD SetDownloadAll(bool aDownloadAll) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsINewsDownloadDialogArgs, NS_INEWSDOWNLOADDIALOGARGS_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSINEWSDOWNLOADDIALOGARGS \
  NS_IMETHOD GetGroupName(nsAString & aGroupName); \
  NS_IMETHOD SetGroupName(const nsAString & aGroupName); \
  NS_IMETHOD GetArticleCount(int32_t *aArticleCount); \
  NS_IMETHOD SetArticleCount(int32_t aArticleCount); \
  NS_IMETHOD GetServerKey(char * *aServerKey); \
  NS_IMETHOD SetServerKey(const char * aServerKey); \
  NS_IMETHOD GetHitOK(bool *aHitOK); \
  NS_IMETHOD SetHitOK(bool aHitOK); \
  NS_IMETHOD GetDownloadAll(bool *aDownloadAll); \
  NS_IMETHOD SetDownloadAll(bool aDownloadAll); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSINEWSDOWNLOADDIALOGARGS(_to) \
  NS_IMETHOD GetGroupName(nsAString & aGroupName) { return _to GetGroupName(aGroupName); } \
  NS_IMETHOD SetGroupName(const nsAString & aGroupName) { return _to SetGroupName(aGroupName); } \
  NS_IMETHOD GetArticleCount(int32_t *aArticleCount) { return _to GetArticleCount(aArticleCount); } \
  NS_IMETHOD SetArticleCount(int32_t aArticleCount) { return _to SetArticleCount(aArticleCount); } \
  NS_IMETHOD GetServerKey(char * *aServerKey) { return _to GetServerKey(aServerKey); } \
  NS_IMETHOD SetServerKey(const char * aServerKey) { return _to SetServerKey(aServerKey); } \
  NS_IMETHOD GetHitOK(bool *aHitOK) { return _to GetHitOK(aHitOK); } \
  NS_IMETHOD SetHitOK(bool aHitOK) { return _to SetHitOK(aHitOK); } \
  NS_IMETHOD GetDownloadAll(bool *aDownloadAll) { return _to GetDownloadAll(aDownloadAll); } \
  NS_IMETHOD SetDownloadAll(bool aDownloadAll) { return _to SetDownloadAll(aDownloadAll); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSINEWSDOWNLOADDIALOGARGS(_to) \
  NS_IMETHOD GetGroupName(nsAString & aGroupName) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetGroupName(aGroupName); } \
  NS_IMETHOD SetGroupName(const nsAString & aGroupName) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetGroupName(aGroupName); } \
  NS_IMETHOD GetArticleCount(int32_t *aArticleCount) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetArticleCount(aArticleCount); } \
  NS_IMETHOD SetArticleCount(int32_t aArticleCount) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetArticleCount(aArticleCount); } \
  NS_IMETHOD GetServerKey(char * *aServerKey) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetServerKey(aServerKey); } \
  NS_IMETHOD SetServerKey(const char * aServerKey) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetServerKey(aServerKey); } \
  NS_IMETHOD GetHitOK(bool *aHitOK) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetHitOK(aHitOK); } \
  NS_IMETHOD SetHitOK(bool aHitOK) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetHitOK(aHitOK); } \
  NS_IMETHOD GetDownloadAll(bool *aDownloadAll) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDownloadAll(aDownloadAll); } \
  NS_IMETHOD SetDownloadAll(bool aDownloadAll) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetDownloadAll(aDownloadAll); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsNewsDownloadDialogArgs : public nsINewsDownloadDialogArgs
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSINEWSDOWNLOADDIALOGARGS

  nsNewsDownloadDialogArgs();

private:
  ~nsNewsDownloadDialogArgs();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsNewsDownloadDialogArgs, nsINewsDownloadDialogArgs)

nsNewsDownloadDialogArgs::nsNewsDownloadDialogArgs()
{
  /* member initializers and constructor code */
}

nsNewsDownloadDialogArgs::~nsNewsDownloadDialogArgs()
{
  /* destructor code */
}

/* attribute AString groupName; */
NS_IMETHODIMP nsNewsDownloadDialogArgs::GetGroupName(nsAString & aGroupName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsNewsDownloadDialogArgs::SetGroupName(const nsAString & aGroupName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute long articleCount; */
NS_IMETHODIMP nsNewsDownloadDialogArgs::GetArticleCount(int32_t *aArticleCount)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsNewsDownloadDialogArgs::SetArticleCount(int32_t aArticleCount)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute string serverKey; */
NS_IMETHODIMP nsNewsDownloadDialogArgs::GetServerKey(char * *aServerKey)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsNewsDownloadDialogArgs::SetServerKey(const char * aServerKey)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean hitOK; */
NS_IMETHODIMP nsNewsDownloadDialogArgs::GetHitOK(bool *aHitOK)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsNewsDownloadDialogArgs::SetHitOK(bool aHitOK)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean downloadAll; */
NS_IMETHODIMP nsNewsDownloadDialogArgs::GetDownloadAll(bool *aDownloadAll)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsNewsDownloadDialogArgs::SetDownloadAll(bool aDownloadAll)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif

#define DOWNLOAD_HEADERS_URL "chrome://messenger/content/downloadheaders.xul"

#endif /* __gen_nsINewsDownloadDialogArgs_h__ */
