/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsIDOMElement.idl"
#include "nsIDOMXULControlElement.idl"

[scriptable, uuid(DD80E029-5535-4418-B3A0-13CF6BD2AA6B)]
interface nsIDOMXULLabeledControlElement : nsIDOMXULControlElement {
  attribute DOMString crop;
  attribute DOMString image;
  attribute DOMString label;
  attribute DOMString accessKey;
  attribute DOMString command;

//  void doCommand();
};

