/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/base/public/nsIMsgStatusFeedback.idl
 */

#ifndef __gen_nsIMsgStatusFeedback_h__
#define __gen_nsIMsgStatusFeedback_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIMsgStatusFeedback */
#define NS_IMSGSTATUSFEEDBACK_IID_STR "aacbfa34-8d29-4a08-9283-a8e5b3ab067f"

#define NS_IMSGSTATUSFEEDBACK_IID \
  {0xaacbfa34, 0x8d29, 0x4a08, \
    { 0x92, 0x83, 0xa8, 0xe5, 0xb3, 0xab, 0x06, 0x7f }}

class NS_NO_VTABLE nsIMsgStatusFeedback : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IMSGSTATUSFEEDBACK_IID)

  /* void showStatusString (in AString aStatus); */
  NS_IMETHOD ShowStatusString(const nsAString & aStatus) = 0;

  /* void startMeteors (); */
  NS_IMETHOD StartMeteors(void) = 0;

  /* void stopMeteors (); */
  NS_IMETHOD StopMeteors(void) = 0;

  /* void showProgress (in long aPercent); */
  NS_IMETHOD ShowProgress(int32_t aPercent) = 0;

  /* void setStatusString (in AString aStatus); */
  NS_IMETHOD SetStatusString(const nsAString & aStatus) = 0;

  /* void setWrappedStatusFeedback (in nsIMsgStatusFeedback aStatusFeedback); */
  NS_IMETHOD SetWrappedStatusFeedback(nsIMsgStatusFeedback *aStatusFeedback) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIMsgStatusFeedback, NS_IMSGSTATUSFEEDBACK_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGSTATUSFEEDBACK \
  NS_IMETHOD ShowStatusString(const nsAString & aStatus); \
  NS_IMETHOD StartMeteors(void); \
  NS_IMETHOD StopMeteors(void); \
  NS_IMETHOD ShowProgress(int32_t aPercent); \
  NS_IMETHOD SetStatusString(const nsAString & aStatus); \
  NS_IMETHOD SetWrappedStatusFeedback(nsIMsgStatusFeedback *aStatusFeedback); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGSTATUSFEEDBACK(_to) \
  NS_IMETHOD ShowStatusString(const nsAString & aStatus) { return _to ShowStatusString(aStatus); } \
  NS_IMETHOD StartMeteors(void) { return _to StartMeteors(); } \
  NS_IMETHOD StopMeteors(void) { return _to StopMeteors(); } \
  NS_IMETHOD ShowProgress(int32_t aPercent) { return _to ShowProgress(aPercent); } \
  NS_IMETHOD SetStatusString(const nsAString & aStatus) { return _to SetStatusString(aStatus); } \
  NS_IMETHOD SetWrappedStatusFeedback(nsIMsgStatusFeedback *aStatusFeedback) { return _to SetWrappedStatusFeedback(aStatusFeedback); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGSTATUSFEEDBACK(_to) \
  NS_IMETHOD ShowStatusString(const nsAString & aStatus) { return !_to ? NS_ERROR_NULL_POINTER : _to->ShowStatusString(aStatus); } \
  NS_IMETHOD StartMeteors(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->StartMeteors(); } \
  NS_IMETHOD StopMeteors(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->StopMeteors(); } \
  NS_IMETHOD ShowProgress(int32_t aPercent) { return !_to ? NS_ERROR_NULL_POINTER : _to->ShowProgress(aPercent); } \
  NS_IMETHOD SetStatusString(const nsAString & aStatus) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetStatusString(aStatus); } \
  NS_IMETHOD SetWrappedStatusFeedback(nsIMsgStatusFeedback *aStatusFeedback) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetWrappedStatusFeedback(aStatusFeedback); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgStatusFeedback : public nsIMsgStatusFeedback
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGSTATUSFEEDBACK

  nsMsgStatusFeedback();

private:
  ~nsMsgStatusFeedback();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgStatusFeedback, nsIMsgStatusFeedback)

nsMsgStatusFeedback::nsMsgStatusFeedback()
{
  /* member initializers and constructor code */
}

nsMsgStatusFeedback::~nsMsgStatusFeedback()
{
  /* destructor code */
}

/* void showStatusString (in AString aStatus); */
NS_IMETHODIMP nsMsgStatusFeedback::ShowStatusString(const nsAString & aStatus)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void startMeteors (); */
NS_IMETHODIMP nsMsgStatusFeedback::StartMeteors()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void stopMeteors (); */
NS_IMETHODIMP nsMsgStatusFeedback::StopMeteors()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void showProgress (in long aPercent); */
NS_IMETHODIMP nsMsgStatusFeedback::ShowProgress(int32_t aPercent)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setStatusString (in AString aStatus); */
NS_IMETHODIMP nsMsgStatusFeedback::SetStatusString(const nsAString & aStatus)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setWrappedStatusFeedback (in nsIMsgStatusFeedback aStatusFeedback); */
NS_IMETHODIMP nsMsgStatusFeedback::SetWrappedStatusFeedback(nsIMsgStatusFeedback *aStatusFeedback)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgStatusFeedback_h__ */
