/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/suite/common/public/nsISuiteGlue.idl
 */

#ifndef __gen_nsISuiteGlue_h__
#define __gen_nsISuiteGlue_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIDOMWindow; /* forward declaration */


/* starting interface:    nsISuiteGlue */
#define NS_ISUITEGLUE_IID_STR "2559bb36-2eef-4190-9df1-8afcfbd35bd3"

#define NS_ISUITEGLUE_IID \
  {0x2559bb36, 0x2eef, 0x4190, \
    { 0x9d, 0xf1, 0x8a, 0xfc, 0xfb, 0xd3, 0x5b, 0xd3 }}

class NS_NO_VTABLE nsISuiteGlue : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_ISUITEGLUE_IID)

  /* void sanitize (in nsIDOMWindow aParentWindow); */
  NS_IMETHOD Sanitize(nsIDOMWindow *aParentWindow) = 0;

  /* void ensurePlacesDefaultQueriesInitialized (); */
  NS_IMETHOD EnsurePlacesDefaultQueriesInitialized(void) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsISuiteGlue, NS_ISUITEGLUE_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSISUITEGLUE \
  NS_IMETHOD Sanitize(nsIDOMWindow *aParentWindow); \
  NS_IMETHOD EnsurePlacesDefaultQueriesInitialized(void); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSISUITEGLUE(_to) \
  NS_IMETHOD Sanitize(nsIDOMWindow *aParentWindow) { return _to Sanitize(aParentWindow); } \
  NS_IMETHOD EnsurePlacesDefaultQueriesInitialized(void) { return _to EnsurePlacesDefaultQueriesInitialized(); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSISUITEGLUE(_to) \
  NS_IMETHOD Sanitize(nsIDOMWindow *aParentWindow) { return !_to ? NS_ERROR_NULL_POINTER : _to->Sanitize(aParentWindow); } \
  NS_IMETHOD EnsurePlacesDefaultQueriesInitialized(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->EnsurePlacesDefaultQueriesInitialized(); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsSuiteGlue : public nsISuiteGlue
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSISUITEGLUE

  nsSuiteGlue();

private:
  ~nsSuiteGlue();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsSuiteGlue, nsISuiteGlue)

nsSuiteGlue::nsSuiteGlue()
{
  /* member initializers and constructor code */
}

nsSuiteGlue::~nsSuiteGlue()
{
  /* destructor code */
}

/* void sanitize (in nsIDOMWindow aParentWindow); */
NS_IMETHODIMP nsSuiteGlue::Sanitize(nsIDOMWindow *aParentWindow)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void ensurePlacesDefaultQueriesInitialized (); */
NS_IMETHODIMP nsSuiteGlue::EnsurePlacesDefaultQueriesInitialized()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsISuiteGlue_h__ */
