/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"
#include "nsIUrlListener.idl"
#include "nsIMovemailIncomingServer.idl"
#include "nsIMsgFolder.idl"

[scriptable, uuid(4c7786a4-1dd2-11b2-9fbe-c59d742de59b)]
interface nsIMovemailService : nsISupports {

    nsIURI GetNewMail(in nsIMsgWindow aMsgWindow,
                      in nsIUrlListener aUrlListener,
                      in nsIMsgFolder aMsgFolder,
                      in nsIMovemailIncomingServer movemailServer);
    
    nsIURI CheckForNewMail(in nsIUrlListener aUrlListener,
                           in nsIMsgFolder inbox,
                           in nsIMovemailIncomingServer movemailServer);
};
