/* -*- Mode: C++; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* vim: set ts=2 et sw=2 tw=80: */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"

interface nsIDOMDOMError;
interface nsIDOMEventListener;
interface nsIIDBTransaction;

/**
 * IDBRequest interface.  See
 * http://dev.w3.org/2006/webapi/WebSimpleDB/#idl-def-IDBRequest for more
 * information.
 */
[scriptable, builtinclass, uuid(4b9d901b-14a4-430c-b41b-5ecb238f4184)]
interface nsIIDBRequest : nsISupports
{
  readonly attribute jsval result;

  readonly attribute nsIDOMDOMError error;

  readonly attribute nsISupports source;

  readonly attribute nsIIDBTransaction transaction;

  // "pending" or "done"
  readonly attribute DOMString readyState;

  attribute nsIDOMEventListener onsuccess;
  attribute nsIDOMEventListener onerror;
};
