/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/import/public/nsIImportGeneric.idl
 */

#ifndef __gen_nsIImportGeneric_h__
#define __gen_nsIImportGeneric_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsISupportsString; /* forward declaration */


/* starting interface:    nsIImportGeneric */
#define NS_IIMPORTGENERIC_IID_STR "d64a87b8-aeb4-da40-fe28-57df1e50c64f"

#define NS_IIMPORTGENERIC_IID \
  {0xd64a87b8, 0xaeb4, 0xda40, \
    { 0xfe, 0x28, 0x57, 0xdf, 0x1e, 0x50, 0xc6, 0x4f }}

class NS_NO_VTABLE nsIImportGeneric : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IIMPORTGENERIC_IID)

  /* nsISupports GetData (in string dataId); */
  NS_IMETHOD GetData(const char * dataId, nsISupports * *_retval) = 0;

  /* void SetData (in string dataId, in nsISupports pData); */
  NS_IMETHOD SetData(const char * dataId, nsISupports *pData) = 0;

  /* long GetStatus (in string statusKind); */
  NS_IMETHOD GetStatus(const char * statusKind, int32_t *_retval) = 0;

  /* boolean WantsProgress (); */
  NS_IMETHOD WantsProgress(bool *_retval) = 0;

  /* boolean BeginImport (in nsISupportsString successLog, in nsISupportsString errorLog); */
  NS_IMETHOD BeginImport(nsISupportsString *successLog, nsISupportsString *errorLog, bool *_retval) = 0;

  /* boolean ContinueImport (); */
  NS_IMETHOD ContinueImport(bool *_retval) = 0;

  /* long GetProgress (); */
  NS_IMETHOD GetProgress(int32_t *_retval) = 0;

  /* void CancelImport (); */
  NS_IMETHOD CancelImport(void) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIImportGeneric, NS_IIMPORTGENERIC_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIIMPORTGENERIC \
  NS_IMETHOD GetData(const char * dataId, nsISupports * *_retval); \
  NS_IMETHOD SetData(const char * dataId, nsISupports *pData); \
  NS_IMETHOD GetStatus(const char * statusKind, int32_t *_retval); \
  NS_IMETHOD WantsProgress(bool *_retval); \
  NS_IMETHOD BeginImport(nsISupportsString *successLog, nsISupportsString *errorLog, bool *_retval); \
  NS_IMETHOD ContinueImport(bool *_retval); \
  NS_IMETHOD GetProgress(int32_t *_retval); \
  NS_IMETHOD CancelImport(void); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIIMPORTGENERIC(_to) \
  NS_IMETHOD GetData(const char * dataId, nsISupports * *_retval) { return _to GetData(dataId, _retval); } \
  NS_IMETHOD SetData(const char * dataId, nsISupports *pData) { return _to SetData(dataId, pData); } \
  NS_IMETHOD GetStatus(const char * statusKind, int32_t *_retval) { return _to GetStatus(statusKind, _retval); } \
  NS_IMETHOD WantsProgress(bool *_retval) { return _to WantsProgress(_retval); } \
  NS_IMETHOD BeginImport(nsISupportsString *successLog, nsISupportsString *errorLog, bool *_retval) { return _to BeginImport(successLog, errorLog, _retval); } \
  NS_IMETHOD ContinueImport(bool *_retval) { return _to ContinueImport(_retval); } \
  NS_IMETHOD GetProgress(int32_t *_retval) { return _to GetProgress(_retval); } \
  NS_IMETHOD CancelImport(void) { return _to CancelImport(); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIIMPORTGENERIC(_to) \
  NS_IMETHOD GetData(const char * dataId, nsISupports * *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetData(dataId, _retval); } \
  NS_IMETHOD SetData(const char * dataId, nsISupports *pData) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetData(dataId, pData); } \
  NS_IMETHOD GetStatus(const char * statusKind, int32_t *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetStatus(statusKind, _retval); } \
  NS_IMETHOD WantsProgress(bool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->WantsProgress(_retval); } \
  NS_IMETHOD BeginImport(nsISupportsString *successLog, nsISupportsString *errorLog, bool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->BeginImport(successLog, errorLog, _retval); } \
  NS_IMETHOD ContinueImport(bool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->ContinueImport(_retval); } \
  NS_IMETHOD GetProgress(int32_t *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetProgress(_retval); } \
  NS_IMETHOD CancelImport(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->CancelImport(); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsImportGeneric : public nsIImportGeneric
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIIMPORTGENERIC

  nsImportGeneric();

private:
  ~nsImportGeneric();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsImportGeneric, nsIImportGeneric)

nsImportGeneric::nsImportGeneric()
{
  /* member initializers and constructor code */
}

nsImportGeneric::~nsImportGeneric()
{
  /* destructor code */
}

/* nsISupports GetData (in string dataId); */
NS_IMETHODIMP nsImportGeneric::GetData(const char * dataId, nsISupports * *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void SetData (in string dataId, in nsISupports pData); */
NS_IMETHODIMP nsImportGeneric::SetData(const char * dataId, nsISupports *pData)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* long GetStatus (in string statusKind); */
NS_IMETHODIMP nsImportGeneric::GetStatus(const char * statusKind, int32_t *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean WantsProgress (); */
NS_IMETHODIMP nsImportGeneric::WantsProgress(bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean BeginImport (in nsISupportsString successLog, in nsISupportsString errorLog); */
NS_IMETHODIMP nsImportGeneric::BeginImport(nsISupportsString *successLog, nsISupportsString *errorLog, bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean ContinueImport (); */
NS_IMETHODIMP nsImportGeneric::ContinueImport(bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* long GetProgress (); */
NS_IMETHODIMP nsImportGeneric::GetProgress(int32_t *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void CancelImport (); */
NS_IMETHODIMP nsImportGeneric::CancelImport()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif



#endif /* __gen_nsIImportGeneric_h__ */
