/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/base/public/nsIMsgPrintEngine.idl
 */

#ifndef __gen_nsIMsgPrintEngine_h__
#define __gen_nsIMsgPrintEngine_h__


#ifndef __gen_nsrootidl_h__
#include "nsrootidl.h"
#endif

#ifndef __gen_nsIMsgStatusFeedback_h__
#include "nsIMsgStatusFeedback.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIDOMWindow; /* forward declaration */

class nsIPrintSettings; /* forward declaration */

class nsIObserver; /* forward declaration */

class nsIWebBrowserPrint; /* forward declaration */


/* starting interface:    nsIMsgPrintEngine */
#define NS_IMSGPRINTENGINE_IID_STR "e5f5e4a2-9d74-46b3-ade7-25e1a1ddf54e"

#define NS_IMSGPRINTENGINE_IID \
  {0xe5f5e4a2, 0x9d74, 0x46b3, \
    { 0xad, 0xe7, 0x25, 0xe1, 0xa1, 0xdd, 0xf5, 0x4e }}

class NS_NO_VTABLE nsIMsgPrintEngine : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IMSGPRINTENGINE_IID)

  enum {
    MNAB_START = 0,
    MNAB_PRINT_MSG = 0,
    MNAB_PRINTPREVIEW_MSG = 1,
    MNAB_PRINT_AB_CARD = 2,
    MNAB_PRINTPREVIEW_AB_CARD = 3,
    MNAB_PRINT_ADDRBOOK = 4,
    MNAB_PRINTPREVIEW_ADDRBOOK = 5,
    MNAB_END = 6
  };

  /* void setWindow (in nsIDOMWindow ptr); */
  NS_IMETHOD SetWindow(nsIDOMWindow *ptr) = 0;

  /* void setParentWindow (in nsIDOMWindow ptr); */
  NS_IMETHOD SetParentWindow(nsIDOMWindow *ptr) = 0;

  /* void showWindow (in boolean aShow); */
  NS_IMETHOD ShowWindow(bool aShow) = 0;

  /* void setStatusFeedback (in nsIMsgStatusFeedback feedback); */
  NS_IMETHOD SetStatusFeedback(nsIMsgStatusFeedback *feedback) = 0;

  /* void setPrintURICount (in int32_t aCount); */
  NS_IMETHOD SetPrintURICount(int32_t aCount) = 0;

  /* void addPrintURI (in wstring aURI); */
  NS_IMETHOD AddPrintURI(const PRUnichar * aURI) = 0;

  /* void startPrintOperation (in nsIPrintSettings aPS); */
  NS_IMETHOD StartPrintOperation(nsIPrintSettings *aPS) = 0;

  /* void setStartupPPObserver (in nsIObserver startupPPObs); */
  NS_IMETHOD SetStartupPPObserver(nsIObserver *startupPPObs) = 0;

  /* void setMsgType (in long aMsgType); */
  NS_IMETHOD SetMsgType(int32_t aMsgType) = 0;

  /* attribute boolean doPrintPreview; */
  NS_IMETHOD GetDoPrintPreview(bool *aDoPrintPreview) = 0;
  NS_IMETHOD SetDoPrintPreview(bool aDoPrintPreview) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIMsgPrintEngine, NS_IMSGPRINTENGINE_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGPRINTENGINE \
  NS_IMETHOD SetWindow(nsIDOMWindow *ptr); \
  NS_IMETHOD SetParentWindow(nsIDOMWindow *ptr); \
  NS_IMETHOD ShowWindow(bool aShow); \
  NS_IMETHOD SetStatusFeedback(nsIMsgStatusFeedback *feedback); \
  NS_IMETHOD SetPrintURICount(int32_t aCount); \
  NS_IMETHOD AddPrintURI(const PRUnichar * aURI); \
  NS_IMETHOD StartPrintOperation(nsIPrintSettings *aPS); \
  NS_IMETHOD SetStartupPPObserver(nsIObserver *startupPPObs); \
  NS_IMETHOD SetMsgType(int32_t aMsgType); \
  NS_IMETHOD GetDoPrintPreview(bool *aDoPrintPreview); \
  NS_IMETHOD SetDoPrintPreview(bool aDoPrintPreview); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGPRINTENGINE(_to) \
  NS_IMETHOD SetWindow(nsIDOMWindow *ptr) { return _to SetWindow(ptr); } \
  NS_IMETHOD SetParentWindow(nsIDOMWindow *ptr) { return _to SetParentWindow(ptr); } \
  NS_IMETHOD ShowWindow(bool aShow) { return _to ShowWindow(aShow); } \
  NS_IMETHOD SetStatusFeedback(nsIMsgStatusFeedback *feedback) { return _to SetStatusFeedback(feedback); } \
  NS_IMETHOD SetPrintURICount(int32_t aCount) { return _to SetPrintURICount(aCount); } \
  NS_IMETHOD AddPrintURI(const PRUnichar * aURI) { return _to AddPrintURI(aURI); } \
  NS_IMETHOD StartPrintOperation(nsIPrintSettings *aPS) { return _to StartPrintOperation(aPS); } \
  NS_IMETHOD SetStartupPPObserver(nsIObserver *startupPPObs) { return _to SetStartupPPObserver(startupPPObs); } \
  NS_IMETHOD SetMsgType(int32_t aMsgType) { return _to SetMsgType(aMsgType); } \
  NS_IMETHOD GetDoPrintPreview(bool *aDoPrintPreview) { return _to GetDoPrintPreview(aDoPrintPreview); } \
  NS_IMETHOD SetDoPrintPreview(bool aDoPrintPreview) { return _to SetDoPrintPreview(aDoPrintPreview); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGPRINTENGINE(_to) \
  NS_IMETHOD SetWindow(nsIDOMWindow *ptr) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetWindow(ptr); } \
  NS_IMETHOD SetParentWindow(nsIDOMWindow *ptr) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetParentWindow(ptr); } \
  NS_IMETHOD ShowWindow(bool aShow) { return !_to ? NS_ERROR_NULL_POINTER : _to->ShowWindow(aShow); } \
  NS_IMETHOD SetStatusFeedback(nsIMsgStatusFeedback *feedback) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetStatusFeedback(feedback); } \
  NS_IMETHOD SetPrintURICount(int32_t aCount) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetPrintURICount(aCount); } \
  NS_IMETHOD AddPrintURI(const PRUnichar * aURI) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddPrintURI(aURI); } \
  NS_IMETHOD StartPrintOperation(nsIPrintSettings *aPS) { return !_to ? NS_ERROR_NULL_POINTER : _to->StartPrintOperation(aPS); } \
  NS_IMETHOD SetStartupPPObserver(nsIObserver *startupPPObs) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetStartupPPObserver(startupPPObs); } \
  NS_IMETHOD SetMsgType(int32_t aMsgType) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMsgType(aMsgType); } \
  NS_IMETHOD GetDoPrintPreview(bool *aDoPrintPreview) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDoPrintPreview(aDoPrintPreview); } \
  NS_IMETHOD SetDoPrintPreview(bool aDoPrintPreview) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetDoPrintPreview(aDoPrintPreview); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgPrintEngine : public nsIMsgPrintEngine
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGPRINTENGINE

  nsMsgPrintEngine();

private:
  ~nsMsgPrintEngine();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgPrintEngine, nsIMsgPrintEngine)

nsMsgPrintEngine::nsMsgPrintEngine()
{
  /* member initializers and constructor code */
}

nsMsgPrintEngine::~nsMsgPrintEngine()
{
  /* destructor code */
}

/* void setWindow (in nsIDOMWindow ptr); */
NS_IMETHODIMP nsMsgPrintEngine::SetWindow(nsIDOMWindow *ptr)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setParentWindow (in nsIDOMWindow ptr); */
NS_IMETHODIMP nsMsgPrintEngine::SetParentWindow(nsIDOMWindow *ptr)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void showWindow (in boolean aShow); */
NS_IMETHODIMP nsMsgPrintEngine::ShowWindow(bool aShow)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setStatusFeedback (in nsIMsgStatusFeedback feedback); */
NS_IMETHODIMP nsMsgPrintEngine::SetStatusFeedback(nsIMsgStatusFeedback *feedback)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setPrintURICount (in int32_t aCount); */
NS_IMETHODIMP nsMsgPrintEngine::SetPrintURICount(int32_t aCount)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void addPrintURI (in wstring aURI); */
NS_IMETHODIMP nsMsgPrintEngine::AddPrintURI(const PRUnichar * aURI)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void startPrintOperation (in nsIPrintSettings aPS); */
NS_IMETHODIMP nsMsgPrintEngine::StartPrintOperation(nsIPrintSettings *aPS)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setStartupPPObserver (in nsIObserver startupPPObs); */
NS_IMETHODIMP nsMsgPrintEngine::SetStartupPPObserver(nsIObserver *startupPPObs)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setMsgType (in long aMsgType); */
NS_IMETHODIMP nsMsgPrintEngine::SetMsgType(int32_t aMsgType)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean doPrintPreview; */
NS_IMETHODIMP nsMsgPrintEngine::GetDoPrintPreview(bool *aDoPrintPreview)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgPrintEngine::SetDoPrintPreview(bool aDoPrintPreview)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgPrintEngine_h__ */
