/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"

interface nsIDOMEventListener;

[scriptable, uuid(8c6b574d-1135-4387-a6e3-6d8ba38d79a1)]
interface nsIDOMMozConnection : nsISupports
{
  readonly attribute double  bandwidth;
  readonly attribute boolean metered;

           attribute nsIDOMEventListener onchange;
};
