/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /root/tmp/build-seamonkey/comm-release/mailnews/base/public/nsIMsgShutdown.idl
 */

#ifndef __gen_nsIMsgShutdown_h__
#define __gen_nsIMsgShutdown_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIUrlListener; /* forward declaration */

class nsIMsgWindow; /* forward declaration */

class nsIWebProgressListener; /* forward declaration */


/* starting interface:    nsIMsgShutdownTask */
#define NS_IMSGSHUTDOWNTASK_IID_STR "d1b43428-b631-4629-b691-ab0e01a2db4b"

#define NS_IMSGSHUTDOWNTASK_IID \
  {0xd1b43428, 0xb631, 0x4629, \
    { 0xb6, 0x91, 0xab, 0x0e, 0x01, 0xa2, 0xdb, 0x4b }}

class NS_NO_VTABLE nsIMsgShutdownTask : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IMSGSHUTDOWNTASK_IID)

  /* readonly attribute boolean needsToRunTask; */
  NS_IMETHOD GetNeedsToRunTask(bool *aNeedsToRunTask) = 0;

  /* boolean doShutdownTask (in nsIUrlListener inUrlListener, in nsIMsgWindow inMsgWindow); */
  NS_IMETHOD DoShutdownTask(nsIUrlListener *inUrlListener, nsIMsgWindow *inMsgWindow, bool *_retval) = 0;

  /* AString getCurrentTaskName (); */
  NS_IMETHOD GetCurrentTaskName(nsAString & _retval) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIMsgShutdownTask, NS_IMSGSHUTDOWNTASK_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGSHUTDOWNTASK \
  NS_IMETHOD GetNeedsToRunTask(bool *aNeedsToRunTask); \
  NS_IMETHOD DoShutdownTask(nsIUrlListener *inUrlListener, nsIMsgWindow *inMsgWindow, bool *_retval); \
  NS_IMETHOD GetCurrentTaskName(nsAString & _retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGSHUTDOWNTASK(_to) \
  NS_IMETHOD GetNeedsToRunTask(bool *aNeedsToRunTask) { return _to GetNeedsToRunTask(aNeedsToRunTask); } \
  NS_IMETHOD DoShutdownTask(nsIUrlListener *inUrlListener, nsIMsgWindow *inMsgWindow, bool *_retval) { return _to DoShutdownTask(inUrlListener, inMsgWindow, _retval); } \
  NS_IMETHOD GetCurrentTaskName(nsAString & _retval) { return _to GetCurrentTaskName(_retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGSHUTDOWNTASK(_to) \
  NS_IMETHOD GetNeedsToRunTask(bool *aNeedsToRunTask) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNeedsToRunTask(aNeedsToRunTask); } \
  NS_IMETHOD DoShutdownTask(nsIUrlListener *inUrlListener, nsIMsgWindow *inMsgWindow, bool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->DoShutdownTask(inUrlListener, inMsgWindow, _retval); } \
  NS_IMETHOD GetCurrentTaskName(nsAString & _retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetCurrentTaskName(_retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgShutdownTask : public nsIMsgShutdownTask
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGSHUTDOWNTASK

  nsMsgShutdownTask();

private:
  ~nsMsgShutdownTask();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgShutdownTask, nsIMsgShutdownTask)

nsMsgShutdownTask::nsMsgShutdownTask()
{
  /* member initializers and constructor code */
}

nsMsgShutdownTask::~nsMsgShutdownTask()
{
  /* destructor code */
}

/* readonly attribute boolean needsToRunTask; */
NS_IMETHODIMP nsMsgShutdownTask::GetNeedsToRunTask(bool *aNeedsToRunTask)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean doShutdownTask (in nsIUrlListener inUrlListener, in nsIMsgWindow inMsgWindow); */
NS_IMETHODIMP nsMsgShutdownTask::DoShutdownTask(nsIUrlListener *inUrlListener, nsIMsgWindow *inMsgWindow, bool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* AString getCurrentTaskName (); */
NS_IMETHODIMP nsMsgShutdownTask::GetCurrentTaskName(nsAString & _retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


/* starting interface:    nsIMsgShutdownService */
#define NS_IMSGSHUTDOWNSERVICE_IID_STR "483c8abb-ecf9-48a3-a394-2c604b603bd5"

#define NS_IMSGSHUTDOWNSERVICE_IID \
  {0x483c8abb, 0xecf9, 0x48a3, \
    { 0xa3, 0x94, 0x2c, 0x60, 0x4b, 0x60, 0x3b, 0xd5 }}

class NS_NO_VTABLE nsIMsgShutdownService : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IMSGSHUTDOWNSERVICE_IID)

  /* long getNumTasks (); */
  NS_IMETHOD GetNumTasks(int32_t *_retval) = 0;

  /* void startShutdownTasks (); */
  NS_IMETHOD StartShutdownTasks(void) = 0;

  /* void cancelShutdownTasks (); */
  NS_IMETHOD CancelShutdownTasks(void) = 0;

  /* void setShutdownListener (in nsIWebProgressListener inListener); */
  NS_IMETHOD SetShutdownListener(nsIWebProgressListener *inListener) = 0;

  /* void setStatusText (in AString inStatusString); */
  NS_IMETHOD SetStatusText(const nsAString & inStatusString) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIMsgShutdownService, NS_IMSGSHUTDOWNSERVICE_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGSHUTDOWNSERVICE \
  NS_IMETHOD GetNumTasks(int32_t *_retval); \
  NS_IMETHOD StartShutdownTasks(void); \
  NS_IMETHOD CancelShutdownTasks(void); \
  NS_IMETHOD SetShutdownListener(nsIWebProgressListener *inListener); \
  NS_IMETHOD SetStatusText(const nsAString & inStatusString); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGSHUTDOWNSERVICE(_to) \
  NS_IMETHOD GetNumTasks(int32_t *_retval) { return _to GetNumTasks(_retval); } \
  NS_IMETHOD StartShutdownTasks(void) { return _to StartShutdownTasks(); } \
  NS_IMETHOD CancelShutdownTasks(void) { return _to CancelShutdownTasks(); } \
  NS_IMETHOD SetShutdownListener(nsIWebProgressListener *inListener) { return _to SetShutdownListener(inListener); } \
  NS_IMETHOD SetStatusText(const nsAString & inStatusString) { return _to SetStatusText(inStatusString); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGSHUTDOWNSERVICE(_to) \
  NS_IMETHOD GetNumTasks(int32_t *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNumTasks(_retval); } \
  NS_IMETHOD StartShutdownTasks(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->StartShutdownTasks(); } \
  NS_IMETHOD CancelShutdownTasks(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->CancelShutdownTasks(); } \
  NS_IMETHOD SetShutdownListener(nsIWebProgressListener *inListener) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetShutdownListener(inListener); } \
  NS_IMETHOD SetStatusText(const nsAString & inStatusString) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetStatusText(inStatusString); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgShutdownService : public nsIMsgShutdownService
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGSHUTDOWNSERVICE

  nsMsgShutdownService();

private:
  ~nsMsgShutdownService();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgShutdownService, nsIMsgShutdownService)

nsMsgShutdownService::nsMsgShutdownService()
{
  /* member initializers and constructor code */
}

nsMsgShutdownService::~nsMsgShutdownService()
{
  /* destructor code */
}

/* long getNumTasks (); */
NS_IMETHODIMP nsMsgShutdownService::GetNumTasks(int32_t *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void startShutdownTasks (); */
NS_IMETHODIMP nsMsgShutdownService::StartShutdownTasks()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void cancelShutdownTasks (); */
NS_IMETHODIMP nsMsgShutdownService::CancelShutdownTasks()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setShutdownListener (in nsIWebProgressListener inListener); */
NS_IMETHODIMP nsMsgShutdownService::SetShutdownListener(nsIWebProgressListener *inListener)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setStatusText (in AString inStatusString); */
NS_IMETHODIMP nsMsgShutdownService::SetStatusText(const nsAString & inStatusString)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgShutdown_h__ */
